(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.1'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[  18411367,     257593]*)
(*NotebookOutlinePosition[  18412084,     257618]*)
(*  CellTagsIndexPosition[  18412040,     257614]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Sfruttare strumenti computazionali esterni", "Title"],

Cell[CellGroupData[{

Cell[TextData[{
  "Come fare quando ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " \[EGrave] troppo lento"
}], "Section"],

Cell[TextData[{
  "Consideriamo la seguente funzione ",
  StyleBox["highestDivisor", "InlineInput"],
  ", che considera tutti i divisori del suo argomento e ritorna il \
pi\[UGrave] alto ad eccezione dell'argomento stesso:"
}], "Text"],

Cell[BoxData[
    \(highestDivisor[n_] := 
      Block[{i = n - 1}, \[IndentingNewLine]While[
          Mod[n, i] \[NotEqual] 0, \(i--\); ]; \[IndentingNewLine]Return[
          i]; \[IndentingNewLine]]\)], "Input"],

Cell[TextData[{
  "L'implementazione di ",
  StyleBox["highestDivisor", "InlineInput"],
  ", decisamente semplice, \[EGrave] stata scelta in modo da evidenziare come \
il tempo necessario per produrre il risultato diventi elevato quando \
l'argomento assume valori relativamente alti: operando ad esempio con un \
PowerBook G4 a 800 MHz, per trovare il pi\[UGrave] altro tra i divisori di ",
  Cell[BoxData[
      \(TraditionalForm\`10\^6 - 1\)]],
  " sono necessari pi\[UGrave] di sette secondi:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Timing[highestDivisor[10^6 - 1]]\)], "Input"],

Cell[BoxData[
    \({7.465187999999671`\ Second, 333333}\)], "Output"]
}, Open  ]],

Cell["\<\
Voi otterrete probabilmente un tempo differente, soprattutto se \
state utilizzando un calcolatore differente da quello preso in esempio. La \
funzione Timing interpreta il suo argomento come un'espressione che provvede \
a valutare, cronometrando il tempo necessario per portare a termine \
l'operazione. Il valore restituito \[EGrave] una lista contenente \
rispettivmente il tempo di elaborazione e il risultato della \
valutazione.\
\>", "Text"],

Cell[TextData[{
  "L'elevata quantit\[AGrave] di tempo necessario per portare a termine \
questa computazione dipende dal fatto che per ognuna delle istruzioni che \
compongono ",
  StyleBox["highestDivisor", "InlineInput"],
  " \[EGrave] necessario tener conto del tempo richiesto per la trasmissione \
dell'istruzione stessa al kernel, il suo controllo sintattico e semantico, la \
sua traduzione in linguaggio macchina, l'esecuzione di quest'ultimo e la \
trasmissione al front end dei risultati. La presenza di un ciclo concorre poi \
ad enfatizzare la dipendenza del tempo totale di esecuzione della funzione \
dalla grandezza del suo argomento."
}], "Text"],

Cell[TextData[{
  "\[CapitalEGrave] per\[OGrave] possibile sfruttare il meccanismo di \
comunicazione tra front end e kernel proprio per diminuire il tempo di \
calcolo in casi come questo. Infatti questa comunicazione \[EGrave] regolata \
da un particolare protocollo di trasmissione chiamato ",
  StyleBox["MathLink",
    FontSlant->"Italic"],
  " \[RegisteredTrademark], le cui specifiche possono essere utilizzate per \
costruire un programma esterno che calcola l'equivalente della funzione \
highestDivisor ma in modo pi\[UGrave] efficiente, per esempio scrivendolo in \
C per poi compilarlo in linguaggio macchina."
}], "Text"],

Cell["\<\
Se leggete questo file, lo avete probabilmente scaricato dal sito \
del corso. Questa operazione ha avuto come effetto quello di creare nel \
vostro desktop una cartella il cui nome \[EGrave] math-bin. Se cos\[IGrave] \
non fosse, create una nuova cartella sul desktop (posizionandovi sul desktop \
e selezionanando la voce di menu File/New Folder dal Finder) e rinominatela \
in modo che si chiami math-bin, copiandovi infine i file mandelbrot.c e \
mandelbrot.tm che avete scaricato dal sito del corso. A questo punto possiamo \
utilizzare questa directory come directory corrente:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(SetDirectory["\<~/Desktop/math-bin\>"]\)], "Input"],

Cell[BoxData[
    \("/Users/silsis2/Desktop/math-bin"\)], "Output"]
}, Open  ]],

Cell["\<\
Naturalmente la cella di output che otterrete potrebbe essere \
diversa, in quanto il pathname assoluto della directory conterr\[AGrave] il \
nome dell'utente da voi utilizzato.\
\>", "Text"],

Cell["\<\
Per procedere con il resto dell'esercitazione risulter\[AGrave] \
comodo  eseguire un terminale. Trovate l'icona corrispondente nella directory \
Applications/Utilities (la directory Applications si trova nella root \
directory del disco fisso, ma trovate un link a essa anche nella parte \
sinistra delle finestre del finder). Se eseguite un doppio click su questa \
icona comparir\[AGrave] una nuova finestra, simile a quella di un terminale \
in U*ix.\
\>", "Text"],

Cell["\<\
Il terminale \[EGrave] inizialmente posizionato nella vostra home \
directory: se provate a eseguire il comando pwd dovreste ottenere come output \
/Users/silsis2. Se cos\[IGrave] non fosse, eseguite il comando\
\>", "Text"],

Cell[" cd /Users/silsis2", "Program"],

Cell["oppure il comando", "Text"],

Cell[" cd ~", "Program"],

Cell["\<\
in modo da posizionarvi nella vostra home. A questo punto \[EGrave] \
necessario spostarsi nella directory math-bin, eseguendo il comando\
\>", \
"Text"],

Cell["cd Desktop/math-bin", "Program"],

Cell["\<\
Entro questa directory dovreste trovare, tra gli altri, due file \
aventi per nome highestDivisor.tm e highestDivisor.c. Per sincerarvene potete \
eseguire il comando\
\>", "Text"],

Cell["ls", "Program"],

Cell["\<\
che stampa l'elenco dei file contenuti nella directory \
corrente.\
\>", "Text"],

Cell[TextData[{
  "\[CapitalEGrave] ora possibile scrivere, in linguaggio C, il programma \
highestDivisor.c, che conterr\[AGrave] l'implementazione di una funzione ",
  StyleBox["highestDivisorC (la controparte di highestDivisor, ma che verr\
\[AGrave] eseguita nella sua versione compilata in linguaggio macchina)", 
    "InlineInput"],
  "; tale implementazione deve essere inserita, sotto forma di metodo avente \
la stessa segnatura della funzione, in un particolare sorgente come quello \
seguente:"
}], "Text"],

Cell["\<\
#include \"mathlink.h\"

int highestDivisor(int n) {
  int i=n-1;
  while(n%i!=0) i--;
  return i; 
}

int main(int argc, char *argv[]) {
  return MLMain(argc, argv);
}\
\>", "Program"],

Cell["\<\
In realt\[AGrave] non \[EGrave] necessario scrivere questo \
sorgente, giacch\[EAcute] l'avete gi\[AGrave] a disposizione. Nel caso \
voleste farlo per conto vostro, potete utilizzare un editor grafico (come \
TextEdit, che abbiamo gi\[AGrave] visto nelle precedenti lezioni) oppure un \
editor a caratteri (come vi). In ogni caso abbiate cura di salvare il tutto \
nella directory math-bin.\
\>", "Text"],

Cell[TextData[{
  "Il codice descritto \[EGrave] composto da tre parti fondamentali: \
l'inclusione del file mathlink.h (distribuito assieme a ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "), l'implementazione vera e propria della funzione ",
  StyleBox["highestDivisorC", "InlineInput"],
  " (deputata al metodo highestDivisor) nonch\[EAcute] un'implementazione \
standard del metodo main."
}], "Text"],

Cell[TextData[{
  "Per poter interfacciare ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " con il programma appena scritto \[EGrave] necessario introdurre un \
ulteriore file, che in questo caso avr\[AGrave] come nome highestDivisor.tm e \
il cui contenuto \[EGrave] il seguente:"
}], "Text"],

Cell["\<\
:Begin:
:Function:\t\thighestDivisor
:Pattern:\t\thighestDivisorC[n_Integer]
:Arguments:\t\t{n}
:ArgumentTypes:\t{Integer}
:ReturnType:\tInteger
:End:\
\>", "Program"],

Cell["\<\
Anche in questo caso, potete utilizzare il file scaricato dal sito \
del corso oppure crearlo per conto vostro.\
\>", "Text"],

Cell[TextData[{
  "Utilizzando il terminale \[EGrave] ora possibile compilare il sorgente \
contenuto nel file highestDivisor.c. Il processo di compilazione sar\[AGrave] \
leggermente diverso rispetto a quello che utilizzate normalmente, in quanto \
\[EGrave] necessario far riferimento ad alcune librerie fornite assieme a ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ". Il modo pi\[UGrave] semplice per eseguire questa operazione consiste nel \
copiare i contenuti della directory /Applications/Mathematica\\ \
5.0.app/AddOns/MathLink/DeveloperKit/Darwin/CompilerAdditions/\nall'interno \
della directory corrente (dove stiamo facendo riferimento a una particolare \
versione del software e a un particolare sistema operativo; se utilizzate una \
versione differente \[EGrave] necessario verificare in quale punto del file \
system si trovi la directory CompilerAdditions adeguata per il sistema \
operativa che utilizzate). Questo pu\[OGrave] essere fatto eseguendo il \
seguente comando:"
}], "Text"],

Cell["\<\
cp /Applications/Mathematica\\ \
5.0.app/AddOns/MathLink/DeveloperKit/Darwin/CompilerAdditions/* .\
\>", \
"Program"],

Cell["\<\
Va anche rimarcato come questo modo di procedere non sia \
sicuramente quello pi\[UGrave] elegante, ma ci permette di lavorare in una \
cartella su cui abbiamo i diritti di scrittura. Se l'operazione \[EGrave] \
andata a buon fine, nella directory corrente dovreste trovare, oltre ai file \
precedentemente copiati, anche libML.a (contenente le librerie sopra \
menzionate), mathlink,h (il file incluso all'interno di highestDivisor.c), \
mcc (che utilizzeremo al posto di cc) e mprep (che in realt\[AGrave] non \
utilizzeremo). A questo punto siamo in grado di generare l'eseguibile \
corrispondente a highestDivisor.c, eseguendo il comando\
\>", "Text"],

Cell["\<\
./mcc ./highestDivisor.tm ./highestDivisor.c \
-o./highestDivisor\
\>", "Program"],

Cell["\<\
Probabilmente otterrete un errore che segnala che \[EGrave] \
necessario eseguire il comando ranlib per poter utilizzare le librerie \
contenute in libML.a (se cos\[IGrave] non fosse, saltate questo passo e \
saltate direttamente al prossimo capoverso). Sar\[AGrave] sufficiente \
eseguire il comando ranlib ./limML.a (ed \[EGrave] in questa fase che \
necessitiamo dei diritti di scrittura sulla directory), che non dovrebbe \
produrre alcun output. Dopodich\[EAcute] dovreste poter eseguire senza \
problemi il processo di compilazione precedentemente descritto.\
\>", "Text"],

Cell["\<\
Se tutto \[EGrave] andato a buon fine, nella directory corrente \
dovreste trovare un nuovo file, il cui nome \[EGrave] highestDivisor. Se \
provate a lanciarlo eseguento il comando\
\>", "Text"],

Cell["./highestDivisor", "Program"],

Cell[TextData[{
  "otterrete la stampa del messaggio \"Create link:\". Premete CTRL-C per due \
volte in modo da terminare l'esecuzione . In realt\[AGrave] questo programma \
non \[EGrave] pensato per essere eseguito in questo modo, ma per venire \
lanciato direttamente da ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ", valutando la cella seguente:"
}], "Text"],

Cell[TextData[{
  "Per poter valutare la funzione ",
  StyleBox["highestDivisorC", "InlineInput"],
  " eseguendo effettivamente il codice scritto in highestDivisor.c \[EGrave] \
infine necessario ",
  StyleBox["installarla", "Emphasis"],
  ", valutando la funzione ",
  StyleBox["Install", "InlineInput"],
  " passandole come argomento il nome del file eseguibile creato con mcc. \
Tale funzione mantiene in esecuzione una copia del programma esterno cui far\
\[AGrave] riferimento ogni volta che verr\[AGrave] valutata ",
  StyleBox["highestDivisorC", "InlineInput"],
  ". ",
  StyleBox["Install", "InlineInput"],
  " ritorna un valore di tipo ",
  StyleBox["LinkObject", "InlineInput"],
  " che \[EGrave] opportuno memorizzare per poter in seguito eseguire \
l'operazione duale di disinstallazione."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(link = Install["\<highestDivisor\>"]\)], "Input"],

Cell[BoxData[
    \(LinkObject["./highestDivisor", 5, 3]\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Una volta installato il programma eseguibile, la funzione (o le funzioni) \
che esso descrive possono venire valutate nello stesso modo delle funzioni \
standard di ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ":"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Timing[highestDivisorC[10^6 - 1]]\)], "Input"],

Cell[BoxData[
    \({0.0018810000001394656`\ Second, 333333}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Salta agli occhi la differenza tra il tempo di esecuzione di \
highestDivisor e highestDivisorC: per lo stesso argomento ",
  Cell[BoxData[
      \(TraditionalForm\`10\^6 - 1\)]],
  ", si passa da pi\[UGrave] di sette secondi a un tempo trascurabile. Per \
apprezzare meglio la diminuzione del tempo di calcolo si possono ad esempio \
valutare le due funzioni su un insieme di argomenti: generando ad esempio i \
pi\[UGrave] alti divisori di tutti gli interi da due a 999 si hanno i \
seguenti risultati"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Timing[
      highest = Table[{i, highestDivisor[i]}, {i, 2, 10^3 - 1}]; ]\)], "Input"],

Cell[BoxData[
    \({3.5352490000000216`\ Second, Null}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Timing[
      highestC = 
        Table[{i, highestDivisorC[i]}, {i, 2, 10^3 - 1}]; ]\)], "Input"],

Cell[BoxData[
    \({0.23174699999981385`\ Second, Null}\)], "Output"]
}, Open  ]],

Cell["\<\
mentre ripetendo l'esperimento per i gli interi da 2 a 9999 si \
otterrebbero i seguenti risultati. Il condizionale \[EGrave] d'obbligo, nel \
senso che potete tranquillamente fidarvi dei risultati riportati in questo \
notebook SENZA VALUTARE LE CELLE CORRISPONDENTI, cosa che richiederebbe un \
tempo di esecuzione di vari minuti.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Timing[
      highest = Table[{i, highestDivisor[i]}, {i, 2, 10^4 - 1}]; ]\)], "Input"],

Cell[BoxData[
    \({366.57378199999994`\ Second, Null}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Timing[
      highestC = 
        Table[{i, highestDivisorC[i]}, {i, 2, 10^4 - 1}]; ]\)], "Input"],

Cell[BoxData[
    \({1.9354820000003201`\ Second, Null}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Una volta terminato l'utilizzo di una funzione esterna \[EGrave] opportuno \
",
  StyleBox["disinstallarla", "Emphasis"],
  " passando alla funzione ",
  StyleBox["Uninstall", "InlineInput"],
  " l'oggetto che era stato ritornato da ",
  StyleBox["Install", "InlineInput"],
  ". L'operazione di disinstallazione si occupa di terminare l'esecuzione del \
programma esterno lanciato da ",
  StyleBox["Install, come potete verificare rieseguendo il comando top (o \
tornando a controllare il suo output nel caso non lo aveste mai bloccato \
tramite la sequenza CTRL-C)", "InlineInput"],
  ":"
}], "Text"],

Cell[BoxData[
    \(Uninstall[link]; \)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Disegnare l'insieme di Mandelbrot", "Section"],

Cell[TextData[{
  "Nella seconda parte dell'esercitazione sfrutteremo quello che abbiamo \
imparato per visualizzare in tempi relativamente brevi dei grafici che \
richiederebbero invece tempi proibitivi qualora tentassimo di disegnarli \
utilizzando esclusivamente ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ". ",
  "L'idea di questa esercitazione \[EGrave] quella di passare da ",
  Cell[BoxData[
      \(\@\(-1\)\)]],
  " al seguente grafico:"
}], "Text"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .8125 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.770433 0.300481 0.40625 0.300481 [
[.01923 -0.0125 -12 -9 ]
[.01923 -0.0125 12 0 ]
[.16947 -0.0125 -6 -9 ]
[.16947 -0.0125 6 0 ]
[.31971 -0.0125 -12 -9 ]
[.31971 -0.0125 12 0 ]
[.46995 -0.0125 -6 -9 ]
[.46995 -0.0125 6 0 ]
[.62019 -0.0125 -12 -9 ]
[.62019 -0.0125 12 0 ]
[.77043 -0.0125 -3 -9 ]
[.77043 -0.0125 3 0 ]
[.92067 -0.0125 -9 -9 ]
[.92067 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .10577 -12 -4.5 ]
[-0.0125 .10577 0 4.5 ]
[-0.0125 .25601 -24 -4.5 ]
[-0.0125 .25601 0 4.5 ]
[-0.0125 .40625 -6 -4.5 ]
[-0.0125 .40625 0 4.5 ]
[-0.0125 .55649 -18 -4.5 ]
[-0.0125 .55649 0 4.5 ]
[-0.0125 .70673 -6 -4.5 ]
[-0.0125 .70673 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .8125 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .8125 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.01923 0 m
.01923 .00625 L
s
[(-2.5)] .01923 -0.0125 0 1 Mshowa
.16947 0 m
.16947 .00625 L
s
[(-2)] .16947 -0.0125 0 1 Mshowa
.31971 0 m
.31971 .00625 L
s
[(-1.5)] .31971 -0.0125 0 1 Mshowa
.46995 0 m
.46995 .00625 L
s
[(-1)] .46995 -0.0125 0 1 Mshowa
.62019 0 m
.62019 .00625 L
s
[(-0.5)] .62019 -0.0125 0 1 Mshowa
.77043 0 m
.77043 .00625 L
s
[(0)] .77043 -0.0125 0 1 Mshowa
.92067 0 m
.92067 .00625 L
s
[(0.5)] .92067 -0.0125 0 1 Mshowa
.125 Mabswid
.04928 0 m
.04928 .00375 L
s
.07933 0 m
.07933 .00375 L
s
.10937 0 m
.10937 .00375 L
s
.13942 0 m
.13942 .00375 L
s
.19952 0 m
.19952 .00375 L
s
.22957 0 m
.22957 .00375 L
s
.25962 0 m
.25962 .00375 L
s
.28966 0 m
.28966 .00375 L
s
.34976 0 m
.34976 .00375 L
s
.37981 0 m
.37981 .00375 L
s
.40986 0 m
.40986 .00375 L
s
.4399 0 m
.4399 .00375 L
s
.5 0 m
.5 .00375 L
s
.53005 0 m
.53005 .00375 L
s
.5601 0 m
.5601 .00375 L
s
.59014 0 m
.59014 .00375 L
s
.65024 0 m
.65024 .00375 L
s
.68029 0 m
.68029 .00375 L
s
.71034 0 m
.71034 .00375 L
s
.74038 0 m
.74038 .00375 L
s
.80048 0 m
.80048 .00375 L
s
.83053 0 m
.83053 .00375 L
s
.86058 0 m
.86058 .00375 L
s
.89063 0 m
.89063 .00375 L
s
.95072 0 m
.95072 .00375 L
s
.98077 0 m
.98077 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .10577 m
.00625 .10577 L
s
[(-1)] -0.0125 .10577 1 0 Mshowa
0 .25601 m
.00625 .25601 L
s
[(-0.5)] -0.0125 .25601 1 0 Mshowa
0 .40625 m
.00625 .40625 L
s
[(0)] -0.0125 .40625 1 0 Mshowa
0 .55649 m
.00625 .55649 L
s
[(0.5)] -0.0125 .55649 1 0 Mshowa
0 .70673 m
.00625 .70673 L
s
[(1)] -0.0125 .70673 1 0 Mshowa
.125 Mabswid
0 .13582 m
.00375 .13582 L
s
0 .16587 m
.00375 .16587 L
s
0 .19591 m
.00375 .19591 L
s
0 .22596 m
.00375 .22596 L
s
0 .28606 m
.00375 .28606 L
s
0 .31611 m
.00375 .31611 L
s
0 .34615 m
.00375 .34615 L
s
0 .3762 m
.00375 .3762 L
s
0 .4363 m
.00375 .4363 L
s
0 .46635 m
.00375 .46635 L
s
0 .49639 m
.00375 .49639 L
s
0 .52644 m
.00375 .52644 L
s
0 .58654 m
.00375 .58654 L
s
0 .61659 m
.00375 .61659 L
s
0 .64663 m
.00375 .64663 L
s
0 .67668 m
.00375 .67668 L
s
0 .07572 m
.00375 .07572 L
s
0 .04567 m
.00375 .04567 L
s
0 .01562 m
.00375 .01562 L
s
0 .73678 m
.00375 .73678 L
s
0 .76683 m
.00375 .76683 L
s
0 .79688 m
.00375 .79688 L
s
.25 Mabswid
0 0 m
0 .8125 L
s
.01923 .80625 m
.01923 .8125 L
s
.16947 .80625 m
.16947 .8125 L
s
.31971 .80625 m
.31971 .8125 L
s
.46995 .80625 m
.46995 .8125 L
s
.62019 .80625 m
.62019 .8125 L
s
.77043 .80625 m
.77043 .8125 L
s
.92067 .80625 m
.92067 .8125 L
s
.125 Mabswid
.04928 .80875 m
.04928 .8125 L
s
.07933 .80875 m
.07933 .8125 L
s
.10937 .80875 m
.10937 .8125 L
s
.13942 .80875 m
.13942 .8125 L
s
.19952 .80875 m
.19952 .8125 L
s
.22957 .80875 m
.22957 .8125 L
s
.25962 .80875 m
.25962 .8125 L
s
.28966 .80875 m
.28966 .8125 L
s
.34976 .80875 m
.34976 .8125 L
s
.37981 .80875 m
.37981 .8125 L
s
.40986 .80875 m
.40986 .8125 L
s
.4399 .80875 m
.4399 .8125 L
s
.5 .80875 m
.5 .8125 L
s
.53005 .80875 m
.53005 .8125 L
s
.5601 .80875 m
.5601 .8125 L
s
.59014 .80875 m
.59014 .8125 L
s
.65024 .80875 m
.65024 .8125 L
s
.68029 .80875 m
.68029 .8125 L
s
.71034 .80875 m
.71034 .8125 L
s
.74038 .80875 m
.74038 .8125 L
s
.80048 .80875 m
.80048 .8125 L
s
.83053 .80875 m
.83053 .8125 L
s
.86058 .80875 m
.86058 .8125 L
s
.89063 .80875 m
.89063 .8125 L
s
.95072 .80875 m
.95072 .8125 L
s
.98077 .80875 m
.98077 .8125 L
s
.25 Mabswid
0 .8125 m
1 .8125 L
s
.99375 .10577 m
1 .10577 L
s
.99375 .25601 m
1 .25601 L
s
.99375 .40625 m
1 .40625 L
s
.99375 .55649 m
1 .55649 L
s
.99375 .70673 m
1 .70673 L
s
.125 Mabswid
.99625 .13582 m
1 .13582 L
s
.99625 .16587 m
1 .16587 L
s
.99625 .19591 m
1 .19591 L
s
.99625 .22596 m
1 .22596 L
s
.99625 .28606 m
1 .28606 L
s
.99625 .31611 m
1 .31611 L
s
.99625 .34615 m
1 .34615 L
s
.99625 .3762 m
1 .3762 L
s
.99625 .4363 m
1 .4363 L
s
.99625 .46635 m
1 .46635 L
s
.99625 .49639 m
1 .49639 L
s
.99625 .52644 m
1 .52644 L
s
.99625 .58654 m
1 .58654 L
s
.99625 .61659 m
1 .61659 L
s
.99625 .64663 m
1 .64663 L
s
.99625 .67668 m
1 .67668 L
s
.99625 .07572 m
1 .07572 L
s
.99625 .04567 m
1 .04567 L
s
.99625 .01562 m
1 .01562 L
s
.99625 .73678 m
1 .73678 L
s
.99625 .76683 m
1 .76683 L
s
.99625 .79688 m
1 .79688 L
s
.25 Mabswid
1 0 m
1 .8125 L
s
0 0 m
1 0 L
1 .8125 L
0 .8125 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.01923 .01563 translate
.96154 .78125 scale
3000 string
1000 1000 8 [1000 0 0 1000 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00
FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00
FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00
FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF7A00
FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00
FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF6B00FF6B00FF6B00FF7A00
FF6B00FF6B00FF6B00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00
FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF7A00FF7A00FF6B00FF6B00FF7A00FF7A00
FF7A00FF6B00FF6B00FF7A00FF7A00FF7A00FF6B00FF6B00FF7A00FF7A00FF6B00FF6B00
FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00
FF6B00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00
FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00
FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00
FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF7A00FF7A00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF8A00FF8A00FF7A00FF8A00
FF7A00FF8A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00
FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00
FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FFA800FFA800FF9900FF9900
FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00
FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF6B00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00
FF8A00FF8A00FF9900FF9900FFA800FFA800FFA800FFA800FFB800FFE600FFA800FF9900
FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF6B00FF6B00FF6B00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00
FF8A00FF9900FFA800FFC700FFE600FFB800FFB800FFB800FFC700FFC700FFA800FFA800
FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00
FF8A00FF9900EBFF00FFD700FFF500FFE600FFE600FFD700FFF500FFC700FFB800FFA800
FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FFA800FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00
FF8A00FF9900FFA800FFA800FFB800FFC700FFD700FFF500FAFF00FFC700FFB800FFA800
FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800
FFF500FFA800FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF7A00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF8A00FF8A00
FF8A00FF9900FF9900FFA800FFA800FFB800FFC700FFD700AEFF00FFD700FFC700FFB800
FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFB800
42FF00FFB800FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF8A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF7A00FF7A00FF7A00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF9900FF9900FFA800FFA800FFB800FFC700FFE600FFE600FFC700FFC700
FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFC700
EBFF00FFB800FFA800FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00
FF8A00FF9900FF9900FF9900FF9900FFA800FFA800FFB800FFE600FAFF00FFE600FFD700
FFC700FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFD700
DCFF00FFE600FFB800FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF9900FF9900FF9900FFA800FFA800FFB800FFD700FFE600DCFF00FAFF00
FFE600FFD700FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700BDFF00
FFE600FFC700FFB800FF9900FF9900FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00
FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF6B00FF6B00FF6B00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF9900FF9900FF9900FFA800FFB800FFB800FFC700FFF50051FF00
BDFF00FFF500FFD700FFF500FFC700FFC700FFB800FFB800FFB800FFD700FFF500FAFF00
FFC700FFB800FFA800FFA800FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF9900FF9900FF9900FF9900FFA800FFA800FFB800FFB800FFD700CCFF00
FFF500EBFF008FFF008FFF00FFD700FFC700FFC700FFC700FFC700FFF500BDFF00FFF500
FFC700FFB800FFA800FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FFA800FFA800FFB800FFC700FFD700
FFD700FFE600FFF500CCFF00FFE600FFD700FFD700FFD700FFD700FAFF00FFF500FFC700
FFB800FFA800FFA800FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF7A00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFB800FFB800FFB800
FFC700FFC700FFD700FAFF0061FF00FFF500FFE600FFE600FFF5008FFF00FFE600FFC700
FFB800FFA800FFA800FFA800FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FFA800FFA800FFB800FFB800
FFB800FFC700FFD700FFD700FAFF00DCFF00FAFF00FAFF009EFF00FFE600FFD700FFB800
FFB800FFA800FFA800FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFB800
FFB800FFB800FFC700FFD700FFE600FFF500CCFF00DCFF00FFF500FFD700FFC700FFB800
FFB800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800
FFB800FFB800FFC700FFD700FFD700FFE6008FFF00FFF500FFE600FFD700FFC700FFB800
FFB800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF8A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF6B00FF6B00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00
FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF7A00FF7A00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800
FFB800FFB800FFB800FFC700FFD700FFE600AEFF00FFF500FFD700FFD700FFC700FFB800
FFB800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF8A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800
FFA800FFB800FFC700FFC700FFD700FFF5009EFF00FFF500FFD700FFC700FFC700FFB800
FFB800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF9900
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FFA800FFA800FFA800
FFA800FFB800FFB800FFC700FFD700FFE60080FF00FAFF00FFE600FFD700FFC700FFB800
FFB800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00
FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800
FFA800FFB800FFB800FFC700FFC700FFE600EBFF00DCFF00BDFF00FFD700FFC700FFB800
FFB800FFA800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00
FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800
FFA800FFB800FFB800FFC700FFC700FFE60051FF0070FF0000FF75FFD700FFC700FFC700
FFB800FFB800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF8A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FFA800FFA800
FFA800FFB800FFB800FFB800FFC700FFE600FAFF0061FF00FFF500FFD700FFC700FFC700
FFB800FFB800FFA800FFB800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF7A00FF7A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00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FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00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FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00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FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00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FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800
FFA800FFB800FFC700FFE600FFF50070FF00DCFF00BDFF00FFF500FFE600FFD700FFD700
FFD700FFC700FFC700FFC700FFC700FFD700FFB800FFA800FFA800FFA800FFA800FF9900
FF9900FF9900FF9900FF9900FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00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FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00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FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00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FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00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FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00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FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00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FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00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FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00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FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00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FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00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FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00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FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00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FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00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FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00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FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00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FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800
FFA800FFA800FFB800FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFE600
FFF500FFE600FFF500FFF500FAFF00DCFF008FFF00CCFF00FAFF00FFF500FFE600FFD700
FFC700FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFB800FFB800FFB800FFC700FFD700FFF500CCFF00FFD700FFC700FFB800
FFA800FFA800FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00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FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00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FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00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FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800
FFA800FFA800FFB800FFA800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFC700
FFD700FFD700FFD700FFE600FFF500FAFF0000FFA314FF00DCFF00FFF500FFE600FFE600
FFD700FFC700FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFD700FFE600FFF500EBFF009EFF00FAFF00FAFF0042FF00
FAFF00AEFF00FFC700FFA800FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00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FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00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FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00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FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00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FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00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FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00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FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00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FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00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FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00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FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00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FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFC700
FFC700FFC700FFC700FFD700FFE600AEFF00FAFF00FAFF00FAFF00FAFF00EBFF00CCFF00
80FF00AEFF00BDFF008FFF00FFF500FFF500FFF500FFE600FFE600FFF500FAFF00AEFF00
BDFF00CCFF0051FF00CCFF0005FF008FFF00DCFF00FAFF00FFF500FFF500FFF500FFF500
FAFF0070FF00EBFF00FFD700FFC700FFC700FFC700FFB800FFB800FFA800FFA800FFA800
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00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FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00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FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00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FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00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FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00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FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00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FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00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FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800
FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFD700FFE600FFE600FFE600FFF500
FAFF00FAFF00EBFF00DCFF00BDFF009EFF0080FF00BDFF00CCFF00EBFF00EBFF00FAFF00
FFF500FFF500FFE600FFE600FFE600FFD700FFD700FFD700FFC700FFC700FFC700FFB800
FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00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FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00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FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00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FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00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FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00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FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00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FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00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FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00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FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFB800FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700
FFC700FFD700FFD700FFD700FFD700FFD700FFE600FFE600FFE600FFF500FAFF00EBFF00
BDFF0000FF1980FF0080FF0042FF0033FF008FFF00AEFF009EFF0023FF0033FF00FAFF00
FFF500FFE600FFE600FFD700FFD700FFD700FFC700FFC700FFC700FFC700FFB800FFB800
FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00
FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00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FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00
FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFC700
FFD700FFD700FFD700FFD700FFE600FFE600FFE600FFE600FFF500BDFF0070FF0014FF00
0019FF14FF0033FF0000FF75FF0000FF005C05FF0033FF0080FF00BDFF00EBFF00FAFF00
FFF500FFE600FFE600FFE600FFD700FFD700FFC700FFC700FFC700FFC700FFB800FFB800
FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00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FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00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FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00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FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00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FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00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FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00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FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00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FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00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FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00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FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00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FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00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FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00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FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00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FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00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FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00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FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00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FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00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FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00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FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800
FFA800FFB800FFB800FFB800FFB800FFC700FFD700FFE600DCFF0000FF19AEFF00FAFF00
FFF500FFF500FFF500FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700
FFD700FFD700FFD700FFE600FFE600FFE600FFF500FFF500FAFF00FAFF00EBFF00EBFF00
CCFF00AEFF009EFF0080FF0000FF2800FF0A00FFF0FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000F00E1FF00D1FF00FFE10085FF
14FF0033FF0000FF2833FF00BDFF00CCFF00CCFF00CCFF009EFF00FAFF00FFF500FFE600
FFD700FFD700FFC700FFC700FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFA800
FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF8A00FF8A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00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FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00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FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00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FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00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FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800
FFC700FFC700FFC700FFD700FFD700FFD700FFE600FFF500FAFF00EBFF00BDFF009EFF00
23FF008FFF00DCFF00FAFF00FFF500FFF500FFF500FFE600FFE600FFE600FFE600FFF500
FFF500FFF500FFF500FAFF00FAFF00EBFF00EBFF00EBFF00EBFF00EBFF00DCFF00BDFF00
80FF0080FF0070FF0051FF0000FF19FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFC200FF75
00FF5751FF0000A3FF00FF759EFF00EBFF00EBFF00FAFF00FFF500FFF500FFE600FFE600
FFD700FFD700FFD700FFD700FFD700FFD700FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFD700FFE60014FF0000FF0AFFF500FFC700
FFB800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00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FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00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FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00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FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00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FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00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FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00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FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800
FFA800FFB800FFF50005FF00CCFF00CCFF00DCFF0000FF19BDFF00DCFF00EBFF00BDFF00
9EFF0023FF0070FF009EFF008FFF0000FF0A9EFF00AEFF009EFF0080FF0000FFD100FF75
14FF00AEFF00BDFF00CCFF00DCFF00EBFF00EBFF00EBFF00EBFF00EBFF00EBFF00DCFF00
DCFF00CCFF00AEFF009EFF0042FF0000FFB323FF000057FF70FF0080FF0061FF0005FF00
05FF0033FF0000FF38FF000F00FF0A00FF2800FF5700B3FF8000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000B3FFFF004C05FF0042FF00
61FF0080FF008FFF0014FF00BDFF00BDFF00CCFF00BDFF009EFF009E00FF00FF28DCFF00
FAFF00FFF500FFF500FFF500FFE600FFE600FFE600FFE600FFE600FFF500FFF500FAFF00
EBFF00CCFF000057FF14FF0014FF0051FF008FFF00BDFF00FAFF0005FF00FFD700FFC700
FFC700FFB800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF8A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800
FFA800FFC700FFF500FFF50000FF38FAFF00FAFF009EFF008FFF00AEFF00CCFF009EFF00
FF00000075FFAEFF00CCFF00CCFF00BDFF00CCFF00BDFF00AEFF0080FF0000FF0A70FF00
8FFF00AEFF00BDFF00CCFF00DCFF00DCFF00DCFF00DCFF00DCFF00DCFF00DCFF00DCFF00
CCFF00BDFF00AEFF008FFF0023FF009E00FF00FF1900FF4700FF9461FF0000FFD100FF75
0057FF00FF1900FF1900FFF000FF4700FFA300FFC200FFC200C2FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF006B00FFB300FF2814FF0033FF00
61FF0070FF0051FF0000FF669EFF00AEFF00BDFF00AEFF0000FFE100FFC29EFF00CCFF00
EBFF00FAFF00FFF500FFF500FFF500FFF500FFE600FFF500FFF500FFF500EBFF00CCFF00
BDFF00AEFF0000FFD180FF00AEFF0051FF00EBFF00FFF500FFF500FFE600FFD700FFC700
FFB800FFB800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF7A00FF7A00FF7A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800
FFA800FFB800FFC700FFD700FFE600FFE600FFF500AEFF00BDFF0080FF0070FF0080FF00
00FF5700FF0ACCFF00DCFF00DCFF00DCFF00DCFF00CCFF00BDFF0033FF0000FF3861FF00
8FFF00AEFF00BDFF00CCFF00CCFF00CCFF00CCFF00BDFF00CCFF00CCFF00CCFF00CCFF00
BDFF00BDFF008FFF0061FF0000FFA30085FFFF0000FF000014FF0033FF000094FFFF0000
FF000000FF85FF0000FF0000FF0000FF0000FF0000FF00008000FF5100FFFF00B8FF0000
FF0000FF0000FF0000FF0000FF0000FF00001400FF00FFD100FF7500FF3805FF0000FF19
33FF0051FF0023FF0033FF0061FF009EFF00AEFF009EFF0051FF0014FF008FFF0080FF00
BDFF00DCFF00FAFF00FFF500FFF500FFF500FFF500FFF500FFF500FAFF00AEFF0070FF00
05FF0080FF0000FF2851FF00CCFF00EBFF00FAFF00FFF500FFE600FFD700FFC700FFC700
FFB800FFB800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800
FFA800FFB800FFB800FFC700FFD700FFD700FFE600FFF500DCFF008FFF008FFF0080FF00
BDFF0000FF38DCFF00EBFF00EBFF00EBFF00DCFF00DCFF00BDFF0080FF0000FF4700FF94
8FFF009EFF00AEFF00BDFF00CCFF00CCFF00AEFF0033FF00AEFF00BDFF009EFF00BDFF00
BDFF009EFF0000D1FF00FF380038FFFF00000066FF00FFA300FF6600FF1900FFF0000AFF
FF0000FF00000028FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF001E0047FF0075FF00A3FF00FFA300FF4700FF57
00FF1933FF0014FF0000FF1942FF008FFF008FFF008FFF0061FF0000FF7500B3FF0047FF
00FF85CCFF00FAFF00FAFF00FFF500FFF500FFF500FAFF00FAFF00FAFF00DCFF00AEFF00
70FF0000FF2851FF00BDFF00DCFF00EBFF00FFF500FFE600FFE600FFD700FFC700FFC700
FFB800FFB800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800
FFA800FFA800FFB800FFB800FFC700FFC700FFD700FFF50000FF6614FF00CCFF008FFF00
EBFF00EBFF00EBFF00FAFF00FAFF00EBFF00EBFF00DCFF00BDFF008FFF0000FF0A00FF94
70FF0070FF0014FF00AEFF00BDFF00BDFF008FFF0000FF3861FF0070FF0061FF00AEFF00
AEFF009EFF0070FF0000FF0ACC00FFDC00FFFF00008000FFFF000000FF7500E1FFFF00C7
FF0000FF004CFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000A3FFFF0000
00FF8500FF28BD00FF00FFFF51FF0070FF0051FF0070FF0051FF0000FF9461FF0000FFC2
00FFD1DCFF00EBFF00FAFF00FAFF00FAFF00FAFF00FAFF00FAFF00EBFF00DCFF00BDFF00
51FF0033FF009EFF00CCFF00DCFF00FAFF00FFF500FFE600FFE600FFD700FFC700FFC700
FFB800FFB800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800
FFA800FFA800FFB800FFB800FFB800FFC700FFD700FFE600EBFF00BDFF00EBFF00FAFF00
FFF500FAFF00FAFF00FAFF00FAFF00FAFF00EBFF00DCFF0070FF0051FF0000FF2800FF38
00FFB342FF0033FF0080FF00AEFF00AEFF008FFF0061FF0000FFC214FF0033FF008FFF00
9EFF008FFF0070FF0033FF0000FF470094FFFF0000FF0000FF000000F0FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
2300FF00FFC2FF0000FF008A00FF4751FF0000B3FF14FF0000FF0A0028FF70FF00AEFF00
BDFF00DCFF00EBFF00EBFF00FAFF00FAFF00FAFF00FAFF00EBFF00EBFF00DCFF008FFF00
51FF0000FF28AEFF00CCFF00DCFF00EBFF00FAFF00FFF500FFE600FFD700FFC700FFC700
FFB800FFB800FFB800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800
FFA800FFA800FFB800FFB800FFB800FFC700FFC700FFD700FFF5008FFF00FFF500FFF500
FFF500FFF500FFF500FFF500FFF500FAFF00FAFF00EBFF00AEFF0061FF0014FF0000FF47
00FF5700FF3800FF0A42FF008FFF008FFF0080FF0061FF0000FF2800FFB351FF0080FF00
80FF0070FF0023FF0023FF0000FF85FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000085FF00FF1914FF0000FF190019FF00FFF000C2FF80FF00AEFF00
CCFF00DCFF00DCFF00EBFF00EBFF00EBFF00FAFF00EBFF00EBFF00DCFF00CCFF0000B3FF
00FF0A61FF00AEFF00BDFF00CCFF00DCFF00EBFF00FFF500FFF500FFE600FFD700FFC700
FFC700FFB800FFB800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900
FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00
FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800
FFA800FFA800FFB800FFB800FFB800FFC700FFC700FFD700FFD700FAFF00FFE600FFE600
FFE600FFE600FFE600FFF500FFF500FFF500FAFF00EBFF00BDFF00AEFF0000FF5700FF28
FF000000FF4705FF0061FF0070FF0042FF000085FF14FF0000FFA323FF0061FF0070FF00
61FF0000A3FF6100FF00FF0A00FF570057FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF000000FFF000FF5700FF94FF004C00C2FFFF0000FF000051FF0000FF28
BDFF00CCFF00DCFF00DCFF00EBFF00EBFF00EBFF00EBFF00EBFF00DCFF00CCFF009EFF00
0075FF00FF6680FF008FFF0051FF009EFF0080FF00EBFF00EBFF00FFF500FFD700FFC700
FFC700FFB800FFB800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF7A00
FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800
FFA800FFA800FFA800FFB800FFB800FFB800FFC700FFC700FFD700FFD700FFD700FFD700
FFE600FFE600FFE600FFE600FFF500FFF500FAFF00EBFF00DCFF00BDFF0023FF0005FF00
0500FF00FF5723FF0051FF0051FF0042FF0000FFB30019FF00FFC205FF0033FF0051FF00
51FF0023FF00FF0000FF007A00FFA300A3FFFF00A8FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000028FF00A3FF7000FFFF00004200FF00D1FF00FF6661FF00
AEFF00BDFF00BDFF0000FF19CCFF00DCFF00DCFF00DCFF00DCFF00DCFF00CCFF00AEFF00
23FF0000FF2800D1FF00FF3800FF3833FF009EFF00CCFF0000FF19FAFF00FFE600FFD700
FFC700FFC700FFB800FFB800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900
FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF8A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800
FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFC700FFC700FFD700FFD700FFD700
FFD700FFD700FFE600FFE600FFF500FFF500FAFF00EBFF00DCFF00BDFF008FFF0061FF00
00FF570094FF00FF4723FF005100FF05FF00CC00FFAE00FF00FF8500FF1900FF1900FF38
33FF0000F0FFFF003D9E00FF0085FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000A3FF00FFB300FF4780FF00
9EFF00AEFF00AEFF0061FF00AEFF00CCFF00CCFF00DCFF00DCFF00CCFF00BDFF00AEFF00
8FFF0033FF0000FFF080FF0080FF0070FF0000A3FF8FFF0033FF00EBFF00FFE600FFD700
FFD700FFC700FFC700FFB800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800
FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFD700
FFD700FFD700FFD700FFE600FFE600FFF500FAFF00DCFF00BDFF00AEFF009EFF0051FF00
00FF28FF000000FF4700FFB30057FF00FF5700FFC28F00FF0066FF9E00FF5100FF00FF47
05FF0000FF38FF00F5FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000057FF42FF0080FF00
9EFF009EFF0080FF00FA00FF8FFF008FFF00AEFF00CCFF00CCFF00BDFF00BDFF00AEFF00
8FFF0070FF00AE00FF8FFF00AEFF00AEFF0000FF0A42FF008FFF00DCFF00FFF500FFF500
FFE600FFE600FAFF00FFB800FFB800FFA800FFA800FFA800FF9900FF9900FF9900FF9900
FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800
FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFD700
FFD700FFD700FFD700FFE600FFE600FFF500FAFF0033FF0000D1FF80FF0080FF0000FF57
00FF75FF00E600E1FF00FFC20057FF00FFFFFF0000FF0000FF0000FF005C00B3FF00C2FF
00FF38FF00E60085FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF1923FF000028FF
80FF008FFF0000FF3800FFA305FF0000D1FF9EFF00BDFF00BDFF00AEFF00AEFF009EFF00
80FF0042FF0000FF198FFF00BDFF00CCFF00BDFF009EFF0000FF28CCFF00FAFF00FAFF00
61FF00EBFF00EBFF00FFB800FFB800FFA800FFA800FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00
FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800
FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFC700
FFD700FFD700FFD700FFE600FFE600FFF500FAFF00DCFF0080FF0014FF0042FF0000FF85
00F0FF00FF85DC00FFFF006BFF00008F00FFFF0000FF0000FF0000FF0000CC00FF00E1FF
00FF85FF004CFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00E600FFFF00FFC200FF284200FF
61FF0070FF0061FF0000FFF000FF6661FF008FFF009EFF009EFF0080FF0023FF0080FF00
00FF940094FF23FF00AEFF00CCFF00DCFF00DCFF00BDFF0000FF5742FF00DCFF00CCFF00
AEFF00EBFF00FFD700FFC700FFB800FFA800FFA800FFA800FFA800FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00
FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700
FFC700FFD700FFD700FFD700FFE600FFF500FAFF00CCFF0005FF0033FF0000FFA30028FF
00FF0A00FF2800FFC2FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0019FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000085FFFF000014FF00
51FF0061FF0051FF0023FF0000FFC233FF0000FF758FFF0080FF0000FF4700FF2842FF00
14FF0000FFD180FF00BDFF00DCFF00EBFF00DCFF00DCFF009EFF0051FF0080FF009EFF00
80FF00FFF500FFC700FFB800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800
FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700
FFC700FFD700FFD700FFD700FFE600FFE600FAFF008FFF0061FF00AEFF00BD00FF23FF00
51FF0000FF850047FF8000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000BD00FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF47
33FF0000FF3814FF0000FFFF0094FF00FF2800FF3870FF0070FF0005FF0000FF4700B3FF
00FF9400B3FF23FF0080FF00DCFF00EBFF00FAFF00EBFF00CCFF009EFF009EFF0061FF00
DCFF00DCFF00FFC700FFB800FFA800FFA800FFA800FFA800FF9900FFA800FF9900FF9900
FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800
FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700
FFC700FFD700FFD700FFD700FFE600FFE600FAFF00BDFF00AEFF00CCFF00AEFF009EFF00
70FF0000FF0A0085FF00FFE1FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000000AFF00F0FF
00FF0A00A3FF00FF5700FF57FF00000047FF00FFC200FFB351FF0033FF0000FF38FF0000
00FF2861FF008FFF00CCFF00EBFF00FAFF00FAFF00FAFF00FAFF00DCFF0023FF00FFF500
FFE600FFE600FFC700FFB800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00
FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFC700FFC700
FFC700FFD700FFD700FFD700FFE600FFE600FFF500EBFF00EBFF00DCFF00BDFF008FFF00
61FF0033FF0000FF2800B3FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00007000FF
00FF4700FF66AE00FF00B3FFFF00000057FF00FF4700B3FF14FF0000FF3800FFA300C2FF
33FF008FFF00CCFF00EBFF00FAFF00FAFF00FFF500FFF500FFF500FAFF00FAFF00FFE600
FFD700FFC700FFB800FFB800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700
FFC700FFD700FFD700FFD700FFE600FFF500FFF500FAFF00FAFF00EBFF00CCFF0000FF47
00FF7505FF0000F0FF00FFF0FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000E1FF
00FFA3FA00FFFF0000FF0000FF00005100FF00E1FFFF007A00FF5700FF570047FF23FF00
80FF00AEFF00CCFF00EBFF00FAFF00FFF500FFF500FFE600FFE600FFE600FFD700FFD700
FFC700FFC700FFB800FFB800FFA800FFA800FFA800FFA800FFA800FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700
FFC700FFD700FFD700FFD700FFE600FFE600FFF500FFF500FAFF00EBFF00DCFF009EFF00
05FF00BD00FF00FFA3FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
00C2FFFF0000FF0000FF0000FF0000FF00004200FFFF000000E1FF2300FF00FFA305FF00
70FF00AEFF00BDFF00DCFF00FAFF00FFF500FFE600FFE600FFD700FFD700FFD700FFC700
FFC700FFB800FFB800FFB800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FFA800FF9900FF9900FF9900FF9900FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFC700FFC700FFC700FFC700FFC700
FFC700FFD700FFD700FFD700FFE600FFE600FFF500FFF500FAFF00EBFF00DCFF0070FF00
42FF0061FF0000FF1900FF7500FFC2FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0500FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FA00FFFF000F00FFFF00FFE1
61FF0051FF0000FF57BDFF00FAFF00FFF500FFE600FFD700FFD700FFD700FFC700FFC700
FFC700FFB800FFB800FFB800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00
FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FFA800FF9900FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700
FFC700FFD700FFD700FFD700FFE600FFF500FFF500FAFF00FAFF00EBFF00DCFF008FFF00
8FFF008FFF0000FFF023FF00AE00FF0085FFFF0000FF0000AE00FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00A8FF0000FF0000FF0000FF0000FF0000FF0000FF00000047FF00FF5705FF000500FF
00FF8500FF0A8FFF0080FF00FAFF00FFE600FFE600FFD700FFD700FFC700FFC700FFC700
FFC700FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF9900FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700
FFC700FFD700FFD700FFE600FFE600FFF500FFF500FAFF00FAFF00EBFF00DCFF00BDFF00
AEFF009EFF0080FF0051FF0005FF0000FF2800FF7500FFF0FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00008F00FF0094FF00FF3851FF0023FF00
05FF008FFF0023FF00EBFF00FFF500FFE600FFD700FFD700FFD700FFC700FFC700FFC700
FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00
FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900
FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFC700FFC700
FFC700FFD700FFD700FFE600FFF500FFF500FAFF00FAFF00EBFF00EBFF00DCFF00CCFF00
BDFF009EFF0080FF0061FF0033FF0000D1FF00FF75FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00F500FF2833FF0070FF009EFF00
BDFF00BDFF0061FF00FAFF00FFF500FFE600FFD700FFD700FFC700FFC700FFC700FFB800
FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FF9900FF9900FFA800
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00
FF8A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF9900FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800
FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700
FFD700FFD700FFE600FFF500FAFF00FAFF00EBFF00EBFF00EBFF00DCFF00DCFF00CCFF00
BDFF009EFF0033FF0042FF0023FF0000A3FF0085FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF000000E1FFBD00FF23FF0000FF5761FF00
CCFF00EBFF00FAFF00FFF500FFF500FFE600FFD700FFD700FFC700FFC700FFC700FFB800
FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700
FFD700FFE600FFF50070FF00EBFF00CCFF008FFF00CCFF00DCFF00DCFF00CCFF00CCFF00
AEFF008FFF0014FF0000FF8514FF0000FF47FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00002300FF00FFB39E00FF00FF0A00FF57
DCFF00EBFF00FAFF00FFF500FFE600FFE600FFD700FFD700FFC700FFC700FFC700FFC700
FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700
FFD700FFE6009EFF0000FF47BDFF0061FF0061FF00AEFF00BDFF00CCFF00CCFF00BDFF00
9EFF0033FF0000FF2800FF4700FF8500FF75FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000BD00FF6100FFFF0000FF000000F0FF00FF8505FF0061FF00FF00F5BDFF00
DCFF00FAFF00FFF500FFF500FFE600FFE600FFD700FFD700FFC700FFC700FFC700FFB800
FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF9900FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFC700
FFD700FFE600EBFF0042FF0023FF0000FF190094FF14FF0000FF28BDFF00BDFF00AEFF00
9EFF0023FF0033FF00FF007AFF00004200FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF000000E1FF00FF7500FF3800FF4742FF0070FF008FFF0080FF00CCFF00
EBFF00FAFF00FAFF00FFF500FFE600FFE600FFD700FFD700FFC700FFC700FFC700FFB800
FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00
FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FFA800FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFD700
FFD700FFE600FFF5009EFF008FFF0051FF0000FFF000A3FF61FF009EFF00AEFF00AEFF00
9EFF0080FF0051FF0000FFD1FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF000000FF6600FF3842FF0070FF008FFF00AEFF00BDFF00DCFF00
EBFF00FAFF00FAFF00FFF500FFF500FFE600FFD700FFD700FFC700FFC700FFC700FFB800
FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00
FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF8A00FF8A00FF8A00
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FFA800FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFD700
FFD700FFE600FFF500EBFF00BDFF009EFF0061FF0000FF2800FF2880FF009EFF009EFF00
8FFF0070FF0051FF000057FF0028FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00004200FF00E1FF00FF8542FF0051FF0080FF00AEFF00CCFF00DCFF00
EBFF00EBFF00FAFF00FAFF00FFF500FFE600FFE600FFD700FFD700FFC700FFC700FFB800
FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00
FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF6B00FF6B00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00
FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFD700
FFD700FFE600FAFF00EBFF00AEFF0061FF0000FFB305FF0000D1FF80FF008FFF008FFF00
80FF00FF000033FF0005FF0000FF940038FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF000000FF1914FF00FF001EEB00FFAEFF00CCFF00CCFF00
DCFF00EBFF00EBFF00EBFF00FAFF00FFF500FFE600FFE600FFD700FFC700FFC700FFB800
FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900FF9900
FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00
FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFD700
FFE600FFF500EBFF00BDFF0033FF0000FF2800FF1900FF6614FF0070FF0080FF0070FF00
00FF0A00FF2800FF1900FF28FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF000000FFFFFF00A800FF2800FF9470FF00AEFF00BDFF00CCFF00
CCFF00DCFF00DCFF00CCFF008FFF00FAFF00FFF500FFE600FFE600FFD700FFC700FFB800
FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00
FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF8A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFD700FFD700
FFE600FAFF0080FF0070FF0000FF0A51FF0000FFD100FF0A42FF0061FF0061FF0061FF00
14FF00000AFF00FF3800FF3800D1FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00002300FFEB00FF23FF0000FF579EFF00BDFF00BDFF00
BDFF008FFF0033FF00AEFF0014FF00DCFF00EBFF00DCFF00BDFF00FFD700FFC700FFC700
FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF9900FF9900FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFB800FFB800FFB800FFB800FFC700FFB800FFC700FFC700FFC700FFD700FFE600
FAFF00EBFF0000FF5700FF2861FF0070FF0023FF0000FF5723FF0033FF0042FF0042FF00
00FF28FF000000FF850066FF00F0FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF000033FF0080FF009EFF00AEFF00AEFF00
9EFF0080FF0000FF4742FF0000FF3800FFB3BDFF0080FF00FAFF00FFD700FFC700FFC700
FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00
FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FF9900FF9900FF9900FF9900
FF9900FFA800FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFD700FAFF00
51FF00CCFF009EFF0033FF008FFF009EFF0000FF1900FFFF0085FF00FF0A0085FF05FF00
00F0FFFF00D75100FFAE00FF0057FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF000000A3FF6100FF51FF0080FF009EFF009EFF009EFF00
00FF4700FFF000FF4714FF0014FF0005FF008FFF0051FF00FAFF00FFD700FFC700FFC700
FFB800FFC700FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900
FF9900FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00
FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00
FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFA800
FFA800FFA800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFD700FFE600FAFF00
00FF5780FF0080FF0000FF289EFF00AEFF0080FF0000FF28EB00FFFF001E00FF9400FF38
00FFC2FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF000000FFB305FF0023FF0000FF6680FF008FFF008FFF00
42FF0000FFF051FF0080FF009EFF008FFF0051FF00EBFF00FFE600FFD700FFC700FFC700
FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF8A00
FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFD700FFF500BDFF00
8FFF0042FF000057FF61FF00BDFF00BDFF00AEFF0080FF0000FF19FF006B00FFFF00FFA3
FF008AFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF000000C2FF00FF1900F0FFFF000061FF0080FF0070FF00
23FF0000FF1900FF9470FF00BDFF00CCFF00DCFF00FFF500FFD700FFD700FFC700FFC700
FFB800FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900
FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FF9900FF9900
FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFD700FAFF00BDFF00
DCFF00BDFF0033FF0000FF75CCFF00DCFF00CCFF009EFF0061FF0000FF0AFF009900A3FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF000000FFB300FF9400FF6600FF1951FF0070FF0061FF00
33FF0000FFB300FF2800FFA342FF00DCFF00FAFF00FFE600FFD700FFC700FFC700FFC700
FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00
FF7A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFD700FFE600FFF500
FFF500EBFF0005FF00DCFF00EBFF00DCFF00DCFF0061FF000057FF00FF38FF00000500FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000EB00FFFF000000F0FF00FF7533FF0033FF0042FF00
33FF0000FF0A00FF0A33FF0000FFA3BDFF00FFF500FFE600FFD700FFC700FFC700FFC700
FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF9900FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF6B00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00
FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF9900
FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF8A00FF8A00FF8A00FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFD700FFD700FFE600
FFE600FFF500EBFF00FAFF00EBFF00EBFF00DCFF00BDFF0042FF0000D1FF00FF9400FF85
00C2FFEB00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0AFF00D714FF00
00A3FF00FFD161FF0070FF0000B3FFBDFF00FFF500FFE600FFD700FFC700FFC700FFC700
FFB800FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF9900FF9900FF8A00FF8A00
FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00
FF8A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF9900
FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FFA800FF9900FF9900FF9900FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFD700FFE600
FFE600FFF500FFF500FFF500FAFF00FAFF00EBFF00CCFF009EFF008FFF0000A3FF14FF00
00FF75FF00E60019FF000AFF1400FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000D1FF00FF4700FF945100FF
0019FF51FF009EFF008FFF000019FFCCFF00FAFF00FFE600FFD700FFD700FFC700FFC700
FFC700FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FF9900FF9900FF9900FFA800FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00
FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF9900
FF9900FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FF9900FF9900FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFD700FFD700
FFE600FFE600FFE600FFF500FFF500FAFF00FAFF00DCFF00CCFF00BDFF0080FF0061FF00
00FF280085FF00FF472300FF0047FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFF0FF0000FF00F5
0019FF80FF00BDFF009EFF0042FF0000FF288FFF00FFE600FFD700FFC700FFC700FFC700
FFB800FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FF9900FF9900FFA800FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00
FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF8A00FF8A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF8A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00
FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF9900FF9900FF8A00FF8A00FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFA800FFA800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFD700FFD700
FFD700FFE600FFE600FFE600FFF500FFF500FAFF00EBFF00DCFF00CCFF00AEFF008FFF00
51FF0042FF0000FF6600FF85FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00D733FF00
80FF00BDFF00DCFF00BDFF0061FF008FFF00FAFF00FFE600FFD700FFC700FFC700FFC700
FFB800FFB800FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FFA800FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00
FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF8A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF9900FF9900
FF8A00FF9900FF9900FF9900FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FFA800FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFC700FFD700FFD700
FFD700FFE600FFE600FFE600FFF500FFF500FAFF00EBFF00DCFF00BDFF00AEFF008FFF00
70FF0051FF0000E1FF00FFD1FF004CFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF005CFF0000FF0000DC00FF0500FFFF000000FF4700FF28
00FF19CCFF00EBFF00EBFF00DCFF00FAFF00FFF500FFD700FFD700FFC700FFC700FFC700
FFB800FFB800FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00
FF7A00FF7A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF7A00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF9900FF9900FF8A00FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FF9900FF9900FF9900FFA800
FF9900FF9900FF9900FFA800FFA800FF9900FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFD700FFD700
FFD700FFD700FFE600FFE600FFF500FFF500FAFF00EBFF00CCFF008FFF0080FF0080FF00
70FF0042FF0000FF19FF00E6FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF000000E1FF0075FFFF007A00FF578000FFFF00A89EFF00
BDFF00EBFF00FAFF00FAFF00FFF500FFF500FFE600FFD700FFD700FFC700FFC700FFC700
FFB800FFB800FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FFA800FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF7A00
FF7A00FF7A00FF8A00FF8A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF8A00
FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFA800FFA800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFC700FFD700FFD700
FFD700FFD700FFE600FFE600FFF500FFF500FAFF00CCFF009EFF0000FF0A00FF5700FF57
51FF0042FF0014FF0000FF660047FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF000000FFB300FF1900FF0ADC00FF80FF009EFF00BDFF00
DCFF00EBFF00FAFF00FFF500FFF500FFE600FFD700FFD700FFD700FFC700FFC700FFC700
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00
FF7A00FF8A00FF8A00FF8A00FF7A00FF7A00FF8A00FF8A00FF8A00FF7A00FF8A00FF8A00
FF7A00FF7A00FF8A00FF7A00FF7A00FF8A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FFA800FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFB800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFC700FFC700FFD700
FFD700FFD700FFE600FFE600FFF500FFF500FAFF00FF000000FF0A14FF0000FF28FA00FF
33FF0033FF0000FF0A00FFB3FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000000AFF00FF940085FF51FF0070FF009EFF00BDFF00CCFF00
EBFF00FAFF00FFF500FFF500FFE600FFE600FFD700FFD700FFD700FFC700FFC700FFC700
FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FF9900FF9900FF9900
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFD700FFD700FFD700
FFD700FFD700FFE600FFE600FFE600FFF500FAFF00DCFF009EFF000057FF00FFF0000AFF
14FF0014FF0000FF6600F0FF000AFFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000019FF61FF0080FF009EFF00AEFF00CCFF00
EBFF00FAFF00FFF500FFF500FFE600FFE600FFD700FFD700FFC700FFC700FFC700FFC700
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFA800FFB800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900FFA800FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF9900FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FFA800FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FF9900FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFD700FFD700
FFD700FFD700FFE600FFE600FFE600FFF500FAFF00EBFF00AEFF0000FF94DC00FF00FF57
00FF0A00FF0A00FF66FF002EFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00005100FF23FF0051FF0061FF0061FF0000FFE1FA00FF
DCFF00FAFF00FFF500FFF500FFE600FFE600FFD700FFD700FFC700FFC700FFC700FFC700
FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF8A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00
FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF9900FF8A00
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FFA800FF9900FF9900FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFB800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFC700FFC700FFD700FFD700
FFD700FFD700FFE600FFE600FFE600FFF500FAFF00DCFF0000FF3805FF00FF00A800FF94
00FF470019FF00FFA3FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF000000FFE1FF000014FF0042FF000038FFBD00FF00FF9400FF19
BDFF00DCFF00FFF500FFE600FFE600FFD700FFD700FFD700FFC700FFC700FFC700FFC700
FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFA800FFA800FFB800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FF9900FF9900FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00
FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FFA800FF9900FF9900FF9900FFA800FF9900FF9900FFA800FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFB800FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFC700FFB800FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFD700FFD700
FFD700FFD700FFE600FFE600FFE600FFF500FAFF00BDFF0061FF0000FF4761FF0000FF19
FF00B83300FF0085FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF006BFF000000A3FF00FF0A23FF0000FF9400FF5723FF000085FF
00FF0ABDFF00FFF500FFE600FFE600FFD700FFD700FFD700FFC700FFC700FFC700FFC700
FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FF9900FF9900FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00
FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900FFA800FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FF9900
FF9900FF9900FFA800FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800
FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFD700FFD700
FFD700FFD700FFE600FFE600FFE600FFF500FAFF0051FF0023FF0000FFC28FFF0080FF00
23FF002300FFFF00C7FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF000000FF2805FF0000FF47FF0000FF009970FF00
9EFF00EBFF00FFF500FFE600FFE600FFD700FFD700FFD700FFD700FFD700FFC700FFC700
FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FF9900FFA800FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FF9900FF9900FF9900FF9900FFA800FF9900FF9900FF9900FF9900FF9900
FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFD700
FFD700FFD700FFE600FFE600FFF500FFF500FAFF0000FF0A8FFF0014FF00AEFF00AEFF00
00FFA30075FFFF000000FFC2FF000000FFFFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000047FFFF000000FF4700FF57FF0000FF001EBDFF00
EBFF00FAFF00FFF500FFE600FFE600FFD700FFD700FFD700FFD700FFC700FFC700FFC700
FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900FFA800FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800
FFA800FFA800FFA800FFA800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FF9900FFA800FF9900FF9900FF9900FF9900FF9900
FFA800FF9900FF9900FF9900FF9900FF9900FF9900FFA800FF9900FF9900FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFB800FFB800
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFD700
FFD700FFD700FFE600FFE600FFF500FFF500FAFF00EBFF00DCFF00BDFF00CCFF00BDFF00
8FFF0080FF0042FF0014FF0000FF19AE00FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF000000E1FF00FF1951FF0000B3FFCCFF00
EBFF00FFF500FFF500FFE600FFE600FFE600FFD700FFD700FFD700FFD700FFC700FFC700
FFC700FFC700FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFA800FFA800FFA800FFA800FFA800FFB800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900FFA800FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF8A00FF8A00FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FFA800FF9900FFA800FF9900FFA800FFA800FFA800
FFA800FFA800FFB800FFB800FFC700FFC700FFB800FFB800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900FF9900FFA800FF9900FF9900
FFA800FF9900FF9900FFA800FF9900FF9900FF9900FFA800FF9900FF9900FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFB800FFB800FFB800FFB800
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFD700FFD700
FFD700FFD700FFE600FFE600FFF500FFF500FAFF00FAFF00EBFF00DCFF00DCFF00CCFF00
BDFF009EFF0070FF0033FF0005FF0000FF66FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000EB00FF0038FF8000FF2300FF00FF0A8FFF0070FF0005FF0070FF00
FAFF00FFF500FFF500FFE600FFE600FFD700FFD700FFD700FFD700FFC700FFC700FFC700
FFC700FFC700FFC700FFB800FFB800FFC700FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFA800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900
FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00
FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900
FF9900FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF7A00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FF9900FF9900
FFA800FF9900FF9900FF9900FF9900FFA800FF9900FFA800FFA800FFA800FFA800FFA800
FFA800FFB800FFB800FFC700BDFF00FFE600FFD700FFB800FFB800FFB800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900FFA800
FFA800FF9900FF9900FFA800FFA800FF9900FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFD700FFD700
FFE600FFE600FFE600FFE600FFF500FFF500FFF500FAFF00FAFF00EBFF00EBFF00DCFF00
BDFF0000FFE100FFC21400FF00FF0A00FF4700F0FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF000000FFB300FF758000FF0057FF42FF00BDFF00BDFF00BDFF00DCFF00
FAFF00FFF500FFE600FFE600FFE600FFD700FFD700FFD700FFD700FFD700FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FF9900FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900
FFA800FFA800FFB800FFB800FFA800FFA800FFA800FF9900FF9900FF9900FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FFA800FFA800FFA800FF9900FF9900FFA800FF9900FF9900
FFA800FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFB800FFB800FFD700DCFF009EFF00FFF500FFC700FFB800FFB800FFB800FFB800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFA800FFB800
FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFB800FFC700FFC700
FFC700FFC700FFC700FFC700FFD700FFC700FFC700FFD700FFD700FFD700FFD700FFD700
FFD700FFE600FFE600FFE600FFE600FFF500FFF500FAFF00FAFF00EBFF00EBFF00DCFF00
BDFF0000FF1900FF4700F0FF00FF3800FF669E00FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF000000FF4723FF0051FF008FFF00BDFF00CCFF00DCFF00EBFF00FAFF00
FAFF00FFF500FFE600FFE600FFE600FFE600FFD700FFD700FFD700FFD700FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFB800FFC700FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFA800FFA800FFB800FFA800FFB800FFA800
FFB800FFA800FFA800FFB800FFB800FFA800FFA800FFA800FFB800FFA800FFA800FFA800
FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF9900FF9900FF9900FF9900FF9900FFA800
FFA800FAFF009EFF00DCFF00FFC700FFC700FFD700FFA800FF9900FF9900FF9900FF9900
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800
FFB800FFB800FFC700FFD700EBFF0000FF0AFFE600FFD700FFC700FFC700FFB800FFB800
FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFB800FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFD700FFD700FFD700
FFE600FFE600FFE600FFE600FFE600FFF500FFF500FAFF00FAFF00EBFF00EBFF00DCFF00
CCFF009EFF0000FFA300B3FF00FF750085FFFF008AFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000047FFFF005C00FF1900FF0A00FFFF70FF00BDFF00DCFF00EBFF00EBFF00FAFF00
FFF500FFF500FFE600FFE600FFE600FFD700FFD700FFD700FFD700FFD700FFD700FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFB800FFC700FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00
FF9900FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF9900FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800
FFA800FFC700FFE600EBFF00FFE600FFE600FFE600FFB800FFA800FF9900FF9900FF9900
FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF9900FF8A00FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFA800FFB800FFB800
FFB800FFC700FFC700FFE600FAFF0051FF00FFF500FFF500FFD700FFC700FFC700FFC700
FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFA800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700
FFB800FFB800FFC700FFB800FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFD700FFC700FFD700FFD700FFD700FFD700FFD700FFD700FFD700
FFE600FFE600FFE600FFE600FFF500FFF500FFF500FFF500FAFF00FAFF00EBFF00EBFF00
CCFF008FFF0000FF3800FF660057FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF000000FFC200FF38CC00FF00FF750028FFAEFF00DCFF00EBFF00FAFF00FAFF00
FFF500FFF500FFE600FFE600FFE600FFE600FFD700FFD700FFD700FFD700FFD700FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFA800FFA800
FFA800FFA800FFA800FFA800FF9900FFA800FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF9900
FF9900FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00
FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800
FFA800FFB800FFC700FFE600FAFF00AEFF00FFF500FFD700FFA800FFA800FF9900FF9900
FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00
FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800
FFA800FFA800FFB800FFB800FFE600FFC700FFB800FFB800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFC700FFC700FFD700FFE600AEFF009EFF00DCFF008FFF00FFE600FFD700FFD700FFD700
FFC700FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFD700FFD700FFD700FFD700FFD700FFE600FFD700FFE600
FFE600FFE600FFE600FFE600FFF500FFF500FFF500FFF500FAFF00FAFF00EBFF00EBFF00
CCFF0000FFC200FF6651FF0033FF00FF0000FF0000FF00000094FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF000000E1FF00FF750047FF00FFD1FF006B9EFF00DCFF00EBFF00FAFF00FAFF00
FFF500FFF500FFF500FFE600FFE600FFE600FFD700FFD700FFD700FFD700FFD700FFD700
FFD700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFB800FFB800FFB800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF8A00FF8A00FF8A00FF9900FF9900FF8A00FF8A00FF8A00FF9900FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF9900FF8A00
FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800
FFA800FFB800FFC700FFD700FFF500BDFF00FAFF00FFD700FFB800FFA800FFA800FF9900
FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00
FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF9900FF9900FF9900FFA800FFA800FFA800FFB800FFB800FFB800
FFB800FFB800FFB800FFC700FFF500FFE600FFC700FFB800FFB800FFB800FFB800FFA800
FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700
FFC700FFE600DCFF00EBFF00DCFF0000FF5770FF00BDFF00FAFF00FFF500DCFF0070FF00
FFC700FFB800FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFB800FFA800FFB800FFB800FFB800FFB800FFB800FFC700FFB800
FFB800FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFE600FFE600
FFE600FFE600FFE600FFE600FFF500FFF500FFF500FFF500FAFF00FAFF00EBFF00EBFF00
DCFF0000FF75000AFF8FFF0080FF0051FF0014FF0000FF3800FFD1FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000EB00FF00FFFF00FF94AEFF00CCFF00EBFF00EBFF00FAFF00FAFF00
FFF500FFF500FFF500FFE600FFE600FFE600FFE600FFD700FFD700FFD700FFD700FFD700
FFD700FFD700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFB800FFC700
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFC700FFC700BDFF00EBFF00FFE600FFC700FFC700FFB800FFB800
FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF9900FF8A00FF8A00
FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800
FFA800FFB800FFC700FFD700FAFF00CCFF00FFE600FFC700FFB800FFA800FFA800FFA800
FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF9900FF9900FF9900FF9900FFA800FFB800FFB800FFE600FFD700FFC700
FFC700FFC700FFC700FFE600BDFF00AEFF00CCFF00FFC700FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700
FFD700FFF50000FFD170FF00AEFF0061FF0023FF008FFF0051FF00DCFF0000FF578FFF00
FFD700FFC700FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFB800FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFD700
FFC700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFE600FFE600
FFE600FFE600FFE600FFF500FFF500FFF500FFF500FAFF00FAFF00FAFF00EBFF00EBFF00
DCFF00CCFF00BDFF00AEFF009EFF0080FF00FF000000FFA300FF94000AFFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
5100FF00FF8500FFF000FFB370FF0000FFC2BDFF00DCFF00EBFF00EBFF00FAFF00FAFF00
FFF500FFF500FFF500FFE600FFE600FFE600FFE600FFE600FFD700FFD700FFD700FFD700
FFD700FFD700FFD700FFC700FFC700FFD700FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFC700FFC700FFC700FFD700FFF50061FF008FFF00FFE600FFD700FFC700FFB800
FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FF9900FFA800FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF9900FF9900FF9900FF8A00
FF8A00FF9900FF9900FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FF9900FFA800FFA800FFA800
FFA800FFB800FFB800FFD700DCFF00DCFF00FFF500FFC700FFC700FFB800FFA800FFA800
FFA800FFA800FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00
FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF9900FF9900FF9900FFA800FFB800FFF500FFE600DCFF00FFE600FFD700
FFD700BDFF00FFE600FFF50070FF00FAFF00FFF500FFC700FFC700FFB800FFB800FFB800
FFB800FFB800FFB800FFC700FFB800FFB800FFB800FFC700FFB800FFC700FFC700FFC700
FFD700FFE600EBFF00CCFF0033FF0000FF197000FF8FFF009EFF0061FF009EFF00BDFF00
FFE600FFC700FFB800FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFA800FFA800FFA800FFA800FFB800
FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFD700FFD700
FFD700FFD700FFD700FFC700FFC700FFD700FFD700FFD700FFD700FFE600FFD700FFD700
FFD700FFD700FFC700FFC700FFC700FFC700FFC700FFC700FFD700FFC700FFC700FFD700
FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFE600FFE600FFE600
FFE600FFE600FFF500FFF500FFF500FFF500FAFF00FAFF00FAFF00FAFF00EBFF00EBFF00
DCFF00CCFF00CCFF00BDFF00AEFF0000FF940094FFFF007A00FFC2FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00995100FF
00FF6600FF4761FF008FFF00AEFF00AEFF00CCFF00DCFF00EBFF00EBFF00FAFF00FAFF00
FFF500FFF500FFF500FFF500FFE600FFE600FFE600FFE600FFE600FFD700FFD700FFD700
FFD700FFD700FFD700FFD700FFD700FFD700FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFB800FFC700FFB800FFB800FFB800FFB800FFC700FFB800FFB800
FFC700FFC700FFC700FFC700FFD700FFF500DCFF00BDFF0000FF5780FF00FFD700FFC700
FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800
FFB800FFB800FFB800FFC700FFE6009EFF0000FF28FFD700FFC700FFB800FFB800FFB800
FFF500FFB800FFA800FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF9900FF9900FF9900FF9900FFA800FFB800FFF500DCFF00AEFF00FAFF00FFE600
FFF500CCFF00FAFF00EBFF0070FF00FFF500FFE600FFD700FFC700FFC700FFB800FFC700
FFB800FFB800FFC700FFC700FFD700FFC700FFC700FFC700FFC700FFC700FFC700FFD700
FFD700FFE600FFF500EBFF00BDFF009EFF0000FFB3AEFF00DCFF00DCFF00EBFF00DCFF00
FFD700FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFD700FFF500FFE600FFE600
00D1FFFFE600FFD700FFD700FFD700FFD700FFD700FFD700FFF50042FF00FFF500FFE600
FFD700FFD700FFD700FFD700FFD700FFD700FFC700FFD700FFD700FFD700FFD700FFD700
FFD700FFD700FFD700FFD700FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFF500FFF500FFF500FFF500FFF500FAFF00FAFF00FAFF00EBFF00EBFF00
DCFF00DCFF00CCFF00BDFF00AEFF009EFF00FF005CFF0000FF007AFF00A8FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFFF
00FFB300B3FF00FFA39EFF00BDFF00CCFF00DCFF00DCFF00EBFF00EBFF00FAFF00FAFF00
FFF500FFF500FFF500FFF500FFF500FFE600FFE600FFE600FFE600FFE600FFD700FFD700
FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFD700FFE600FFF500CCFF0080FF0000E1FFCCFF00FFE600FFC700
FFC700FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FFA800FF9900FFA800FFA800FFA800FFA800
FFB800FFB800FFB800FFC700FFD700DCFF009EFF00FAFF00FFD700FFC700FFC700FFC700
FFF500FFC700FFA800FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF8A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00
FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF9900FF9900FF9900FFA800FFA800FFC7008FFF00EBFF0042FF00AEFF00
CCFF00BDFF00BDFF0080FF00EBFF00FFF500FFE600FFD700FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFE6008FFF00FFE600FFD700FFD700FFD700FFD700FFD700FFD700
FFD700FFE600FFF500EBFF00DCFF009EFF0023FF00CCFF00EBFF00FAFF00FFF500FFE600
FFD700FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFA800
FFA800FFB800FFA800FFA800FFA800FFA800FFB800FFA800FFA800FFB800FFA800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFE60023FF00CCFF00BDFF00
00FF38FFF500FFE600FFE600FFE600FFE600FFE600FFE600FAFF0000FFD1BDFF00FFF500
FFE600FFE600FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700
FFD700FFD700FFD700FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFF500FFF500FFF500FFF500FFF500FFF500FAFF00FAFF00FAFF00EBFF00EBFF00EBFF00
DCFF00DCFF00CCFF00CCFF00BDFF009EFF0000FFB333FF0000C2FFDC00FF00FFA30094FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF007A
00D1FF00FFFF00C2FFAEFF00BDFF00CCFF00DCFF00DCFF00EBFF00EBFF00FAFF00FAFF00
FAFF00FFF500FFF500FFF500FFF500FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFD700FFD700FFE600CCFF0042FF0005FF0000FFA38FFF00FAFF00FFD700
FFC700FFC700FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FF9900FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800
FFB800FFB800FFB800FFC700FFD700FAFF00EBFF0061FF00FAFF00FFD700FFD700FFE600
8FFF00FFE600FFA800FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900
FF8A00FF9900FF9900FF9900FF9900FFA800FFA800FFC700FFD700FFE600FFF500EBFF00
AEFF0042FF0061FF00BDFF00EBFF00FFF500FFE600FFD700FFD700FFC700FFC700FFC700
FFC700FFC700FFD700FFF5000500FFAEFF0014FF00FFE600FFD700FFD700FFD700FFE600
FFE600FFF500FAFF00EBFF00CCFF0042FF0080FF00BDFF00EBFF00FFF500FFE600FFE600
FFD700FFC700FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFA800FFB800FFB800FFA800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFD700FFE600EBFF0051FF0000A3FF
80FF00EBFF00FFF500FAFF00FFF500FFF500FFF500CCFF009EFF0000FF2833FF0000D1FF
FFF500FFE600FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF500FFE600FFF500FFF500
FFF500FFF500FFF500FFF500FFF500FAFF00FAFF00FAFF00FAFF00EBFF00EBFF00EBFF00
DCFF00DCFF00CCFF00CCFF00BDFF00AEFF0080FF0080FF0070FF00DC00FFFF00D700E1FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFFF00FF85FF0000
51FF0000FFE19EFF00BDFF00BDFF00CCFF00DCFF00DCFF00EBFF00EBFF00EBFF00FAFF00
FAFF00FAFF00FFF500FFF500FFF500FFF500FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD700FFD700FFD700FFD700FFD700
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFD700FFD700FFE600FFF500EBFF00BDFF0080FF0061FF0051FF0000FFA3FFE600
FFC700FFC700FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800
FFB800FFB800FFC700FFC700FFD700FFE600FFF500DCFF00EBFF00FFF500FFF5000075FF
FFE600FFC700FFA800FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00
FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF9900FF9900FF9900FF9900FFA800FFA800FFB800FFC700FFC700FFE600FFF500
DCFF0000FF3842FF00CCFF00EBFF00FFF500FFE600FFE600FFE600FFD700FFD700FFD700
FFD700FFD700FFE60080FF0070FF0000FF57CCFF00FFF500FFE600FFE600FFE600FFE600
FFF500FFF500EBFF009EFF00BDFF0080FF0051FF0000FFF0DCFF00FFF500FFE600FFE600
FFD700FFD700FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFD700FFE600FAFF0080FF000057FF
80FF00CCFF00EBFF00AEFF0000FF57FAFF00FAFF00DCFF0080FF0000FF1900FF85CCFF00
FAFF00FFE600FFE600FFE600FFE600FFD700FFD700FFD700FFD700FFD700FFE600FFE600
FFE600FFE600FFE600FFF500FFF500FFF500FFF500FFF500FFF500FFF500FFF500FFF500
FFF500FFF500FFF500FFF500FAFF00FAFF00FAFF00FAFF00EBFF00EBFF00EBFF00DCFF00
DCFF00DCFF00CCFF00BDFF00BDFF00AEFF009EFF008FFF0080FF0023FF000047FFFF0000
FF0000AE00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFFF0085FF51FF00
80FF008FFF00AEFF00BDFF00CCFF00CCFF00DCFF00DCFF00EBFF00EBFF00EBFF00FAFF00
FAFF00FAFF00FAFF00FFF500FFF500FFF500FFF500FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFF500FAFF0051FF00FFF500FFE600FFE600FFD700FFD700FFD700
FFD700FFD700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFD700
FFD700FFD700FFD700FFE600FFF500FAFF00DCFF0000FF2870FF00CCFF00EBFF00FFE600
FFD700FFC700FFC700FFC700FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFB800
FFB800FFB800FFC700FFC700FFD700FFE600FFF500EBFF0061FF00FAFF00EBFF00FAFF00
FFD700FFB800FFA800FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF9900FF9900FF9900FF9900FFA800FFA800FFB800FFB800FFC700FFE600FFF500
9EFF00AEFF0042FF0023FF00DCFF00EBFF00FAFF00FFF500FFE600FFD700FFD700FFD700
FFD700FFD700FFE600EBFF00BDFF0080FF00DCFF00FAFF00FFF500FFE600FFF500FAFF00
FAFF00EBFF00AEFF0042FF008FFF0080FF0000FF5723FF00CCFF00FFF500FFE600FFD700
FFD700FFD700FFC700FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFD700FFE600CCFF0000FFD170FF00
14FF00AEFF00CCFF008FFF0070FF00CCFF00CCFF00CCFF008FFF0000FF4780FF00CCFF00
FAFF00FFF500FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFF500FFF500FFF500FFF500FFF500FFF500FAFF00FAFF00FAFF00FFF500FFF500FFF500
FAFF00FFF500FAFF00FAFF00FAFF00FAFF00FAFF00EBFF00EBFF00EBFF00EBFF00DCFF00
DCFF00DCFF00CCFF00CCFF00BDFF00AEFF00AEFF009EFF008FFF00FF00000094FF0038FF
00FF8500D1FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000047FFFF0000FF000000B3FF33FF00
8FFF009EFF00AEFF00BDFF00CCFF00CCFF00DCFF00DCFF00EBFF00EBFF00EBFF00EBFF00
FAFF00FAFF00FAFF00FAFF00FAFF00FFF500FFF500FFF500FFF500FFF500FFF500FFF500
FFE600FFE600FFF500FFF500EBFF0000FF2800FF66FAFF00FFE600FFE600FFD700FFD700
FFD700FFD700FFD700FFD700FFC700FFC700FFC700FFC700FFD700FFD700FFD700FFD700
FFD700FFE600FFE600FFE600FFF500FAFF00DCFF0051FF0070FF00DCFF00FAFF00FFE600
FFE600FFD700FFC700FFC700FFC700FFB800FFB800FFB800FFB800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FFA800FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFB800
FFB800FFB800FFC700FFC700FFD700FFE600FFF500EBFF00CCFF00BDFF00BDFF00FFF500
FFC700FFB800FFA800FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00
FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFB800FFB800FFC700EBFF00EBFF00
14FF00DCFF00DCFF009EFF009EFF0042FF00EBFF00DCFF00FAFF00FFE600FFE600FFE600
FFE600FFE600FFF500FAFF008FFF0000FF2880FF00FAFF00FFF500FFF500FFF500DCFF00
9EFF00AEFF00AEFF0005FF0000FF2833FF0051FF008FFF0061FF00FFF500FFE600FFD700
FFD700FFD700FFC700FFC700FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFC700FFC700FFC700FFC700FFC700FFD700FFE600DCFF0023FF00BDFF00
0075FF23FF008FFF0005FF0000FF2870FF0061FF008FFF0023FF0005FF00AEFF00DCFF00
FAFF00FFF500FFF500FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF500
DCFF0051FF0000FFE1EBFF00FAFF00FAFF00CCFF00DCFF00FAFF00FAFF00FAFF00FAFF00
FAFF00FAFF00FAFF00FAFF00EBFF00EBFF00EBFF00EBFF00EBFF00EBFF00DCFF00DCFF00
DCFF00CCFF00CCFF00CCFF00BDFF00AEFF009EFF009EFF008FFF0070FF0061FF0042FF00
FF00000075FFFF0000FF00A8FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000000AFF00FF1942FF0000FF2880FF00
9EFF00AEFF00AEFF00BDFF00CCFF00CCFF00DCFF00DCFF00DCFF00EBFF00EBFF00EBFF00
EBFF00FAFF00FAFF00FAFF00FAFF00FAFF00FAFF00FFF500FFF500FFF500FFF500FFF500
FFF500FFF500FAFF00FAFF00CCFF0023FF00FF0000BDFF00FFF500FFE600FFE600FFE600
FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700
FFE600FFE600FFF500FAFF00FAFF00EBFF00CCFF0000FF940094FFCCFF00FAFF00FAFF00
FFE600FFE600FFE600FFE600FFE600FFC700FFB800FFB800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FF9900FF9900FFA800FF9900FF9900FFA800FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FFA800FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFA800FFB800
FFB800FFB800FFC700FFC700FFD700FFE600FFF500EBFF00AEFF0070FF00EBFF00FFF500
FFD700FFC700FFA800FFA800FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF6B00FF6B00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFB800FFC700FAFF0014FF00
EBFF00FAFF00EBFF00BDFF0023FF009EFF00BDFF0080FF0080FF00FFF500FFF500FFF500
FFE600FFF500FFF500EBFF00BDFF0000FF94AEFF00EBFF00FAFF00FAFF00EBFF00CCFF00
00FF5742FF0000FF190094FFFF000000FFD19EFF00CCFF00FAFF00FFF500FFE600FFE600
FFD700FFD700FFC700FFC700FFC700FFC700FFC700FFC700FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFC700FFC700FFC700FFC700FFD700FFD700FFE600FFF500EBFF00CCFF00
8FFF0000FF9433FF0033FF0000FF0A00FFD151FF0000FF0A000AFFFF0000BDFF00CCFF00
EBFF00EBFF00FFF500FFF500FFE600FFE600FFE600FFE600FFE600FFE600FFF500FFF500
DCFF00000AFF05FF00BDFF00CCFF00CCFF0000FF0A00FF85DCFF00EBFF00FAFF00FAFF00
FAFF00FAFF00FAFF00EBFF00EBFF00EBFF00EBFF00DCFF00DCFF00DCFF00DCFF00DCFF00
CCFF00CCFF00CCFF00BDFF00BDFF00AEFF00AEFF009EFF008FFF0080FF0070FF0051FF00
2300FF00FF0A00FF750075FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FA00FFFF0000FF00000094FF61FF0070FF008FFF00
9EFF00AEFF00AEFF00BDFF00BDFF00CCFF00CCFF00DCFF00DCFF00DCFF00EBFF00EBFF00
EBFF00EBFF00EBFF00EBFF00DCFF00EBFF00FAFF00FAFF00FAFF00FFF500FFF500FFF500
FFF500FAFF00FAFF00EBFF00CCFF0070FF0042FF000066FFEBFF00FFF500FFF500FFE600
FFE600FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFE600FFE600
FFF500CCFF00EBFF008FFF00EBFF00DCFF00BDFF0080FF0000F0FF33FF00DCFF0070FF00
00FF47FFF500FFF500FAFF0000F0FFFFD700FFC700FFB800FFB800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900
FFA800FF9900FF9900FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FF9900
FF9900FFA800FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800
FFB800FFC700FFC700FFD700FFD700FFF500FAFF00AEFF00BDFF00CCFF0000FF289EFF00
FFF500FFF500FFB800FFA800FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFB800FFC7009EFF00AEFF00
FFF500FFF500FAFF0080FF0000FFC205FF0000FF1914FF00CCFF00EBFF00FAFF00DCFF00
FAFF00FFF500FAFF00DCFF0070FF0000FF388FFF00CCFF00EBFF00EBFF00DCFF0042FF00
00FF3800FF1905FF0000FF9400FF4761FF00AEFF00EBFF00FAFF00FFF500FFE600FFE600
FFD700FFD700FFC700FFC700FFC700FFC700FFC700FFC700FFB800FFB800FFB800FFB800
FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFE600FFF500FAFF00CCFF00
AEFF0051FF00FF008A05FF0000FFA3FF000000D1FFFF000042FF0080FF009EFF0014FF00
BDFF0070FF00FAFF00FFF500FFF500FFE600FFE600FFE600FFF500FFF500FFF500FAFF00
CCFF0033FF0000FF3842FF0000FF0A9EFF0023FF000075FFCCFF00DCFF00EBFF00EBFF00
EBFF00EBFF00DCFF00DCFF00DCFF00DCFF00CCFF00DCFF00DCFF00DCFF00DCFF00CCFF00
CCFF00BDFF00BDFF00BDFF00BDFF00AEFF009EFF009EFF008FFF0080FF0070FF0061FF00
42FF0033FF0000FF19FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF000000FF7523FF0051FF0070FF0080FF008FFF00
9EFF009EFF00AEFF00BDFF00BDFF00BDFF00CCFF00CCFF00CCFF00DCFF00DCFF00DCFF00
DCFF00DCFF00DCFF00CCFF0000FF0A9EFF00EBFF00FAFF00FAFF00FAFF00FAFF00FAFF00
FAFF00FAFF00DCFF0051FF0061FF0070FF0000FF0A9EFF008FFF00DCFF0000FF94FFF500
FFE600FFE600FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFE600FFE600EBFF00
00FF6614FF0023FF0000FF0ABDFF00CCFF00BDFF0005FF0005FF0023FF00BDFF0080FF00
61FF00EBFF00DCFF0080FF008FFF00FFE600FFC700FFB800FFB800FFB800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900FFA800FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800
FFB800FFC700FFC700FFD700FFF500FFF500CCFF0033FF00DCFF00FAFF00EBFF00DCFF00
CCFF00FFE600FFB800FFA800FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF7A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFB800FFB800FFD700FFD700
FFD700FFE600FFE600FAFF00EBFF00AEFF0000FFD1FF00009EFF008FFF00BDFF009EFF00
EBFF00FAFF00EBFF00DCFF0070FF0000FF3851FF00BDFF00DCFF00DCFF00CCFF00AEFF00
61FF0000FF0A80FF0000FF7500FF4700FF4780FF00EBFF00FFF500FFF500FFE600FFE600
FFD700FFD700FFD700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700
FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFE600FFE600FFF500EBFF0051FF00
80FF0051FF0000FF19FF00D7FF005C00FFFF2300FF00FF1933FF0051FF0080FF0051FF00
0066FF61FF00EBFF00FAFF00FFF500FFF500FFF500FFF500FFF500FFF500FAFF00FAFF00
DCFF009EFF0000FF6600FF4700FFF0CC00FF00FFE161FF009EFF00CCFF00EBFF00DCFF00
EBFF00DCFF00CCFF00FF0000AEFF00BDFF00FF0000BDFF00CCFF00CCFF00CCFF00BDFF00
BDFF00BDFF00BDFF00AEFF00AEFF00AEFF009EFF009EFF008FFF0080FF0070FF0061FF00
51FF0042FF0023FF0000FF0A00F0FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00009E00FFFF000000FF2823FF0042FF0061FF0070FF0080FF008FFF00
8FFF009EFF00AEFF00AEFF00AEFF00BDFF00BDFF00BDFF00BDFF00CCFF00CCFF00DCFF00
DCFF00DCFF00CCFF00BDFF00FF0000FF00B8CCFF00DCFF00EBFF00FAFF00FAFF00FAFF00
FAFF00EBFF00FF00000038FF33FF0051FF0000FFFF00FF3800FF4780FF0000FF75FAFF00
FFF500FFE600FFE600FFE600FFD700FFD700FFD700FFD700FFE600FFE600FFF500CCFF00
0066FF05FF0000FFF042FF009EFF00AEFF00AEFF008FFF0000FFE100FF0A80FF0000FFB3
AEFF00CCFF00CCFF0061FF0000A3FFFFF500FFC700FFB800FFB800FFB800FFB800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FFA800FF9900FF9900FFA800FF9900FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800
FFC700FFC700FFD700FFE6009EFF00EBFF00CCFF009EFF00FAFF00FFF500FFE600FFE600
FFE600FFC700FFA800FFA800FF9900FF9900FF9900FF8A00FF9900FF8A00FF8A00FF8A00
FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFB800FFC700FFC700
FFD700FFD700FFE600FFE600FAFF00AEFF0000FF1961FF0033FF0042FF0000FFC2BDFF00
DCFF00EBFF00EBFF00CCFF008FFF00FA00FF8FFF00BDFF00CCFF00CCFF00BDFF008FFF00
0047FF23FF008FFF009EFF009EFF0023FF00BDFF00EBFF00FAFF00FFF500FFE600FFE600
FFD700FFD700FFD700FFD700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFD700FFD700FFD700FFE600FFF500FAFF00CCFF0000FFB3
00FF4700FFF000FFFF00FFB3FF0000FF000000FFA30075FF00FF66FF00C700FF2823FF00
00FFD100FF28BDFF00FAFF00FAFF00FFF500FFF500FFF500FAFF00FAFF00FAFF00EBFF00
CCFF008FFF00FF000000B3FFFF0000FF000000FF8500FF66FF0000BDFF00DCFF00DCFF00
DCFF00CCFF00AEFF0000FF19FF000014FF00FF00008FFF00BDFF00BDFF00BDFF009EFF00
9EFF009EFF009EFF00AEFF009EFF009EFF008FFF008FFF0080FF0080FF0070FF0061FF00
51FF0042FF0033FF0014FF0000FF1900FF38FF00002300FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF000000FF4700FF0A14FF0033FF0042FF0051FF0061FF0070FF0080FF00
8FFF008FFF008FFF009EFF00AEFF00AEFF00AEFF00AEFF000094FF9EFF00BDFF00CCFF00
CCFF00CCFF009EFF000019FF14FF0014FF00FF002ECC00FFDCFF00EBFF00EBFF00EBFF00
EBFF00DCFF00AEFF0033FF00FF001E00FFF000FF660057FF00FF94FF000F8FFF00EBFF00
FFF500FFF500FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF500EBFF00
AEFF0000FF1900FFA351FF0061FF0005FF0061FF0080FF0014FF006100FF42FF0000FF38
8FFF0023FF00FF000051FF0000FF19FFE600FFC700FFC700FFB800FFB800FFB800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FF9900FF9900FFA800FF9900FF9900FFA800FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FFA800FF9900FF9900FFA800FF9900FF9900FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800
FFC700FFC700FFE600EBFF00BDFF00AEFF0061FF0061FF00FFF500FFE600FFE600FFD700
FFC700FFB800FFA800FFA800FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900
FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFC700
FFC700FFD700FFD700FFE600FFF50033FF00AEFF00BDFF009EFF0000FF3833FF009EFF00
BDFF00CCFF00CCFF00CCFF009EFF0000FF0A42FF00AEFF00BDFF009EFF0080FF000038FF
00FF0A33FF009EFF00BDFF00BDFF00BDFF00EBFF00FAFF00FFF500FFF500FFE600FFE600
FFE600FFD700FFD700FFD700FFD700FFC700FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFB800FFC700FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFD700FFD700FFD700FFE600FFE600FFF500FAFF00DCFF0000FF85
00FF3800FF1900FFA300FFF0FF00A800B3FF0075FF0094FFFF000000FF75FF0000FF0000
05FF0051FF00AEFF00EBFF00FAFF00FAFF00FAFF00FAFF00FAFF00EBFF00DCFF00CCFF00
AEFF0000FFE100FFB30028FFFF00000047FF00FFC200FF1961FF00AEFF00CCFF00CCFF00
CCFF00BDFF009EFF0005FF00FF00005100FF2300FFFF0000AEFF00AEFF00AEFF0000FF75
FF000000FF8570FF008FFF008FFF0080FF0070FF0080FF0070FF0070FF0061FF0061FF00
51FF0042FF0033FF0014FF0005FF0000FF2800FF47FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00E600FF4700FF1905FF0014FF0033FF0042FF0051FF0061FF0061FF0070FF00
80FF0080FF0080FF00FF001E8FFF009EFF009EFF000085FF00FF4733FF0000F0FFBDFF00
BDFF00BDFF009EFF0023FF00FF00C7FF0000FF000051FF00CCFF00DCFF00DCFF00EBFF00
DCFF00DCFF00BDFF0070FF0023FF0000FF66FF0000FF0099FF0000FA00FF9EFF00EBFF00
FAFF00FFF500FFF500FFE600FFE600FFE600FFE600FFE600FFF500FFF500FFF500FAFF00
8FFF0080FF000057FF00FF282300FF00FFA300FF1951FF0033FF00FF000000FF1905FF00
00FFA300FF199EFF00DCFF00FAFF00FFE600FFC700FFC700FFC700FFB800FFB800FFB800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FF9900FFA800FFA800FF9900FFA800FFA800FF9900FFA800
FFA800FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFC700
FFC700FFD700FAFF00CCFF00AEFF009EFF00DCFF00FAFF00FFF500FFE600FFD700FFC700
FFB800FFB800FFA800FFA800FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFB800FFB800FFB800
FFC700FFC700FFD700FFE600FFE600EBFF00EBFF00DCFF0080FF0080FF0042FF0023FF00
00FF57AEFF00AEFF00AEFF008FFF007000FF00D1FF9EFF009EFF0023FF0000FFA300A3FF
00FFF00047FF9EFF00BDFF00CCFF00DCFF00EBFF00FAFF00FFF500FFF500FFE600FFE600
FFE600FFE600FFD700FFE600FFD700FFD700FFD700FFD700FFD700FFD700FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFD700FFD700FFE600FFE600FAFF0070FF00DCFF00CCFF00AEFF00
70FF0033FF0000D1FF0019FF00FFE1FF000000FF8500FF473300FF05FF000028FF00FFC2
80FF009EFF00CCFF00EBFF00FAFF00FAFF00FAFF00FAFF00EBFF00FF00000500FF00FF19
80FF0023FF0000FF75FF00003300FF3300FF8000FFFF009900A3FF9EFF00BDFF00BDFF00
23FF0000FF19FF00001400FFFF0000FF000FFF000000FFA38FFF008FFF0080FF00FF0000
FF0000FF000000FF0A80FF0070FF003300FF00FF8542FF0061FF00FF000000C2FF42FF00
33FF0023FF0014FF0005FF0000FF0A00FF2800FF3800FF5700FF9400FFD1FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000075FF00FFE1
00FF9400FF6600FF3800FF1900FF0A05FF0014FF0033FF0005FF0051FF0051FF00FF0000
51FF0070FF0000FF19AE00FF00FF8580FF008FFF0042FF000066FFFF000000FFA38FFF00
AEFF00AEFF0080FF0000D1FFFF0000FF005CFF000000FF479EFF000047FFCCFF00DCFF00
DCFF00CCFF0014FF00FF006BFF003DFF0000FF00008000FFFF000000F0FF00FF85CCFF00
DCFF00EBFF00FFF500FFF500FFE600FFF500FFE600FFE600FFF500FFF500FAFF00EBFF00
CCFF00BDFF000038FFEB00FF00FFFF00FF0A9E00FF0019FF00FF1900FF6600FF9400FF75
00FF1970FF00BDFF00EBFF00FFF500FFE600FFD700FFC700FFC700FFB800FFB800FFB800
FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFC700
FFC700FFD700FFE600FAFF00BDFF00AEFF00DCFF00FAFF00FFF500FFE600FFD700FFC700
FFB800FFB800FFA800FFA800FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900
FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800
FFC700FFC700FFC700FFD700FFE600FFF500FAFF00EBFF0000FF47BDFF0000FFE105FF00
0094FF14FF0080FF009EFF008FFF0023FF0042FF0080FF0080FF0051FF0000FFF000FF57
14FF0070FF00AEFF00CCFF00DCFF00EBFF00EBFF00FAFF00FFF500FFF500FFF500FFE600
FFE600FFE600FFE600FFD700FFD700FFD700FFD700FFD700FFD700FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700
FFD700FFC700FFD700FFD700FFE600FFE600FFF500DCFF0051FF0000FFC2AEFF0070FF00
00FF8500FF280047FFFF008A00FF850047FFFF000000FF2805FF0033FF0051FF0070FF00
9EFF00BDFF00CCFF00DCFF00EBFF00EBFF00EBFF00EBFF00EBFF00BDFF0000FF94CC00FF
00FF0AFF008AFF000000A3FF000AFFFF000000FFB3FA00FFFF002E80FF00AEFF00AEFF00
80FF00FF002E00FF47FF0000FF00007000FF5100FF14FF0070FF0051FF009E00FF00D1FF
FF0000FF00E600FF0A42FF000094FFFF00B8FF000005FF0000FF0AFF0000FF000014FF00
00F0FFCC00FF00FF19FF007A00FF3800FF5700FF5700FF7500FF9400FFC200FFF000D1FF
0085FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000066FF00C2FF00FFFF00FFC2
00FF9400FF8500FF5700FF389E00FF00FF19FF000005FF00FF00D700FF0A14FF00FF0000
DC00FF23FF0014FF00FF0000FF004C00FF6661FF0033FF00FF0000FF00002300FF00FF0A
00FF0A8FFF0080FF0000FF85FF00008000FFFF000000FF9405FF00FF0000AEFF00CCFF00
CCFF00AEFF00FF00C700FFE1FF0000FF000000FFFFFF0000FF00C700FF7542FF009EFF00
0094FF51FF00FAFF00FAFF00FFF500FFF500FFF500FFF500FFF500FFF500FAFF00EBFF00
DCFF00CCFF009EFF0061FF0000FF6642FF00FF000000FFA3FF0000FF00003300FF00FF94
00FFD100FF578FFF0080FF00FFF500FFE600FFD700FFC700FFC700FFB800FFB800FFB800
FFB800FFA800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFC700FFC700
FFD700FFE600FFF500FAFF0070FF00AEFF00BDFF00FAFF00FFF500FFE600FFD700FFC700
FFB800FFB800FFA800FFA800FFA800FF9900FF9900FF9900FF8A00FF9900FF8A00FF8A00
FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00
FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFB800FFB800FFB800
FFB800FFC700FFC700FFD700FFD700FFE600FFF500FAFF00EBFF00DCFF00CCFF0070FF00
42FF0000FF2814FF0070FF0070FF00EB00FF05FF0061FF00FF002E00FF2814FF0033FF00
23FF009EFF00BDFF00CCFF00DCFF00EBFF00EBFF00FAFF00FFF500FFF500FFF500FFF500
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD700FFD700FFD700FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFD700
FFC700FFD700FFD700FFD700FFE600FFF500CCFF0000FFC200FF6600A3FF70FF0000FFF0
00F0FF0047FFFF000000FF3800FF750085FF1400FF00FF6600FF2833FF0061FF0080FF00
9EFF00AEFF00CCFF00DCFF00DCFF00EBFF00EBFF00EBFF00DCFF00BDFF0014FF0000FF75
0075FF00FFF0FF002E00FFB3FF0000FF005CFF000000FF2833FF0080FF009EFF008FFF00
1400FF00FF94FF000000F0FF0066FFFF000000FFFF8F00FF51FF001400FFFF00000075FF
FF00000019FF00FF19FF00004200FFFF0000CC00FF00FF47FF0000FF003D3300FF0066FF
FF000000FFE1FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000BD00FFEB00FFFF00F5FF003DFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000AE00FFFF00003300FFFF0000FF0000FF0000
FF0000FF0000FF00C7FF0000FF00008000FFFF0000FF0000BD00FFFF0000FF0000FF0000
FF00005100FF00FF289E00FFFF0000FF00006100FF14FF00FF0000FF00002300FFFF0000
FF000061FF0051FF0000FFF000FFF0FF000000B3FFFF00008000FF00FFC200D1FFAEFF00
BDFF00AEFF0070FF0033FF0000FF1900FF75FF00004200FF00FFC2FF00000500FF33FF00
00E1FF0085FFEBFF00FAFF00FFF500FFF500FFF500FFF500FFF500FAFF00FAFF00EBFF00
DCFF00CCFF00AEFF008FFF0070FF0061FF0000FF0A00FF0A00FF4700FF9400F0FF00FF85
00FFB300FF0A00FF9461FF00FFF500FFE600FFD700FFD700FFC700FFC700FFB800FFB800
FFB800FFB800FFB800FFA800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700
FFE600FFF500FAFF00DCFF0042FF0042FF0000FF28DCFF00FAFF00FAFF00FFD700FFC700
FFB800FFB800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFB800FFB800
FFB800FFC700FFD700FFD700FFD700FFE600FFE600FFF500FAFF00EBFF00DCFF009EFF00
00FF3861FF0000FFFF0057FF33FF0014FF0005FF0023FF0000FF8500FFC233FF0070FF00
42FF00AEFF00CCFF00CCFF00DCFF00EBFF00EBFF00FAFF00FAFF00FFF500FFF500FFF500
FFF500FFF500FFE600FFE600FFE600FFE600FFF500EBFF00FFE600FFD700FFD700FFD700
FFD700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700
FFD700FFD700FFD700FFD700FFE600AEFF000057FF05FF0000B3FF00FF0A14FF00FF0000
00FF3800FFA305FF0005FF00FF00B80028FF0019FF00FFFF000AFFFF000051FF0070FF00
51FF008FFF00AEFF00BDFF00DCFF00DCFF00DCFF00DCFF00CCFF000094FF00FFB323FF00
00FF380075FF00FF380075FFFF0000FF0000FF000000FF38FF000061FF0080FF0080FF00
00FF0A05FF0000FF3800FFB3FF0000FF000000F0FF00FF1923FF0000FF1900FF66FF0000
FF0000FF0000FF000000FF66FF0000FF0000FF000000FFC200D1FFFF0000FF00000038FF
FF00004200FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF005CFF0000FF0000FF0000FF000000D1FFFF0000
FF000000FFD14200FFFF00D7FF0000FF000000FF4700FF280085FFFF00000094FF00FF75
00FF2842FF0042FF00FF0000FF0000FF0000FF000000FF7500FF2805FF0051FF009EFF00
9EFF009EFF0070FF0005FF0000FF19FF00000038FFFF004C00FF7500FF4700D1FF00FFA3
FF00000019FFDCFF00FAFF00FAFF00FAFF00FAFF00FAFF00FAFF00FAFF00EBFF00DCFF00
CCFF00BDFF00AEFF009EFF0080FF0061FF0042FF0014FF0000FF66FF009900FF85BD00FF
00FF0A61FF009EFF00CCFF00FAFF00FFF500FFE600FFD700FFC700FFC700FFB800FFB800
FFB800FFB800FFB800FFB800FFA800FFA800FFB800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFD700
EBFF00CCFF00DCFF00BDFF0000FF75FF000014FF008FFF00CCFF00BDFF00FFD700FFC700
FFB800FFB800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFB800FFB800
FFC700FFC700FFC700FFD700FFD700FFE600FFE600FFF500FAFF00EBFF00DCFF00CCFF00
AEFF008FFF0000FF0A23FF000066FF00FF3800FF389E00FF00FFFF00FF0A70FF008FFF00
9EFF00AEFF00BDFF00CCFF00DCFF00EBFF00EBFF00FAFF00FAFF00FAFF00FAFF00FFF500
FFF500FFF500FFF500FFF500FFF500FFF500FAFF0051FF00FFF500FFE600FFD700FFD700
FFD700FFD700FFD700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFD700FFD700
FFD700FFD700FFD700FFE600FFE600FAFF00CCFF0023FF0000FF1900FF280066FF0057FF
00FF8533FF0033FF0014FF0000FF3800FFE1FF0000FF000000FFFFFF00000019FF42FF00
00FF0A33FF0061FF005100FFCCFF00CCFF00CCFF00CCFF00CCFF00AEFF0000FFD161FF00
42FF0014FF0000FF28FF0000FF0000FF0000FF000000FFC2FF0000FF002E70FF0070FF00
51FF0023FF00FF0000FF00A8FF0000FF0000FF0000FF000000FF0A00FF2800FF75FF0000
FF0000FF000000C2FFFF0000000AFFFF0000FF00004200FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000028FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
00FF0A14FF008000FFFF0000FF007AFF0000FF0000FF00005100FF42FF0070FF008FFF00
8FFF0070FF0000FF66FF000000FFB3FF0000FF0000FF0000EB00FF05FF0000FF8500D1FF
33FF000066FFDCFF00EBFF00FAFF00FAFF00FAFF00FAFF00EBFF00EBFF00DCFF00CCFF00
8FFF009EFF009EFF008FFF0070FF0000FF0A23FF0000FF380085FF0019FF00FF3800FF75
FF009942FF0070FF00CCFF00DCFF00EBFF00FAFF00FFF500FFD700FFC700FFC700FFB800
FFB800FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFD700FFE600
FAFF0023FF0014FF009EFF0000FF19FF0000FF000042FF00AEFF00CCFF00FFD700FFC700
FFB800FFB800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFB800FFB800FFB800
FFC700FFC700FFC700FFD700FFD700FFE600FFE600FFF500FAFF00EBFF00DCFF00CCFF00
BDFF009EFF0080FF0061FF0023FF0000FF5700FF7505FF0042FF0061FF0080FF008FFF00
AEFF00BDFF00BDFF00CCFF00DCFF00DCFF00EBFF00EBFF00FAFF00FAFF00FAFF00FAFF00
FAFF00EBFF00FAFF00FAFF00FAFF00FAFF0000FF6600FF859EFF00FFF500FFE600FFD700
FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700
FFD700FFD700FFE600FFE600FFE600FFF500EBFF0000FFD10094FF61FF00FF004C42FF00
05FF0051FF0042FF0000FF19FF0000FF0000FF0000FF0000FF00000075FF0075FF14FF00
0094FF00FF8500D1FFFF0000AEFF00CCFF00CCFF00CCFF00BDFF00AEFF008FFF0080FF00
42FF0000FF5700FF9400B3FFFF0000FF0000FF0000FF0000FF0000FF000042FF0051FF00
42FF0014FF00FF001EFF0000FF0000FF0000FF0000000AFF00E1FFFF000000FFE1FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF000000A3FFFF0000FF0000FF00000094FF
FF003D00FF3800FF75FF0000FF0000FF0000FF0000FF0000FF000051FF0070FF0080FF00
70FF000075FFFF000000A3FF00B3FFFF0000FF0000FF00007000FF05FF0042FF0070FF00
80FF009EFF00DCFF00EBFF00EBFF00EBFF00EBFF00EBFF00DCFF00CCFF0000FFB38FFF00
33FF0014FF0080FF0061FF0000FF0A00FF6600FF28FF00F5FF00000094FF00FF3814FF00
0075FF00FF94FF0000AEFF00AEFF0070FF009EFF00EBFF00FFD700FFC700FFC700FFC700
FFB800FFB800FFB800FFB800FFB800FFB800FFA800FFA800FFB800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFB800FFA800FFA800FFB800FFA800FFA800FFB800FFA800FFB800FFA800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFD700FFF500
23FF00CCFF00AEFF0000FFF000FFD1FF0000FF000014FF00EBFF00FFF500FFD700FFC700
FFB800FFB800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFB800FFB800
FFB800FFC700FFC700FFD700FFE600FFE600FFE600FFF500FAFF00EBFF00DCFF00CCFF00
BDFF009EFF0080FF0042FF0000FF3800FF4700FFA300FF0A42FF0061FF0080FF008FFF00
9EFF00AEFF00BDFF00CCFF00CCFF00DCFF00DCFF00EBFF00EBFF00FAFF00FAFF00FAFF00
EBFF00CCFF00AEFF0061FF00EBFF00DCFF00AEFF0033FF00CCFF00FAFF00FFE600FFE600
FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700
FFD700FFD700FFE600FFE600FFE600FFF500EBFF0000FF6651FF009EFF008FFF0080FF00
80FF0070FF0051FF000085FF0028FF0038FFFF0000FF0000FF00000500FF00FF5700FF19
FF00F59E00FFFF00000094FFFF0000AEFF00BDFF00BDFF00BDFF00AEFF009EFF0080FF00
33FF00FF00E600B3FFFF0000FF0000FF0000FF0000FF0000FF0000FF000023FF0005FF00
FF000000FF19FF0000FF0000FF0000FF0000FF0000FF000000A3FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF007AFF0000
FF002EFF000000FFB3FF0000FF0000FF0000FF0000FF0000FF000023FF00FF000061FF00
51FF00FF0000FF0000FF0000FF0000FF0000FF0000EB00FF00FFC200FFB300FF1980FF00
9EFF00BDFF00CCFF00DCFF00EBFF00EBFF00EBFF00CCFF0000FFE151FF0000FFA35100FF
FF00000057FF61FF0033FF0000C2FFFA00FF00FF9400F0FFFF00C74200FF14FF0042FF00
14FF000094FF00FF5700FFC270FF0023FF0070FF00FFF500FFD700FFD700FFC700FFC700
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFA800FFB800FFA800
FFA800FFA800FFA800FFA800FFB800FFA800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFD700FAFF00
FAFF00EBFF00DCFF00AEFF0033FF00FF000000FF38BDFF00FAFF00FFE600FFD700FFD700
FFB800FFB800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFB800FFB800
FFC700FFC700FFD700FFD700FFE600FFE600FFF500FFF500EBFF00CCFF00CCFF00BDFF00
9EFF0042FF0051FF0000FFA300FF3823FF0000FF0A00FFB300FF1951FF0061FF0080FF00
9EFF00AEFF00AEFF00BDFF00BDFF00CCFF00CCFF00DCFF00EBFF00EBFF00EBFF00EBFF00
DCFF0000F0FF00FFC28FFF00CCFF0070FF0051FF0042FF00CCFF00FAFF00FFF500FFE600
FFE600FFE600FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700
FFD700FFE600FFE600FFE600FFF500FFF500FAFF00BDFF0051FF00BDFF00AEFF009EFF00
8FFF0070FF0051FF00FF0000FF0000FF0000FF0000FF0000FF00000066FFFF00000066FF
00FF9400B3FFFF00003300FF61FF009EFF00AEFF00AEFF00AEFF009EFF008FFF0080FF00
00FF47FF0000AE00FFFF0000FF0000FF0000FF0000FF0000FF0000FF000000FF28FF0000
FF0000FF000000FFB3FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF5700FF57FF000000FF0A
33FF0000FF19FF0000FF0000FF0000FF0000FF0000FF0000FF00004200FFFF00B8FF004C
9EFF00BDFF00CCFF00DCFF00DCFF00DCFF00DCFF00CCFF008FFF0005FF00BD00FFFF0000
FF000000FF1933FF0000FF3800FFA3FF000FFF0000FF00B800B3FF00FF4705FF0051FF00
70FF0051FF0000FFA300FF1900FF2800FF7500FFC2CCFF00FFE600FFD700FFC700FFC700
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFD700FFD700FFE600
FFF500FFF500FAFF00DCFF0051FF008FFF0070FF00AEFF00FAFF00FFF500FFD700FFC700
FFB800FFB800FFB800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFB800FFB800FFB800
FFC700FFD700FFD700FFD700FFE600FFF500FFF500FAFF00EBFF0070FF009EFF009EFF00
000AFF0066FF00FFA300D1FF00FF0A42FF0023FF0000F0FF00FF5723FF000085FF00FFF0
8FFF009EFF009EFF0070FF009EFF009EFF0005FF00CCFF00DCFF00DCFF00EBFF00DCFF00
CCFF009EFF0061FF0000FF859EFF0070FF0000FF858FFF00BDFF00CCFF00FAFF00FFF500
FFF500FFE600FFE600FFE600FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700
FFE600FFE600FFE600FFE600FFF500FFF500FAFF00EBFF00DCFF00CCFF00BDFF00AEFF00
8FFF0051FF0042FF00FF001E00FFB3FF0000FF0000FF0000FF0000FF00008000FFFF0000
FF0000FF0000FF0000FF00000500FF9EFF009EFF009EFF008FFF0070FF0070FF0061FF00
CC00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFD100FF75FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF000000F0FFFF00000057FFFF0000FF0000
00FF0A0019FFFA00FFFF0000FF0000FF0000FF0000FF0000FF00000019FFFF000061FF00
9EFF00AEFF00BDFF00CCFF00CCFF00CCFF00CCFF00BDFF0042FF0000D1FF0094FF00E1FF
00FF8500FF1900FF2800FF664200FFFF0000FF0000FF0000EB00FF00FF75FF004C51FF00
80FF0080FF0042FF0000FFFF33FF0033FF0000A3FFEBFF00FFE600FFD700FFC700FFC700
FFC700FFB800FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFD700FFD700FFE600
FFE600FFF500FAFF00EBFF0061FF00BDFF0023FF00AEFF00DCFF00EBFF00FFE600FFC700
FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900
FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF8A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFB800FFB800FFB800
FFC700FFD700FFE600FFF500FFF500FFF500FAFF00DCFF00BDFF0070FF0061FF0080FF00
0057FF00FFB314FF0023FF0061FF0061FF0042FF0000FF283300FF00FF2800B3FF00FF47
70FF008FFF008FFF0042FF0014FF0000FF0A00FFA3BDFF00CCFF00CCFF00DCFF00DCFF00
CCFF00AEFF0061FF000019FF70FF0000FF2800FF0A33FF0023FF0005FF00EBFF00FAFF00
FAFF00FFF500FFE600FFE600FFE600FFD700FFD700FFD700FFE600FFD700FFD700FFE600
FFE600FFE600FFE600FFE600FFF500FFF500FAFF00EBFF00EBFF00DCFF00CCFF00AEFF00
80FF000019FF14FF0000FF1900B3FF0094FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF000005FF0051FF008FFF008FFF0070FF0000FF9400F0FF5100FF51FF00
14FF0000FF57FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFF0FF00000028FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFF0
FF000000FF75FF00B8FF0000FF0000FF0000FF0000FF0000FF00009E00FF0094FF70FF00
8FFF009EFF0000FF38BDFF00BDFF00CCFF00BDFF009EFF0000FFE1FF00C700FFD1FF0000
FF000000FF751400FF00FFD100D1FFFF0000FF0000FF0000FF0000FF0000FF000023FF00
8FFF009EFF00AEFF009EFF00AEFF000075FFDCFF00FFF500FFE600FFD700FFC700FFC700
FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFB800FFC700FFC700FFC700
FFB800FFC700FFC700FFB800FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFC700FFB800FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFE600
FFE600FFF500FFF500EBFF00DCFF00CCFF009EFF0061FF0070FF00CCFF00FFE600FFC700
FFC700FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FF9900FF9900
FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFB800FFB800FFC700
FFD700FAFF0033FF00FAFF00FFF500FAFF00EBFF008FFF0000D1FF00FF7533FF00FF00E6
00FF190038FF0066FF70FF0080FF0070FF0051FF0014FF0000FF850075FFFF000000FFC2
00D1FF70FF0070FF0000E1FF0066FF00FF9442FF008FFF00BDFF00BDFF00CCFF00CCFF00
BDFF0080FF0000A3FFFF000033FF0000FF9400FF380094FF33FF009EFF00DCFF00DCFF00
DCFF009EFF00FFF500FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFF500FFF500FAFF00FAFF00EBFF00EBFF00DCFF00CCFF0000C2FF
00F0FFFF00001400FF00FF47BD00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF000000FFC20057FF51FF0070FF0061FF00FF0000FF00C7FF0000FF000005FF00
14FF0000FF287000FFFF0000FF0000FF0000FF0000FF0000FF00A8FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF000000FFD1FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF003D0066FF61FF00
80FF0000FFC200FF3880FF00AEFF00BDFF00BDFF009EFF0070FF0033FF00FF000FFF0000
FF00000094FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000A3FF70FF00
9EFF00AEFF00BDFF00CCFF00DCFF00BDFF00EBFF00FFE600FFD700FFD700FFC700FFC700
FFC700FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFE600
FFE600FFF500FFF500FAFF00EBFF00DCFF00AEFF0000FF0AAEFF00FAFF00FFE600FFC700
FFC700FFB800FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800
FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFC700
FFD700CCFF009EFF00DCFF00FAFF00EBFF00DCFF00BDFF0070FF0000FF4700FF7533FF00
00FFA300FF1942FF008FFF008FFF0080FF000038FF0066FFCC00FFFF00000019FF00FF19
23FF0051FF0051FF0023FF007000FF00FFF000FF8561FF0000FF948FFF00BDFF00BDFF00
BDFF008FFF0000FF8500FFA300FFC200FF470028FFFF000000FF4751FF0000FF858FFF00
00FF479EFF00FAFF00FFF500FFF500FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFF500FFF500FFF500FAFF00FAFF00EBFF00EBFF00DCFF00CCFF008FFF00
FF000000F0FFFF00C700FFB3FF001EFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF000000A3FFFF000033FF0061FF0005FF00FF0000FF0000FF0000FF000FFF0000
9E00FFFF006B00FFA30019FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000000AFFFF0000FF0000FF0000FF0000FF0000FF0000FF000023FF0051FF00
42FF0000FF288000FFFF00008FFF009EFF00AEFF008FFF0080FF00FF000000FF57FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000CC00FF00FF750085FF70FF00
8FFF00AEFF00CCFF00DCFF00EBFF00FAFF00FFF500FFE600FFE600FFD700FFD700FFC700
FFC700FFC700FFC700FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFC700FFB800FFC700FFC700FFC700FFD700FFD700FFE600FFE600FFD700
FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFD700FFE600
FFE600FFE600FFF500FAFF00EBFF00CCFF0033FF008FFF0051FF0042FF00FFE600FFD700
FFC700FFC700FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFB800FFB800FFB800FFC700
FFD700FAFF0080FF0000FFFFDCFF00DCFF00BDFF0023FF0000FF0A23FF0070FF0080FF00
70FF0042FF008FFF009EFF009EFF008FFF0070FF003300FF00FFFF0500FF0047FF0085FF
14FF0000FFC233FF0023FF0000FF280075FF00FFE100FFFF0094FF80FF00AEFF00AEFF00
AEFF008FFF0070FF0000FF94FF000000C2FFFF000000FFF000FF195100FF5100FF61FF00
00FF6600FF47DCFF00FFF500FFF500FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFF500FFF500FFF500FFF500FAFF00FAFF00EBFF00EBFF00DCFF00BDFF0051FF00
8000FFFF000000FFF0FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF000014FF0042FF0033FF00FF00002300FFFF00008F00FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000E1FF00FF3800FF3823FF00
00FFE1FF0000FF0000FF00000019FF70FF008FFF0080FF0042FF00FF00C700FFB33300FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000075FF0038FF23FF0061FF00
00FFC28FFF00CCFF00DCFF00EBFF00FAFF00FFF500FFE600FFE600FFD700FFD700FFC700
FFC700FFC700FFC700FFC700FFC700FFB800FFC700FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFC700FFC700FFC700FFC700FFD700FAFF0000FF0AFAFF00AEFF00FFF500
FFE600FFD700FFD700FFE600CCFF00EBFF00FFE600FFD700FFD700FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFD700FFD700FFD700FFE600
FFE600FFF500FFF500FAFF00DCFF00BDFF0042FF00AEFF00DCFF00FAFF00FFE600FFD700
FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFD700
FFA800FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900
FF9900FFA800FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFB800FFB800FFC700
FFD700FAFF00CCFF0005FF00BDFF00CCFF00AEFF000066FFFF000000FFE180FF009EFF00
AEFF00AEFF00AEFF00AEFF00AEFF009EFF0070FF0000FF3800E1FF00FF470028FF00FFB3
00FF3800FFFFFA00FF00FF190038FF8000FF00FF1905FF000085FF80FF009EFF009EFF00
9EFF008FFF0070FF0023FF0000FF1900FF5700FF660047FF05FF0033FF00000AFF00FF94
33FF0000FF38DCFF00FAFF00FFF500FFF500FFF500FFF500FFF500FFF500FFF500FFF500
FFF500FFF500FFF500FFF500FAFF00FAFF00FAFF00EBFF00DCFF00DCFF0000FF28FF0000
0500FFFF0000FF002EFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF000005FF0014FF00FF000000FF38FF0000FF0000FF00000075FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF008A0047FFFF000000FFB3FF0000FF0000
00FF5700A3FFFF0000FF000000FF4751FF0080FF0070FF0000FF661400FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000014FF0000FF28
00FF5751FF00BDFF00DCFF00FAFF00FFF500FFF500FFE600FFE600FFD700FFD700FFD700
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFB800FFC700FFB800FFB800FFB800
FFB800FFC700FFC700FFC700FFC700FFD700FFF500CCFF008FFF000085FF42FF0061FF00
FFF500FFE600FFE600FFF500DCFF00CC00FFEBFF00FFE600FFD700FFD700FFD700FFD700
FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFD700FFD700FFD700FFD700FFE600
FFE600FFF500FFF500EBFF00CCFF0033FF0051FF00BDFF00EBFF00FFF500FFE600FFD700
FFD700FFC700FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFC700FFD700DCFF00
FFB800FFA800FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFB800FFB800FFC700FFD700
FFE60061FF0051FF0000FF759EFF0000FF198FFF0042FF00FF000000FF1980FF00AEFF00
BDFF00BDFF00BDFF00BDFF00AEFF009EFF008FFF0051FF0000FF5705FF0000FFA3EB00FF
00FFF08F00FF00FF7500FF663300FF0028FF00FF0A33FF0061FF0080FF0080FF0080FF00
8FFF0080FF0070FF0051FF0033FF0000FF0A00FF47FF005C00FFB351FF0070FF0051FF00
00FF28CCFF00EBFF00FAFF00FFF500FFF500FFF500FFF500FFF500FFF500FFF500FFF500
FFF500FFF500FAFF00FAFF00FAFF00EBFF00EBFF00EBFF00DCFF00CCFF00BDFF008FFF00
FF005C00FFA3FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF000000FF19FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00004200FFFF0000FF0000
FF000FFF0000FF000000FFFF00D1FF51FF0061FF0061FF0000FFE13300FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00004200FF00FF380085FF
00FFA300FF8500F0FFDCFF00FAFF00FFF500FFF500FFE600FFE600FFD700FFD700FFD700
FFD700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFD700FFE600FAFF00CCFF008FFF0000FF8542FF00
EBFF00FAFF00FFF500FAFF0061FF0000FF0AEBFF00FFF500FFE600FFE600FFE600FFD700
FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFE600FFE600FFE600
FFE600FFF500FAFF00DCFF0051FF0033FF0070FF0000FF3870FF00FFF500FFE600FFE600
FFD700FFD700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFD700BDFF00
FFD700FFA800FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFB800FFB800FFC700FFE600
FFF500BDFF0000FF1905FF0051FF0000FF9400FFC223FF0000FF3861FF0000FF66BDFF00
CCFF00CCFF00CCFF00CCFF00BDFF00AEFF008FFF0070FF0042FF0000FFB300FF570047FF
FF008AFF006B00E1FF00E1FF000AFF3300FF00FF4700FF0A51FF0061FF0042FF0000FF66
51FF0000FF4761FF0042FF0023FF0000FF0A00D1FF0075FF00FF0A61FF008FFF009EFF00
BDFF00DCFF00EBFF00FAFF00FAFF00FFF500FFF500FFF500FFF500FFF500FFF500FFF500
FAFF00FAFF00FAFF00FAFF00EBFF00EBFF00DCFF00DCFF00DCFF00CCFF00BDFF008FFF00
9E00FF00FF47000AFF0038FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF000000FF9400FF8500FFE1FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF000000FF1900FFD105FF0042FF0014FF00FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000B3FFFF000000FFD1
0094FFFF00F59EFF00DCFF00FAFF00FFF500FFF500FFE600FFE600FFE600FFD700FFD700
FFD700FFD700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFD700FFD700FFE600FFF500EBFF008FFF0042FF00AEFF00
CCFF0023FF00BDFF00DCFF00BDFF0014FF008FFF00FAFF00FAFF009EFF00FFF500FFE600
FFE600FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFE600FFE600FFE600
FFF500FFF500FAFF00DCFF00AEFF0005FF0000D1FF14FF00DCFF00FFF500FFE600FFE600
FFD700FFD700FFD700FFD700FFD700FFC700FFC700FFC700FFC700FFD700FFF500DCFF00
FFC700FFA800FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFB800FFB800FFC7008FFF00
DCFF0080FF008FFF0070FF0061FF009EFF0000FF1900FF0A8FFF009EFF00BDFF00CCFF00
DCFF00DCFF00DCFF00CCFF00BDFF009EFF008FFF0070FF0051FF0000B3FF00FFC2000AFF
FF0000FF0000FF0000FF00B8FF00006100FF00FFF0FF000023FF0033FF00FF000000C2FF
AE00FF14FF0033FF0005FF000019FF00FF6600A3FF0066FF00FF1900FFD18FFF00AEFF00
BDFF00DCFF00EBFF00FAFF00FAFF00FAFF00FFF500FFF500FFF500FFF500FAFF00FAFF00
EBFF00EBFF00EBFF00EBFF00AEFF00BDFF00CCFF00CCFF00CCFF00BDFF00BDFF0042FF00
00FFF033FF00FF000000A3FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF000000FFC2FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF000000FFF0FF0000FF0000FF000014FF0000FF28FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFF0
FF000000FFE19EFF00EBFF00FAFF00FFF500FFF500FFF500FFE600FFE600FFD700FFD700
FFD700FFD700FFD700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFD700FFD700FFD700FFE600FFF500EBFF0000FF2800FF2805FF00
23FF002300FF9EFF00AEFF00AEFF0000FF85AEFF00DCFF00CCFF008FFF0070FF00FFF500
FFE600FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFE600FFE600FFE600FFE600
FFF500FAFF00EBFF0042FF0000FFC200FF2800FFB380FF0051FF00FAFF00FFF500FFE600
FFE600FFE600FFF500FFE600FFD700FFD700FFD700FFD700FFD700BDFF00AEFF00FFD700
FFB800FFA800FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFB800FFC700FFD70033FF00
00FF57DCFF00AEFF008FFF00BDFF00CCFF0000FF0A9EFF0000D1FFCCFF00DCFF00DCFF00
EBFF00DCFF00DCFF00CCFF00AEFF0042FF0000FF2851FF0042FF0000FF38FF007AFF0000
FF0000FF0000FF0000FF0000FF0000FF00D7FF000000FF8500FF1905FF0000FF4700FFD1
00FFB300FF0A000AFFFF0000FF007A00FFC200F0FF0038FF00FFC22300FF8FFF00AEFF00
BDFF00DCFF00EBFF00EBFF00FAFF00FAFF00FAFF00FAFF00FAFF00FAFF00FAFF00EBFF00
00FF3800FF38CCFF00CCFF000066FF00D1FFBDFF00BDFF00BDFF00BDFF00AEFF009EFF00
70FF0051FF00000AFFCC00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000075FF3300FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF28FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00008000FF
00FFC200FFB39EFF00EBFF00FAFF00FAFF00FFF500FFF500FFF500FFE600FFE600FFE600
FFD700FFD700FFD700FFD700FFD700FFC700FFC700FFD700FFC700FFC700FFC700FFC700
FFC700FFC700FFD700FFD700FFD700FFD700FFE600FFF500EBFF0061FF0000FF198F00FF
42FF0000FF6600FF8505FF0080FF0023FF0042FF00BDFF0080FF0070FF0000FF38FFF500
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF500
FFF500FAFF00EBFF00AEFF0080FF0080FF0051FF0033FF00CCFF00FAFF00FFF500FFF500
FFF500FFF500FAFF0080FF00FFF500FFE600FFE600FFE600FFE600FAFF008FFF00FFE600
FFC700FFA800FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFB800FFB800FFF500FAFF00
FAFF00FAFF00DCFF0061FF00DCFF00EBFF00EBFF00EBFF0005FF00EBFF00EBFF00EBFF00
EBFF00EBFF00DCFF00DCFF00AEFF0000FF4700FFA305FF0023FF0000FF1900FFA30094FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00D700FF470047FF00FF57FF0000
FF000000FFC200FF4700FFC28F00FFFF0000FF0000FF000000B3FF8000FF80FF009EFF00
AEFF00CCFF00DCFF00DCFF00EBFF00FAFF00FAFF00FAFF00FAFF00FAFF00EBFF00DCFF00
80FF0000FF9470FF0051FF0014FF0033FF009EFF003300FFAEFF00AEFF00AEFF009EFF00
80FF0061FF0000FF2800C2FF0066FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000047FFFF000000FF6600FFFFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFF0
FF00C770FF00CCFF00EBFF00EBFF00FAFF00FFF500FFF500FFF500FFF500FFF500FFE600
FFE600FFD700FFD700FFD700FFD700FFD700FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFD700FFD700FFD700FFD700FFE600FFE600FFF500EBFF00BDFF00BDFF008FFF00
8FFF0080FF0042FF0000FF7500FF8500FF0A70FF0070FF0000FFE19EFF00DCFF00FFF500
FFF500FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF500FFF500FFF500
FAFF00FAFF00EBFF00DCFF00BDFF00AEFF0000FF758FFF00CCFF00EBFF00FAFF00FFF500
FFF500FAFF00EBFF0033FF00EBFF00AEFF00FAFF0051FF00FAFF00DCFF00BDFF00CCFF00
FFF500FFB800FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFC700FFD700
FFE600FFE60000FF1951FF00EBFF00FAFF00FAFF00FAFF00FAFF00FAFF00FAFF00FAFF00
EBFF00EBFF00EBFF00DCFF00CCFF009EFF0033FF001400FF00FF0A00FF7500B3FF8F00FF
FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFF000FF94FF0000EB00FFFF0000
FF000000FFFF0085FFFF0000FF0000FF0000FF0000FF004CFF000033FF0070FF0061FF00
00FFC2AEFF00FF003DDCFF00EBFF00EBFF00FAFF00EBFF00FAFF00EBFF00EBFF00DCFF00
AEFF0023FF0000FFB3FF00009E00FF00FFFF42FF00FF0000FF00009EFF009EFF008FFF00
80FF0061FF0033FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF001EFF000000FFD1FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF7533FF00
0075FF00E1FFCCFF00DCFF00EBFF00FAFF00FAFF00FAFF00FFF500FAFF00FAFF00FFF500
FFF500FFE600FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFC700FFD700FFD700
FFD700FFD700FFD700FFD700FFD700FFE600FFE600FFF500FAFF00EBFF00DCFF00BDFF00
AEFF009EFF0080FF0042FF0000FFA33300FF42FF0000FF1900FF5700FF47EBFF00FAFF00
FFF500FFF500FFF500FFF500FFF500FFE600FFF500FFF500FFF500FFF500FFF500FFF500
FAFF00FAFF00EBFF00DCFF00CCFF00AEFF0023FF008FFF00CCFF00EBFF00EBFF00EBFF00
EBFF00EBFF00CCFF0033FF00AEFF0000FF47AEFF0000FFD170FF0000FF7500FF0AFFF500
51FF00FFA800FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFB800FFB800FFC700FFC700
FFD700FFD700FFF500BDFF00FFF500FFF500FFF500FFF500FFF500FFF500FAFF00FAFF00
FAFF00EBFF00EBFF00DCFF00CCFF0070FF0000FFA300FFC200FF66FF00000500FFFF00A8
FF0000FF0000FF0000FF0000FF0000FF0000FF000000D1FFFF003DFF0000AE00FFFF0000
FF0000FF0000FF00000047FFFF0000FF0000FF0000FF00B8FF000000FF3842FF0000FFE1
05FF0000FF9400FF85DCFF00DCFF00EBFF00EBFF00EBFF00EBFF00EBFF00DCFF00CCFF00
AEFF0000FF28FF0000FF0000FF000000FFC200FF94FF0000FF000080FF0080FF0061FF00
FF000042FF0033FF0005FF0000FF3800FFA3000AFFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000A3FF0047FF51FF00
80FF00AEFF00CCFF00DCFF00EBFF00EBFF00FAFF00FAFF00FAFF00FAFF00AEFF00DCFF00
FFF500FFE600FFE600FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700
FFD700FFD700FFD700FFD700FFE600FFE600FFE600FFF500FAFF00EBFF00DCFF00CCFF00
BDFF009EFF0070FF0000FF8500FF3800F0FF00FFE100FF2880FF009EFF00DCFF00FAFF00
FAFF00FFF500FFF500FFF500FFF500FFF500FFF500FFF500FFF500FFF500FFF500FAFF00
FAFF00EBFF00EBFF00DCFF00CCFF0070FF0000FF3842FF00BDFF00DCFF00DCFF0000FF75
9EFF00AEFF00AEFF0042FF0000FF1900FFF070FF00BDFF00EBFF00FFF500BDFF00FFD700
FFB800FFA800FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00
FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFC700
FFC700FFD700FFD700FFE600FFE600FFE600FFE600FFE600FFF500FFF500FAFF00FAFF00
FAFF00FAFF00EBFF00DCFF00CCFF008FFF0000FF381400FF00FFFF0057FF0038FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00008000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00C700FF5705FF0005FF000038FF
FF00D70047FF8FFF00CCFF00DCFF00DCFF00EBFF00EBFF00EBFF00DCFF00CCFF009EFF00
00F0FF00FF38FF0000FF00F5FF0000FA00FFFF000000FF7533FF0070FF0061FF008000FF
FF0000FF000005FF0000FF8500FF6600FFD1FF00000028FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000070FF00
9EFF00BDFF00CCFF00DCFF00DCFF00EBFF00EBFF00EBFF00EBFF00DCFF0070FF000057FF
EBFF00FFF500FFE600FFE600FFE600FFD700FFD700FFD700FFD700FFD700FFD700FFD700
FFD700FFD700FFD700FFE600FFE600FFE600FFF500FFF500FAFF00EBFF00DCFF00CCFF00
BDFF008FFF00FF00998F00FF05FF0042FF000019FF05FF009EFF00CCFF00EBFF00EBFF00
FAFF00FAFF00FAFF00AEFF0000FF0AFAFF00FAFF00EBFF00FAFF00FAFF00FAFF00FAFF00
FAFF00EBFF00EBFF00DCFF00CCFF0000FF0A00FF0A05FF00AEFF00BDFF00BDFF0061FF00
61FF0023FF0000FF289EFF00BDFF00CCFF00CCFF00FAFF00DCFF00FFD700FFE600FFD700
FFA800FFA800FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800
FFC700FFC700FFD700FFD700FFD700FFD700FFE600FFE600FFE600FFF500FFF500FFF500
FAFF00FAFF00EBFF00DCFF00AEFF0000E1FF14FF007000FF00FF19FF000000C2FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000047FF0066FF00FF4700FF1900D1FF
1400FF00A3FF70FF00AEFF00CCFF00DCFF00DCFF00DCFF00DCFF00DCFF00BDFF0000D1FF
FF00E64200FF0094FF0038FFFF002EFF000000FF8500FF3823FF0042FF000075FFFF0000
FF0000EB00FF00FF66FF000000E1FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00E600FF2833FF0080FF00
9EFF00AEFF00CCFF00CCFF00DCFF00CCFF00AEFF00BDFF00CCFF00BDFF0061FF0005FF00
DCFF00FAFF00FFF500FFE600FFE600FFE600FFD700FFD700FFD700FFD700FFD700FFE600
FFD700FFE600FFE600FFE600FFE600FFF500FFF500FAFF00FAFF00EBFF00DCFF00CCFF00
00FFFF70FF000085FF00F0FF05FF0061FF0080FF009EFF00BDFF00CCFF00DCFF00EBFF00
EBFF00EBFF00EBFF00BDFF0000FF19CCFF00DCFF0000FF47DCFF00EBFF00EBFF00EBFF00
EBFF00EBFF00DCFF00DCFF00CCFF009EFF0070FF0014FF009EFF0080FF0061FF0014FF00
42FF0070FF00BDFF00DCFF00AEFF00FAFF00FFF500FFE600FFD700FFC700FFC700FFB800
FFA800FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800
FFC700FFC700FFD700FFD700FFD700FFD700FFD700FFE600FFE600FFE600FFF500FFF500
FAFF00FAFF00EBFF00DCFF00CCFF009EFF0061FF000500FF23FF0000FF0A00FFA3FF005C
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFB300FF4700FF75
00FFFF00FFB36100FFFF00C7BDFF00CCFF00DCFF00DCFF00CCFF00CCFF00BDFF00FF00E6
33FF0000FF384200FF00C2FFFF0000FF00E63300FFFF0000FF000023FF00FF0000FF003D
FF0000FF000000F0FFFF0000FF008AFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000BD00FF00FF3833FF0061FF0080FF00
8FFF009EFF00BDFF00BDFF00CCFF00BDFF0061FF00FF002E00FF4770FF0051FF0005FF00
00F0FFDCFF00FAFF00FFF500FFE600FFE600FFE600FFD700FFD700FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFF500FFF500FFF500FAFF00EBFF00EBFF00DCFF009EFF00
FF007A33FF0000FF47AE00FF0047FF61FF0080FF009EFF00BDFF00CCFF00CCFF00DCFF00
EBFF00EBFF00DCFF00AEFF0000FF5700FFFF9EFF0000FFFFBDFF0005FF00DCFF00DCFF00
DCFF00DCFF00DCFF00CCFF00BDFF00AEFF0080FF0000FF4770FF0051FF0000FF2880FF00
00FFD1CCFF00EBFF00FAFF00FFF500FFE600FFD700FFC700FFC700FFC700FFB800FFA800
FFA800FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800
FFB800FFC700FFC700FFC700FFD700FFD700FFD700FFD700FFE600FFE600FFF500FFF500
FFF500FAFF00EBFF00DCFF00CCFF00BDFF009E00FF6100FF42FF0033FF00FF000000FFE1
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000E1FFFF000000FFD1
0057FFFF0000FA00FF00FFB3BDFF00CCFF00CCFF00CCFF00CCFF00CCFF00BDFF009EFF00
70FF00FF00000075FF9E00FFFF0000FF0000FF00F5FF00D7FF000000FF4700FF47FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00002300FF00C2FF00FFA300FF4705FF0023FF0051FF0061FF00
61FF00FF007A9EFF00AEFF00BDFF009EFF00DC00FF0075FF14FF0005FF0000FF7500FF57
00FF0A33FF0000D1FFFFF500FFF500FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFF500FFF500FFF500FAFF00FAFF00EBFF00DCFF00DCFF00BDFF006100FF
00FF4700FF8500F0FF00FFA300FFF051FF0042FF008FFF009EFF00AEFF00BDFF00CCFF00
DCFF00DCFF00CCFF0000A3FF61FF0000FF5761FF00FF004C70FF0033FF00BDFF00CCFF00
CCFF00CCFF00CCFF00BDFF00AEFF009EFF0080FF0000FFD100FF0A33FF008FFF00BDFF00
DCFF00EBFF00FAFF00FFF500FFE600FFD700FFC700FFC700FFB800FFB800FFA800FFA800
FFA800FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800
FFB800FFB800FFC700FFC700FFC700FFD700FFD700FFD700FFE600FFE600FFF500FFF500
FAFF00FAFF00EBFF00DCFF00DCFF00BDFF0070FF0070FF0070FF0051FF0000FF3800FF47
FF00A8FF00004200FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0066FFFF00C751FF008FFF00AEFF00BDFF00CCFF00CCFF00BDFF00BDFF00AEFF009EFF00
61FF0000FFC200FF2800FFC2FF0000FF0000FF0000FF0000FF001E00FF75FF000000D1FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF4700A3FF00FF1923FF00
5100FFFF000000FF759EFF009EFF008FFF0023FF00FF000FCC00FF00FF940085FFDC00FF
00FFF042FF00DCFF00FAFF00FFF500FFF500FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFF500FFF500FFF500FAFF00CCFF00DCFF008FFF0000D1FFCCFF00BDFF008FFF00
33FF0000FFFFFF000000FF9400FF1923FF0000B3FF80FF009EFF008FFF0000FFF0AEFF00
BDFF00CCFF00BDFF00AEFF008FFF0033FF0000FF6600FF6600F0FF00FF94BDFF00BDFF00
00FFB39EFF00AE00FF00FFD19EFF0080FF0051FF0000FF3800FF6670FF00AEFF00CCFF00
DCFF00FAFF00FFF500FFE600FFD700FFD700FFC700FFC700FFB800FFB800FFA800FFA800
FFA800FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF9900FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800
FFB800FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFD700FFE600FFE600FFF500
FAFF00FAFF00EBFF00DCFF00CCFF00BDFF00AEFF008FFF0070FF0051FF0023FF0000FF28
00FF850094FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF009923FF0070FF009EFF00AEFF00BDFF00BDFF00BDFF00BDFF00AEFF00AEFF008FFF00
80FF0051FF0000FF75FF0000FF0000FF0000FF0000FF0000FF000000FFE1FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF28
FF0000FF00003300FF33FF008FFF0080FF0061FF0014FF0000FFB3FF0000FF0000FF0000
000AFF14FF00CCFF00EBFF00FFF500FFF500FFF500FFE600FFE600FFE600FFE600FFE600
FFF500FFF500FAFF00FAFF00EBFF0000FF6600FF9442FF0023FF009EFF00AEFF0080FF00
4200FF5100FFFF0000FF000F00FFD100FF9400FFC242FF0080FF0070FF0000FFE151FF00
9EFF00BDFF00AEFF00AEFF008FFF0070FF0033FF0000FF3851FF008FFF009EFF00AEFF00
8FFF0000FFC200FF1900FF3870FF0000FF750057FF51FF0061FF0000FFB38FFF00BDFF00
DCFF00FAFF00FFF500FFE600FFD700FFD700FFC700FFC700FFB800FFB800FFA800FFA800
FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800
FFB800FFB800FFC700FFC700FFC700FFC700FFD700FFD700FFD700FFE600FFE600FFF500
EBFF00EBFF00DCFF00DCFF00CCFF00BDFF00AEFF009EFF0051FF0000D1FF05FF00FF00E6
00A3FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
00FF850057FF05FF008FFF00AEFF00AEFF00AEFF00AEFF009EFF009EFF00FF006B70FF00
70FF0051FF000094FFFF002EFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000066FF0038FF
FF0000FF0000FF000051FF0070FF0051FF0000FFD100FF1900FF4700FFB3AE00FFFF0000
FF002E00FF0A1400FF00FF75FAFF00FFF500FFF500FFF500FFF500FFF500FFF500FFF500
FFF500FAFF00CCFF0000C2FF80FF0070FF0000FF0A05FF0000FF5780FF008FFF0000FF75
2300FF00FFF0FF0000FF0000FF000000C2FF00FF5700F0FF61FF0051FF0005FF0000FFC2
00FFF09EFF009EFF009EFF0080FF0061FF000085FF00FFE123FF0070FF0080FF008FFF00
80FF0042FF0000FF1900FF3800FF7500FFFF00FF289E00FF8FFF0000FF0A51FF0000FFF0
CCFF00EBFF00FAFF00FFE600FFD700FFC700FFC700FFB800FFB800FFA800FFA800FFA800
FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00
FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800
FFB800FFB800FFB800FFC700FFC700FFC700FFD700FFD700FFD700FFE600FFF500FAFF00
00E1FFBDFF00CCFF00BDFF00BDFF00BDFF00AEFF008FFF0051FF00CC00FF00FF3800FF85
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000019FF
00FF940038FF00C2FF70FF009EFF009EFF00AEFF009EFF000075FF0019FFFF00A823FF00
DC00FF33FF0000FF38FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF000023FF0042FF00FF0000CC00FF00FFA3FF00000038FFFF000000FFFF
00FFD100FF47FF0000FF00B8FAFF00FAFF00FFF500FFF500FFF500FFF500FFF500FFF500
FAFF009EFF00FF008A0085FF00FFC200FF280057FF00FF8500FF4770FF0070FF0042FF00
00FFE1FF00A8FF0000FF0000FF0000FF000000FF4705FF0014FF00FF00D7FF000000FF28
23FF0080FF0080FF0070FF0033FF0042FF0000FF195100FF00FF5733FF0000FF1942FF00
61FF0042FF0000FFB3FF00D700FF3851FF008FFF009EFF00AEFF0080FF0000FF6600FFB3
9EFF00EBFF00EBFF00DCFF00FFE600FFD700FFC700FFB800FFB800FFA800FFA800FFA800
FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800
FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800
FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFD700FFD700FFE600FFF500EBFF00
70FF008FFF00AEFF0080FF008FFF00AEFF009EFF0080FF000057FF0028FF00FFA300FFFF
8000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
00FFFF0019FF0075FF70FF008FFF009EFF009EFF008FFF0042FF00FF0000FF0000FF0000
FF000000FF1900FF1900FF75FF000FFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF000000FF5705FF0000FF0A00F0FFAE00FFFF0000FF0000FF00000019FF00FF94
0085FF14FF0080FF00CCFF00EBFF00FAFF00FAFF00FFF500FFF500FFF500FFF500FAFF00
FAFF00DCFF00AEFF0000FF5723FF0023FF0000FFA300FF8514FF0051FF0042FF0000FFF0
00FF66FF00D7FF0000FF0000FF0000FF000000FF8500FFA300FF47FF006BBD00FF00FFE1
42FF0061FF0061FF001400FF00FFD100FF190075FF00D1FF00FF4705FF0000FF5705FF00
23FF0000FFFF00F0FF0094FF00FF0A42FF008FFF00BDFF00BDFF00BDFF0061FF00FF0000
61FF00CCFF009EFF0000FF0AFFE600FFD700FFC700FFB800FFB800FFA800FFA800FFA800
FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800
FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFD700FFD700FFE600FFF50000FF19
00FFB361FF0061FF0000C2FF61FF008FFF008FFF0080FF000028FF00FF75FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF000000FFA300FF1980FF008FFF008FFF0061FF00FF00D7FF00E6FF00001400FF
FF000000FF57FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00002300FFFF0000FF000000FF28FF0000FF0000FF0000FF0000FF0000FF000000FF38
FF0000AE00FFAEFF00DCFF00EBFF00FAFF00FAFF00FAFF00FAFF00FAFF00FAFF00FAFF00
FAFF00DCFF00CCFF0080FF0080FF00FF00B80028FF00FF2814FF0023FF0000FF8500C2FF
00FF75FF0000FF0000FF0000FF0000BD00FFFF0000FF000000FFFFFF00006100FF00FF57
00FF190057FF42FF0005FF000047FFFF0000FF0000EB00FF00FFF000FF8500A3FF00FF57
00FF660085FF00FF2814FF0000FF8533FF0051FF00BDFF00CCFF00CCFF009EFF0005FF00
00FF579EFF0051FF00EBFF00FFE600FFD700FFC700FFC700FFB800FFB800FFA800FFA800
FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00
FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00
FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FFA800FFA800FFA800FFB800FFA800FFA800FFA800FFA800FFB800FFB800
FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFD700FFD700FFE600FFF500EBFF00
9EFF0000FF1900FF8500FF7542FF0070FF0080FF0061FF0023FF0000FF198F00FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00A823FF0051FF0070FF0080FF0070FF0061FF00FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF000000FF94FF0000FF0000FF0000FF0000FF000000FFF000FFB3
42FF0061FF00BDFF00CCFF00EBFF00EBFF00FAFF00FAFF00FAFF00FAFF00FAFF00FAFF00
EBFF00DCFF00CCFF00AEFF008FFF0005FF00FF000000FFFF00FFA3FF007AAE00FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFD1
00FFE1FF000005FF00FF000000E1FFFF0000FF0000FF0000FF00000085FFFF00002300FF
0500FF00FF0A42FF0051FF0051FF0080FF00BDFF00DCFF00DCFF00DCFF00CCFF0070FF00
9EFF0051FF0051FF0005FF00FFF500FFE600FFD700FFC700FFC700FFB800FFA800FFA800
FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF8A00
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800
FFB800FFB800FFB800FFC700FFC700FFC700FFD700FFD700FFD700FFE600FFF500FAFF00
DCFF008FFF0005FF000094FF0028FF00FF8561FF0061FF0033FF0000FF0A00FF940028FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00D7FF00B800FF1951FF0070FF0070FF0061FF0042FF0014FF00AE00FF8F00FFFF0000
FF0000000AFFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF000000B3FFFF0000FF0000FF0000FF0000FF00000085FFFF0000
61FF009EFF00BDFF00CCFF00DCFF00DCFF00EBFF00EBFF00FAFF00EBFF00FAFF00EBFF00
EBFF00DCFF00CCFF00BDFF008FFF00FF00D7FF0000FF0000FF009900FFC2FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00F5
FF000000FF8500FF3800FF94FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
00FF9414FF0061FF008FFF009EFF00BDFF00DCFF00DCFF00EBFF00EBFF00EBFF00CCFF00
CCFF009EFF0014FF00CCFF00FFF500FFE600FFD700FFD700FFD700FFC700FFA800FFA800
FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800
FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFD700FFD700FFE600FFF500FAFF00
CCFF008FFF0051FF0000FF196100FF14FF0042FF0042FF0000FF0A00FF7500B3FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
EB00FF5100FF00FFD142FF0051FF0051FF0000FFA300FFB3FF001E00FF66FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
70FF008FFF009EFF00BDFF00AEFF00CCFF00DCFF00EBFF00EBFF00EBFF00EBFF00EBFF00
DCFF00DCFF00CCFF009EFF0080FF0000FFC20500FFFF0000FF00000047FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF000000FFA3000AFFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00F5
FF006B00B3FF00FFE19EFF00BDFF00CCFF00DCFF00EBFF00FAFF00FAFF00FAFF00EBFF00
DCFF0051FF00FF000014FF00FAFF00FFF500FFF500FFE600FFE6009EFF00FFB800FFA800
FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800
FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFD700FFD700FFE600FFF500EBFF00
00C2FF00F0FF00E1FF00FF28CC00FF00FF5733FF0005FF00EB00FF00FFC20066FFFF000F
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF000033FF0042FF004200FFFF0000FF00000075FF00FFE10019FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0A
61FF0070FF00FF00008FFF0000FFC2FF0099CCFF00DCFF00DCFF00DCFF00EBFF00DCFF00
DCFF00CCFF0061FF00FF000005FF0023FF00FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000066FF0019FFFF0000FF0000FF0000FF0000FF0000FF0000FF000000F0FF
00FF3800FFB380FF00AEFF00BDFF00CCFF00EBFF00EBFF00FAFF00FAFF00FAFF00FAFF00
EBFF0080FF0005FF00AEFF00DCFF00FAFF00DCFF00EBFF00DCFF00FFE600FFB800FFA800
FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800
FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFD700FFD700FFE600FFF500EBFF00
AEFF0051FF0000FF470038FF0019FF00FF1905FF0000FF190094FF0075FFFF0000EB00FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF000000FF0A23FF0023FF0005FF00FF0000FF0000FF00001400FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF3814FF00
51FF0014FF0000E1FF00FF0AFF000000FF5700FFF0CCFF00DCFF00DCFF00DCFF00DCFF00
CCFF00AEFF0061FF00FF004CFF000F00FF0A00FFA3FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000DC00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
00FF1951FF0080FF009EFF00AEFF00CCFF00EBFF00FAFF00FFF500FFF500FFF500FFF500
FAFF00DCFF008FFF0000FF2800E1FFCCFF0005FF00EBFF00CCFF00FFC700FFA800FFA800
FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800
FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFD700FFD700FFE600FAFF00DCFF00
61FF0000FFFF00FF660047FF00FFE100FF38FF000000FF85FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF000000FF0A05FF00FF00A800FF85FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFA3FF0000
05FF0005FF0000FF85FF0000FF0000FF001E05FF00BDFF00CCFF00DCFF00DCFF00CCFF00
BDFF007000FF00FF6600E1FF00FF7500FF570047FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000E1FF
00FF1923FF0070FF0070FF0000FFE1BDFF00DCFF00FAFF00FFF500FFF500FFF500FFF500
FFF500FAFF009EFF008FFF00BDFF0000FFD180FF00FFF500FFD700FFB800FFA800FFA800
FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FF9900FF9900
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800
FFB800FFB800FFB800FFC700FFC700FFC700FFD700FFD700FFE600FFF50042FF00BDFF00
00FF4714FF0000FF7500FFB30066FFFF00000500FF00FFF0FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF000000FF2800FF19DC00FFFF00000019FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
00FFB3FF0000FF005CFF002EFF0000FF000000FF75AEFF00CCFF00CCFF00CCFF00CCFF00
AEFF0042FF0023FF001400FF00FFB3DC00FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000BD00FF
6100FF00FFC233FF0000C2FF00FFE161FF0070FF00FAFF00FFF500FFE600FFE600FFE600
FFE600FFF500FAFF00DCFF00FAFF00CCFF00DCFF00EBFF00FFD700FFB800FFA800FFA800
FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFC700FFC700FFC700FFD700FFD700FFE600FAFF0000FF8570FF00
00FF5770FF0000FFA300FF1900FF47FF003DFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF000000FF47DC00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
00FFC2FF0000FF0000FF00001400FFFF000005FF009EFF00BDFF00BDFF00BDFF00BDFF00
AEFF008FFF0061FF00AE00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000DC00FF
00A3FF0028FF00FFC242FF008FFF009EFF00CCFF00FFF500FFE600FFE600FFE600FFD700
FFD700FFD700FFE600FFE600FFE60000FF38FFE600AEFF00FFC700FFA800FFA800FF9900
FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800
FFB800FFB800FFB800FFC700FFC700FFC700FFD700FFD700FFE60000FF0A00FFB342FF00
8FFF008FFF005100FF05FF0023FF0000FFE100FF38FF00000019FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF000000FF8500FF85FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF000000F0FFFF000061FF009EFF00AEFF00AEFF00BDFF00AEFF00
AEFF008FFF0042FF0000FF66FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000085FF00FF0A
14FF0023FF006100FF00FF66AEFF00EBFF00FAFF00FFF500FFE600FFE600FFD700FFD700
FFD700FFD700FFD700FFD700FFD700FFE600FFC700FFC700FFB800FFA800FFA800FF9900
FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800
FFB800FFB800FFC700FFC700FFC700FFC700FFD700FFD700FFE600FAFF000057FFDCFF00
CCFF009EFF0000D1FF05FF0051FF0051FF00FF00F5FF000000FF85FF004CFF008AFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF000000FFB3FF0000FF002EFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF000023FF0014FF0070FF008FFF00AEFF00AEFF00AEFF00
9EFF0070FF000038FF00FF850028FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000028FF0075FFFF00E600FF752300FF00FFFF
61FF0070FF0000FFA38FFF0033FF00FAFF00FFF500FFE600FFE600FFD700FFD700FFD700
FFC700FFC700FFC700FFC700FFC700FFC700FFB800FFB800FFA800FFA800FF9900FF9900
FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FF9900FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFD700FFE600FFE600FAFF00FAFF00
DCFF00BDFF0061FF0000FFC270FF0080FF0033FF00CC00FF14FF0000D1FF00FF6600F0FF
FF003DFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
00E1FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF000000FF7500FF386100FF00FFC2FF00008FFF009EFF009EFF00
8FFF000019FF0028FF00FFF0FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFA300FF3805FF0000FFB342FF00
8FFF008FFF0005FF00CCFF00EBFF00FAFF00FFF500FFE600FFD700FFD700FFD700FFD700
FFC700FFC700FFC700FFB800FFB800FFB800FFB800FFA800FFA800FFA800FF9900FF9900
FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800
FFB800FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFD700FFE600FFF500FAFF00
EBFF0014FF0000FF280075FF51FF009EFF008FFF0080FF0051FF0023FF0000FF19FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF000000FF9400B3FFFF0000FF000042FF008FFF008FFF00
80FF0042FF000028FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000000AFF00FF1923FF0061FF008FFF00
AEFF00BDFF0000FF19DCFF00FAFF00FFF500FFE600FFE600FFD700FFD700FFC700FFC700
FFC700FFC700FFB800FFB800FFB800FFB800FFA800FFA800FFA800FF9900FF9900FF9900
FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFC700FFC700FFC700FFD700FFD700FFD700FFD700FFE600FFE600FFF500
FAFF00AEFF000019FF80FF00AEFF00BDFF00AEFF008FFF0042FF0014FF0000FF0A00FF66
00B3FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00004200FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000051FF0080FF0080FF00
70FF0051FF00FF00B8FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000038FF00FF7523FF0070FF008FFF00
AEFF00CCFF00DCFF00EBFF00FAFF00FFF500FFE600FFE600FFD700FFD700FFC700FFC700
FFC700FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800FF9900FF9900FF9900
FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FFA800FF9900FF9900FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800
FFC700FFB800FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFE600FFE600FFF500
FAFF00BDFF00AEFF00AEFF00CCFF00CCFF00BDFF0070FF0000FF8500FFB300FF57FF0000
2300FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00B8FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF2833FF0061FF0070FF00
61FF0042FF00FF005C0085FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFC223FF0061FF0000FF47
8FFF00CCFF00EBFF00FAFF00FFF500FFF500FFE600FFE600FFD700FFD700FFC700FFC700
FFC700FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800FF9900FF9900FF9900
FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFD700FFD700FFE600FFE600
FFF500FAFF00EBFF00DCFF00DCFF00DCFF00BDFF0000FFF000FF3800FFE1FF000000FF94
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFFFAE00FFFF004C51FF00
51FF0014FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000DC00FF00FF7505FF0014FF00FF005C
70FF00DCFF00EBFF00FAFF00FAFF00FFF500FFE600FFE600FFD700FFD700FFC700FFC700
FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FFA800FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFD700FFD700FFE600FFE600
FFF500FFF500FAFF00EBFF00EBFF00DCFF00CCFF00AEFF00FF0000FA00FFFF00000075FF
FF0000FF00008F00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000057FF33FF00
42FF0023FF000047FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00004200FF00E1FF00FF5700FFC2
AEFF00DCFF00EBFF00EBFF00FAFF00FFF500FFE600FFE600FFD700FFD700FFC700FFC700
FFB800FFB800FFB800FFA800FFA800FFA800FFA800FF9900FFA800FF9900FF9900FF9900
FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00
FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FFA800FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFC700FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFD700FFE600FFE600FFE600
FFF500FFF500FAFF00FAFF00EBFF00EBFF00DCFF00BDFF0014FF0000B3FFFF00F5FF0000
FF00008000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF005CFF006B
23FF0014FF0000FFC2FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF2823FF00
BDFF00DCFF00EBFF00EBFF00FAFF00FAFF00FFF500FFE600FFE600FFD700FFC700FFC700
FFB800FFB800FFB800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900
FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800
FFA800FFA800FFB800FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFC700FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFD700FFD700FFE600FFE600
FFF500FFF500FFF500FAFF00FAFF00EBFF00DCFF00BDFF0000FF190057FF00FF5723FF00
00FF9400FF2800FFA3FF004CFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
05FF0005FF0000FF66FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000038FF42FF0042FF00
BDFF00CCFF00DCFF00DCFF00EBFF00CCFF00FAFF00FFF500FFE600FFD700FFD700FFC700
FFB800FFB800FFB800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FFA800FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFD700FFD700FFE600FFE600
FFE600FFF500FFF500FAFF00FAFF00EBFF00EBFF00BDFF0014FF0080FF0000FF8551FF00
61FF00FF00004200FF0047FFFF0000FF0099FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000028FF
FF000000FF1900FF66FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFA314FF0061FF008FFF00
AEFF00CCFF00CCFF00CCFF00CCFF0000FF75CCFF00FFF500FFF500FFF500FFF500FFC700
FFB800FFB800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FFA800FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700
FFC700FFC700FFC700FFC700FFD700FFD700FFD700FFD700FFD700FFE600FFE600FFE600
FFE600FFF500FFF500FAFF00FAFF00EBFF00EBFF00DCFF00BDFF00AEFF0042FF008FFF00
80FF0005FF00FF00C70047FFFF00002300FF3300FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0075FF00FF5700FF66FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFA314FF0000FFA38FFF00
AEFF00AEFF0070FF0080FF00AEFF0033FF0061FF00EBFF00DCFF00DCFF00EBFF00FFC700
FFB800FFB800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFB800FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFD700FFD700FFE600FFE600FFE600
FFE600FFF500FFF500FAFF00FAFF00FAFF00EBFF00DCFF00CCFF00BDFF00AEFF009EFF00
9EFF0051FF0000FF0A0019FF05FF00FF0000EB00FFFF0000FF00E6FF0000FF0000FF0000
FF00000028FF4200FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF000000F0FF00FF85FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFA300FF2800FF6661FF00
9EFF009EFF0080FF0000FF2814FF0000FF0A9EFF00CCFF00AEFF00AEFF00FFE600FFC700
FFB800FFB800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFD700FFD700FFD700FFD700FFD700FFD700FFE600FFE600FFE600
FFF500FFF500FFF500FAFF00FAFF00FAFF00EBFF00DCFF00DCFF00CCFF00BDFF00AEFF00
9EFF008FFF0070FF0051FF0051FF00FF00005100FF00FF19FF0000FF000000FF9400FFC2
00E1FF0500FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF000000FFFF00B3FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00005100FF0057FF00FFD100FFFF0094FF
8FFF0080FF00FF000000FF8500FF5723FF0000FF280094FF61FF0000FF19FFE600FFC700
FFB800FFB800FFA800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900
FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFD700FFD700FFD700FFD700FFE600FFE600FFE600FFE600
FFF500FFF500FFF500FAFF00FAFF00EBFF00EBFF00DCFF00DCFF00CCFF00BDFF00AEFF00
AEFF009EFF008FFF0070FF0061FF0042FF0023FF0014FF0000FF1900FF4700FF85FF007A
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF000000D1FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00006100FF51FF00
70FF0061FF00FF000000FF0A80FF00AEFF00BDFF0051FF00DCFF00FAFF00FFD700FFB800
FFB800FFB800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FF9900FF9900FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFD700FFD700FFD700FFD700FFD700FFE600FFE600FFE600FFE600FFF500
FFF500FFF500FAFF00FAFF00FAFF00EBFF00EBFF00DCFF00DCFF00CCFF00BDFF00BDFF00
9EFF009EFF008FFF0070FF0061FF0051FF0033FF0005FF0000FF1900FFF0FF0000FF00B8
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFC2FF0000
42FF0033FF00FF008A05FF0061FF00BDFF00DCFF00FAFF00FFE600FFD700FFC700FFB800
FFB800FFA800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00
FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FF9900FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800
FFB800FFB800FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFD700
FFC700FFD700FFD700FFD700FFD700FFD700FFE600FFD700FFE600FFE600FFE600FFF500
FFF500FAFF00FAFF00FAFF00EBFF00EBFF00EBFF00DCFF00DCFF00CCFF00BDFF00AEFF00
9EFF009EFF008FFF0070FF0051FF0042FF0014FF00FF00B800FF66FF0000FF00F5FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00005100FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF9400FFA3
00FF1905FF0000FF9400FF382300FF8FFF00CCFF00FFF500FFD700FFC700FFC700FFB800
FFB800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800
FFA800FFB800FFA800FFA800FFA800FFB800FFA800FFB800FFB800FFB800FFB800FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFD700FFD700
FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFE600FFE600FFE600FFF500FFF500
FFF500FAFF00FAFF00EBFF00EBFF00EBFF00DCFF00DCFF00CCFF00CCFF00BDFF009EFF00
8FFF008FFF0080FF0051FF00FF000014FF00FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000094FFFF0000FF00005100FFFF004C00B3FF
1400FF00D1FF00FFC2FF00D770FF000094FFDCFF00FFF500FFD700FFC700FFB800FFB800
FFB800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF7A00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFC700FFC700
FFC700FFC700FFC700FFC700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700
FFD700FFD700FFD700FFD700FFD700FFD700FFE600FFE600FFE600FFE600FFF500FFF500
FAFF00FAFF00EBFF00DCFF00DCFF00DCFF00DCFF00CCFF00CCFF00BDFF00AEFF00FF004C
23FF0070FF0061FF00FF0000FF0000FF0000FF0000FF0000FF00D7FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000057FF0066FFFF00F500FF578F00FF23FF00
33FF0042FF0051FF0000FF949EFF0005FF00BDFF00EBFF00FFD700FFC700FFB800FFB800
FFA800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF7A00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFD700
FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700
FFD700FFD700FFE600FFD700FFD700FFE600FFE600FFE600FFE600FFF500FFF500FAFF00
FAFF00CCFF00BDFF009EFF00CCFF00CCFF00CCFF00CCFF00BDFF0042FF00CC00FF00FF94
00B3FF51FF0042FF00FF0000FF00000047FF00E1FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00006100FF00FFB314FF0000FF5700FF280057FF00FF94
9EFF008FFF0070FF0042FF00BDFF009EFF0014FF00EBFF00FFD700FFC700FFB800FFB800
FFB800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF7A00FF7A00FF7A00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFC700FFB800FFC700FFC700FFE600
42FF0061FF00FFE600FFE600FFE600FFF500FFF500FFE600FFD700FFD700FFE600FFD700
FFD700FFD700FFD700FFD700FFE600FFE600FFE600FFE600FFF500FFF500FAFF00FAFF00
EBFF00AEFF000500FF0075FFAEFF00BDFF00BDFF00BDFF00AEFF0000FF75DC00FFFF00C7
EB00FF05FF0005FF00FF0000FF0000FF0000CC00FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF005C51FF0080FF008FFF0000FF758FFF00
BDFF00AEFF0000FF388FFF00EBFF00FAFF00FAFF00FFD700FFC700FFC700FFB800FFB800
FFA800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFD700FFE600
00FF94BDFF00EBFF00EBFF00FAFF00BD00FFDCFF00FFF500FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF500FAFF00EBFF00EBFF00EBFF00
CCFF009EFF0000FFC200FF859EFF00AEFF00BDFF00AEFF008FFF0000FF66FF0000FF0000
FF00F5BD00FF00FF2800FFF0FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000075FF0019FF33FF0061FF008FFF00AEFF00CCFF00DCFF00
DCFF00BDFF0000FFB3AEFF00FAFF00FFE600FFD700FFC700FFC700FFB800FFB800FFA800
FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00
FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFD700FFF500
CCFF0070FF0080FF0080FF00CCFF0005FF0051FF00EBFF00FFF500FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFF500FFF500FFF500CCFF0070FF00BDFF00BDFF00
FF007A61FF000500FF42FF0061FF0070FF009EFF009EFF0080FF0014FF005100FFFF0000
FF0000FF0000FF0000FF00005100FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000BD00FF00FF7523FF0033FF0061FF009EFF00DCFF00EBFF00
EBFF00EBFF009EFF008FFF00DCFF00FFD700FFD700FFC700FFC700FFB800FFB800FFB800
FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00
FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900
FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFD700FFE600CCFF00
8FFF000019FF00FF6633FF0000FF8500C2FF61FF0051FF00FAFF00FFF500FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFF500FFF500FAFF00CCFF0000B3FF61FF0014FF00
000AFF00FFA300FFD105FF00FA00FF00FFFF80FF008FFF0070FF0000E1FFFF0000FF0000
FF0000FF00000075FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000500FF00FF3800FF3800D1FF0057FF00FF57DCFF00FAFF00
FAFF00FFF500FAFF00FAFF00FFE600FFD700FFC700FFC700FFB800FFB800FFB800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00
FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFD700FFD700FFE600EBFF00
8FFF000066FF00FF6642FF0061FF008FFF00BDFF00CCFF00FAFF00FFF500FFF500FFF500
FFE600FFE600FFE600FFF500FFF500FFF500FFF500FAFF00DCFF000500FF00F0FF00FFF0
FF0000FF000000FFB3AE00FF0047FF000AFF61FF0080FF0051FF00FF000000FFD1FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
000AFFDC00FF00FF668000FFFF000000FF940094FF00E1FF23FF0070FF00BDFF00FAFF00
FFF500FFF500FFE600FFE600FFD700FFC700FFC700FFC700FFB800FFB800FFB800FFA800
FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00
FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800
FFB800FFB800FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFE600FFE600FAFF00
05FF000075FF23FF0033FF008FFF00BDFF00CCFF00EBFF00FAFF00FFF500FFF500FFF500
FFF500FFF500FFF500FFF500FFF500FFF500FAFF00EBFF00DCFF009EFF00FF0000DC00FF
FF0000FF006B7000FF00FFF00066FF14FF0042FF0051FF0051FF00FF000000FF57FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0028FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000CC00FFFF0000
FF000000FF4705FF0000FF5700FFA300FFD100FFFF00FF7580FF003300FFDCFF00FFF500
FFE600FFE600FFD700FFD700FFD700FFC700FFC700FFC700FFB800FFB800FFB800FFA800
FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800
FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFD700FFE600FFE600FFF500EBFF00
8FFF008FFF0051FF0014FF0000FF19BDFF00DCFF00EBFF00FAFF00FAFF00FFF500FFF500
FFF500FFF500FFF500FFF500FFF500FFF500FAFF00EBFF00BDFF0000FF856100FF0094FF
FF005CFF000000B3FF00FFFF00FF576100FFFF00B805FF0023FF0014FF0000FF47FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF000000F0FF00E1FFFA00FFFF0000FF0000FF0000FF00D7FF0000FF000F00FFA38F00FF
8000FFFF0000FF000070FF008FFF0070FF002300FF61FF00AEFF00EBFF00FFF500FFE600
FFE600FFD700FFD700FFD700FFC700FFC700FFC700FFB800FFB800FFB800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FF9900FF9900FF9900FF9900
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFC700FFC700
FFD700FFD700FFC700FFC700FFD700FFD700FFE600FFF500FAFF00FAFF00FAFF00EBFF00
CCFF008FFF0051FF0000FFFF5100FF23FF00DCFF00EBFF00EBFF00FAFF00FAFF00FFF500
FFF500FFF500FFF500FFF500FAFF00FAFF00FAFF00EBFF0070FF0000FF3800FF0AFF0000
FF0000FF0000FF00B83300FF6100FFFF0000FF0000FF000000FF0A0019FFFF000000B3FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF000000FF9400FF66FF000000FFB300FFB30028FF00FF66FF00990047FF23FF00
00FF280028FF00FF4780FF00BDFF009EFF0000FF19CCFF00DCFF00FFF500FFF500FFE600
FFE600FFD700FFD700FFC700FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFA800
FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFC700FFC700FFC700FFE600
DCFF00FFE600FFD700FFD700FFD700FFE600FFF50000FFC200F0FFAEFF00EBFF00DCFF00
BDFF0000FFE10085FF00A3FF00FF28AEFF00DCFF00EBFF00EBFF00FAFF00FAFF00FAFF00
FAFF00FAFF00FAFF00FAFF00FAFF00FAFF00EBFF00DCFF00CCFF009EFF00FF001E00FFC2
FF00B800E1FFFF00B8FF0000FF0000FF0000FF000000D1FF00FF47FF0000FF0000FF008A
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF000000FF5700FF1905FF0023FF0005FF00000AFF0038FFFF000061FF00
51FF0005FF008FFF00AEFF00CCFF00DCFF00DCFF00EBFF00FAFF00FFF500FFE600FFE600
FFD700FFD700FFD700FFC700FFC700FFC700FFB800FFB800FFB800FFB800FFA800FFA800
FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF8A00FF8A00FF8A00FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FFA800FFA800FFA800FFA800FFB800FFB800FFC700FFD700FFD700FFE600FAFF00
00FFF000FF47FFE600FFE600FFE600FFE600FAFF0033FF0042FF00BDFF00CCFF00AEFF00
80FF0023FF00FF000000FFB380FF00BDFF00CCFF00DCFF00EBFF00EBFF00EBFF00EBFF00
FAFF00FAFF00FAFF00FAFF00FAFF00FAFF00EBFF00DCFF00CCFF00AEFF0000FF19FF00D7
00FFB300C2FFFF0000FF0000FF0000FF0000FF0000FF00D700F0FFFF001EFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF000000FF2814FF0042FF0051FF0070FF0080FF008FFF009EFF00
AEFF00AEFF00BDFF00DCFF00DCFF00EBFF00FAFF00FAFF00FFF500FFE600FFE600FFE600
FFD700FFD700FFC700FFC700FFC700FFC700FFC700FFB800FFB800FFB800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF6B00
FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800
FFA800FFA800FFA800FFA800FFB800FFB800FFC700FFE60000FF94FFF50023FF00CCFF00
80FF00DCFF00FFF500FFF500FFF500FAFF00EBFF00BDFF0000C2FF9EFF00AEFF0000FF75
AE00FFEB00FF1400FF00F0FF00E1FFBDFF00CCFF00DCFF00DCFF00DCFF00DCFF00EBFF00
EBFF00EBFF00EBFF00EBFF00EBFF00EBFF00EBFF00DCFF00CCFF009EFF000066FF00A3FF
00FF8500FF941400FFFF0000FF0000FF0000FF0000FF00000038FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF000005FF0033FF0061FF0070FF008FFF009EFF00AEFF00
BDFF00CCFF00DCFF00DCFF00EBFF00FAFF00FAFF00FFF500FFF500FFE600FFE600FFD700
FFD700FFD700FFD700FFC700FFC700FFC700FFB800FFB800FFB800FFB800FFA800FFA800
FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800
FFA800FFA800FFA800FFA800FFB800FFB800FFC700BDFF0080FF00CCFF0061FF0061FF00
BDFF00DCFF00FAFF00FAFF00EBFF0000FF85AEFF009EFF0000B3FF0085FF8FFF0005FF00
00C2FF05FF0033FF0033FF0070FF00BDFF00CCFF00CCFF00DCFF00CCFF00CCFF006100FF
DCFF00EBFF00EBFF00EBFF00EBFF00EBFF00DCFF00DCFF00CCFF00FF0000FF000000FF47
05FF000075FFFF0099FF0000FF0000FF0000FF0000FF00008000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF000000FF6600FF2851FF0070FF008FFF009EFF00AEFF00
BDFF00CCFF00DCFF00EBFF00EBFF00FAFF00FAFF00FFF500FFE600FFE600FFE600FFE600
FFD700FFD700FFC700FFC700FFC700FFC700FFB800FFB800FFB800FFB800FFA800FFA800
FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00
FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800
FFA800FFA800FFA800FFA800FFB800FFB800FFC700FFE600EBFF009EFF0000FFA351FF00
AEFF00CCFF00DCFF00EBFF00CCFF0033FF0070FF0080FF0000FF3842FF0070FF0042FF00
00FF57000AFF51FF0070FF008FFF00AEFF00BDFF00CCFF00BDFF008FFF00AEFF00FF005C
AEFF00DCFF00DCFF00DCFF00DCFF00DCFF00DCFF00CCFF00BDFF009EFF0070FF0033FF00
23FF006100FF0019FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00E6000AFF33FF0000E1FF80FF009EFF00AEFF00
BDFF00CCFF00DCFF00EBFF00EBFF00FAFF00FFF500FFF500FFE600FFE600FFE600FFD700
FFD700FFD700FFC700FFC700FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFA800
FFA800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00
FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF8A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00
FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFB800FFB800FFC700FFD700BDFF0000FF8500FF3861FF00
00FF1980FF0033FF00BDFF00BDFF0000FF0A00F0FF51FF000085FF14FF0033FF008F00FF
FF0000EB00FF61FF0080FF009EFF00AEFF00AEFF00BDFF00AEFF0000FF9442FF0000FF38
70FF00AEFF00BDFF00AEFF00CCFF00CCFF00CCFF00CCFF00BDFF00AEFF008FFF0070FF00
51FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF000000A3FFFF002EFA00FF80FF008FFF009EFF00
BDFF00CCFF00DCFF00EBFF00EBFF00FAFF00FFF500FFF500FFE600FFE600FFE600FFD700
FFD700FFD700FFC700FFC700FFC700FFC700FFB800FFB800FFB800FFB800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF8A00FF8A00
FF7A00FF7A00FF8A00FF8A00FF7A00FF8A00FF8A00FF7A00FF7A00FF7A00FF8A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800
FFA800FFA800FFA800FFB800FFB800FFB800FFC700FFD70033FF00DCFF0051FF00AEFF00
51FF000047FF00FF2814FF0080FF0070FF0000FF1900FF471400FF00FF0A00FF0A7000FF
00FFF033FF0070FF0080FF008FFF009EFF009EFF008FFF0005FF00FF00A800FF75FA00FF
00C2FF51FF000028FF00FFA3AEFF00BDFF00CCFF00BDFF00BDFF00AEFF008FFF0080FF00
51FF00FF0000CC00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF000000A3FFFF0000FF000061FF0070FF0000FF0A
AEFF00CCFF00DCFF00EBFF00EBFF00FAFF00FAFF00FFF500FFE600FFE600FFE600FFD700
FFD700FFD700FFC700FFC700FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFA800
FFA800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF8A00FF7A00FF7A00FF8A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF7A00FF7A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF9900FF9900FF9900FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800
FFA800FFA800FFA800FFA800FFB800FFB800FFC700FFC700FFD700FFF50080FF00EBFF00
DCFF0014FF0000FF5700FFA300FF38FF000014FF00FF000000FFC200FF475100FFFF0000
00FF0A42FF0061FF0070FF0080FF008FFF008FFF0061FF0000FF7500FF47FF0000FF0000
FF0000FF000000FF19FF00000028FFAEFF00BDFF00BDFF00AEFF009EFF0070FF0042FF00
42FF0023FF0000FF2800FFB3FF00008F00FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000033FF0000FF38FF008A
9EFF00CCFF00CCFF00DCFF00EBFF00EBFF00FAFF00FFF500FFE600FFE600FFE600FFD700
FFD700FFD700FFC700FFC700FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFA800
FFA800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF6B00FF6B00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00
FF7A00FF7A00FF8A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF8A00FF8A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00
FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FF9900FF9900FFA800FFA800
FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFC700FFD700FFE600FFF500FAFF00
EBFF00CCFF009EFF0080FF0000FF2800FF6600FFFF00FFA3FF00C76100FF00FFA300FF19
14FF0042FF0051FF0051FF0000FF7580FF0080FF0061FF0000FF0ACC00FFEB00FF0028FF
FF00F500FF571400FFFF00A880FF009EFF00AEFF00AEFF009EFF0080FF0023FF0000FF38
FF000000FF0A00FF75FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFA300FF28FF0000FF0000
00FFE1BDFF00CCFF00CCFF00DCFF00DCFF00FAFF00FFF500FFF500FFE600FFE600FFE600
FFD700FFD700FFD700FFC700FFC700FFC700FFC700FFB800FFB800FFB800FFB800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00
FF7A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00
FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF7A00
FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800
FFA800FFB800FFA800FFA800FFB800FFB800FFB800FFC700FFD700FFD700FFE600FAFF00
EBFF00DCFF00BDFF009EFF0070FF0023FF0000FF3800FFE1FF00D700FFC200FF5700FF19
14FF0033FF0000FF2800FF28FF000014FF0014FF0051FF0023FF0000FF3800FFB300FFD1
FF000000FF6614FF0051FF0080FF009EFF009EFF009EFF0080FF00FF0000FF00000047FF
FF000000FF57FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF004CFF0000
FF0000AEFF00AEFF00BDFF00AEFF0000FF75EBFF00FFF500FFF500FFE600FFE600FFE600
FFD700FFD700FFD700FFD700FFC700FFC700FFC700FFC700FFB800FFB800FFB800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00
FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800
FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFC700FFC700FFD700FFE600FAFF00
EBFF00DCFF00BDFF0005FF0051FF009E00FF7000FF00FFA300FFF0FF00A8FF000000FFE1
00C2FF05FF0000FF28BD00FFFF004CFF000F0066FF23FF0014FF0000FF1900FF6600FFFF
FF00000066FF14FF0042FF0070FF008FFF008FFF008FFF0005FF000028FFFF0000AE00FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000066FF
FF00008FFF009EFF000066FF70FF007000FFDCFF00FAFF00FFF500FFF500FFE600FFE600
FFE600FFD700FFD700FFD700FFC700FFC700FFC700FFB800FFB800FFB800FFB800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FFA800FF9900FF9900FF9900FF9900FFA800FFA800FFA800
FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFC700FFC700FFD700FFF50061FF00
CCFF00CCFF0080FF0000D1FF00FF570019FF00FF1900FFB300FF9400D1FFFF000000D1FF
0028FFFA00FF00FF4700FFA3FF000000FFB300FF3800FF28FF000000FF94FF001EFF0000
FF00000094FF00FF28FF001E0057FF61FF0080FF0080FF0061FF0000FFF0FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF94
FF000070FF0061FF0000FF3800FF1951FF00CCFF00FAFF00FAFF00FFF500FFE600FFE600
FFE600FFE600FFD700FFD700FFD700FFC700FFC700FFB800FFB800FFB800FFB800FFB800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF8A00FF8A00FF8A00
FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FFA800FF9900FF9900FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFC700FFC700FFD700FFF50000FF28
AEFF00AEFF0033FF0000FFF005FF0033FF0014FF00FF00001400FF00FF3800FFC2FF0000
9E00FF00FFC2FF000000F0FFFF00004200FF00FF758000FFFF008AFF00000085FFFF0000
FF0000FF000000FF94FF0000FF000023FF0061FF0070FF0051FF0000FFB3FF003DFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000E1FF00FF47
23FF0042FF0000A3FFFF0000FF00C700FFFFFF00B8EBFF00FAFF00FFF500FFF500FFE600
FFE600FFE600FFE600FFE600FFD700FFD700FFC700FFC700FFB800FFB800FFB800FFB800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF8A00
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFB800FFB800FFB800FFC700FFC700FFC700FFD700FFF5009EFF00
23FF0000FFA3FF000042FF0070FF0061FF0000FF2800B3FF00FF3800FF0A00FFD10057FF
FF0000FF0000FF0099FF0000FF0000FF000000C2FF0066FFFF00F5FF0000FF0000FF0000
FF00005100FFFF000000B3FFFF0000FF000000FF0A51FF0042FF0014FF0000FF57FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
00FF66FF000000FF6600E1FFEB00FFFF009951FF00EBFF00FAFF00FAFF00FFF500FFF500
FFF500FFF500FFF500FAFF00FAFF00FFD700FFC700FFC700FFB800FFB800FFB800FFB800
FFB800FFA800FFA800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF8A00FF9900FF8A00FF9900FF8A00FF9900FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFD700FAFF0000FF57
00FF2800FF0A33FF008FFF009EFF0000A3FF05FF00FF00C74200FF23FF0000FF0A00FF75
00FFC20019FFFF0000FF0000FF0000FF00002300FFAE00FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF000000FF2823FF0042FF0000FF0A0094FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000B3FF
FF0000FF00006100FFFF00004200FF7000FF00FF57DCFF00EBFF00FAFF00FAFF00FFF500
FFF500FFF500FAFF00EBFF0000FFC2FFE600FFD700FFC700FFC700FFB800FFB800FFB800
FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF9900FFA800FFB800FFA800FFA800FFA800FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFC700FFC700FFD70061FF0080FF00
0057FFAEFF00BDFF00BDFF00AEFF000085FF00FF6600FFE114FF0042FF0023FF0000FF0A
00FFA31400FFFF0000FF0000FF0000FF0000FF004CFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00008000FFFF000005FF0023FF000028FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF000000FFF0FF00009EFF00DCFF00EBFF00EBFF00FAFF00FAFF00
FAFF00FAFF00EBFF00BDFF0000FF38EBFF00FFD700FFC700FFC700FFB800FFB800FFB800
FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF9900FF9900FFA800FFE600FFC700FFB800FFA800FFA800FFA800FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FFA800FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFE600EBFF000057FF
CCFF00DCFF00DCFF00CCFF00AEFF0000FF6600FFC205FF0051FF0051FF0000FF38FF0000
00FF9400D1FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000BD00FFFF000000FF0AFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000066FF00FF570057FF0066FFCCFF00DCFF00DCFF00DCFF00DCFF00
DCFF00EBFF00CCFF0042FF0000FF578FFF00FFE600FFD700FFC700FFC700FFB800FFB800
FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF9900FF9900FFA800FFD700FFE600FFE600FFC700FFC700FFA800FFA800
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00
FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFD700FFE600FFF500
FFF500FAFF00EBFF00CCFF009EFF0070FF00FF000000FFE161FF0070FF000038FF00FF38
0047FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF000000FF6600FF38FF0000000AFFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00B800FF280047FF61FF00CCFF00DCFF00DCFF00BDFF00EB00FF
FF00E6BDFF00BDFF0023FF0014FF00BDFF00FFE600FFD700FFC700FFC700FFB800FFB800
FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF9900FF9900FFA800FFC700FFE600EBFF00FFF500FFC700FFB800FFA800
FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF9900FF9900FF9900FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFC700FFC700FFD700FFD700FFE600
FFE600FFF500FAFF0061FF0000FF6651FF0000FF2800FF3870FF008FFF0080FF0000FF28
FF000000F0FF0075FFFF00E6FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00008000FF00FF75FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF000042FF0070FF009EFF00BDFF00CCFF00CCFF00AEFF0000FF94
00FFB305FF008FFF0000FFA380FF00DCFF00FFE600FFD700FFC700FFC700FFC700FFB800
FFB800FFB800FFA800FFA800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF9900FF9900FFA800FFB800FFC700FFD700EBFF00FFC700FFB800FFA800
FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800
FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFD700FFD700
FFE600FFE600FAFF00BDFF0033FF0000FF0A00FF1923FF008FFF009EFF008FFF00FF006B
00FF757000FF0085FF00F0FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00F5FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF000000FF2805FF0070FF009EFF009EFF00AEFF00AEFF009EFF0061FF00
000AFF00FF4761FF009E00FF9EFF00DCFF00FFF500FFE600FFD700FFC700FFC700FFB800
FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF9900FF9900FFA800FFA800FFB800FFD700DCFF00FFD700FFB800FFB800
FFA800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FFA800FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFD700FFD700
FFE600FFE600FFF500EBFF001400FF00FF7561FF00AEFF00AEFF009EFF008FFF0070FF00
42FF0005FF0000FF94FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF000000D1FF0094FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF000000F0FFFF000023FF0080FF0061FF0033FF0042FF0080FF0061FF00
00FFB300FFFF05FF00FF000051FF0070FF00DCFF00FFF500FFD700FFC700FFC700FFB800
FFB800FFB800FFB800FFB800FFA800FFB800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FF9900FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF9900FF9900FF9900FFA800FFB800FFB800FFD700AEFF00FFD700FFC700FFB800
FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF9900FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF8A00FF8A00FF8A00FF8A00
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFA800
FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFD700
FFD700FFE600FFF500EBFF0000D1FF33FF00CC00FFBDFF00BDFF00AEFF008FFF0070FF00
51FF0023FF000066FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000075FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF000014FF0051FF00FF00000038FFFF0000FF000042FF00
05FF001400FF0500FF3300FF0075FF33FF0023FF0080FF00FFD700FFC700FFC700FFB800
FFB800FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FF9900FFA800FF9900FFA800FF9900FF9900FF9900FF9900FF9900
FF9900FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00
FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF9900FF9900FFA800FFA800FFB800FFD7009EFF00FFD700FFC700FFC700
FFB800FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF9900FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF9900FF8A00FF8A00FF8A00
FF9900FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900
FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF8A00FF8A00FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FF9900FF9900FF9900FF9900
FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFC700FFD700
FFD700FFE600FFE600FAFF00DCFF0042FF00DCFF00DCFF00CCFF00AEFF0061FF0000FF57
00FFE114FF0000FFB3FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF000005FF0023FF0000FF38FF000000A3FF00FF2800FF38
00FF3800FF57FF001E9E00FF0019FF33FF00BDFF00FFF500FFD700FFD700FFC700FFC700
FFB800FFB800FFB800FFB800FFB800FFA800FFB800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FF9900FFA800FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF9900FF9900FF9900FFA800FFB800FFC700FFF500AEFF00FFE600FFD700FFC700
FFC700FFC700FFC700FFB800FFB800FFB800FFA800FFA800FFB800FFA800FFA800FFA800
FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF9900
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00
FF8A00FF9900FF9900FF8A00FF9900FF9900FF8A00FF8A00FF9900FF9900FF8A00FF8A00
FF9900FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00
FF8A00FF8A00FF8A00FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900
FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFD700FFD700
FFD700FFE600FFE600FFF500FAFF00FAFF00EBFF00EBFF00DCFF00AEFF00EB00FF00FF75
00FF4700FF2800FF4700FFFFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF000000FF28FF00000075FFFF00000057FF00FFE10057FF
00F0FFFF00998000FF7000FF00FFFF05FF00DCFF00FFF500FFE600FFD700FFC700FFC700
FFC700FFB800FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF9900FF9900FF9900FFA800FFA80070FF00DCFF00FFF500BDFF00FFE600FFE600
FFF500FFD700FAFF00FFC700FFB800FFB800FFB800FFB800FFB800FFC700FFD700FFB800
FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF9900FF9900
FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF8A00FF8A00FF9900FF9900FF8A00FF8A00FF8A00FF9900FF9900FF8A00
FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00
FF8A00FF8A00FF8A00FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900
FF9900FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFC700FFD700
FFD700FFD700FFE600FFE600FFF500FAFF00FAFF00EBFF00DCFF0080FF0023FF000500FF
4200FF00FF9400FF751400FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000AE00FF00FF85FF0000FF0000FF0000FF0000FA00FFFF0000
FF0000FF00000094FFFF000000FFF00066FF0057FFFFF500FFD700FFD700FFC700FFC700
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF9900FF9900FF9900FF9900FFA800FFA800FFC700FFD700FFD700EBFF00EBFF00BDFF00
8FFF00FAFF0061FF00FFD700FFC700FFC700FFC700FFC700FFD700FFD700FFE600FFB800
FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF9900FF9900FF9900FF8A00
FF8A00FF8A00FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00
FF8A00FF8A00FF8A00FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900
FF9900FF9900FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FF9900
FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFD700
FFD700FFD700FFE600FFE600FFF500FFF500FAFF00FAFF00EBFF00DCFF008FFF0000FFFF
00D1FF00D1FF00FFB3FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF000000F0FFFF0000FF0000FF0000FF0000FF0000FF0000
FF000000FFD100FF47FF000000FF478FFF0000FF38FFF500FFD700FFD700FFC700FFC700
FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFA800FFA800
FFA800FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF9900FF9900FF9900FFA800FFA800FFB800FFB800FFC7009EFF00FAFF00FFF500
FFF500CCFF00DCFF00FFE600FFD700FFC700FFC700FFD700DCFF0051FF00FAFF00FFB800
FFA800FFA800FF9900FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF8A00FF8A00FF9900FF9900FF9900FF8A00FF8A00FF8A00FF9900FF9900FF9900FF8A00
FF8A00FF8A00FF8A00FF9900FF9900FF9900FF8A00FF8A00FF8A00FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFC700FFD700FFD700
FFD700FFD700FFE600FFE600FFF500FFF500FAFF00FAFF00EBFF00DCFF00AEFF00FF008A
FF000000B3FFEB00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00004200FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0099DC00FF00FF0ABD00FF70FF00CCFF00FAFF00FFE600FFD700FFD700FFC700FFC700
FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFA800FFB800
FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFC700FFB800FFB800
FFA800FFA800FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900
FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFB800FFB800FFC700FFD700FFD700
FFE600FFF500DCFF00EBFF00FFE600FFE600FFD700FFF500EBFF00FFE600FFD700FFB800
FFB800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF9900
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF9900
FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFC700FFD700
FFD700FFD700FFE600FFE600FFE600FFF500FFF500FAFF00EBFF00DCFF0070FF0000FFD1
FF00002300FF0038FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
00FF9414FF0033FF00FF000042FF00CCFF00FAFF00FFE600FFE600FFD700FFC700FFC700
FFC700FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFA800FFB800FFB800FFA800FFB800FFB800FFB800FFC700FFE6009EFF0000FF0AFFC700
FFB800FFA800FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFB800FFC700FFC700FFD700
FFD700FFE600EBFF0070FF00FFF500FFE600FFE600FAFF00FAFF00FFD700FFC700FFB800
FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF9900
FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FFA800FF9900FF9900FF9900FF9900FF9900FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFA800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFC700FFD700
FFD700FFD700FFE600FFE600FFE600FFF500FFF500FAFF00FAFF00DCFF00FF0000FF00B8
0057FF00B3FF00FF2800FFC200FF6600FFF0FA00FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00008F00FF
00FF75FF000070FF00DC00FF3300FF51FF00FAFF00FFE600FFE600FFD700FFD700FFC700
FFC700FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFD700FFF500CCFF00FFE600
FAFF00FFB800FFA800FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFB800FFC700FFC700FFC700
FFD700FFD7009EFF00CCFF00EBFF00FAFF00DCFF00BDFF00FFF500FFD700FFC700FFB800
FFB800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF9900FF9900
FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF9900FF9900FF8A00FF8A00
FF8A00FF9900FF9900FF8A00FF8A00FF8A00FF9900FF9900FF8A00FF8A00FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FFA800FF9900FF9900FF9900FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFD700FFD700
FFD700FFD700FFE600FFE600FFF500FFF500FFF500FAFF00FAFF00DCFF00BDFF009E00FF
FF000000FF28000AFF33FF00FF0000FF002EFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF000000FF288FFF000500FF23FF00DCFF00FFF500FFE600FFE600FFD700FFD700FFD700
FFD700FFC700FFC700FFC700FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFD700FFE600EBFF0000FF94
FFF500FFB800FFA800FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFB800FFB800FFB800FFC700
FFC700FFD700FFE600FAFF00CCFF00BDFF00BDFF00EBFF00FFF500FFD700FFC700FFB800
FFB800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF8A00FF8A00FF9900FF9900FF8A00FF8A00FF8A00FF9900FF9900FF8A00FF8A00
FF8A00FF9900FF9900FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FF9900
FF9900FFA800FFA800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FF9900FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFD700FFD700
FFD700FFD700FFE600FFE600FFE600FFF500FFF500FAFF00FAFF00EBFF00DCFF00AEFF00
9EFF0070FF0061FF0070FF0000FFC2FF000000E1FF0094FF7000FF5100FFFF0000FF0000
0038FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000047FFFF0000
FF0000CC00FFAEFF00CCFF00DCFF00FAFF00FFF500FFF500FFE600FFD700FFD700FFD700
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFD700FFE600FAFF0014FF00
DCFF00FFB800FFA800FFA800FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00
FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFB800FFB800FFC700
FFC700FFD700FFD700FFF500EBFF0070FF00FAFF00FFF500FFD700FFC700FFC700FFB800
FFB800FFB800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900FFA800FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFA800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFC700FFD700FFD700
FFD700FFE600FFE600FFE600FFF500FFF500FAFF00FAFF00FAFF00EBFF00DCFF00CCFF00
BDFF00AEFF009EFF008FFF0000FFC2FF0000CC00FF00FF19FF000000FF6600D1FF00FFE1
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFF0FF0000FF000000FF19
51FF009EFF00BDFF00DCFF00EBFF00FAFF00FFF500FFE600FFE600FFE600FFD700FFD700
FFD700FFD700FFC700FFC700FFC700FFC700FFC700FFC700FFB800FFB800FFC700FFB800
FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFC700FFD700FFE60000FF28CCFF00
DCFF00FFC700FFB800FFA800FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF6B00
FF6B00FF6B00FF6B00FF6B00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFB800FFB800FFB800
FFC700FFD700FFD700FFF500DCFF00DCFF00FAFF00FFE600FFD700FFC700FFC700FFB800
FFB800FFA800FFA800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FF9900FFA800
FFA800FFA800FFA800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FFA800FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFD700FFD700FFD700
FFE600FFE600FFE600FFF500FFF500FFF500FAFF00FAFF00FAFF00EBFF00DCFF00CCFF00
CCFF00BDFF00AEFF009EFF0080FF0061FF0042FF0023FF0005FF0000FF3800FF7500E1FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000023FF0061FF00
8FFF00AEFF00CCFF00DCFF00EBFF00FAFF00FFF500FFF500FFE600FFE600FFE600FFD700
FFD700FFD700FFD700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700
FFB800FFB800FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFE6009EFF00AEFF00
FFE600FFC700FFB800FFA800FFA800FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800
FFC700FFC700FFD700FFE600EBFF00BDFF00FAFF00FFE600FFD700FFC700FFC700FFB800
FFB800FFA800FFA800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FFA800FF9900FF9900FF9900FFA800FFA800FFA800
FFA800FFA800FFB800FFE600FFC700FFB800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FF9900FF9900FF9900FF9900FFA800FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFB800FFA800FFA800FFA800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFD700
FFE600FFE600FFE600FFF500FFF500FFF500FAFF00FAFF00FAFF00EBFF00EBFF00DCFF00
CCFF00BDFF00AEFF009EFF008FFF0070FF0051FF0033FF0005FF00FF000000FFD1FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFD1FF000051FF00
80FF009EFF00BDFF00CCFF00EBFF00FAFF00FFF500FFF500FFE600FFE600FFE600FFE600
FFE600FFD700FFD700FFD700FFD700FFC700FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFE600FFF50080FF0061FF00
FFF500FFD700FFD700FFB800FFA800FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFB800FFC700
FFC700FFC700FFD700FFE600FAFF00DCFF00DCFF00FFF500FFD700FFD700FFC700FFB800
FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800
FFA800FFB800FFB800EBFF00FFD700FFC700FFB800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FFA800FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFA800FFB800FFB800FFB800FFB800
FFB800FFB800FFC700FFB800FFC700FFC700FFC700FFD700FFD700FFD700FFD700FFE600
FFE600FFE600FFF500FFF500FFF500FAFF00FAFF00FAFF00EBFF00EBFF00DCFF00DCFF00
CCFF00BDFF00AEFF008FFF0080FF0070FF0042FF0000FF5700FF19FF00000019FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000075FF
61FF00FF002E9EFF008FFF00DCFF00FAFF00FAFF00FFF500FFF500FFF500FFE600FFE600
FFE600FFE600FFE600FFE600FFD700FFD700FFD700FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFD700FFE600FFF500EBFF00BDFF00
00FF66FFF500FAFF00FFD700FFA800FFA800FF9900FF9900FF9900FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFB800FFB800FFB800
FFC700FFD700FFD700FFF500FAFF00DCFF00AEFF00CCFF00FFD700FFD700FFC700FFB800
FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800
FFB800FFB800FFC700FFF50061FF00EBFF00FFB800FFB800FFB800FFA800FFB800FFA800
FFA800FFA800FFA800FF9900FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FF9900FF9900FF9900
FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFD700FFD700FFD700FFE600FFE600
FFE600FFF500FFF500FAFF00FAFF00FAFF00FAFF00FAFF00EBFF00EBFF00DCFF00DCFF00
CCFF00AEFF00FF006B80FF0070FF0051FF0000F0FFFF000000FF75FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000028FF05FF00
23FF0000A3FF33FF00FF001EBDFF00EBFF00FAFF00FFF500FFF500FFF500FFF500FFF500
FFF500AEFF00EBFF00FFF500FFE600FFD700FFD700FFD700FFD700FFC700FFD700FFC700
FFC700FFC700FFC700FFC700FFD700FFD700FFD700FFE600FFF500FFF500EBFF00BDFF00
CCFF00BDFF00DCFF00FFC700FFA800FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFB800FFB800FFB800
FFC700FFD700FFF500FAFF00EBFF00CCFF00BDFF00FAFF00FFE600FFD700FFC700FFC700
FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FFA800FF9900FFA800FFA800FFA800FFA800FFA800FFA800
FFB800FFC700FFD700FFF50080FF00FFE600FFC700FFB800FFB800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FF9900FF9900FFA800FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFE600FFE600FFF500
FAFF00EBFF00EBFF00EBFF00EBFF00FAFF00EBFF00EBFF00EBFF00DCFF00DCFF00CCFF00
BDFF00FF000000D1FF51FF0061FF0033FF00FF0000FF00000075FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF000000FFF000FFD19EFF00EBFF00FAFF00FAFF00FFF500FFF500FFF500FFF500
FAFF00CCFF0061FF0023FF00FFF500FFE600FFE600FFE600FFD700FFD700FFD700FFD700
FFD700FFD700FFD700FFD700FFD700FFD700FFE600FFF500FAFF00EBFF00DCFF00AEFF00
61FF009EFF00FFE600FFC700FFA800FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFB800FFB800
FFC700FFE600FAFF00CCFF00AEFF0051FF009EFF00FAFF00FFF500FFE600FFD700FFC700
FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900
FF9900FFA800FF9900FF9900FF9900FF9900FF9900FFA800FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800
FFB800FFC700FAFF0033FF00EBFF00FFE600FFC700FFC700FFB800FFB800FFB800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FF9900FF9900
FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFC700FFC700FFC700FFC700FFD700FFD700FFE600FFF500EBFF00FAFF00
EBFF0000FF1933FF00AEFF00DCFF00EBFF00EBFF00EBFF00DCFF00DCFF00CCFF00BDFF00
AEFF0061FF00FF001E05FF0033FF0023FF00FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00003300FFFF000000FF85DCFF00EBFF00FAFF00FAFF00FAFF00FAFF00FAFF00
EBFF00CCFF0061FF0000FF66DCFF00FAFF00FAFF00FFE600FFE600FFE600FFD700FFD700
FFD700FFD700FFD700FFD700FFD700FFE600FFF50000FF8570FF009EFF0000FF5780FF00
33FF00AEFF00FAFF00FFC700FFA800FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFB800FFB800FFC700
FFD700CCFF00CCFF00BDFF00FF001EFF000080FF00DCFF00DCFF0023FF00FFD700FFC700
FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FF9900FF9900FFA800
FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800
FFB800FFC700FFF5009EFF00EBFF00FFF500FFD700FFC700FFC700FFB800FFB800FFB800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900
FF9900FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FFA800FF9900FF9900FF9900FF9900FF9900FFA800FFA800FF9900
FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFC700FFC700FFC700FFC700FFD700FFD700FFD700FFE600FAFF0000FF758FFF00
00FF384200FF00FF2800FF47CCFF00DCFF00DCFF00DCFF00DCFF00DCFF00BDFF006100FF
23FF0000E1FFEB00FF0085FF00FF8505FF00FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00004200FF0028FF00FFA3DCFF00EBFF00EBFF00FAFF00FAFF00FAFF00FAFF00
EBFF00BDFF0000FF0A61FF0080FF00DCFF0070FF00FAFF00FFE600FFE600FFD700FFD700
FFD700FFD700FFD700FFE600FFE600FFF500FAFF00CCFF0000FF7500FF389EFF00CCFF00
61FF00EBFF00FAFF00FFB800FFA800FFA800FF9900FF9900FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFB800FFB800FFB800
FFC700FFE600FFF500DCFF0000FF19FF000042FF0080FF00DCFF00FFF500FFD700FFC700
FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800
FFC700FFC700FFE600BDFF009EFF008FFF00EBFF00FFD700FFC700FFC700FFB800FFB800
FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900FF9900
FF9900FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFC700FFC700FFC700FFC700FFD700FFD700FFD700FFE600FFE600EBFF0051FF000057FF
00FF5700B3FF05FF0080FF00BDFF00CCFF00DCFF00DCFF00DCFF00CCFF00AEFF00FA00FF
FF0000FF004CFF0000FF000000FF8500FF6600FF750066FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000000AFF4200FF0047FF8FFF00CCFF00DCFF00EBFF00EBFF00EBFF00EBFF00DCFF00
DCFF0005FF0061FF00FF00000057FF9EFF00FF004CDCFF00FAFF00FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFF50000FF4780FF00AEFF0051FF00AEFF00DCFF00EBFF00
CCFF00EBFF00FFC700FFB800FFA800FFA800FF9900FF9900FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFB800FFB800FFB800FFC700
FFC700FFD700FFF500EBFF0061FF0080FF00BDFF00DCFF00DCFF00FFE600FFD700FFC700
FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800
FFC700FFC700FFE600FAFF00DCFF00BDFF0061FF00FFF500FFD700FFD700FFC700FFB800
FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900
FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FFA800FF9900FF9900FF9900
FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FFA800FF9900FF9900FF9900FF9900FFA800FF9900
FF9900FF9900FF9900FF9900FFA800FF9900FF9900FF9900FF9900FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFC700FFC700FFC700FFC700FFD700FFD700FFD700FFE600FFF500EBFF0051FF00FF008A
0038FF42FF0080FF009EFF00BDFF00CCFF00CCFF00CCFF00CCFF00BDFF00AEFF0000FF94
FF0000FF0000FF0000FF0000FF0000FF000000FFF0FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF000070FF00AEFF00CCFF00DCFF00DCFF00DCFF00DCFF00DCFF00DCFF00
CCFF00BDFF008FFF0042FF0000FF1900FF0A2300FF80FF0000FFC2FFF500FFE600FFE600
FFE600FFE600FFE600FFF50070FF0000FFB351FF0000FF0A1400FF9EFF00DCFF00FFF500
FFF500FFE600FFC700FFB800FFA800FFA800FF9900FF9900FF9900FF8A00FF8A00FF8A00
FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFB800FFB800FFC700
FFC700FFD700FFF500BDFF0070FF00DCFF00EBFF00FFF500FFF500FFD700FFD700FFC700
FFC700FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900FFA800FF9900FF9900
FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFB800FFA800FFA800FFB800FFB800FFB800FFC700
FFC700FFD700FFE600FFF500FAFF00DCFF0000FF38FAFF00FAFF00EBFF00FFD700FFC700
FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FF9900FF9900FFA800FF9900FF9900FF9900FFA800FF9900FF9900FF9900
FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FFA800FF9900FF9900FF9900FF9900FFA800FF9900
FF9900FF9900FF9900FF9900FFA800FFA800FF9900FF9900FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700
FFC700FFC700FFD700FFD700FFD700FFD700FFE600FFE600FFF500EBFF009EFF000019FF
2300FF00FFC261FF009EFF00BDFF00BDFF00CCFF00CCFF00CCFF00BDFF009EFF0042FF00
00A3FFFF0000FF0000FF0000FF0000FF0000000AFFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
00E1FF00FF0A42FF008FFF00AEFF00CCFF00CCFF00CCFF00BDFF00BDFF00AEFF00BDFF00
BDFF00AEFF008FFF0070FF0033FF0000FF4700D1FF00FFB3CCFF00FAFF00FFF500FFF500
FFE600FFF500FFF500FAFF00CCFF00BDFF0000FFE100A3FFFF000000FF0AAEFF00FFF500
FFD700FFC700FFB800FFA800FFA800FFA800FF9900FF9900FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFB800FFB800FFB800FFC700
FFD700FFD700FFF500EBFF0042FF00EBFF00FAFF00FFF500FFE600FFD700FFD700FFC700
FFC700FFC700FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FF9900FF9900FFA800FF9900FF9900FF9900FF9900FFA800FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FFA800FF9900FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFB800FFA800FFB800FFB800FFB800FFB800FFB800FFC700
FFC700FFD700FFE600FFF500FAFF00DCFF0000FF57DCFF00AEFF00FAFF00FFD700FFC700
FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FF9900FF9900FFA800FF9900FF9900FF9900
FFA800FF9900FF9900FF9900FFA800FF9900FF9900FF9900FFA800FF9900FF9900FF9900
FFA800FF9900FF9900FF9900FF9900FFA800FF9900FF9900FF9900FF9900FFA800FF9900
FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700
FFC700FFC700FFD700FFD700FFE600FFE600FFE600FFF500EBFF00DCFF00AEFF0061FF00
00FF190066FF61FF009EFF00AEFF00BDFF00BDFF00BDFF00BDFF00AEFF009EFF0033FF00
00FF0A8000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF000000FF57CC00FFFF0000AEFF00BDFF00BDFF00BDFF0023FF0014FF0014FF00FF00F5
00FF948FFF00FF006B23FF005100FF00FF94FF00D751FF009EFF00DCFF00FAFF00FFF500
FFF500FFF500FFF500FAFF00DCFF00CCFF009EFF0000FFC200FFC28FFF00CCFF00FFE600
FFD700FFC700FFB800FFA800FFA800FFA800FF9900FF9900FF9900FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00
FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900
FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFC700
FFC700FFD700FFE600EBFF009EFF00EBFF00FAFF00FFF500FFE600FFD700FFC700FFC700
FFC700FFB800FFC700FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900FFA800FF9900FF9900FFA800
FF9900FF9900FFA800FFA800FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFC700FFC700FFC700
FFD700FFD700FFE600FFF500FAFF00DCFF0070FF0000FF4700FF75FFF500FFD700FFC700
FFC700FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900FFA800
FFA800FF9900FF9900FFA800FFA800FF9900FF9900FF9900FFA800FF9900FF9900FF9900
FFA800FF9900FF9900FF9900FF9900FFA800FF9900FF9900FF9900FF9900FFA800FFA800
FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFB800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700
FFC700FFD700FFD700FFE600FFE600FFE600FFF500DCFF0023FF0080FF009EFF0051FF00
FF0000FF00C761FF008FFF009EFF009EFF009EFF00AEFF00AEFF00AEFF009EFF0080FF00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00004200FFFF00008FFF00AEFF00AEFF00AEFF0042FF0000FF0AFF000000C2FF
4200FF61FF006100FF00FFD1AE00FF00FF285100FF00FF8500FF2805FF00FAFF00FAFF00
FAFF00FFF500FAFF00FAFF00EBFF00CCFF00AEFF0070FF0000FF38DCFF00FFF500FFD700
FFC700FFC700FFB800FFA800FFA800FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900
FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFC700FFC700
FFD700FFD700FFF500FAFF009EFF00DCFF00FAFF00FFE600FFE600FFD700FFD700FFC700
FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFA800FFB800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFC700FFC700FFC700FFC700FFD700
FFE600FFE600FFF500FAFF00DCFF00BDFF0000FFB38FFF00EBFF00FFE600FFD700FFC700
FFC700FFB800FFB800FFB800FFA800FFA800FFA800FFB800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FF9900FF9900FFA800FFA800FF9900FF9900FF9900
FFA800FFA800FF9900FF9900FF9900FFA800FFA800FF9900FF9900FF9900FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700
FFD700FFD700FFE600FAFF00FFF500FFF500FAFF00CCFF0000FF0A70FF0061FF0000A3FF
6100FFFF002E51FF0080FF008FFF0033FF00FF00F58FFF008FFF008FFF008FFF0080FF00
42FF0000FF0AFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF000080FF009EFF009EFF008FFF0070FF0000FF6600C2FF00FF75
14FF00FF00F500FFC2FF007A00F0FF14FF0042FF0033FF009EFF00CCFF00EBFF00FAFF00
FAFF00FAFF00FAFF00EBFF00EBFF00CCFF00BDFF008FFF0000FF1970FF00FFF500FFD700
FFC700FFC700FFB800FFB800FFA800FFA800FF9900FF9900FF9900FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900
FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFB800FFB800FFC700FFC700FFD700
FFE600FFE600FFF500FAFF00DCFF00AEFF00FAFF00FFE600FFE600FFD700FFD700FFC700
FFC700FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFC700FFD700FFD700FFD700FFE600
80FF00FAFF00FAFF00CCFF0033FF009EFF00AEFF0005FF008FFF00FFF500FFD700FFC700
FFC700FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFA800FFA800
FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFD700
FFD700FFE600FAFF000038FF00F0FFEBFF00DCFF0023FF0000FF6600A3FF33FF0000E1FF
00FF3805FF0042FF0070FF0042FF005100FF1400FF00FF9400FF4700FF3861FF0061FF00
51FF0000FF0A00FF3800FFC21400FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF000000FF7523FF0080FF008FFF0061FF004200FF00E1FF0066FF0019FF00C2FF
FF000000FF85FF0000FF00000500FF0085FF61FF008FFF00AEFF00CCFF00DCFF00EBFF00
EBFF00EBFF00EBFF00EBFF00DCFF00CCFF009EFF0014FF0000FF38AEFF00FFF500FFD700
FFC700FFC700FFB800FFB800FFA800FFA800FF9900FF9900FF9900FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900
FF9900FF9900FF9900FFA800FFA800FFA800FFB800FFC700FFC700FFC700FFD700FFE600
FFE600FFF500FAFF00EBFF00BDFF0000FF47DCFF00FFF500FFE600FFD700FFD700FFC700
FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFD700EBFF00FFF500FFF500FAFF00
CCFF0051FF00DCFF0000FF75FF000023FF00DCFF00EBFF00FAFF00FFE600FFD700FFC700
FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFA800
FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFD700FFD700
FAFF00CCFF0051FF0000FFA3AEFF00CCFF00AEFF008000FF14FF0000FF7500FF66FF0000
00FFA323FF0042FF0051FF00BD00FFCC00FFFF00000057FFFF0000FF000042FF0051FF00
23FF00FF0000FF00007000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF000000C2FFFF000061FF0070FF0014FF00FF000000F0FFFF0000FF00000047FF
FF0000FF0000FF0000FF00000047FFFF00D742FF0061FF009EFF00AEFF0000E1FFDCFF00
DCFF00EBFF00EBFF00DCFF00CCFF0051FF0000FFD100F0FF9EFF00EBFF00FFF500FFD700
FFD700FFC700FFC700FFB800FFB800FFA800FF9900FF9900FF9900FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900
FF9900FF9900FF9900FFA800FFA800FFB800FFB800FFC700FFC700FFD700FFE600EBFF00
EBFF00EBFF00DCFF00DCFF0000FF19CCFF00FAFF00FFF500FFE600FFD700FFD700FFD700
FFC700FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFB800FFB800FFB800FFB800FFC700FFD700FAFF00CCFF0061FF0070FF00
9EFF0051FF009EFF008FFF0061FF00AEFF00EBFF00FFF500FFE600FFD700FFD700FFC700
FFC700FFB800FFC700FFB800FFB800FFB800FFB800FFA800FFB800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFD700
AEFF0042FF000047FF42FF009EFF009EFF00FF006B00FF1900D1FF00FFC200FFC200D1FF
00FF4714FF0033FF0033FF0000FFE1FF0000FF0000AE00FF00FF8500FF0A33FF0033FF00
FF0000FF0000FF0000DC00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF000042FF0051FF0023FF00FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00001400FF00FF3800FF0A23FF008FFF008FFF0000FF75AEFF00
CCFF00DCFF00DCFF00CCFF00AEFF0061FF000047FF00FF75BDFF00FAFF00FFF500FFE600
FFD700FFD700FFC700FFC700FFC700FFB800FFA800FF9900FF9900FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900
FF9900FF9900FF9900FFA800FFA800FFB800FFD700FFF500FFD700FFE600FFF500CCFF00
AEFF0042FF009EFF0061FF009EFF00DCFF00FAFF00FFF500FFE600FFD700FFD700FFD700
FFC700FFC700FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFB800FFA800FFB800FFA800FFA800
FFA800FFB800FFB800FFA800FFA800FFA800FFB800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFA800FFA800FFA800FFA800
FFA800FFB800FFB800FFB800FFB800FFB800FFC700FFD700FAFF0061FF00CCFF0061FF00
80FF0000FF3823FF00BDFF00CCFF00DCFF00FAFF00FFF500FFE600FFD700FFD700FFC700
FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFA800FFB800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFA800FFA800FFA800FFA800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFD700FFD700
FFF50061FF0033FF0000FF19FF00008F00FF14FF000019FF0028FF00F0FF4200FF00FF85
00FF2800FF2800FF94FF000000FF3800FFA3FF0000FF000000C2FFFF000000FF2814FF00
00FF28FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF000000FF3833FF0000FF38FF00000500FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000075FF0085FF00F0FF70FF0061FF0000FF6642FF00
8FFF00BDFF00CCFF00BDFF008FFF0000FFFF00FFE133FF00DCFF00EBFF00FAFF00FFF500
FFE600FFD700FFD700FFE60061FF00FFB800FFA800FF9900FF9900FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900
FF9900FF9900FF9900FFA800FFB800FFE600DCFF00CCFF009EFF00FFF500DCFF00CCFF00
DCFF00AEFF00CCFF00BDFF00AEFF00DCFF00FAFF00FFF500FFE600FFE600FFD700FFD700
FFD700FFC700FFC700FFC700FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFB800FFA800FFA800FFA800FFA800FFA800FFA800
FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFD700FFE600FFF500EBFF00DCFF00
80FF008FFF00AEFF00DCFF00EBFF00FAFF00FFF500FFE600FFE600FFD700FFD700FFC700
FFC700FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFA800
FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFB800FFA800FFA800FFA800FFA800FFB800FFA800FFA800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFD700FFD700
FFE600FAFF00CCFF00AEFF0070FF0005FF0000F0FFFF0000FA00FFFF000000FFF000FF85
00FF576100FFFF0000FF0000FF0000FF0099FA00FFFF00000019FFFF00000028FFFF001E
00FF2800FFC27000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF000005FF0000FF28FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00005100FF00FF2842FF0051FF0005FF0000FFF0
05FF00AEFF00BDFF00BDFF009EFF0080FF001400FF61FF00CCFF00DCFF00EBFF00DCFF00
FFF500FFE600FFE600FFF50042FF00FFB800FFA800FF9900FF9900FF9900FF8A00FF8A00
FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900
FF9900FF9900FF9900FFA800FFB800FFD700FFD700FFF500CCFF0080FF008FFF00FAFF00
FFF500FAFF00EBFF00CCFF009EFF00DCFF00EBFF00FAFF00FFF500FFE600FFE600FFD700
FFD700FFC700FFC700FFC700FFC700FFC700FFC700FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFD700FFE600FFF500FAFF00CCFF00
70FF0000F0FFCCFF00DCFF00EBFF00FAFF00FFF500FFE600FFE600FFD700FFD700FFD700
FFC700FFC700FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFD700FFD700
FFE600FFF500EBFF00BDFF008FFF0000FF380019FFFF00001400FFFF0000FF0000FF0000
FF000000B3FFFF0000FF00000094FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF000000FF28DC00FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000000AFF00FF660085FF00FFB30094FF
00FF5780FF00AEFF00AEFF009EFF000085FF00FF759EFF00BDFF00CCFF00CCFF0070FF00
42FF00FAFF00FAFF008FFF00FFE600FFB800FFA800FF9900FF9900FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900
FF9900FF9900FFA800FFA800FFA800FFB800FFC700FFD700AEFF00FFF500FFF500FFE600
FFE600FFF500FFF500EBFF009EFF0080FF00CCFF0080FF00EBFF00FAFF00FFE600FFD700
FFD700FFD700FFC700FFC700FFC700FFC700FFC700FFC700FFB800FFC700FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFC700FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFA800FFA800
FFA800FFA800FFA800FFB800FFA800FFA800FFA800FFA800FFB800FFA800FFB800FFB800
FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFD700FFE600FFF500FAFF00CCFF00
00FFE100FF19BDFF00EBFF00FAFF00FFF500FFF500FFE600FFE600FFD700FFD700FFD700
FFC700FFC700FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFA800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFA800FFB800
FFA800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFB800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFD700FFD700
FFE600FFF500DCFF0070FF0051FF000038FF00FF7500A3FF0094FF00F0FF00C2FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
00FFB3FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF000000FF75FA00FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF006BFF00000094FF00F0FF
14FF0070FF0080FF008FFF0080FF0014FF0000FF6680FF0080FF0061FF008FFF0061FF00
0075FF00FF0ABDFF00BDFF00FFF500FFB800FFA800FF9900FF9900FF9900FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF9900FF9900FF9900
FF9900FF9900FF9900FFA800FFA800FFB800FFB800FFC700FFD700FFD700FFD700FFD700
FFE600FFE600FFF500FAFF00CCFF0080FF0061FF0000FF1900FFFFCCFF00FFF500FFE600
FFD700FFD700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFB800
FFB800FFB800FFB800FFB800FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFC700
FFC700FFD70005FF00FFD700FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFA800FFB800FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFD700FFE600FFF500BDFF00AEFF00
00FF8580FF00AEFF00EBFF00FAFF00FFF500FFF500FFE600FFE600FFE600FFD700FFD700
FFC700FFC700FFC700FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFA800FFB800FFA800FFB800FFA800FFB800
FFA800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFC700FFB800FFC700FFC700FFC700FFC700FFD700FFD700
FFE600FFF500EBFF0000C2FF00FFC233FF0000FF0A0047FF00FFE100FFE1FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
00B3FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF000000FFC2FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000500FFFF0000FF0000FF0000FF004C
6100FF33FF0000B3FF00FF5761FF0042FF0000F0FF33FF0000FF4700FF1970FF0061FF00
80FF009EFF00CCFF0051FF00FFD700FFA800FFA800FF9900FF9900FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900
FF9900FF9900FF9900FFA800FFA800FFA800FFB800FFB800FFC700FFC700FFC700FFD700
FFD700FFD700FFF500EBFF00AEFF0051FF008F00FF8FFF0070FF00DCFF00FFF500FFE600
FFD700FFD700FFD700FFC700FFC700FFD700FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFB800FFB800FFC700FFB800FFB800FFB800FFB800FFC700FFC700FFC700
FFD700FFE60014FF00FFD700FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFD700FFE600FAFF00BDFF0000FF38
33FF00AEFF00DCFF00EBFF00FAFF00FAFF00FFF500FFE600FFE600FFE600FFD700FFD700
FFD700FFC700FFC700FFC700FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFB800FFA800FFA800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFC700FFD700FFD700
FFE600FFF50000FF8500FFA38FFF0080FF000028FF00FF2800FF667000FF00FF4700FF75
00F0FFFF003DFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF000000D1FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00003300FF
00E1FF00FFF000FF6600FF380075FF14FF004200FF00FF4770FF00AEFF00CCFF00EBFF00
FFF500FFF500FFF500FFD700FFB800FFA800FF9900FF9900FF9900FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900
FF9900FF9900FF9900FFA800FFA800FFA800FFB800FFB800FFB800FFC700FFC700FFC700
FFD700FFD700FFE60023FF00AEFF008FFF0000FF47BDFF00DCFF00FAFF00FFF500FFE600
FFE600FFD700FFD700FFD700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFD700
FFD700FFF500CCFF00FFF500FFD700FFC700FFC700FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFC700FFC700FFC700FFC700FFD700FFE600FFF500DCFF0023FF0000FF38
80FF00BDFF00CCFF00EBFF00FAFF00FAFF00FFF500FFF500FFE600FFE600FFD700FFD700
FFD700FFD700FFC700FFC700FFC700FFC700FFC700FFC700FFB800FFC700FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFB800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFC700FFD700FFD700
FFE600FFE600EBFF00CCFF00CCFF0061FF0000B3FF33FF0000FFA300FFC200FF19FF00F5
FF00999E00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000038FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00B800B3FF00E1FF00FFFF00FF5700FF2800E1FF00FFC270FF00BDFF00DCFF00FAFF00
FFE600FFD700FFC700FFB800FFB800FFA800FF9900FF9900FF9900FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900
FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFB800FFB800FFB800FFC700FFC700
FFC700FFD700FFE600FFF500EBFF00DCFF008FFF00AEFF00DCFF00FAFF00FFF500FFE600
FFE600FFD700FFD700FFD700FFD700FFD700FFD700FFC700FFC700FFC700FFD700FFD700
FFD700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFD700FFE600
FFF500EBFF009EFF0070FF00FFE600FFD700FFC700FFC700FFC700FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFC700FFC700FFC700FFD700FFD700FFE600DCFF0005FF00BDFF0080FF00
42FF00AEFF00CCFF00DCFF00EBFF00FAFF00FAFF00FFF500FFF500FFE600FFE600FFD700
FFD700FFD700FFD700FFD700FFC700FFC700FFC700FFC700FFC700FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFA800FFB800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFB800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFC700FFC700FFD700FFD700
FFD700FFE600FFF500FAFF00EBFF0042FF0000FF9470FF0023FF00FF000000FF0A23FF00
FF00006100FF00B3FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000DC00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00008000FF
CC00FF00FF1900FF856100FF42FF0051FF003300FF51FF0000FF949EFF00BDFF00FFF500
FFE600FFD700FFC700FFB800FFA800FFA800FF9900FF9900FF9900FF8A00FF8A00FF9900
FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900
FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFC700
FFC700FFC700FFD700FFE600FFF500EBFF00DCFF008FFF00CCFF00FAFF00FFF500FFF500
FFE600FFE600FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700
FFE600FFD700FFD700FFC700FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFF500
00FF2823FF00AEFF00FAFF00FFE600FFD700FFC700FFC700FFC700FFC700FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700
FFB800FFC700FFC700FFC700FFC700FFC700FFD700FFE600FFF500FAFF00DCFF009EFF00
00FF0A8FFF00CCFF00DCFF00EBFF00EBFF00EBFF00FAFF00FFF500FFF500FFF500FFE600
FFE600FFD700FFD700FFD700FFD700FFC700FFC700FFC700FFC700FFC700FFC700FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFC700FFB800FFB800FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFA800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFB800FFB800FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFD700
FFD700FFE600FFF500FFF500FAFF0000FF0A000AFF9EFF004200FF0057FF42FF0042FF00
14FF0000FF47FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000E1FF
00E1FF51FF0070FF0061FF0070FF0070FF0000FF4780FF008FFF0000FF9470FF00FAFF00
FFE600FFD700FFB800FFB800FFA800FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFC700
FFC700FFC700FFD700FFE600FFF500FAFF00DCFF008FFF00BDFF00EBFF00FAFF00FFF500
FFF500FFE600FFE600FFE600FFE600FFD700FFD700FFD700FFD700FFD700FFE600FFE600
8FFF00FFE600FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFE600FFF500
BDFF0080FF00EBFF00FFF500FFE600FFD700FFC700FFC700FFC700FFC700FFC700FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFD700FFE600FAFF00EBFF0023FF00
00FF289EFF00BDFF00CCFF00CCFF00CCFF00CCFF00CCFF00FAFF00FAFF00EBFF00FFF500
FFE600FFE600FFD700FFD700FFD700FFD700FFD700FFC700FFC700FFC700FFC700FFC700
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFB800FFB800FFC700
FFC700FFC700FFC700FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFA800FFA800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFA800FFA800FFA800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFC700FFC700FFD700FFD700
FFD700FFE600FFE600FFF500FAFF00EBFF00CCFF00CCFF0051FF00FF005C80FF0000FFC2
FF000000FF8500FFFFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000094FF6100FF4200FFFF0000
05FF0051FF008FFF009EFF009EFF0070FF000094FF9EFF00CCFF008FFF0000FF85EBFF00
FFF500FFF500FFB800FFA800FFA800FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800
FFC700FFC700FFD700FFE600FFF500FAFF00CCFF0080FF00BDFF00DCFF00EBFF00FAFF00
FFF500FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE6008FFF00
00FF38FFF500FFE600FFD700FFD700FFD700FFD700FFD700FFD700FFE600FFE600EBFF00
42FF00CCFF00FAFF00FFF500FFE600FFD700FFD700FFD700FFC700FFC700FFC700FFC700
FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFE600FFE600FFF500EBFF0070FF00
00FF0A00FFB3AEFF00AEFF0051FF000085FF8FFF008FFF00DCFF00CCFF0070FF00FAFF00
FFF500FFE600FFE600FFE600FFE600FFE600FFE600FFD700FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFB800FFC700FFC700FFB800FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFD700FFD700FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFB800FFA800FFA800FFB800
FFA800FFA800FFA800FFB800FFA800FFA800FFA800FFA800FFB800FFB800FFA800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFD700
FFD700FFE600FFE600FFF500FFF500FAFF00EBFF00DCFF009EFF0042FF009EFF0061FF00
0075FFDC00FF00E1FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFA39E00FF00FFB300FF94
FF0099DC00FF8FFF00BDFF00BDFF0070FF0005FF009EFF00DCFF00EBFF0080FF00BDFF00
8FFF00AEFF00FFB800FFA800FFA800FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFB800FFB800FFB800FFB800
FFC700FFC700FFD700FFE600FAFF00CCFF0033FF0080FF009EFF00BDFF0080FF00CCFF00
FAFF00FFF500FFF500FFF500FFF500FFF500FAFF00FFF500FFF500FFF500FFF50080FF00
DCFF00FAFF00FFE600FFE600FFD700FFD700FFD700FFD700FFE600FFE600FFF500EBFF00
33FF00CCFF00FAFF00FFF500FFE600FFD700FFD700FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFD700FFD700FFD700FFE600FFE600FFF500EBFF000066FF
80FF0000FF1980FF0080FF0061FF0051FF0000FF0A00FF47AEFF00AEFF0000FF57EBFF00
FFF500FFF500FFF500FFF500FFF500EBFF00FFF500FFD700FFD700FFD700FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700
FFD700FFD7009EFF00FFE600FFD700FFC700FFC700FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFA800FFA800FFB800
FFB800FFA800FFA800FFB800FFB800FFA800FFA800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFD700
FFD700FFE600FFE600FFF500FFF500FAFF00EBFF00EBFF00DCFF00CCFF00BDFF009EFF00
FF0000FF00000019FFFF0000CC00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00E600FF9433FF0051FF00FF0000
00FF0A8FFF0042FF00CCFF00CCFF009EFF0000FF0A8FFF00FAFF00FAFF00FAFF008FFF00
8FFF00FFD700FFB800FFA800FFA800FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFB800FFB800FFB800
FFC700FFC700FFD700FFE600FAFF0080FF0080FF00CCFF0000FF4742FF0080FF00DCFF00
FAFF00FAFF00FFF500FFF500FAFF00FAFF00CCFF00EBFF00FAFF00FAFF00FAFF00DCFF00
61FF00FAFF00FFF500FFF500FFE600FFE600FFE600FFE600FFE600FFE600FFF500FAFF00
AEFF0070FF00EBFF00FFF500FFE600FFE600FFD700FFD700FFD700FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFD700FFD700FFD700FFD700FFE600FFE600FFF500FAFF00DCFF00
CCFF0014FF0000FF5700FF199EFF009EFF0080FF0000FF4761FF0070FF0000FF19BDFF00
FAFF00FAFF00FFF500FAFF0061FF009EFF00EBFF00FFE600FFD700FFD700FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFD700FFD700
FFE600EBFF00BDFF00DCFF00FFD700FFC700FFC700FFC700FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFC700FFB800FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFD700
FFE600FFE600FFE600FFF500FFF500FAFF00FAFF00EBFF00DCFF00CCFF00BDFF00AEFF00
23FF00FF00000085FFFF00000038FFFF0000FF0000FF0000FF0000FF00B8FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF751400FF8FFF0070FF00
AEFF00CCFF00DCFF00EBFF00DCFF0061FF0014FF00DCFF00FFF500FFE600FFE600FFF500
FFE600FFB800FFA800FFA800FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800
FFC700FFC700FFD700FFF500DCFF00DCFF00EBFF00EBFF00AEFF0023FF0033FF00BDFF00
EBFF00EBFF00FAFF00FAFF00BDFF00DCFF00BDFF00BDFF00DCFF00DCFF00DCFF00BDFF00
00FF47DCFF00FAFF00FFF500FFF500FFF500FFF500FFE600FFF500FFF500FFF500EBFF00
DCFF009EFF0070FF00EBFF00FFF500FFE600FFE600FFD700FFD700FFD700FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFD700FFD700FFD700FFE600FFE600FFE600FFF500FFF500FAFF00
DCFF008FFF00AEFF00AEFF00BDFF00AEFF009EFF0042FF0000FF0A00FF1923FF0000FFA3
DCFF00FAFF00EBFF00BDFF0080FF00BDFF00FAFF00FFE600FFD700FFD700FFD700FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFD700FFD700
FFE6009EFF00BDFF00FAFF00FFE600FFD700FFC700FFC700FFC700FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFD700
FFD700FFE600FFF500FFF500FFF500FAFF00EBFF00EBFF00DCFF00CCFF00BDFF00AEFF00
51FF0000FF7500FF6605FF00FF00000066FFFF000000E1FF0075FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF8500FF479EFF00BDFF00
DCFF00EBFF00EBFF00FAFF00EBFF0005FF0051FF00DCFF00FFF500FFE600FFD700FFC700
FFB800FFB800FFA800FFA800FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFB800FFB800FFB800
FFB800FFC700FFE600AEFF00BDFF00FAFF00FFF500FAFF00BDFF00CCFF00AEFF0080FF00
BDFF00DCFF00EBFF00DCFF008FFF0061FF0023FF008FFF0000FFC2BDFF00BDFF0042FF00
00FF38DCFF00EBFF00EBFF00EBFF00FAFF00FFF500FFF500FFF500FFF500FAFF00EBFF00
DCFF00AEFF0000FF38DCFF00EBFF00FAFF00FFE600FFD700FFD700FFD700FFD700FFD700
FFD700FFD700FFD700FFC700FFC700FFC700FFC700FFC700FFD700FFC700FFC700FFC700
FFC700FFC700FFD700FFD700FFD700FFD700FFD700FFE600FFE600FFF500FAFF00FAFF00
EBFF00DCFF00DCFF00CCFF00CCFF00BDFF009EFF0000FF7551FF0000FF1923FF009EFF00
CCFF00DCFF00DCFF00AEFF0051FF00DCFF00FAFF00FFE600FFE600FFD700FFD700FFD700
FFD700FFC700FFC700FFC700FFD700FFD700FFD700FFD700FFE600FFE600FFE600FFE600
FFF500CCFF0000FFF0CCFF00FFE600FFD700FFD700FFC700FFC700FFC700FFB800FFC700
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFD700FFD700
FFD700FFE600FFE600FFF500FFF500FAFF00FAFF00EBFF00DCFF00CCFF00CCFF00BDFF00
9EFF0070FF0061FF0042FF0005FF0000FF2800FF57FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000AE00FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF000000B3FF00FF4742FF008FFF009EFF00BDFF00
DCFF00EBFF00FAFF00FAFF00FAFF009EFF0023FF0023FF00EBFF00FFD700FFC700FFB800
FFB800FFA800FFA800FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFB800FFB800
FFB800FFC700FFE600FFE600FFF500FFE600FFE600FFF500FAFF00EBFF008FFF0000FFE1
00FFA3AEFF00BDFF0080FF009EFF009EFF009EFF0000FF7505FF0061FF0070FF0042FF00
8FFF00CCFF00DCFF00CCFF0000FF0ADCFF00FAFF00FFF500FFF500FAFF00FAFF00EBFF00
CCFF0070FF0042FF009EFF00AEFF00FAFF00FFE600FFE600FFD700FFD700FFD700FFD700
FFD700FFD700FFD700FFD700FFD700FFC700FFC700FFC700FFD700FFC700FFC700FFD700
FFC700FFD700FFD700FFD700FFD700FFD700FFD700FFE600FFE600FFE600FFF500FAFF00
FAFF00EBFF00EBFF00DCFF00CCFF00CCFF00BDFF009EFF0080FF0000FF3842FF0014FF00
00FF57CCFF00CCFF00BDFF0080FF009EFF00FAFF00FFF500FFE600FFE600FFD700FFD700
FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFE600FFF500FAFF00FFF500FAFF00
FAFF00DCFF00AEFF0005FF00FAFF00FFE600FFD700FFC700FFC700FFC700FFC700FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFB800
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFD700FFD700
FFE600FFE600FFF500FFF500FAFF00FAFF00EBFF00DCFF00DCFF00CCFF00BDFF00AEFF00
9EFF008FFF0070FF0042FF0023FF0000FF0A00FFA3FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000051FF0061FF008FFF0023FF00
DCFF00FAFF00FFF500FFF500FFF500FAFF0070FF00CCFF00BDFF00FFC700FFB800FFB800
FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900
FF9900FF9900FFA800FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFB800
FFB800FFB800FFC700FFD700FFD700FFD700FFD700FFE600FFF500FAFF0080FF00CCFF00
9EFF0000FFA370FF00AEFF00DCFF00DCFF00CCFF00AEFF0000FF6670FF0042FF0000FF47
80FF00AEFF00BDFF0000FFC2BDFF00DCFF00FAFF00FAFF00FAFF00EBFF00DCFF00DCFF00
CCFF008FFF000085FF23FF00AEFF00FAFF00FFF500FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFD700FFD700FFD700FFD700FFC700FFD700FFC700FFC700FFD700
FFD700FFD700FFD700FFD700FFD700FFD700FFE600FFE600FFE600FFE600FFF500FFF500
FAFF00FAFF00EBFF00DCFF00DCFF00CCFF00BDFF00AEFF0080FF0000FFF000FF940066FF
9EFF00BDFF00BDFF00AEFF0033FF0042FF00DCFF00FFF500FFF500FFE600FFE600FFD700
FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFE600FAFF00AEFF00FF000000FF75
CCFF00CCFF00AEFF0051FF0080FF0000FF19FFD700FFD700FFC700FFC700FFC700FFC700
FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFD700FFD700FFE600
FFE600FFE600FFF500FFF500FAFF00EBFF00DCFF00CCFF00CCFF00BDFF00BDFF00AEFF00
9EFF008FFF0061FF000075FF14FF00FF0000FF00006100FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFE1FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000038FFFF0000FF000000FF2833FF0014FF0033FF0000FF94
DCFF00EBFF00FFF500FFE600FFE600FFE600FFF500FFF500FFC700FFB800FFB800FFA800
FFA800FFA800FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFB800
FFB800FFB800FFC700FFC700FFD700FFD700FFD700FFD700FFE600FAFF009EFF00EBFF00
EBFF0000FFB3DCFF00EBFF00EBFF00EBFF00DCFF00BDFF0061FF009EFF009EFF0042FF00
23FF009EFF009EFF0051FF00AEFF00DCFF00EBFF00EBFF00EBFF00CCFF0080FF00BDFF00
AEFF0061FF000066FF9EFF00DCFF00FAFF00FFF500FFF500FFE600FFE600FFE600FFE600
FFF500FAFF00FAFF00FFE600FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700
FFD700FFD700FFD700FFD700FFD700FFD700FFE600FFE600FFE600FFF500FFF500FFF500
FAFF00FAFF00EBFF00EBFF00DCFF00CCFF00BDFF00AEFF0061FF0005FF00FF000000FFA3
00FF389EFF0000FF4780FF0042FF0000FF0ADCFF00EBFF00FFF500FFF500FFE600FFE600
FFD700FFD700FFD700FFE600FFD700FFE600FFE600FFF500FAFF00AEFF0080FF0000D1FF
80FF0023FF0033FF0005FF0000FF28FFF500FFE600FFD700FFC700FFC700FFC700FFC700
FFC700FFB800FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFB800FFB800FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFD700FFD700FFE600
FFE600FFE600FFF500FAFF00EBFF00DCFF0000FF0A80FF009EFF00AEFF00AEFF00AEFF00
9EFF0080FF0000A3FF0085FF00FF280019FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFF000FF668000FFFF0000FF0000
FF0000FF0000FF000000FFFF00D1FFFF006BFF00000057FF00FFC2FF000000FF7523FF00
9EFF00BDFF00FFE600FFD700FFD700FFD700FFC700FFC700FFB800FFB800FFA800FFA800
FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00
FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800
FFB800FFB800FFB800FFC700FFC700FFC700FFD700FFD700FFE600DCFF00FAFF00FFF500
FFF500EBFF00FAFF00FAFF00FAFF00FAFF00EBFF00BDFF0000FF28BDFF00BDFF0000FF0A
00FF2870FF0070FF0023FF0080FF00CCFF00CCFF00DCFF00DCFF00BDFF0070FF008FFF00
33FF0023FF0000FF4770FF0033FF00EBFF00FAFF00FFF500FFF500FFF500FFF500FAFF00
FAFF00CCFF00EBFF00FFE600FFE600FFD700FFD700FFD700FFD700FFD700FFD700FFD700
FFD700FFD700FFD700FFD700FFD700FFE600FFE600FFE600FFE600FFF500FFF500FFF500
FAFF00FAFF00EBFF00EBFF00DCFF00CCFF00BDFF009EFF0070FF0000FF85FF000000F0FF
00FF3870FF0033FF000085FFFF000061FF00CCFF00DCFF00DCFF00EBFF00FFF500FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF500EBFF00BDFF0000E1FF51FF00
42FF0000F0FF70FF0051FF0005FF00FFF500FFE600FFD700FFD700FFC700FFC700FFC700
FFC700FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFD700FFD700FFD700FFE600
FFE600FFF500FFF500EBFF00CCFF0080FF00CC00FF00FF0A00FFF09EFF00AEFF009EFF00
8FFF0042FF000075FFFF0000FF000000FFC22300FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF3800FF0AFF0000FF0000
00FFFFFF00B88000FF00FF4714FF0005FF0000FF57FF00C700FFC2FF006B00FF6670FF00
00FFF0EBFF00FFE600FFD700FFC700FFC700FFC700FFB800FFB800FFB800FFA800FFA800
FFA800FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800
FFB800FFB800FFC700FFB800FFC700FFC700FFC700FFD700FFD700FFE600FFE600FFE600
FFF500FFF500FFF500FFF500FFF500FAFF00FAFF00EBFF00DCFF00DCFF00CCFF009EFF00
00FF1923FF0000FF3800FF2814FF009EFF009EFF00CCFF00CCFF00BDFF0080FF0000FF57
00FF57FF000000D1FF8FFF00BDFF00EBFF00FAFF00FAFF00FFF500FAFF00FAFF0061FF00
80FF0042FF00CCFF00FFF500FFE600FFE600FFD700FFD700FFD700FFD700FFD700FFD700
FFD700FFD700FFD700FFD700FFE600FFE600FFE600FFE600FFF500FFF500FFF500FFF500
FAFF00FAFF00EBFF00EBFF00DCFF00CCFF009EFF0070FF0051FF0000FF6600FF0A00FF28
00FFB323FF0033FF0000FF7500FF0A8FFF00AEFF0000FF9461FF00EBFF00FFF500FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFF500EBFF008FFF0000FFB300FF858FFF00
AEFF00AEFF00CCFF009EFF00EBFF00FFF500FFE600FFD700FFD700FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFB800FFC700FFB800FFB800FFB800FFB800FFB800
FFB800FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFC700FFB800FFB800FFB800FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFD700FFC700FFD700FFD700FFD700FFE600FFE600FFE600
FFE600FFF500FAFF00DCFF0000FF2800FFA3BD00FF42FF0070FF008FFF009EFF008FFF00
80FF00FF0000FF0000FA00FF8000FFDC00FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF3823FF0042FF0023FF00
FF000014FF00FF0000000AFF0075FF8FFF0023FF0033FF0000FF6600FFE100FF0ADCFF00
FAFF00FFE600FFD700FFD700FFC700FFC700FFB800FFB800FFB800FFA800FFA800FFA800
FFA800FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800
FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFD700FFD700FFD700FFE600
FFE600FFE600FFE600FFF500FFF500FFF500FAFF00FAFF00EBFF00EBFF00CCFF0080FF00
61FF0000FF28FF0000FF000033FF0000FF0A70FF00AEFF00AEFF00AEFF008FFF0033FF00
00FF7505FF0005FF00AEFF00CCFF00EBFF00FAFF00FAFF00FAFF00FAFF00DCFF00AEFF00
14FF0042FF00CCFF00FAFF00FFF500FFE600FFE600FFD700FFD700FFD700FFD700FFD700
FFE600FFD700FFE600FFE600FFE600FFE600FFE600FFE600FFF500FFF500FFF500FAFF00
FAFF00EBFF00EBFF00EBFF00DCFF00CCFF009EFF0000FF2823FF0033FF0033FF0014FF00
1400FF00FFFF00FF28FF000033FF0000FF198FFF0051FF00CCFF00EBFF00FFF500FFF500
FFE600FFE600FFE600FFE600FFE600FFF500FAFF0000FF0A51FF0000FF1970FF009EFF00
BDFF00CCFF00DCFF00EBFF00FAFF00FFF500FFE600FFD700FFD700FFD700FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFB800FFC700FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFC700FFC700FFB800FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFD700FFD700FFD700FFE600FFE600
FFF500FFF500FAFF00DCFF0000FFE100FFFFFF000042FF0070FF0080FF008FFF0080FF00
70FF00DC00FFFF008AFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000033FF0061FF0080FF00
70FF0080FF0000A3FF00A3FF0094FFAEFF00AEFF0000FF0A70FF0000FFA300FF0A8FFF00
FFE600FFD700FFC700FFC700FFC700FFB800FFB800FFB800FFA800FFA800FFA800FFA800
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFB800
FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFD700FFD700FFD700
FFD700FFE600FFE600FFE600FFE600FFF500FFF500FAFF00FAFF00EBFF00DCFF00BDFF00
8FFF0000FF0A0075FFFF00006100FF00FF6661FF0000FF388FFF008FFF0061FF0023FF00
00FF1961FF009EFF00BDFF00CCFF00DCFF00EBFF00EBFF00EBFF00EBFF008FFF0023FF00
80FF00CCFF00EBFF00FAFF00FFF500FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF500FFF500FFF500FFF500FAFF00
FAFF00EBFF00EBFF00EBFF00DCFF00CCFF00AEFF0080FF0042FF0061FF0051FF0023FF00
FF000000D1FF00FF9400FF9400FF3800FFD142FF0000FF94CCFF00EBFF00FAFF00FFF500
FFF500FFF500FFF500FFF500FFF500FFF500FAFF00DCFF008FFF00AE00FF8FFF00AEFF00
BDFF00DCFF00EBFF00FAFF00FFF500FFF500FFE600FFD700FFD700FFD700FFD700FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFB800FFC700FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFC700FFB800FFB800FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFD700FFC700FFD700FFD700FFD700FFD700FFE600FFE600FFF500
FFF500FAFF00EBFF00CCFF008FFF0000FF1900E1FF33FF0061FF0070FF0070FF0070FF00
61FF0033FF00FF00002300FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000DC00FF14FF0042FF008FFF00
9EFF00AEFF00AEFF00AEFF00CCFF00DCFF00DCFF0080FF00CCFF0000FF47FAFF00FFE600
FFD700FFC700FFC700FFC700FFB800FFB800FFB800FFA800FFA800FFA800FFA800FF9900
FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFD700FFD700
FFD700FFD700FFE600FFE600FFE600FFE600FFF500FFF500FAFF00EBFF00DCFF00CCFF00
9EFF0014FF0000FF4700FF5733FF0000FF3805FF000066FF23FF0070FF0014FF006100FF
00FF2823FF009EFF00BDFF00BDFF00DCFF00DCFF00EBFF00EBFF00DCFF0061FF0070FF00
BDFF00DCFF00EBFF00FAFF00FFF500FFF500FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFF500FFF500FFF500FFF500FAFF00FAFF00
FAFF00EBFF00EBFF00DCFF00DCFF00CCFF00BDFF009EFF008FFF0070FF0061FF0000FFA3
00FF2800FF7500C2FFDC00FFCC00FF00FFE15100FF0047FFCCFF00EBFF00FAFF00FAFF00
FFF500FFF500FFF500FFF500FFF500FAFF00EBFF00CCFF0000FFB342FF008FFF00AEFF00
BDFF00CCFF00EBFF00FAFF00FFF500FFF500FFE600FFE600FFD700FFD700FFD700FFD700
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFB800FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFC700FFC700FFB800FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFD700FFD700FFD700FFD700FFD700FFE600FFE600FFF500
FFF500FAFF00DCFF0000FFB370FF0000FF19FF0000FF002E51FF0000FF3800FFFF51FF00
33FF0023FF0000FF5700FFA3FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000F0FFFF00001400FF8FFF00
AEFF00BDFF00CCFF00DCFF00DCFF00EBFF00FAFF00FAFF00FFF500FFF500FFE600FFD700
FFD700FFC700FFC700FFC700FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800
FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800
FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFC700FFD700
FFD700FFD700FFD700FFE600FFE600FFE600FFF500FFF500FAFF00EBFF00DCFF00CCFF00
9EFF0000FF4761FF0042FF0061FF0033FF0000D1FF1400FF00FF0A33FF0000FF0A00FF57
33FF0070FF009EFF00AEFF00BDFF00BDFF00DCFF00DCFF00DCFF00CCFF0080FF008FFF00
BDFF00DCFF00EBFF00FAFF00FFF500FFF500FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFF500FFF500FFF500FFF500FFF500FFF500FFF500FFF500FAFF00FAFF00
EBFF00EBFF00EBFF00DCFF00CCFF00CCFF00BDFF00AEFF008FFF0080FF0061FF0042FF00
14FF0000FF3800F0FF00FFA300FF1923FF0000FF478FFF00BDFF00DCFF00EBFF00FAFF00
FAFF00FFF500FFF500FAFF00FAFF00FAFF00EBFF000047FF05FF0005FF0080FF008FFF00
9EFF00BDFF00DCFF00EBFF00FAFF00FFF500FFE600FFE600FFD700FFD700FFD700FFD700
FFD700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFB800FFC700FFB800FFB800FFC700FFC700FFB800
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFD700FFD700FFD700FFE600FFE600FFE600FFF500FAFF00
EBFF00EBFF00BDFF0000FFD123FF00FF00A800FF94FF000023FF00FF0000FF00000047FF
00FF9405FF0000FF288F00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF758FFF00
AEFF00CCFF00DCFF00EBFF00FAFF00FAFF00FFF500FFF500FFE600FFE600FFD700FFD700
FFC700FFC700FFC700FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFC700
FFD700FFD700FFD700FFD700FFE600FFE600FFF500FFF500FAFF00EBFF00DCFF00CCFF00
9EFF0033FF008FFF0080FF008FFF0061FF0014FF0000FF5700FFB300FF9400D1FF00FF0A
51FF0070FF008FFF008FFF0051FF0000FF47CCFF00CCFF00CCFF00CCFF00AEFF0042FF00
9EFF00DCFF00EBFF00FAFF00FFF500FFF500FFF500FFF500FFF500FFF500FFE600FFF500
FFF500FFF500FFF500FFF500FFF500FFF500FFF500FAFF00FAFF00FAFF00FAFF00EBFF00
EBFF00DCFF00DCFF00DCFF00CCFF00BDFF00AEFF009EFF008FFF0070FF0051FF0033FF00
00FF0A00E1FFFF0000000AFF00FF1923FF0070FF008FFF00BDFF00BDFF00DCFF00EBFF00
FAFF00FAFF00FAFF00FAFF00FAFF00FAFF00EBFF00CCFF0000FFE123FF0061FF0000FFB3
00FF7580FF00BDFF00EBFF00FAFF00FFF500FFF500FFE600FFE600FFD700FFD700FFD700
FFD700FFD700FFC700FFD700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFD700FFD700FFD700FFD700FFD700FFE600FFE600FFF500FAFF00CCFF00
00FFE1CCFF001400FFFF000000FF57FF0000FF000000FF1900FF190057FFBD00FF0066FF
00FF7500FF28FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFFF42FF0061FF00
70FF00CCFF00DCFF00EBFF00FAFF00FAFF00FFF500FFE600FFE600FFE600FFD700FFC700
FFC700FFC700FFC700FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FF9900
FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800
FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFD700
FFC700FFD700FFD700FFD700FFE600FFE600FFF500FFF500FAFF008FFF009EFF009EFF00
80FF0033FF00AEFF009EFF009EFF0080FF0014FF0000FF6614FF0000FF2800C2FF00FF47
23FF0000FF8580FF0070FF0051FF008FFF00BDFF00BDFF00BDFF00BDFF009EFF0023FF00
70FF009EFF00EBFF00FAFF00FAFF00FFF500FFF500FFF500FFF500FFF500FFF500FFF500
FFF500FAFF00FAFF00FAFF00FFF500FFF500FFF500FAFF00FAFF00FAFF00EBFF00EBFF00
CCFF00CCFF00CCFF00CCFF00BDFF00AEFF009EFF0051FF0070FF0014FF0014FF0000FF57
FF00000066FFFF00000019FF00FF7505FF0070FF008FFF0042FF0000FF2842FF00DCFF00
EBFF00FAFF00FAFF00FAFF00FAFF00EBFF00EBFF00CCFF0023FF0000FF7523FF0023FF00
42FF0000FFB30019FFAEFF00CCFF00FAFF00FFF500FFF500FFE600FFE600FFD700FFD700
FFD700FFD700FFD700FFD700FFD700FFC700FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700
FFD700FFC700FFD700FFD700FFD700FFD700FFE600FFE600FFE600FAFF0033FF0000FF75
61FF008FFF00BD00FF0094FF00FFF00085FF00FF8500FF7500FF6600FFF0FF0000FF0000
FF00007000FF00FF940019FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF66FF0000FA00FF
00A3FFCCFF00DCFF00EBFF00FAFF00FFF500FFF500FFE600FFE600FFD700FFD700FFC700
FFC700FFC700FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800FF9900FF9900
FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900
FF9900FFA800FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFC700
FFD700FFD700FFD700FFD700FFE600FFE600FFE600FFF500FAFF009EFF0000FF280094FF
00FF199EFF00BDFF00BDFF00AEFF0080FF0000FF1961FF0033FF0023FF0000C2FF8F00FF
00C2FF42FF0061FF0051FF0051FF009EFF00AEFF00AEFF009EFF008FFF0080FF0005FF00
14FF00BDFF00DCFF00EBFF00EBFF00FAFF00FAFF00FFF500FFF500FFF500FFF500FFF500
FAFF00BDFF00DCFF00EBFF00FAFF00FAFF00FAFF00FAFF00FAFF00FAFF00EBFF00DCFF00
80FF0000C2FFAEFF00BDFF00AEFF0042FF0051FF0042FF000038FF33FF0000FF28FF0000
FF0000FF0000FF000000B3FF1400FF9E00FF61FF0070FF0000FF3880FF008FFF00DCFF00
EBFF00EBFF00FAFF00EBFF00EBFF00EBFF00DCFF00CCFF00BDFF0033FF0000FF3870FF00
61FF0033FF0000FF6661FF00CCFF00EBFF00FAFF00FFF500FFF500FFE600FFE600FFD700
FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFC700FFC700FFD700FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFD700FFD700FFD700FFD700FFD700FFD700FFE600FFE600FAFF0023FF0000FFA3
0075FF00FF47FF0000FF0000FF000000E1FF00FFC2FF00000038FFFF0000FF0000FF0000
FF0000FF000000FFF0FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF003D0057FFFF0000
FF0000BDFF00DCFF00EBFF00FAFF00FFF500FFF500FFE600FFD700FFD700FFD700FFC700
FFC700FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700
FFC700FFD700FFD700FFD700FFD700FFE600FFE600FFF500FAFF00DCFF00CCFF009EFF00
BDFF00CCFF00CCFF00BDFF00BDFF0042FF0080FF0080FF0070FF0042FF0000FF758F00FF
4200FF14FF0023FF0000FF850066FF70FF009EFF009EFF0080FF0051FF0000A3FF00FF66
00FFFFAEFF00CCFF00BDFF009EFF00FAFF00FAFF00FAFF00FAFF00FAFF00FAFF00FAFF00
EBFF00CCFF0000FF75BDFF00EBFF00FAFF00FAFF00FAFF00EBFF00EBFF00EBFF00DCFF00
AEFF000057FF8FFF009EFF008FFF0070FF0000FFE100FFA30075FF00FF0A00FF2800FF94
1400FFFF0000FF0000FF00000094FF00FF3823FF0042FF0000FF198FFF00BDFF00DCFF00
DCFF00EBFF00EBFF00EBFF00EBFF00EBFF00DCFF00CCFF00BDFF00AEFF009EFF008FFF00
80FF0033FF0000FF6600FF3800FF66DCFF00DCFF00DCFF00DCFF00FFF500FFE600FFE600
FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFD700FFD700FFD700FFD700FFD700FFE600FFE600FFF500FAFF00DCFF00AEFF00
61FF0000FF470066FFFF00005100FF1400FFFF0000DC00FFFF0000FF0000FF0000FF0000
FF0000FF00000066FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00008F00FF
00FFF0BDFF00DCFF00EBFF00FAFF00FAFF00FFF500FFE600FFD700FFD700FFC700FFC700
FFC700FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FF9900FF9900
FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFC700
FFC700FFD700FFD700FFD700FFD700FFE600FFE600FFE600FFF500FAFF00EBFF00DCFF00
DCFF00DCFF00CCFF00CCFF00BDFF00AEFF009EFF008FFF0070FF0033FF0000C2FF0075FF
00F0FF00B3FF00FF0ADC00FF00FF0A00FF4780FF008FFF0080FF0042FF0000FF6600C2FF
42FF0080FF009EFF0000FF66BDFF00EBFF00FAFF00FAFF00FAFF00FAFF00FAFF00EBFF00
CCFF0061FF0000FF38BDFF00DCFF00EBFF00EBFF00EBFF00EBFF00EBFF00DCFF00CCFF00
00FF4700FFF070FF0061FF0000FFA305FF0000FFA3FF0000EB00FF00FF8500B3FF00FFFF
FF0000FF0000FF0000FF000000FFA300FF8500FF191400FF00FFF08FFF00BDFF00CCFF00
DCFF00DCFF00EBFF00EBFF00DCFF00DCFF00DCFF00CCFF00BDFF00BDFF00AEFF008FFF00
80FF0051FF0014FF0000FFC200FFFFBDFF008FFF0051FF00BDFF00FFF500FFE600FFE600
FFE600FFE600FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFD700
FFD700FFD700FFD700FFD700FFD700FFD700FFE600FFE600FFE600FFF500EBFF0000FF75
33FF00FF00E60085FFFF002E0057FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000EB00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
80FF00BDFF00CCFF00DCFF00EBFF00EBFF00FFF500FFE600FFD700FFD700FFC700FFC700
FFC700FFC700FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FF9900FF9900
FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700
FFC700FFC700FFD700FFD700FFD700FFD700FFE600FFE600FFF500FFF500FAFF00EBFF00
EBFF00DCFF00DCFF00CCFF00BDFF00BDFF00AEFF008FFF0070FF0005FF0000FF38FF0000
00C2FFFF000000FF6600FFC200D1FF0047FF61FF0070FF0070FF0042FF0000FF5700FF47
00FF1933FF0051FF009EFF00CCFF00EBFF00EBFF00EBFF00FAFF00EBFF00EBFF00DCFF00
8FFF007000FF51FF00BDFF00DCFF00DCFF00EBFF00EBFF00EBFF00DCFF00DCFF00CCFF00
AEFF0000F0FF33FF0000FF2800FF3800B3FF00FFB3FF000000D1FF00E1FF9E00FFFF008A
FF0000FF0000FF00007000FF00D1FFFF000000FFC2FF000000FF2800A3FFAEFF00CCFF00
DCFF00DCFF00DCFF00DCFF00DCFF00DCFF00CCFF00CCFF00CCFF00BDFF00AEFF009EFF00
8FFF0061FF0000FFB300FF380094FF9EFF0070FF0000FF38EBFF00FAFF00FFF500FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD700FFD700FFD700
FFD700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFD700FFC700FFC700FFD700
FFD700FFD700FFD700FFD700FFD700FFD700FFE600FFE600FFE600FFF500FAFF0000FF47
00FF4714FF0000FFC200B3FF6100FF00FFD10075FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF38FF0000
8FFF00AEFF00AEFF00CCFF00CCFF0061FF00FAFF00FFE600FFD700FFD700FFC700FFC700
FFC700FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700
FFC700FFC700FFD700FFD700FFD700FFD700FFE600FFE600FFF500FFF500FAFF00FAFF00
EBFF00EBFF00DCFF00DCFF00CCFF00BDFF00AEFF0080FF0061FF0033FF0000FF1900FFE1
FF00001400FF00D1FFFF000000FF5714FF0023FF0042FF0051FF0005FF0000FF5700FFB3
DC00FF0028FF00FF8500FFB3CCFF00DCFF00EBFF00EBFF00EBFF00EBFF00EBFF00DCFF00
9EFF0000FF388FFF00BDFF00CCFF00DCFF00DCFF00DCFF00DCFF00DCFF00CCFF00CCFF00
AEFF008FFF0000FF0A51FF0033FF0000FF5700FF470094FFFF0000FF00A8FF0000FF0000
FF0000FF0000FF0000FF0000FF000000F0FF00FFB36100FF00FFE123FF00AEFF00BDFF00
CCFF00CCFF00CCFF00CCFF00DCFF00CCFF00CCFF00CCFF00BDFF00BDFF00AEFF009EFF00
80FF0061FF0000FF75FF000042FF0080FF0070FF0000FFA3DCFF00FAFF00FFF500FFF500
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF500FAFF00FFE600FFD700FFD700
FFD700FFD700FFD700FFD700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFD700
FFD700FFD700FFD700FFD700FFD700FFE600FFE600FFE600FFF500FFF500FAFF00BDFF00
AEFF0000FF0A05FF00FF0000FF000000FF8500C2FF8000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000042FF00
70FF0080FF0000FF758FFF00000AFFBD00FFEBFF00FFE600FFD700FFD700FFC700FFC700
FFC700FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFC700
FFC700FFC700FFD700FFD700FFD700FFD700FFE600FFE600FFE600FFF500FFF500FAFF00
EBFF00EBFF00DCFF00DCFF00CCFF00AEFF009EFF0061FF0000FF3800FF2800FF660019FF
FF0000FF0000FF0000BD00FF0066FF00FF1900FF1905FF0023FF0014FF0000FF6600FFF0
00FFE105FF0014FF009EFF00BDFF00CCFF00DCFF00EBFF00EBFF00DCFF00DCFF00CCFF00
70FF0000FFA380FF00AEFF00BDFF00BDFF00BDFF00AEFF00CCFF00CCFF00CCFF00BDFF00
AEFF009EFF0080FF0070FF0042FF0014FF0000FF7500FFF0FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FA00FF0066FFFF0000FF00000500FF9EFF00AEFF00
BDFF00AEFF0080FF00CCFF00CCFF00CCFF00CCFF00BDFF00BDFF00AEFF00AEFF008FFF00
00FF4723FF0000FFA30085FF00FFC200FF0A0094FF00FF38CCFF00EBFF00FAFF00FFF500
FFF500FFF500FFF500FFF500FFF500FFF500FAFF00DCFF0033FF00FFF500FFE600FFD700
FFD700FFD700FFD700FFD700FFC700FFD700FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFD700FFC700FFD700FFD700FFD700FFD700
FFD700FFD700FFD700FFD700FFE600FFE600FFE600FFE600FFF500FFF500FAFF00EBFF00
CCFF0000B3FF00FF57FF00D700FF38FF000000FF2800FFC2CC00FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFD100FFE1
FF000051FF00FF00004200FF14FF0000FFFFFAFF00FFE600FFD700FFD700FFC700FFC700
FFC700FFB800FFC700FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FF9900
FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700
FFC700FFC700FFD700FFD700FFD700FFD700FFE600FFE600FFE600FFF500FFF500FAFF00
FAFF00EBFF00EBFF00DCFF00BDFF009EFF008FFF0061FF0014FF007000FF6100FF0500FF
FF0000FF0000FF0000FF000000B3FF00FF5700FFA3FF00D700FF1900FF3800FF47DC00FF
FF00F523FF0070FF009EFF00AEFF00BDFF00CCFF00DCFF00DCFF00DCFF00DCFF00CCFF00
AEFF0000FF1923FF0000FF7500FF859EFF008FFF008FFF00BDFF00BDFF00BDFF00BDFF00
AEFF009EFF008FFF0070FF0061FF0033FF0000FFE100FFF0EB00FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF009900FF1970FF009EFF009EFF00
9EFF0000FF4700FF47AEFF00BDFF00BDFF00BDFF00BDFF00AEFF00AEFF009EFF008FFF00
00FFC200FF4700FF1900FF6600D1FF00FF28FF00C751FF0000FF479EFF00FAFF00FAFF00
FFF500FFF500FFF500FAFF00DCFF00EBFF00EBFF0000A3FFBDFF00FFF500FFE600FFE600
FFD700FFD700FFD700FFD700FFD700FFD700FFC700FFD700FFC700FFC700FFC700FFC700
FFD700FFC700FFC700FFD700FFC700FFC700FFD700FFD700FFD700FFD700FFD700FFD700
FFD700FFD700FFD700FFD700FFD700FFE600FFE600FFE600FFF500FFF500FAFF00FAFF00
EBFF00CCFF00AEFF0080FF0051FF0005FF000028FFFF00000019FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFD10038FF
FF0000FF003DFF0000DC00FFFF00A8AEFF00FAFF00FFE600FFD700FFD700FFC700FFC700
FFC700FFB800FFB800FFB800FFB800FFA800FFB800FFA800FFA800FFA800FF9900FF9900
FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700
FFC700FFC700FFD700FFD700FFD700FFD700FFE600FFE600FFE600FFF500FFF500FAFF00
FAFF00EBFF00DCFF00CCFF009EFF0023FF0070FF00DC00FF0066FF00FFA34200FFFF0000
FF0000FF0000FF0000FF0000AE00FF0019FFFF0000FF0000FF0000FF00D700B3FF0075FF
FF005C0038FF61FF0080FF0051FF0000FF19BDFF00CCFF00DCFF00DCFF00CCFF00CCFF00
AEFF008FFF0070FF0000FF0AFF00A851FF0070FF0000FF949EFF0070FF00AEFF00AEFF00
9EFF008FFF008FFF0070FF0051FF0000FF0A8F00FF0075FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FA00FF00FF8500FF1951FF008FFF008FFF00
42FF0000FF2861FF009EFF00AEFF00AEFF00AEFF009EFF008FFF008FFF008FFF0080FF00
61FF0023FF0005FF0000FF380075FF00FFB300FF942300FF3300FFCCFF00EBFF00FAFF00
FAFF00FAFF00FAFF00EBFF0014FF0061FF00AEFF008FFF0000FF94FAFF00FFF500FFE600
FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFC700
FFD700FFC700FFC700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700
FFD700FFD700FFD700FFE600FFE600FFE600FFE600FFE600FFF500FFF500FAFF00FAFF00
EBFF00DCFF00CCFF00AEFF009EFF0080FF0061FF00FF0000FF00000075FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF000000FF94FF000000FF758FFF00EBFF00FFE600FFD700FFD700FFC700FFC700
FFC700FFC700FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800FF9900FFA800
FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700
FFC700FFC700FFD700FFD700FFD700FFE600FFE600FFE600FFE600FFF500FFF500FAFF00
FAFF00EBFF00DCFF00CCFF00AEFF0070FF0000FF5733FF0000FF1900FF2800FFC2FF00D7
FF0000FF0000FF0000FF00006100FFAE00FFFF00F5FF0000000AFF0094FFFF0000FF0000
0075FF05FF0042FF0061FF0051FF0080FF00BDFF00CCFF00CCFF00CCFF00CCFF00BDFF00
AEFF009EFF0080FF0000FFE15100FF00FF1900FF9400FF7561FF0051FF008FFF009EFF00
8FFF008FFF0080FF0061FF0005FF00FF00000066FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF002E00FFF051FF0080FF0080FF00
33FF0014FF0070FF008FFF009EFF00AEFF009EFF0080FF00FF009980FF0070FF0070FF00
51FF0033FF0014FF00FF006B00FFA3FF004C0094FF00FF3861FF00CCFF00EBFF00EBFF00
EBFF00EBFF00DCFF00AEFF0070FF0000FF5742FF0070FF0000F0FF33FF00FFF500FFE600
FFE600FFE600FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700
FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700
FFD700FFD700FFD700FFD700FFE600FFE600FFE600FFF500FFF500FFF500FAFF00FAFF00
EBFF00DCFF00CCFF00BDFF00AEFF008FFF0070FF00EB00FF00D1FF00FF470028FF00F0FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000DC00FF0019FFFA00FF61FF00FAFF00FFE600FFE600FFD700FFD700FFC700
FFC700FFC700FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800FF9900FF9900
FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF9900FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700
FFC700FFC700FFD700FFD700FFD700FFD700FFE600FFE600FFF500FFF500FFF500FAFF00
EBFF00EBFF00DCFF00CCFF00BDFF009EFF0080FF0051FF0023FF0000FF0ABD00FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000DC00FFFF0000FF0000
FF000000FF1900FF0A00FF0A42FF009EFF00AEFF00BDFF00BDFF00BDFF00BDFF00BDFF00
AEFF009EFF0080FF0042FF0000D1FFCC00FFFF001EFF000000FF1900FFE180FF0080FF00
8000FF80FF0070FF0061FF000057FF00FF3800FF850057FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0A51FF0061FF0061FF00
51FF0005FF0000FFA361FF0070FF008FFF008FFF0033FF0023FF0051FF0042FF00FF0000
00FF2805FF0000FF2800FF6600FFD1FF00A8FF00000047FF23FF0000FF38DCFF00EBFF00
EBFF00DCFF00BDFF0033FF0000FF9451FF0005FF00CC00FF00FF94CCFF00FFF500FFF500
FFE600FFE600FFE600FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700
FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700
FFD700FFD700FFE600FFE600FFE600FFE600FFE600FFE600FFF500FFF500FAFF00FAFF00
EBFF00DCFF00CCFF00BDFF009EFF008FFF0080FF0051FF0023FF0000FF1900FF6600B3FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF000000FFFFFF000000D1FF00FF19FAFF00FFE600FFD700FFD700FFD700FFC700
FFC700FFC700FFB800FFC700FFB800FFB800FFA800FFA800FFA800FFA800FFA800FF9900
FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFC700
FFC700FFC700FFD700FFD700FFD700FFE600FFE600FFE600FFF500FFF500FFF500FAFF00
EBFF00DCFF00CCFF00BDFF00AEFF009EFF0080FF0061FF0033FF0000FF1900FF750085FF
BD00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
00FFF000FF5700B3FF00FFFF51FF008FFF00AEFF00AEFF00BDFF00AEFF00AEFF00AEFF00
9EFF008FFF0070FF0000FF2800FF940075FFFF0000FF004CFF000000C2FF51FF0051FF00
14FF0061FF0061FF0051FF0023FF0005FF0000FF47FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00009E00FF00FF8514FF0033FF0042FF0051FF00
42FF0000FF19FF004C00FF4723FF0080FF0080FF0042FF0000FF387000FF00D1FFFF0000
8000FF00FF75DC00FFFF004CFF0000FF00B800FF7500C2FFFF0000AEFF00CCFF00DCFF00
DCFF00CCFF008FFF0000FF6651FF0080FF008FFF0080FF008FFF00EBFF00FFF500FFF500
FFE600FFE600FFE600FFE600FFD700FFD700FFE600FFD700FFD700FFD700FFD700FFD700
FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700
FFE600FFD700FFE600FFE600FFE600FFE600FFE600FFF500FFF500FFF500FAFF00FAFF00
EBFF00DCFF00BDFF0000FF6680FF0080FF0070FF0061FF0014FF0000FF66FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF000000FF8500FF4700FFFF00F0FFDCFF00FFF500FFE600FFD700FFD700FFD700FFC700
FFC700FFC700FFC700FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800FF9900
FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700
FFC700FFD700FFD700FFD700FFD700FFE600FFE600FFE600FFF500FFF500FAFF00FAFF00
BDFF0070FF00AEFF0033FF008FFF0080FF0070FF0042FF0005FF0000FF85EB00FF0085FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
1400FF00FFB3FF00A80094FF00D1FF00F0FF9EFF00AEFF00AEFF0070FF009EFF009EFF00
9EFF0070FF0014FF0000E1FFFF000000C2FFFF00000047FF00FFB300FF2823FF0033FF00
00FF3800FF0A14FF0033FF0023FF0005FF0000FF7500F0FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF001E00FF8505FF000075FF14FF0033FF00
00FFB30028FF00FFF0DC00FF00E1FF51FF0061FF0051FF0014FF0000FF1900FFB30047FF
0019FF9E00FF0047FFFF0000FF00000075FFFF000023FF0070FF00AEFF00CCFF00CCFF00
CCFF00BDFF0070FF000094FF51FF0080FF009EFF00BDFF00DCFF00EBFF00FAFF00FFF500
FFE600FFE600FFE600FFE600FFE600FFD700FFD700FFD700FFD700FFD700FFD700FFD700
FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFE600FFD700
FFD700FFE600FFE600FFE600FFE600FFE600FFE600FFF500FFF500FFF500FAFF00EBFF00
DCFF00CCFF0000FFE1FF00E600F0FF70FF0061FF0051FF00FF00009E00FF00F0FFFF006B
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000DC00FF00FFF09E00FFCCFF00FAFF00FFF500FFE600FFE600FFD700FFD700FFC700
FFC700FFC700FFC700FFC700FFB800FFB800FFB800FFB800FFA800FFA800FFA800FF9900
FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800
FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFB800
FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700
FFC700FFC700FFD700FFD700FFE600FFE600FFE600FFF500FFF500FFF500FAFF00EBFF00
DCFF0051FF0000FF1900FFB333FF0051FF0051FF00AE00FF0094FF00A3FF00D1FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF002E3300FF0085FF00FF0A80FF008FFF009EFF008FFF00FF000080FF008FFF00
8FFF0070FF0042FF0000FF0A00FF9400FFD1FF0000FF000000E1FFFF000005FF0000FF38
00FF38FF0000FF001E00FF1900FF3800FF1900FF5700FFB3FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF5700FF2800FF47FF000005FF00
00FF28FF0000FF0000FF00000028FF00FFA342FF0042FF0023FF0000FF0A00FF660047FF
FF0000FF0000FF0000FF0000FF0000FF000000FF3814FF0000FF2800FFE1BDFF00CCFF00
BDFF00BDFF007000FF00FFD100E1FF00FFA361FF00BDFF00DCFF00EBFF00FAFF00FFF500
FFF500FFE600FFE600FFE600FFE600FFE600FFD700FFD700FFD700FFD700FFD700FFD700
FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFE600FFD700FFD700FFD700
FFD700FFE600FFE600FFE600FFE600FFE600FFF500FFF500FFF500FAFF00FAFF00EBFF00
9EFF0070FF0000C2FF00FF0A33FF0051FF0051FF0000FF38FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00C700FF47
33FF0080FF008FFF009EFF00EBFF00FAFF00FFF500FFE600FFE600FFD700FFD700FFD700
FFC700FFC700FFC700FFC700FFC700FFC700FFB800FFB800FFB800FFB800FFA800FFA800
FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FFA800FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700
FFC700FFD700FFD700FFD700FFE600FFE600FFF500FFF500FFF500FAFF00FAFF00EBFF00
DCFF00BDFF008FFF000047FF00FF9405FF0033FF0014FF0000FF47FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF000000FFD133FF0061FF0080FF008FFF0070FF000028FF61FF0070FF00
70FF0061FF0051FF0023FF0000FF6600B3FFFF0000FF0000FF0000FF0000FF000000FF47
EB00FFFF0000FF000000FF75FF00000066FF00FFB300FFB3FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF000000FFE100FFA300FFF000FFC2FF0000CC00FF
00FF5700FFD15100FFFF000000A3FFFF003D00FFE123FF0005FF0000FF28FF0000FF0000
FF0000FF0000FF0000FF0000FF0000000AFF00FF8500FF5733FF008FFF00AEFF00BDFF00
BDFF00AEFF0080FF0000FFE100FF6605FF0000FFD1AEFF00DCFF00EBFF00FAFF00FFF500
FFF500FFF500FFE600FFE600FFE600FFE600FFE600FFE600FFD700FFD700FFE600FFD700
FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFF500FFF500FAFF00FAFF00FAFF00EBFF00
BDFF000019FFFF00E6FF000033FF0042FF0042FF0014FF008F00FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
23FF0080FF00AEFF00DCFF00EBFF00FAFF00FFF500FFF500FFE600FFE600FFE600FFD700
FFD700FFD700FFC700FFC700FFC700FFC700FFC700FFC700FFB800FFB800FFA800FFA800
FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700
FFC700FFD700FFD700FFE600FFE600FFF500FFF500FFF500FAFF00FAFF00EBFF00EBFF00
DCFF00BDFF008FFF0042FF0000FF4700D1FF00FF0A00FF2800FF6600B3FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000038FF00FF3833FF0070FF0080FF0061FF0000FF28FF000033FF00
00B3FF00FF3833FF0000FF38FF00E6FF0000FF0000FF0000FF00006100FF00FF8500FF75
00FFFFFF0000FF000000FFFFFF002EFF0000FF00000075FFFF00002300FFFF0000FF0000
FF0000FF0000FF0000FF00008F00FF0047FF0066FFFF0000FF000000C2FFFF00007000FF
00FFC2FF0099FF0000FF0000FF000000FF5700FFD100FF1900FF2800FFD1FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF000000C2FF00E1FF00A3FF8FFF00AEFF00AEFF00
AEFF009EFF008FFF0000FF1933FF0033FF0000FF3861FF008FFF00EBFF00FAFF00FAFF00
FFF500FFF500FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD700FFE600FFD700
FFD700FFD700FFD700FFD700FFD700FFD700FFE600FFD700FFD700FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFF500FFF500FFF500FAFF00FAFF00EBFF00DCFF00
BDFF0051FF00FF000000FF7514FF00FF000014FF0000FF1900FF4700E1FFFF00A8FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF000000FF0AAEFF00CCFF00EBFF00FAFF00FAFF00FFF500FFE600FFE600FFD700FFD700
FFD700FFD700FFD700FFC700FFC700FFD700FFE600DCFF00FFC700FFB800FFA800FFA800
FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF7A00FF7A00FF7A00
FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF8A00
FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFC700
FFD700FFD700FFE600FFE600FFF500DCFF00FAFF00FAFF00FAFF00EBFF00EBFF00DCFF00
CCFF009EFF0070FF0000FF2800F0FF0094FF00FF470094FF00B3FF0028FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000028FFEB00FF00FF2842FF0061FF0061FF0061FF0042FF0000FF850066FF
7000FFFF000000FF0A00FF284200FFFF0000FF0000FF0000FF0000FF000000E1FFFF0000
0066FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00F500FFD13300FFFF000000FF4700FF85FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00007000FF51FF0080FF009EFF009EFF00
9EFF009EFF008FFF0070FF0061FF0042FF0000FF1900FFFF0066FFCCFF00DCFF00FAFF00
FFF500FFF500FFF500FFF500FFE600FFF500FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFD700FFD700FFD700FFE600FFD700FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFF500FFF500FFF500FFF500FAFF00EBFF00DCFF00CCFF00
FF002E05FF006100FF00FFE100FF28FF0000FF000000FFC200FF75FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0028FFFF0000AEFF00CCFF00DCFF00EBFF00EBFF00FAFF00FFF500FFE600FFE600FFD700
FFD700FFD700FFD700FFD700FFD700FFE600FFF500CCFF00BDFF00FFC700FFB800FFA800
FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFD700
FFD700FFD700FFE600FAFF00EBFF00BDFF00CCFF00DCFF00EBFF00EBFF00DCFF00CCFF00
80FF0080FF0005FF000047FF00F0FF0038FF0038FF1400FFFF003DFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF000000FFFF33FF0051FF0033FF0042FF0000FF28FF0000FF00C7
FF005C0066FF00FF5700FF6600D1FFFF0000FF0000FF0000FF00009E00FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000CC00FFFF000000FFC20066FFFF0000
FF0000FF0000FF0000FF0000FF0000FF00006100FFFF000051FF0061FF0070FF008FFF00
8FFF008FFF008FFF0080FF0061FF0042FF0005FF0000B3FF51FF008FFF0061FF00EBFF00
FAFF00FFF500FFF500FFF500FFF500FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFF500FFF500FFF500FFF500FAFF00EBFF00DCFF00AEFF00AEFF00
00FF5700FFF0FF000000FF9400FF94FF004CFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
4200FFFF00B8AEFF00CCFF00DCFF00DCFF0000FF19CCFF00FAFF00FFF500FFE600FFE600
FFD700FFD700FFD700FFD700FFD700FFE600FFF500EBFF00DCFF00FFF500FFB800FFA800
FFA800FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800
FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFC700
FFD700FFD700FFF50080FF0061FF0000FF579EFF00AEFF00CCFF00DCFF00CCFF00BDFF00
51FF0000FF1900FFD100FF3800FF0A00D1FFFF00D7FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF000000FFF000FF8523FF0023FF000038FF23FF0005FF0000FF66FF004C
FF0000FF000000FFD1FF000000A3FF0028FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF008AFF00000028FF0047FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF9433FF000075FFDC00FF80FF00
8FFF0080FF0080FF0070FF0061FF0033FF0000FFE1FF005C42FF0023FF009EFF00DCFF00
FAFF00FAFF00FFF500FFF500FFF500FFF500FFF500FFF500FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFF500FFF500FFF500FAFF00DCFF008FFF0005FF0051FF00
FF008AFF00D7FF000000E1FFFF0000FF002EFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF000061FF00AEFF00BDFF00CCFF00CCFF00AEFF0000FF19DCFF00FFF500FFF500FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFF500EBFF0080FF00CCFF00FFB800FFA800
FFA800FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFA800FFA800
FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFC700
FFD700FFD700FFE600FAFF00EBFF0080FF0023FF0061FF0061FF00BDFF00BDFF0061FF00
00FFA3FF000000D1FF00FF4723FF0000FF38FF00C7FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF000000FF2814FF0005FF0000FF660094FFFF000000FF75FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00008F00FF00FFB300FF0A14FF000094FF23FF0070FF00
70FF0070FF0070FF0061FF0051FF0000FFB30057FFFF000014FF0014FF0042FF00CCFF00
EBFF00EBFF00FAFF00FAFF00FAFF00FFF500FFF500FFF500FFF500FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFF500FFF500FFF500FFF500FAFF00FAFF00DCFF0000FF4700E1FF0057FF
FF0000FF00000500FF4200FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00007000FF
00FF1980FF009EFF00AEFF00BDFF00BDFF0080FF00BD00FFAEFF00DCFF00FFF500FFF500
FFE600FFE600FFE600FFE600FFE600FFF500FAFF00BDFF00BDFF00FFE600FFB800FFA800
FFA800FFA800FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FF9900FF9900FF9900FF9900
FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800
FFB800FFB800FFB800FFB800FFB800FFC700FFB800FFB800FFC700FFC700FFC700FFC700
FFD700FFD700FFE600FFF500FAFF00DCFF0023FF0023FF0000FF5761FF008FFF0051FF00
00FF4751FF0000FF7551FF0051FF0000FF0A00FFA30038FFFF003DFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF000000FFE100FF3800FF2800FF1900FFD1FF0000FF0000FF00000019FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF000000FF7500FFB300FF1900FF38FF000000FF75
61FF0023FF0005FF0051FF0033FF0000FFC200FF660085FF00FF75FF000033FF00BDFF00
DCFF00EBFF00EBFF00EBFF00FAFF00EBFF00EBFF00FAFF00FFF500FFF500FFF500FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFF500FFF500FFF500FFF500FFF500FAFF00EBFF00EBFF00BDFF0014FF00FF0000
FF0099FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF000070FF0070FF000047FFFF00009EFF0070FF0000FFD100B3FF00FF19EBFF00FFF500
FFF500FFF500FFF500FFF500FFF500FAFF00EBFF0023FF00EBFF00FFE600FFC700FFA800
FFA800FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFD700
FFD700FFD700FFE600FFE600FFF500DCFF009EFF0000FF66EB00FF00FF0A05FF009EFF00
9EFF008FFF0000FFA380FF0070FF0000FF7505FF0000D1FF00F0FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF000000FF5700FF6600FF9400FFC2FF0000FF0000FF00B8FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF004C1400FF0094FF00FFE18F00FF00FF66FF00006100FF0094FF
33FF001400FF00FF2800FF0AFF000000FF1900FF5700A3FFFF00E60075FF000AFFBDFF00
DCFF00DCFF00DCFF00AEFF00CCFF00BDFF0014FF00FAFF00FFF500FFF500FFF500FFF500
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF500
FFE600FFF500FFF500FFF500FFF500FAFF00FAFF00FAFF00EBFF00CCFF0000FFB3FF0000
FF0000FF002E00D1FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
23FF0051FF0051FF0000FF388000FF0085FF51FF0014FF0000FFFFBD00FF51FF00FAFF00
FFF500FFF500FFF500FAFF00FAFF00EBFF00DCFF00AEFF0000FF19FAFF00FFD700FFA800
FFA800FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00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FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00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FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800
FFB800FFB800FFB800FFC700FFB800FFB800FFC700FFC700FFC700FFC700FFC700FFD700
FFD700FFD700FFD700FFE600FFF500FFF500FAFF00FAFF00EBFF00EBFF00DCFF00DCFF00
CCFF00CCFF00BDFF00AEFF0080FF0023FF0000FF75BD00FF00B3FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000066FF0094FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000C2FF
FF000000FF75FF0000FF00C7FF0000FF0000FF0000FF0000FF004C00FF3851FF008FFF00
9EFF0080FF000066FF23FF0051FF0000FF8514FF00DCFF00EBFF00FAFF00FFF500FFF500
FFF500FFF500FFF500FFF500FFF500FFF500FFF500FFF500FFF500FFF500FFF500FFF500
FFF500FFF500FFF500FFF500FAFF00FAFF00FAFF00FAFF00EBFF00DCFF00CCFF00BDFF00
9EFF0080FF0061FF0033FF00EB00FF00FF9400FFFFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000D1FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000005FF000500FF61FF00CCFF00
DCFF00DCFF00AEFF003300FF00FFC200C2FFAEFF00AEFF00AEFF00FFE600FFB800FFA800
FFA800FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFD700
FFD700FFD700FFD700FFE600FFE600FFF500FFF500FAFF00FAFF00EBFF00EBFF00DCFF00
CCFF00CCFF00BDFF00AEFF009EFF0061FF0000FFF0FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00001400FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF000000FFE100D1FFFF0000FF0000FF0000FF0000FF000000FFE100FF6600FF1980FF00
8FFF0051FF0000FF380028FF51FF008FFF00BDFF00DCFF00EBFF00FAFF00FAFF00FFF500
FFF500FFF500FFF500FFF500FFF500FFF500FFF500FFF500FFF500FFF500FFF500FFF500
FFF500FFF500FFF500FAFF00FAFF00FAFF00FAFF00EBFF00EBFF00DCFF00CCFF00BDFF00
9EFF0061FF0051FF0042FF0014FF0000E1FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000094FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00E600FFC270FF009EFF00BDFF00
CCFF00CCFF00AEFF0080FF00FF000005FF0000FF75EBFF00FFE600FFC700FFB800FFA800
FFA800FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FF9900FF9900FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800
FFB800FFB800FFC700FFB800FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFD700
FFD700FFD700FFE600FFE600FFE600FFF500FFF500FAFF00FAFF00FAFF00EBFF00EBFF00
DCFF00CCFF00BDFF00AEFF008FFF002300FF00FFC200FF380075FFBD00FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF005CFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000038FFFF0000FF0000FF0000FF0000FF0000000AFF00FF9451FF0070FF00
70FF0051FF0000FFB3FF0000FF00009EFF00CCFF00DCFF00EBFF00EBFF00FAFF00FAFF00
FFF500FFF500FFF500FFF500FFF500FFF500FFF500FFF500FFF500FFF500FFF500FFF500
FFF500FFF500FFF500FAFF00FAFF00FAFF00FAFF00EBFF00EBFF00DCFF00CCFF00AEFF00
FF00D700FF6623FF0033FF0005FF008000FF0066FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00E642FF0000FFD1AEFF00
BDFF00BDFF00AEFF0080FF000085FFAEFF00FAFF00FFE600FFD700FFC700FFB800FFA800
FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFD700FFD700
FFD700FFE600FFE600FFE600FFE600FFF500FFF500FFF500FAFF00FAFF00EBFF00EBFF00
DCFF00CCFF00BDFF0080FF0070FF0000FFC205FF0014FF0000FF0A00FFFF0057FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF2851FF0061FF00
61FF0051FF0023FF0005FF0000FF5761FF00BDFF00DCFF00EBFF00EBFF00FAFF00FAFF00
FAFF00FFF500FFF500FFF500FFF500FFF500FFF500FFF500FFF500FFF500FFF500FFF500
FFF500FFF500FAFF00FAFF00FAFF00FAFF00FAFF00EBFF00EBFF00DCFF00BDFF0000FF66
5100FF00FF2814FF0014FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFB305FF005100FF42FF00
9EFF009EFF000094FF00FF5700FF75BDFF00FFF500FFE600FFD700FFB800FFB800FFA800
FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00
FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFC700FFB800FFC700FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFD700
FFD700FFD700FFE600FFE600FFF500FFF500FFF500FFF500FAFF00FAFF00EBFF00EBFF00
DCFF00CCFF0000FF4700FF380028FF00FF3861FF0051FF0023FF0000FFA3FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000A3FF00FF19FF007A51FF00
51FF0051FF0033FF0014FF000057FF00FFE1AEFF00CCFF00DCFF00EBFF00EBFF00FAFF00
FAFF00FAFF00FAFF00FFF500FFF500FFF500FFF500FFF500FFF500FFF500FFF500FAFF00
FFF500FAFF00FAFF00FAFF00FAFF00FAFF00EBFF00EBFF00DCFF00DCFF00BDFF0000C2FF
7000FF00FF3800FF1900FF0A00FF47FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000057FF0066FF0047FF00FF19
8FFF0014FF0000FFB35100FF9EFF00EBFF00FFF500FFE600FFD700FFC700FFB800FFA800
FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FFA800FF9900FF9900FF9900FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFC700FFB800
FFB800FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFD700
FFD700FFD700FFE600FFE600FFE600FFF500FFF500FFF500FAFF00FAFF00EBFF00EBFF00
DCFF00CCFF00BDFF0051FF0061FF0070FF0080FF0061FF0042FF000085FF00FF7500FFE1
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF000000D1FF00FFB300FF66EB00FF33FF00
42FF0042FF0033FF0014FF0000FF5700FFC20066FF0047FFDCFF00EBFF00EBFF00EBFF00
FAFF00FAFF00FAFF00FAFF00FAFF00FFF500FAFF00FFF500FFF500FFF500FFF500FAFF00
FAFF00FAFF00FAFF00FAFF00FAFF00FAFF00EBFF00EBFF00DCFF00CCFF00AEFF0000FF47
FF0000FF00F5FF00B8FF000000FFF0FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFC223FF00
70FF0061FF0005FF009E00FFBDFF00DCFF00FAFF00FFF500FFF500FFC700FFB800FFA800
FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00
FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFC700FFC700FFC700FFC700FFC700FFC700FFD700FFC700FFD700FFD700FFD700FFD700
FFD700FFE600FFE600FFE600FFE600FFF500FFF500FFF500FAFF00FAFF00EBFF00EBFF00
DCFF00DCFF00BDFF00AEFF009EFF008FFF0080FF0070FF0000FF3800C2FF00FF0A00FF38
00E1FFFF007AFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000BD00FF00FFE1FF000005FF00
14FF0014FF0014FF0000A3FF0085FF00FFF000FF0A9EFF00CCFF00DCFF00EBFF00EBFF00
EBFF00FAFF00FAFF00FAFF00FAFF00FAFF00FAFF00FAFF00FAFF00FAFF00FAFF00FAFF00
FAFF00FAFF00FAFF00FAFF00FAFF00EBFF00EBFF00DCFF00CCFF00AEFF008FFF00EB00FF
FF000000FFF0000AFFFF0000FF00000047FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00007000FF00FF38
00FF0A33FF00000AFF70FF009EFF008FFF00DCFF00FAFF00DCFF00FFE600FFB800FFA800
FFA800FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00
FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFD700FFE600FFD700
FFE600FFE600FFE600FFE600FFF500FFF500FFF500FAFF00FAFF00FAFF00EBFF00EBFF00
DCFF00CCFF00CCFF00BDFF00AEFF009EFF008FFF0070FF0023FF0033FF0023FF0000B3FF
00FF4700FFA300FFC200E1FF0038FF2300FFFF00D7FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000085FFFF000000FFB3
FF000000FF5700FF3800FF6600FFC2FF0000FF00006100FFBDFF00CCFF00DCFF00DCFF00
DCFF00EBFF00EBFF00EBFF00FAFF00FAFF00FAFF00FAFF00FAFF00FAFF00FAFF00FAFF00
FAFF00FAFF00FAFF00FAFF00EBFF00EBFF00EBFF00CCFF00FF000000FF5700FFC2FF00F5
FF0000FF0000FF00F5FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00E6FF00A8
00FFA305FF000028FF00FF4700FFD100FF0A7000FFAEFF00CCFF00FFC700FFB800FFA800
FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFD700FFD700FFD700FFD700FFE600
FFE600FFE600FFE600FFE600FFF500FFF500FFF500FAFF00FAFF00EBFF00EBFF00DCFF00
DCFF00CCFF00BDFF00BDFF00AEFF009EFF008FFF0080FF0061FF0042FF0033FF0005FF00
00FF2800FF5700FF9400FFF00028FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFD1
00FF85FF006BFF000000C2FF00FFF0FF0000CC00FF00FFC2AEFF00BDFF00AEFF00BDFF00
AEFF00DCFF00EBFF00EBFF00FAFF00FAFF00FAFF00FAFF00FAFF00FAFF00FAFF00FAFF00
FAFF00FAFF00FAFF00FAFF00EBFF00EBFF00DCFF00DCFF008FFF0000FF0A000AFFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000000AFF
FF0000FF0000FF0000FF0000FF0000FF0000FF00000094FFFF0000FF000000FF4700F0FF
00FF570094FF9E00FF14FF008FFF00BDFF00DCFF00AEFF00DCFF00FFB800FFA800FFA800
FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FFA800FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFC700FFC700
FFD700FFC700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFE600FFE600
FFE600FFE600FFE600FFF500FFF500FFF500FAFF00FAFF00EBFF00EBFF00DCFF00DCFF00
CCFF00CCFF00BDFF00AEFF00AEFF009EFF0080FF0070FF0061FF0042FF0023FF0005FF00
00FFB30085FF00B3FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00996100FF
FF0000FF0000FF0000FF0000FF0000FF0000FF00C7FF00008FFF0080FF000047FF0085FF
00FF75CCFF00DCFF00EBFF00EBFF00EBFF00FAFF00FAFF00FAFF00FAFF00FAFF00FAFF00
FAFF00FAFF00FAFF00EBFF00EBFF00EBFF00DCFF00CCFF00BDFF000094FF6100FF9E00FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000D1FF
FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFC205FF008000FF00FF6651FF00
00FF8500FF2800FFC200FF3880FF00DCFF00FFF500FFE600FFC700FFB800FFB800FFA800
FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFD700FFD700FFD700FFD700
FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFE600FFE600FFE600FFE600
FFE600FFF500FFF500FFF500FFF500FAFF00FAFF00EBFF00DCFF00CCFF00CCFF00CCFF00
CCFF00BDFF00AEFF00AEFF009EFF0061FF0061FF0061FF0033FF0033FF0000FF3800FF66
00FF75FF0000FF0099FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0085FFFF0000FF0000FF0000FF0000FA00FFFF000061FF0070FF0000D1FF00FF191400FF
00FF47BDFF00DCFF00EBFF00EBFF00EBFF00EBFF00FAFF00FAFF00FAFF00EBFF00FAFF00
FAFF00EBFF00EBFF00EBFF00EBFF00EBFF00DCFF00CCFF00BDFF009EFF0000FFC2FA00FF
00FFFF00D1FFFF00D7FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0094FFFF0000FF0000FF0000FF0000FF000000FFD105FF0070FF0061FF0051FF0080FF00
51FF0000FFFF33FF0080FF0000FFD1CCFF00FFF500FFC700FFB800FFA800FFA800FF9900
FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFB800FFB800FFB800FFC700FFE600FFE600FFE600FFD700FFE600FFE600
FFE600FFE600FFD700FFD700FFD700FFD700FFD700FFD700FFE600FFE600FFE600FFE600
FFF500FFF500FFF500FAFF00FAFF00FAFF00FAFF00EBFF00CCFF0000FFE1AEFF00BDFF00
BDFF00AEFF0070FF008FFF008FFF0070FF0005FF0023FF00FF000000FFD100FF38FF0000
0038FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000057FF00FF6651FF0042FF0000FF85000AFF51FF00
42FF00BDFF00DCFF00DCFF00EBFF00EBFF00EBFF00EBFF00EBFF00FAFF00EBFF00EBFF00
EBFF00EBFF00EBFF00EBFF00EBFF00DCFF00DCFF00CCFF00CCFF00AEFF008FFF0061FF00
33FF0000FF0AFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
05FF00FF0000FF00000066FFFF0000FF000000FF2800D1FF70FF00AEFF00BDFF00AEFF00
23FF0033FF0080FF0000E1FFDCFF0000FFA380FF00FFC700FFB800FFA800FFA800FF9900
FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FFA800FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFB800FFB800FFB800FFB800FFB800FFC700FFE60061FF00FAFF00FFF500FFF50070FF00
FFF500FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF500
EBFF00FAFF00FAFF00FAFF00FAFF00FAFF00EBFF00EBFF00CCFF0061FF0042FF009EFF00
AEFF009EFF00DC00FF70FF0070FF0061FF0023FF00FF00A8FF003D00FFF000FFE1FF0099
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF000014FF0033FF0023FF00FF002E00FF7542FF00
AEFF00CCFF00DCFF00DCFF00EBFF00EBFF00EBFF00EBFF00EBFF00EBFF00EBFF00EBFF00
EBFF00EBFF00EBFF00EBFF00EBFF00DCFF00DCFF00CCFF00CCFF00AEFF009EFF0051FF00
05FF0005FF0000FF4700E1FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
00FFC261FF005100FFFF000023FF00FF00000057FFFF00006100FFBDFF00DCFF00BDFF00
61FF00CCFF00AEFF00CCFF00FFF500EBFF00FFD700FFB800FFA800FFA800FFA800FF9900
FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900
FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFB800FFB800FFB800FFB800FFC700FFD700DCFF008FFF0080FF008FFF0023FF00
FAFF00FFF500FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF500FFF500FAFF00
BDFF0061FF00EBFF00EBFF00EBFF00EBFF00EBFF00DCFF00CCFF008FFF009E00FF8FFF00
80FF0080FF0042FF00FF00F542FF0051FF0023FF0000A3FFFF00003300FF00E1FFFF00E6
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF000000FF85FF000023FF0014FF0000FF0A00FF3800E1FF
9EFF00BDFF00CCFF00DCFF00DCFF00EBFF00EBFF00EBFF00EBFF00EBFF00EBFF00EBFF00
EBFF00EBFF00EBFF00DCFF00DCFF00DCFF00DCFF00CCFF00BDFF00AEFF0080FF00FF0000
00FF4700FF19FA00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000AE00FF
42FF0070FF008FFF000038FF80FF0000FF47FF00003300FF00FF5780FF00FAFF00DCFF00
33FF00DCFF00FAFF00AEFF00FFE600FFC700FFB800FFB800FFA800FFA800FF9900FF9900
FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900
FF9900FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800
FFB800FFB800FFB800FFB800FFC700FFC700FFD700FFE600FAFF00BDFF0000FF668FFF00
EBFF00FAFF00FFF500FFF500FFE600FFE600FFE600FFE600FFF500FFF500FFF500FAFF00
AEFF0070FF00DCFF00EBFF00EBFF00DCFF00DCFF00DCFF00CCFF00AEFF0042FF0000FF85
FF000F00FF0A0094FFFF000000FFE123FF0000FF19FF0000CC00FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000047FF00FFD1FA00FF05FF0005FF0000FF0A00FF3800A3FF
70FF00AEFF00BDFF00CCFF00DCFF00DCFF00DCFF00EBFF00EBFF00EBFF00EBFF00EBFF00
EBFF00EBFF00DCFF00DCFF00DCFF00DCFF00CCFF00CCFF00BDFF00AEFF00FF0000FF0000
00FF4700FF4700FFB3FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0500FFFF0000AEFF00BDFF00CCFF00AEFF0051FF0005FF00DCFF00FAFF00FFF500FFF500
FAFF00FFE600FFE600FFD700FFC700FFB800FFB800FFA800FFA800FFA800FF9900FF9900
FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FF9900FF9900
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFB800FFB800FFB800FFB800FFC700FFC700FFD700FFE600FFF500BDFF009EFF008FFF00
DCFF00AEFF00FAFF00FFF500FFF500FFF500FFF500FFF500FFF500FFF500FAFF00EBFF00
BDFF00BD00FFBDFF00DCFF00DCFF00DCFF00DCFF00CCFF00CCFF00BDFF009EFF0070FF00
00FFF0FF0000FF00F5FF0000FF000000FF6600FF3800FFB3FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000038FFFF000000FF4700FF4700FF388000FFFF0099
00FF479EFF00BDFF00CCFF00CCFF00DCFF00DCFF00DCFF00DCFF00DCFF00EBFF00EBFF00
EBFF00DCFF00DCFF00DCFF00DCFF00DCFF00CCFF00CCFF00BDFF009EFF0000FF85FF0000
00FFB3FF000000B3FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF000080FF00BDFF00CCFF00DCFF00EBFF00EBFF00FAFF00FFF500FFE600FFE600FFD700
FFD700FFD700FFC700FFC700FFC700FFB800FFA800FFA800FFA800FF9900FFA800FF9900
FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF8A00FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFB800FFB800FFB800FFC700FFC700FFC700FFD700FFD700FFF500EBFF00BDFF0000FF57
AEFF009EFF00EBFF00FAFF00FFF500FFF500FAFF00FFF500FAFF00FAFF00FAFF00EBFF00
CCFF0042FF0080FF00AEFF0070FF00CCFF00CCFF00CCFF00BDFF00AEFF009EFF0080FF00
33FF00FF0000FF0000FF000000A3FFFF000000FF94FF00007000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF005C00FFC20028FFFF000000FFFFFF0000
00FFFF80FF00AEFF00BDFF00CCFF00CCFF00DCFF00DCFF00DCFF00DCFF00DCFF00DCFF00
DCFF00DCFF00DCFF00DCFF00DCFF00CCFF00CCFF00BDFF009EFF0080FF00FF0000FF0000
00A3FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
00FF668FFF00BDFF00CCFF00EBFF00FAFF00FFF500FFF500FFE600FFE600FFD700FFD700
FFC700FFC700FFC700FFB800FFB800FFA800FFA800FFA800FF9900FF9900FF9900FF9900
FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FFA800FF9900FF9900FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800
FFB800FFB800FFB800FFB800FFC700FFC700FFD700FFE600FFE600FAFF00AEFF0070FF00
05FF0070FF00DCFF00EBFF00FAFF00FAFF00FAFF00FAFF00EBFF00EBFF00EBFF00DCFF00
CCFF009EFF0000FFA361FF0051FF00AEFF00BDFF00BDFF00BDFF00AEFF008FFF0070FF00
0075FF00B3FF0057FFFF0000FF0000FF00000057FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF009900B3FFFF0000FF0000FF0000BD00FF
9E00FF80FF008FFF0000FF948FFF00BDFF00CCFF00CCFF00DCFF00DCFF00DCFF00DCFF00
DCFF00DCFF00DCFF00DCFF00DCFF00CCFF00CCFF00AEFF00FF007A00FF47FF0000DC00FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF57
51FF0070FF00AEFF0042FF00EBFF00FFF500FFF500FFE600FFE600FFD700FFD700FFC700
FFC700FFC700FFB800FFB800FFA800FFA800FFA800FFA800FFA800FF9900FF9900FF9900
FF9900FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800
FFB800FFB800FFB800FFB800FFC700FFC700FFD700FFD700FFF500EBFF0005FF0061FF00
00FF758FFF00BDFF00DCFF00EBFF00EBFF00EBFF00EBFF00AEFF00DCFF00DCFF00CCFF00
BDFF0061FF0000FF6600FFA31400FF9EFF009EFF008FFF009EFF009EFF0080FF000019FF
00FFC2FF000000FFF0FF003DFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF005C
00FFC251FF00FF00008000FF00FF38AEFF00CCFF00CCFF00DCFF00DCFF00DCFF00DCFF00
DCFF00DCFF00DCFF00DCFF00CCFF00CCFF00BDFF00AEFF0005FF000075FFFF00008F00FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFD1
CC00FFFF000070FF0000FF0AEBFF00FFF500FFE600FFE600FFE600FFD700FFC700FFC700
FFC700FFB800FFB800FFB800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FF9900FF9900
FF9900FF9900FF9900FFA800FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFC700FFC700FFD700FFD700FAFF0051FF00DCFF009EFF00
8FFF0033FF0000FF94CCFF00DCFF00DCFF00DCFF00CCFF0070FF00BDFF00BDFF0080FF00
9EFF0070FF0005FF0000E1FF05FF0080FF0080FF0000FF288FFF008FFF0080FF0051FF00
14FF0000FF38FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00005100FF
00FF0A14FF0000FFB300FF19FF0000AEFF00BDFF00CCFF00CCFF00DCFF00DCFF00DCFF00
DCFF00CCFF00DCFF00CCFF00CCFF00CCFF00BDFF00AEFF008FFF0000FF3800FFE10019FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
00D1FFFF000000FF8500FFC2EBFF00FFF500FFE600FFE600FFD700FFD700FFC700FFC700
FFC700FFB800FFB800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900
FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FFA800FF9900FF9900FF9900FFA800FF9900FFA800FF9900FF9900
FFA800FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFD700FFE600FFF500FAFF00DCFF00
AEFF0005FF0033FF0080FF00BDFF00BDFF0080FF0000FF3800C2FF8FFF009EFF000038FF
00FFF000FF2800FFA300FF9442FF0070FF0061FF0051FF0070FF0080FF0070FF0061FF00
33FF0000FF2800FFD1AE00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000EB00FF
00FF1900FF190038FF00F0FF80FF009EFF00BDFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00BDFF00BDFF00AEFF009EFF0080FF0042FF0000FF0A
00FF6600E1FFFF003DFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000066FF00E1FF70FF00FAFF00FFF500FFE600FFE600FFD700FFD700FFC700FFC700
FFB800FFB800FFB800FFB800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00
FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FFA800FF9900FFA800FF9900FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFA800FFA800FFB800FFB800FFB800
FFB800FFB800FFC700FFC700FFC700FFC700FFC700FFD700FFE600FFE600FFF500FAFF00
BDFF00AEFF008FFF0000FFC261FF0000FF6600FF7505FF0000FFD151FF0070FF0033FF00
0085FF00FF2800D1FF00FF6633FF0005FF0023FF00CC00FF42FF0042FF0051FF0000FF28
14FF0000FF3800FF7500E1FF9E00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
00FF3800FF2800FF5700FFC270FF009EFF00BDFF00BDFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00BDFF00BDFF00AEFF009EFF0080FF0000A3FFFF0000
00FF57FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000038FFCCFF00FAFF00FFF500FFE600FFE600FFD700FFD700FFC700FFC700
FFB800FFB800FFB800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFD700FFD700FFE600FFE600FFF500
DCFF00EBFF00CCFF00BDFF00BDFF00AEFF0080FF0005FF0000F0FF00FFB300FF2805FF00
FF00990075FFFF000000FF280057FF00FF28FF00001400FFFF000000FF5733FF0005FF00
4200FFFF00000057FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
00FF7500FF5700FF94FF0000FF00008FFF00AEFF00BDFF00BDFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00BDFF00BDFF00BDFF00AEFF009EFF00FF00000085FF00FF85
00FF85FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
05FF0042FF009EFF00EBFF00FAFF00FFF500FFE600FFE600FFD700FFD700FFD700FFC700
FFB800FFB800FFA800FFA800FFA800FFA800FF9900FFA800FF9900FF9900FF9900FF9900
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF9900FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFC700FFC700FFC700FFD700FFD700FFD700FFE600FFE600FFF500
FAFF00FAFF00EBFF00EBFF00DCFF00CCFF00AEFF0000FF4742FF0000F0FF4200FF8000FF
00E1FFFF000000FFB30066FF00FFD100FF470085FFFF002E00F0FF00FF2805FF0000FF19
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
00E1FFFF000000FFFF2300FFFF000080FF009EFF00AEFF00BDFF00BDFF00BDFF00BDFF00
BDFF00BDFF00BDFF00BDFF00BDFF00BDFF00AEFF009EFF008FFF0033FF00FF000000D1FF
FF00992300FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000E1FF00FFC2
80FF00AEFF00DCFF00EBFF00FAFF00FFF500FFE600FFE600FFD700FFD700FFC700FFC700
FFB800FFB800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFD700FFE600FFE600
FFF500FFF500FAFF00EBFF00EBFF00DCFF00AEFF008FFF0080FF0033FF0005FF0000FF57
00A3FFFF0000FF000000D1FFFA00FF00FFD1FF00009E00FFFF0000FF006B00FF3800FF28
00FFB3FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
3300FFFF0000FF00B89E00FFFF000070FF0080FF008FFF00AEFF00BDFF00BDFF00BDFF00
BDFF00BDFF00BDFF00BDFF00BDFF00AEFF00AEFF009EFF0000E1FF00E1FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
8FFF00BDFF00DCFF00EBFF00FAFF00FFF500FFE600FFE600FFE600FFD700FFD700FFC700
FFB800FFB800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFB800
FFB800FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFC700FFB800FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFD700FFE600FFE600
FFF500FFF500FFF500FAFF00EBFF00EBFF00CCFF00BDFF009EFF0070FF0023FF0000FFB3
EB00FF00C2FFFF00F5FF0000FF0000000AFFFF0000FF0000FF000FDC00FF00C2FF00FF85
FF0000FF00E6FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000DC00FF00FF2800FFA300FF949EFF00AEFF00BDFF00BDFF00
BDFF00BDFF00BDFF00BDFF00BDFF00AEFF00AEFF008FFF0000FF75FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF94FF0000
8FFF00AEFF009EFF00DCFF00FAFF00FFF500FFF500FFE600FFE600FFE600FFF500FFD700
FFC700FFB800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF9900FF9900FF9900FF9900FFA800FF9900FFA800FFA800FFB800FFF500
FFD700FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFC700FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFD700FFE600FFE600
FFE600FFF500FFF500FAFF00FAFF00EBFF00DCFF00CCFF009EFF0000FF5700FF1900B3FF
00FF8500FF85FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFC2
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF000000FF3800A3FF0028FF4200FF8FFF00AEFF00AEFF00BDFF00
BDFF00BDFF00BDFF00AEFF00AEFF00AEFF009EFF008FFF0023FF00FF006BFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000051FF00
80FF009EFF0080FF000066FFEBFF00FAFF00FFF500FFF500FFF500FFF500CCFF00DCFF00
FFC700FFB800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00
FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFB800FFC700
9EFF00FFF500FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFA800FFA800FFB800
FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFC700FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFD700FFE600FFE600
FFE600FFF500FFF500FFF500FAFF00EBFF00DCFF00CCFF009EFF0000FF0A0019FF00D1FF
00FF2800FF75FF00E6FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF001E0066FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00006100FF5100FF00FF5700FF8500FFE170FF008FFF009EFF00AEFF00AEFF00
AEFF00AEFF00AEFF00AEFF00AEFF00AEFF009EFF008FFF0070FF0042FF0000FF4700FF94
0047FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF1923FF00
FF000061FF0000FF1942FF00CCFF00EBFF00FAFF00FAFF00FAFF00FAFF00DCFF008FFF00
FFD700FFB800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFB800FFC700
FFF500FFF500FFD700FFC700FFC700FFC700FFC700FFC700FFB800FFB800FFB800FFB800
FFB800FFB800FFA800FFB800FFA800FFA800FFA800FFA800FFB800FFA800FFA800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFC700FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFD700FFE600FFE600FFE600
FFE600FFF500FFF500FFF500FAFF00EBFF00DCFF00BDFF009EFF0000E1FF00FF4700FF0A
23FF0000FF66FF0000FF00D7FF0000FF0000FF0000FF0000FF0000FF0000FF00006100FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF000000FFA300FF9400E1FF33FF008FFF009EFF009EFF00AEFF00
AEFF00AEFF00AEFF00AEFF00AEFF009EFF009EFF008FFF0070FF0000FF0A00FFC200FFB3
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00006100FF
FF005CFF000000FF0A0047FF80FF00EBFF00EBFF00FAFF00EBFF00EBFF00CCFF0042FF00
FFD700FFB800FFB800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFB800FFC700
FFF50033FF00FFF500FFD700FFD700FFC700FFC700FFD700FFC700FFC700FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFC700FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFD700FFD700FFE600FFE600
FFE600FFF500FFF500FFF500FAFF00EBFF00CCFF0033FF0061FF0042FF0000FF0A51FF00
42FF0000FF0A00FF85FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000038FFFF0000FF007A4200FF80FF008FFF009EFF009EFF00
AEFF00AEFF00AEFF00AEFF009EFF009EFF009EFF008FFF0070FF00FF000000F0FFFF00B8
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000038FFFF0000FF0000
FF00000066FFFF00000085FF00FFC2DCFF00DCFF00EBFF00DCFF00DCFF0070FF009EFF00
FFD700FFB800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFB800FFB800
FFD700FFF50051FF00FAFF00FFE600FFD700FFD700FFE600FAFF00FFC700FFC700FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFD700FFD700FFE600FFE600
FFE600FFF500FFF500FAFF00FAFF00EBFF00BDFF0000FFC28FFF009EFF0080FF0080FF00
42FF0000B3FF7000FFFF00D7FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00006100FF51FF0070FF008FFF009EFF00
9EFF009EFF009EFF009EFF009EFF009EFF008FFF0080FF0051FF00FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF000000E1FF00FF19BDFF00BDFF00AEFF0000FF0A80FF0080FF00DCFF00
FFE600FFB800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFB800FFB800
FFC700FFD700EBFF008FFF00FAFF00FFF500FFF50070FF00FFF500FFC700FFC700FFC700
FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFB800FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFD700FFD700FFE600FFE600FFE600
FFE600FFF500FFF500FFF500FAFF00EBFF00DCFF00CCFF00BDFF00AEFF009EFF008FFF00
61FF008F00FFFF00A8FA00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000000AFF00FF3800FFF000FFC280FF008FFF00
9EFF009EFF009EFF009EFF009EFF008FFF008FFF0061FF00FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF000023FF0080FF00AEFF008FFF0000FF94FF00F500FFA300FF0A33FF00
FFD700FFB800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFB800FFB800
FFC700FFD700FFF500CCFF00BDFF00EBFF00DCFF00EBFF00FFE600FFD700FFC700FFC700
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFB800FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFD700FFD700FFD700FFE600FFE600
FFE600FFF500FFF500FFF500FAFF00EBFF00EBFF00CCFF00CCFF00BDFF00AEFF008FFF00
61FF0000FFB3FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF000000FFF000FF85FF000033FF0070FF008FFF00
8FFF009EFF009EFF008FFF008FFF008FFF0080FF0070FF00CC00FFEB00FF00FFE1FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00006100FF00FF3861FF008FFF0080FF00FF0000FF00009EFF0070FF00EBFF00
FFC700FFB800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFB800FFB800
FFC700FFD70033FF00DCFF00BDFF008FFF00BDFF00FFF500FFE600FFD700FFC700FFC700
FFC700FFB800FFB800FFB800FFB800FFC700FFB800FFB800FFB800FFB800FFB800FFB800
FFC700FFB800FFC700FFB800FFC700FFB800FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFD700FFD700FFD700FFD700FFD700FFE600FFE600FFE600
FFE600FFF500FFF500FAFF00FAFF00FAFF00EBFF00DCFF00CCFF00BDFF00AEFF0014FF00
05FF0000FF19FF000000FF66FF002EFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00A800FFC200FFF023FF0070FF0080FF00
8FFF008FFF008FFF008FFF008FFF0080FF0080FF0070FF0051FF000500FF00FFC2FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF000000D1FF0028FF70FF0000FF3805FF0042FF00EBFF00FFF500FFD700
FFB800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF8A00FF8A00FF8A00FF8A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFB800FFB800
FFC700FFC700FFE600FFF500EBFF00AEFF00EBFF00FFF500FFE600FFD700FFD700FFC700
FFC700FFC700FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFD700FFD700FFD700FFD700FFD700FFD700FFE600FFE600FFE600
FFF500FFF500FFF500FAFF00FAFF00EBFF00EBFF00DCFF00CCFF00BDFF00AEFF0061FF00
61FF0051FF0000FF3800FF0AFF000000FFD10094FF000AFFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00004200FF5100FF61FF0080FF00
80FF008FFF008FFF008FFF008FFF0080FF0070FF0070FF0042FF00FF000000E1FF6100FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000075FFFF0000FF0000FF0000
FF0000FF0000FF0000FF000000FF1933FF0000FF8500C2FFCCFF00FAFF00FFE600FFC700
FFB800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFB800FFB800
FFC700FFC700FFD700FFF500EBFF0080FF00CCFF00FFF500FFE600FFE600FFD700FFD700
FFC700FFC700FFC700FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFD700FFC700FFD700FFD700FFD700FFD700FFD700FFD700FFE600FFE600FFE600
FFF500FFF500FFF500FAFF00FAFF00EBFF00EBFF00DCFF00CCFF00BDFF00AEFF009EFF00
80FF0061FF0042FF0014FF0000FF2800FF6600FFF0FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF002E23FF0051FF00
80FF0080FF0080FF0080FF0080FF0080FF0070FF0061FF0023FF00FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFB3FF0000FF0000FF0000
FF0000000AFFFF00006100FF0094FF0094FF00FF9470FF0080FF00EBFF00BDFF00FFC700
FFB800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFB800FFB800
FFC700FFD700FFD700FFF500EBFF0000FF0ABDFF00FAFF00FFE600FFE600FFD700FFD700
FFD700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFB800FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFE600FFE600FFE600FFF500
FFF500FFF500FAFF00FAFF00FAFF00EBFF00DCFF00DCFF00CCFF00BDFF00AEFF008FFF00
80FF0061FF0042FF0014FF0000FF2800FFF00057FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF94FF000000FF47
70FF0070FF0080FF0080FF0080FF0080FF0070FF0042FF00FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0057FF00FFB30075FF00FF380094FF00FFA300FF85CC00FF00FF28AEFF0000FF85FFC700
FFB800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FFA800FF9900FFA800FFA800FFA800FFA800FFA800FFB800FFB800
FFC700FFD700FFE600FFF500EBFF0000FF28DCFF00FAFF00FFF500FFF500FFE600FFD700
FFD700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFD700FFD700
FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFE600FFE600FFE600FFF500FFF500
FAFF00FAFF00FAFF00EBFF00EBFF00EBFF00DCFF00BDFF009EFF00AEFF009EFF008FFF00
70FF0023FF0033FF00000AFF00C2FF0038FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00008000FF00FFE100B3FF42FF00
61FF0070FF0080FF0070FF0070FF0070FF0061FF0051FF0000FF0A00FF94FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF1951FF001400FFFF0000
00FFB314FF0080FF0000FF0A00FF0AFF00C700FF6661FF00CCFF008FFF00FFE600FFB800
FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFC700
FFC700FFE600FAFF00EBFF00BDFF0000FF28CCFF00EBFF00FAFF00FAFF00EBFF00FFE600
FFD700FFD700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFD700FFD700FFD700
FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFE600FFE600FFE600FFF500FAFF00
FAFF00EBFF00EBFF00EBFF00EBFF00DCFF00CCFF00BDFF0000FF7580FF0061FF0070FF00
61FF0014FF00FF0000FF00005100FF0057FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000085FFFF000023FF00
61FF0070FF0070FF0070FF0070FF0070FF0061FF0051FF0014FF0000C2FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000080FF009EFF0000FF66
FF000000FF949EFF0033FF0000FFB300FFE100FFE105FF00CCFF00FFD700FFC700FFB800
FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF9900FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFB800FFB800FFB800
FFE600BDFF0061FF00AEFF009EFF0023FF00AEFF0070FF00DCFF0080FF0000FFFFFFF500
FFD700FFD700FFD700FFD700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFD700FFD700FFD700FFD700FFD700
FFD700FFD700FFD700FFD700FFD700FFD700FFE600FFE600FFE600FFF500FFF500EBFF00
BDFF00BDFF00CCFF00DCFF00DCFF00DCFF00CCFF00BDFF008FFF0000FFF000FF4705FF00
42FF0023FF000057FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000005FF00
42FF0061FF0061FF0070FF0070FF0061FF0061FF0042FF0000FF19CC00FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000DC00FF33FF0080FF00AEFF00CCFF00
00FFB3CCFF00EBFF0000FF85BDFF0070FF00AE00FFEBFF009EFF00FFC700FFB800FFB800
FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF9900
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00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FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00
FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00
FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800
FFC700FFD700FFD700FFE600FFF500DCFF00DCFF00AEFF009EFF00DCFF00FAFF00FFF500
FFE600FFD700FFD700FFD700FFD700FFD700FFC700FFC700FFD700FFC700FFC700FFD700
FFC700FFC700FFD700FFD700FFD700FFD700FFE600FFF500FFE600FFE600FFE600FFE600
FFE600FFD700FFE600FFE600FFE600FFE600FFE600FFE600FFF500FFF500FFF500FAFF00
DCFF0000FF7500FFD180FF00AEFF00AEFF0000FF1980FF0000FF5700FF85EB00FF00FF38
FF000000FF6600FF57FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000C2FF00B3FF
14FF0042FF0051FF0051FF0061FF0051FF0042FF0033FF0000FF4700F0FFEB00FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000C2FFFF0000CCFF00EBFF00
FAFF00FFF500FFE600FFE600FFD700FFD700FFC700FFC700FFB800FFB800FFA800FFA800
FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800
FFC700FFC700FFD700FFE600FFE600FFF500EBFF0051FF0014FF00CCFF00FAFF00FFF500
FFE600FFE600FFE600FFE600FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700
FFD700FFD700FFD700FFD700FFD700FFE600FFF500DCFF00FFF500FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF500FFF500FAFF00FAFF00
CCFF00AEFF0051FF0000FF6680FF0000FF5700FF7523FF0000FF850028FF00C2FF00FFB3
FF005C000AFF00FFD1FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000CC00FFFF00F5
000AFF33FF0042FF0051FF0051FF0051FF0042FF0033FF0000FF660094FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000094FFFF0000AE00FF00FF94DCFF00FAFF00
FFF500FFF500FFE600FFD700FFD700FFC700FFC700FFB800FFB800FFA800FFA800FFA800
FFA800FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00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FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00
FF6B00FF6B00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800
FFB800FFC700FFC700FFD700FFD700FFF500EBFF0023FF0000FF289EFF00BDFF00BDFF00
FFF500FFF500FFE600FFE600FFE600FFE600FFD700FFD700FFD700FFD700FFD700FFD700
FFD700FFD700FFD700FFE600FFE600FFF500FAFF0000FF19BDFF0080FF00FFF500FFF500
FFF500FFE600FFE600FFE600FFF500FFE600FFF500FFF500FFF500FFF500FAFF00FAFF00
EBFF00DCFF00CCFF00BDFF00AEFF0051FF0042FF0000FF47FF008A6100FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
8000FF00FF1933FF0042FF0042FF0042FF0033FF0005FF00FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF000061FF009EFF00CCFF00EBFF00FAFF00
FAFF00FFF500FFE600FFD700FFC700FFC700FFB800FFB800FFB800FFA800FFA800FFA800
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00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FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00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FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00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FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800
FFB800FFC700FFC700FFC700FFD700FFD700FFE600FFE600FFF500EBFF00DCFF0000FF0A
CCFF00EBFF00EBFF00FAFF00FFF500FFF500FAFF00FAFF00FFF500FFE600FFE600FFE600
FFE600FFE600FFF500FFF500FAFF00FAFF00CCFF0014FF0070FF00CCFF00EBFF00FAFF00
FAFF00FAFF00FAFF00FAFF00FFF500FAFF00FAFF00FAFF00FAFF00FAFF00EBFF00EBFF00
EBFF00DCFF00DCFF00CCFF00BDFF00AEFF009EFF0080FF0051FF0023FF00CC00FFFF0000
FF0000AE00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF006B00FF2805FF0014FF0014FF0005FF0000FF0A4200FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000019FFFF007AAEFF00BDFF00
CCFF00BDFF00AE00FFFFE600FFC700FFB800FFB800FFA800FFA800FFA800FFA800FF9900
FF9900FF9900FF9900FF9900FF9900FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF7A00FF7A00
FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF9900FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800
FFB800FFC700FFC700FFC700FFD700FFD700FFD700FFE600FFF500FFF500FAFF00DCFF00
70FF00AEFF008FFF00EBFF00FAFF00FAFF00DCFF00DCFF00FFF500FFF500FFF500FFF500
FFF500FFF500FFF500FFF500FAFF00EBFF00CCFF0023FF0061FF00CCFF00EBFF00EBFF00
FAFF00FAFF00FAFF00FAFF00FAFF00FAFF00FAFF00FAFF00FAFF00FAFF00EBFF00EBFF00
EBFF00DCFF00DCFF00CCFF00BDFF00AEFF009EFF0080FF0061FF0033FF0000FF0A00FF66
00E1FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF000000FF0A05FF0005FF0005FF0000FF28FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00004200FF42FF0080FF0000FF94
00FF5770FF00CCFF00FFD700FFB800FFB800FFB800FFA800FFA800FFA800FF9900FF9900
FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF8A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF8A00FF8A00FF7A00
FF7A00FF7A00FF8A00FF8A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF7A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00
FF8A00FF9900FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800
FFB800FFC700FFC700FFC700FFC700FFD700FFD700FFE600FFE600FFF500FAFF00EBFF00
9EFF0070FF009EFF00DCFF00DCFF00DCFF0070FF00CCFF00FAFF00FFF500FFF500FFF500
FFF500FFF500FFF500FAFF00FAFF00EBFF00DCFF0000FF0A80FF00CCFF00DCFF00EBFF00
EBFF00FAFF00FAFF00FAFF00FAFF00EBFF00EBFF00FAFF00EBFF00EBFF00EBFF00DCFF00
DCFF00DCFF00CCFF00BDFF00BDFF00AEFF008FFF0061FF0014FF0000FF0AFF00000038FF
AE00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF000000FF1900FF0A00FF0A00FF0A00FF38FF00B8FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FA00FF00FF1961FF001400FF
00FF3800FF19AEFF00FFC700FFB800FFB800FFA800FFA800FFA800FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF7A00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00
FF7A00FF8A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF8A00FF8A00FF7A00
FF7A00FF7A00FF8A00FF8A00FF8A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF9900FF9900FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800
FFB800FFC700FFC700FFC700FFC700FFD700FFD700FFD700FFE600FFF500FFF500FAFF00
DCFF008FFF0070FF00AEFF00BDFF00BDFF009EFF00DCFF00FAFF00FAFF00FAFF00FFF500
FFF500FFF500FAFF00FAFF00FAFF00EBFF00DCFF00BDFF0080FF00BDFF00DCFF00DCFF00
EBFF00EBFF00EBFF00EBFF00EBFF00EBFF00EBFF00EBFF00EBFF00EBFF00EBFF00EBFF00
DCFF00CCFF00BDFF00AEFF00AEFF009EFF0080FF0033FF000019FF00FF9400FF47FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF000000FF4700FF1900FF0A00FF1900FF38FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF000FFF0000FF0000FF0000FF0000FF000000FF190066FF00D1FF
BDFF00EBFF00FFE600FFC700FFB800FFA800FFA800FFA800FFA800FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF8A00FF8A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00
FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFC700FFC700FFC700FFD700FFD700FFD700FFD700FFE600FFE600FFF500FAFF00
CCFF0005FF0000FF2800FFA361FF0000FFA3BDFF00DCFF00EBFF00FAFF00FAFF00FAFF00
FAFF00FAFF00FAFF00FAFF00EBFF00EBFF00CCFF00BDFF000075FF00FF75CCFF00DCFF00
DCFF00EBFF00EBFF00EBFF00DCFF00AEFF00CCFF00DCFF00EBFF00EBFF00DCFF00DCFF00
DCFF00CCFF008FFF0000FF7580FF008FFF0070FF0023FF00FF000000FFC200F0FF00F0FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00002300FF00FF5700FF2800FF1900FF2800FF57FF004CFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF000000FFB305FF005100FFFF000000FFE100E1FF00FFFFBD00FF61FF00
CCFF00FAFF00FFD700FFB800FFB800FFA800FFA800FFA800FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800
FFB800FFC700FFC700FFC700FFC700FFD700FFD700FFD700FFE600FFE600FFF500FAFF00
EBFF00CCFF009EFF0023FF0000FFFF23FF00BDFF00DCFF00EBFF00EBFF00EBFF00EBFF00
EBFF00EBFF00EBFF00EBFF00EBFF00DCFF00CCFF009EFF0000F0FF70FF00AEFF0080FF00
CCFF00DCFF00DCFF00DCFF00CCFF0070FF00BDFF00DCFF00DCFF00DCFF00DCFF00DCFF00
CCFF00CCFF00AEFF0000FF0A00FFB351FF00CC00FFFF0000FF00000075FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF000000FF8500FF3800FF2800FF3800FF57FA00FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF000061FF0000FF6600E1FF61FF0005FF0000F0FF00FFE100FF28
00FF7561FF00FFC700FFB800FFB800FFA800FFA800FFA800FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800
FFB800FFC700FFC700FFC700FFC700FFD700FFD700FFD700FFE600FFE600FFF500FAFF00
EBFF00DCFF00BDFF0080FF0000FF0A42FF009EFF00AEFF00DCFF00EBFF00EBFF00DCFF00
00FF38DCFF00EBFF00EBFF00DCFF00CCFF00BDFF009EFF0051FF00FF005C00FFE1AEFF00
CCFF00CCFF00CCFF00CCFF00AEFF0000FF389EFF00CCFF00CCFF00DCFF00DCFF00CCFF00
CCFF00CCFF00AEFF008FFF0061FF0042FF0000FF94DC00FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000BD00FF00FF4700FF3800FF4700FF85FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF000042FF00AEFF00AEFF00BDFF0023FF0000C2FF0085FF00FF0A
FAFF00FFD700FFB800FFB800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FFA800FF9900FF9900FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFC700FFC700FFC700FFC700FFD700FFD700FFD700FFD700FFE600FFE600FFF500FAFF00
EBFF00DCFF0000FF1942FF000094FF00FF0A61FF00AEFF00CCFF00DCFF00DCFF00CCFF00
00FF0ACCFF00DCFF00DCFF00CCFF00AEFF0080FF0070FF0014FF0000FFB361FF00AEFF00
BDFF00CCFF00CCFF00BDFF008FFF00000AFF8FFF00BDFF00CCFF00CCFF00CCFF00CCFF00
CCFF00BDFF00AEFF009EFF008FFF0070FF0000FF85FF00996100FFFF002EFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF000000FF6600FF4700FF5700FF75FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF000070FF00CCFF00DCFF00EBFF00EBFF00BDFF0033FF00CCFF00
FFD700FFC700FFB800FFB800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF9900FF9900FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FFA800FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800
FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFD700FFE600FFE600FFF500FAFF00
EBFF00DCFF00AEFF0080FF000075FF42FF008FFF00AEFF00BDFF00BDFF00CCFF00AEFF00
00FFB3BDFF00CCFF00CCFF00CCFF00AEFF0080FF0000FF855100FF00FF2870FF009EFF00
AEFF00AEFF00BDFF00AEFF009EFF000500FF9EFF00BDFF00BDFF00CCFF00CCFF00CCFF00
BDFF00BDFF00AEFF009EFF008FFF0070FF0042FF0000FF38FF001EFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000CC00FF00FF8500FF6600FF6600FF94BD00FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF000000FF191400FFBDFF00DCFF00EBFF00FAFF00FFF500FFE600FFE600FFD700
FFC700FFB800FFB800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00
FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF9900
FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FF9900
FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700
FFC700FFC700FFC700FFC700FFD700FFD700FFD700FFD700FFE600FFE600FFF500EBFF00
DCFF00CCFF00AEFF0061FF0000FF1923FF0080FF00AEFF00AEFF00AEFF00BDFF009EFF00
70FF00AEFF00BDFF00BDFF00BDFF00AEFF0080FF0000FF0AFF000033FF0061FF0080FF00
61FF009EFF009EFF009EFF008FFF0042FF009EFF00AEFF00BDFF00BDFF00BDFF00BDFF00
BDFF00BDFF00AEFF009EFF008FFF0080FF0061FF0023FF0000FF3800FFB37000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF000000FF7500FF7500FFA3FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF000042FF0080FF00BDFF00DCFF00EBFF00FFF500FFE600FFD700FFC700FFC700
FFB800FFB800FFB800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900
FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00
FF8A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00
FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF9900
FF9900FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFC700FFC700FFC700FFD700FFD700FFD700FFD700FFD700FFE600FFF500EBFF008FFF00
80FF00AEFF0033FF0000FF470075FF00FF6600FF198FFF009EFF0042FF009EFF0070FF00
00FFB39EFF00AEFF0070FF00AEFF009EFF0033FF0000FF8500E1FF00FF280085FF51FF00
00FF1980FF008FFF0042FF0061FF0000FF2880FF009EFF00AEFF00AEFF00AEFF00AEFF00
AEFF00AEFF00AEFF009EFF008FFF0070FF0042FF0000FF280019FF00FFF0FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF000000D1FF00FF8500FF8500FFB3FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF000000A3FFBDFF00CCFF00DCFF00FAFF00FFE600FFD700FFC700FFC700
FFB800FFB800FFB800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF7A00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00
FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF9900FF9900FF8A00FF8A00FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800
FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700
FFC700FFC700FFC700FFC700FFD700FFD700FFD700FFE600FFE600FFF500FAFF00BDFF00
8FFF00AEFF0080FF0080FF0000D1FF00E1FF51FF0070FF0070FF0051FF0080FF0042FF00
14FF0080FF0080FF0000FF758FFF008FFF0070FF0000FF19FF006B00FF85FF000000FF19
05FF0051FF0070FF0042FF000057FF0038FF51FF008FFF009EFF009EFF0000E1FF9EFF00
AEFF009EFF009EFF008FFF0042FF0051FF0033FF0000FFA30085FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF007A00FFA300FF9400FFFFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000500FFAEFF00BDFF00BDFF0000FFA3FFD700FFC700FFC700FFC700
FFB800FFA800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900
FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00
FF8A00FF8A00FF9900FF9900FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FF9900FF9900FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700
FFC700FFC700FFC700FFD700FFD700FFD700FFD700FFE600FFE600FFF500FAFF00EBFF00
DCFF00CCFF00BDFF009EFF0061FF0000FFE100FF3814FF0000FFE100FFA323FF0014FF00
00E1FF42FF0061FF0051FF0080FF0070FF0061FF0042FF0014FF0000FF477000FF00F0FF
00FF8514FF0051FF003300FF00FFFF00FF1961FF0080FF008FFF0070FF0000FF198FFF00
9EFF009EFF008FFF0080FF0023FF00FF00001400FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00D700FFC200FFB300FFFFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF000080FF009EFF008FFF0005FF00FFD700FFC700FFB800FFB800
FFB800FFB800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF7A00FF7A00
FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF9900FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FF9900FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700
FFC700FFC700FFD700FFD700FFD700FFD700FFE600FFE600FFE600FFF500FFF500FAFF00
EBFF00DCFF00CCFF00AEFF0000FF0A23FF005100FF00FF5700F0FF00FFF000FF4700FFE1
7000FF05FF0000FF3800FF3861FF0023FF0042FF0023FF0005FF0000FF4700FFF0FA00FF
0028FF00FF2823FF0000FF3800B3FF00FF9433FF0042FF0070FF0061FF0042FF0080FF00
8FFF008FFF008FFF0080FF0061FF0042FF0000FFD1FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF000000FFE100FFD100FFFFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFE1
FF0000FF0000FF000000FF1923FF00FF00A805FF00CCFF00FFC700FFC700FFB800FFB800
FFA800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900
FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF9900FF9900FF8A00FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700
FFC700FFD700FFD700FFD700FFD700FFD700FFE600FFE600FFE600FFF500FFF500FAFF00
EBFF00EBFF00CCFF0000FFC28FFF0080FF0051FF0042FF0014FF0000FFD10066FF00D1FF
00FFD100FF5700D1FF05FF0023FF0023FF0005FF0014FF000038FF00FF940019FFFF0000
0500FF00B3FF00FF2800FF2800FF94FF00C7FF00B833FF0033FF0000FF6651FF0070FF00
80FF0080FF0080FF0080FF0061FF0042FF0014FF0000FF7500D1FFBD00FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF000000F0FF00FFE100F0FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF000000FF5700D1FF9EFF0051FF00FFE600FFC700FFB800FFB800FFB800
FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FFA800
FFC700FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF9900
FF9900FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FFA800FF9900FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFB800FFA800FFA800FFA800FFA800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFB800FFC700FFC700FFC700FFC700
FFC700FFD700FFD700FFD700FFD700FFD700FFE600FFE600FFE600FFF500FFF500FAFF00
EBFF00EBFF00DCFF00BDFF00AEFF009EFF0080FF0061FF0014FF00CC00FF00FFB300A3FF
0047FF00D1FFDC00FFFF000005FF0000FF3800FF5700FF38FF00000085FFFF0000FF0000
FF000000E1FFFF000000FF7500FFA30028FFFF00A800FF1900FF385100FF00FF0A61FF00
70FF0070FF0070FF0070FF0061FF0042FF0014FF0000FFFF00D1FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF000000C2FF00FFFF00D1FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000023FF00
33FF0000FF2800FF380075FF00C2FF9EFF00FFF500FFD700FFC700FFB800FFB800FFA800
FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF8A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FFA800FFB800
8FFF00FFB800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF9900FF8A00FF8A00
FF9900FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF9900FF9900FF8A00FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FFA800FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFC700
FFD700FFD700FFD700FFD700FFE600FFE600FFE600FFE600FFE600FFF500FFF500FAFF00
FAFF00EBFF00DCFF00CCFF00BDFF00AEFF008FFF0070FF0033FF0005FF0000FF66FF0000
FF00008000FFEB00FF00D1FF00FF5700FF572300FF0047FF00D1FFCC00FFFF0000FF0000
FF00000094FFFF000000FFFFFF0000FF0000FF000000FFF0FF008A00FFD123FF0042FF00
33FF0014FF0061FF0061FF0051FF0000FF1900FF287000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF000000E1FF00B3FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000033FF00
BDFF00BDFF0070FF0000FFB300F0FF61FF00FFD700FFC700FFB800FFB800FFB800FFA800
FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00
FF8A00FF8A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FFA800FFB800
FFE600FFC700FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF9900FF9900FF8A00FF8A00
FF9900FF9900FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FFA800FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFC700FFD700FFD700
FFD700FFD700FFD700FFE600FFE600FFE600FFE600FFE600FFF500FFF500FFF500FAFF00
EBFF00EBFF00DCFF00CCFF00BDFF00AEFF008FFF0070FF0042FF0000FF0A00FF750047FF
FF0000FF0000FF0000FF000000FFA300FFC20038FFFF00009E00FFCC00FFFF0000FF0000
FF0000FF0000FF0000FF000FFF00E6FF0000FF000000FFF000FFD10019FF1400FF23FF00
00FF4742FF0051FF0051FF0042FF0005FF0000FF94FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF000000C2FF0094FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFA342FF009EFF00
CCFF00DCFF00FAFF00EBFF00FAFF00FFE600FFC700FFC700FFB800FFB800FFA800FFA800
FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFB800
FFE600FFD700FFB800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FFA800FF9900FF9900FF9900FF9900FF9900FFA800FF9900FF9900
FFA800FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFC700FFD700FFD700
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF500FFF500FFF500FAFF00FAFF00
EBFF00DCFF00DCFF00CCFF00BDFF0080FF0061FF0061FF0023FF0000FF19FF00D7DC00FF
FF0000FF0000FF0000FF000000C2FFFF0000EB00FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00009E00FF2300FF00FFA3
FF000033FF0042FF0042FF0033FF0014FF0000FF1900FFB31400FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000094FF0066FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00009EFF00
BDFF00DCFF00FFF500FFE600FFD700FFC700FFC700FFB800FFB800FFB800FFA800FFA800
FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFB800
FFE600FFD700FFB800FFB800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FFA800FF9900FF9900FFA800FF9900FF9900
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFC700FFB800FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFE600
FAFF00FFF500FFF500FFF500FFF500FFF500FFF500FFF500FFF500FAFF00FAFF00EBFF00
DCFF00DCFF00CCFF00BDFF00BDFF008FFF0042FF0000FF28FF00009E00FF0066FFFF0000
FF0000FF0000FF0000FF0000EB00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000A3FFFF0000
00FF6614FF0000FF1933FF0023FF0005FF0000FF28FF0000FF002EFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000075FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00008FFF00
9EFF0051FF00FFE600FFD700FFC700FFC700FFB800FFB800FFB800FFA800FFA800FFA800
FFA800FFA800FF9900FF9900FF9900FFA800FF9900FF9900FF9900FF9900FF9900FF9900
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00
FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF8A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFB800
FFD700FFE600FFC700FFB800FFA800FFA800FFA800FF9900FFA800FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FFA800FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FFA800FF9900FF9900FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFC700FFC700FFB800FFB800FFB800
FFC700FFB800FFC700FFC700FFC700FFC700FFC700FFD700FFC700FFD700FFD700FFE600
DCFF00DCFF00EBFF00FAFF00FFF500FFF500FFF500FAFF00FAFF00FAFF00EBFF00DCFF00
AEFF00BDFF00BDFF00BDFF00AEFF009EFF0080FF0051FF0000FF0A00FF3800FFB3FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000038FF
BD00FF00FF4700FF3814FF0014FF0000FF195100FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000038FF000AFFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF38
33FF00FF0000FFE600FFC700FFC700FFC700FFB800FFB800FFB800FFA800FFA800FFA800
FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF8A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00
FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFB800FFB800
FFD700FFF500FFC700FFB800FFB800FFA800FFA800FFA800FFA800FFA800FF9900FFA800
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FF9900FFA800
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FF9900
FF9900FF9900FF9900FFA800FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFA800FFB800
FFB800FFB800FFC700FFD700FFD700FFC700FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFE600FFE600
FAFF0061FF0042FF00EBFF00FAFF00FAFF00FAFF00FAFF00FAFF00FAFF00EBFF00DCFF00
70FF0080FF009EFF00AEFF009EFF008FFF0080FF0061FF0033FF0000FF38FF00A80085FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00F5FF000000FF4700FF0A05FF0000FF1900FF47FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000000AFFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0AFF0000FF000000FFA30028FF
05FF00FFF500FFD700FFC700FFC700FFB800FFB800FFB800FFA800FFA800FFA800FFA800
FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00
FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFB800FFB800
FFC7009EFF00FFC700FFC700FFB800FFA800FFA800FFA800FFA800FFA800FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FFA800FF9900FFA800FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FF9900FFA800FF9900FFA800FF9900FF9900FFA800FF9900
FFA800FFA800FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800
FFB800FFC700FFC700FFE600FAFF00FFD700FFD700FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFD700FFD700FFE600
FAFF00CCFF0070FF00CCFF00DCFF00FAFF00FAFF00FAFF00EBFF00EBFF00EBFF00DCFF00
AEFF0000FF2870FF008FFF0051FF0080FF0000FF6642FF0000FF6600FF2800FF7500F0FF
9E00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF000000FF75FF000000FF1900FF2800FF85FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00004200FF9E00FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000085FF23FF009EFF0000FFB3FF0000000AFF
BDFF00FFD700FFC700FFC700FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800
FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00
FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFB800FFB800
FFD700FAFF00FFD700FFC700FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800
FFB800FFC700FFC700FFE600BDFF00FFF500FFE600FFD700FFD700FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFD700FFD700FFE600FFE600
FAFF00CCFF0070FF0070FF00CCFF00EBFF00EBFF00EBFF00EBFF00EBFF00DCFF00DCFF00
BDFF009EFF0080FF0023FF0014FF0061FF0042FF0000FF9400FF0A00D1FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF000000FF8500FF3800FF3800FF852300FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000DC00FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF000000FF288FFF00BDFF00DCFF0000FFD1DCFF00
FFE600FFD700FFC700FFC700FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800
FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFB800FFC700
FFD700CCFF00FFE600FFC700FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FF9900FFA800FF9900FFA800FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FF9900FF9900FF9900FF9900
FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFA800FFB800FFB800FFB800FFB800
FFB800FFC700FFC700FFE600CCFF00EBFF00FAFF00FFE600FFD700FFD700FFD700FFC700
FFC700FFC700FFC700FFD700FFC700FFD700FFD700FFD700FFD700FFD700FFE600FFF500
FFF500EBFF00CCFF006100FFAEFF00CCFF00DCFF00DCFF00DCFF00DCFF00DCFF00CCFF00
BDFF00AEFF008FFF0005FF0000FFB323FF0005FF000057FF00FF7500FFF0FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF000000FFC200FF8500FF5700FFD1FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF000080FF0080FF00FAFF00FFE600FFE600
FFD700FFC700FFC700FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFB800FFC700
FFD700FAFF00FFE600FFC700FFC700FFB800FFB800FFB800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FF9900FFA800FF9900FFA800FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FFA800FF9900FFA800FF9900FF9900FF9900FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFC700FFB800FFB800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800
FFC700FFC700FFD700FFE600EBFF0042FF0042FF00FFF500FFE600FFD700FFD700FFD700
FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFE600FFE600FFE600
FFF500FAFF00DCFF00BDFF0000FF19BDFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
BDFF00AEFF0080FF0033FF0000FF8500FF8500D1FFDC00FF9E00FF00A3FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FA00FF00FFA300FF8500FFB3FF00C7FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF000000E1FF00F0FF00FF66FFF500FFD700FFD700
FFC700FFC700FFB800FFB800FFB800FFB800FFA800FFB800FFA800FFA800FFA800FFA800
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00
FF7A00FF8A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF9900FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFB800FFB800FFC700
FFD700FFF500FFF500FFD700FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900FFA800FF9900FFA800FF9900
FF9900FF9900FF9900FFA800FF9900FFA800FF9900FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFF500FFC700FFB800FFB800
FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFC700FFC700FFD700EBFF00BDFF008FFF00EBFF00FFF500FFE600FFD700FFD700FFD700
FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFE600FFE600FFF500
FFF500FAFF00EBFF00DCFF00AEFF0061FF00AEFF00BDFF008FFF00CCFF00CCFF00BDFF00
AEFF00AEFF008FFF0070FF0033FF0000FF0A00FFE1FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF000000FFB300FFE1FF0099FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00008F00FF51FF0005FF00FF000070FF00EBFF00FFE600FFD700FFC700
FFC700FFC700FFC700FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFC700
FFD700FFF500FFF500FFD700FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFC700FFF500FFD700FFC700FFB800
FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFA800FFB800
FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700
FFC700FFD700FFD700FFF500EBFF008FFF00DCFF00FFF500FFE600FFE600FFD700FFD700
FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFE600FFE600FFE600FFE600FFF500
FFF500FAFF00EBFF00DCFF00CCFF0070FF0061FF0080FF009EFF00AEFF00BDFF00AEFF00
8FFF009EFF0080FF0070FF0051FF0000FF7500FFA3FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000AE00FF00FFF000E1FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF000080FF00BDFF0000FFB3DCFF00FFE600FFD700FFD700FFD700
FFC700FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900
FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFC700
FFD700FFE600EBFF00FFE600FFD700FFC700FFC700FFC700FFC700FFB800FFB800FFB800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFB800FFA800FFB800FFB800FFB800FFD700FFF500FFE600FFC700FFB800
FFB800FFB800FFB800FFB800FFB800FFA800FFA800FFB800FFA800FFA800FFB800FFA800
FFA800FFB800FFA800FFA800FFB800FFA800FFA800FFA800FFA800FFB800FFA800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700
FFC700FFD700FFD700FFE600FAFF00CCFF00BDFF00EBFF00FFF500FFE600FFE600FFE600
FFE600FFE600FFE600FFD700FFE600FFE600FFE600FFE600FFE600FFE600FFF500FFF500
FFF500FAFF00EBFF00EBFF00CCFF00AEFF0000E1FF00FF0A80FF009EFF00AEFF008FFF00
61FF0080FF0080FF0023FF0033FF0005FF0000FF5700B3FFFF0099FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF000000B3FF00B3FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF000000FFA351FF00DCFF00FFF500FFE600FFD700FFD700FFC700FFC700
FFB800FFC700FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFC700FFC700
FFD700FFE6008FFF00FFE600FFD700FFD700FFD700FFC700FFC700FFD700FFC700FFB800
FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFB800FFA800FFB800FFB800FFB800FFC700FFD700FAFF00FFF500FFD700FFC700
FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700
FFC700FFD700FFD700FFE600FAFF00BDFF0080FF00DCFF00FFF500FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF500FFF500
FAFF00FAFF00EBFF00DCFF00CCFF009EFF0042FF0000FF1933FF008FFF008FFF0080FF00
000AFF70FF0070FF0042FF0000FF8500FF2800D1FF0066FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000094FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF006B00FF471400FFFF0000FFF500FFE600FFD700FFD700FFC700FFC700FFC700
FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00
FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF8A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF9900FF8A00FF9900FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFC700FFC700FFD700
FFD700FFF500DCFF00FFF500FFE600FFE600FFD700FFD700FFE60080FF00FFD700FFB800
FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFE600FAFF00FAFF00FFE600FFD700
FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFC700FFC700FFC700
FFD700FFD700FFE600FFE600FFF500DCFF0051FF00DCFF00FAFF00FFF500FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF500FFF500FFF500FFF500FFF500
FAFF00EBFF00EBFF00DCFF00BDFF0070FF0051FF0000FF4723FF0070FF0070FF0070FF00
23FF0000FFC251FF0042FF0000FF2800C2FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000047FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF000051FF00AEFF0033FF00FAFF00FFE600FFD700FFD700FFD700FFC700FFC700FFC700
FFB800FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00
FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFC700FFC700FFC700FFC700FFD700
FFE600FFF500EBFF00EBFF00FAFF00CCFF00FFE600FFE600FAFF00FFE600FFD700FFC700
FFB800FFB800FFB800FFB800FFA800FFA800FFB800FFA800FFA800FFA800FFB800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFA800FFA800FFB800
FFB800FFB800FFB800FFB800FFC700FFC700FFD700FAFF00EBFF0080FF008FFF00FFE600
FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFD700
FFD700FFD700FFE600FFE600FFF500EBFF0070FF00CCFF00FAFF00FFF500FFF500FFF500
FFE600FFE600FFE600FFF500FFF500FFF500FFF500FFF500FFF500FFF500FFF500FAFF00
FAFF00EBFF00EBFF00DCFF00CCFF00AEFF0080FF0000FF3800FF7542FF0023FF0051FF00
00FF1900FFA323FF0014FF0000FF0A00FF660094FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00002300FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF47
FF0000FF0000EBFF00FFF500FFE600FFE600FFD700FFD700FFC700FFC700FFC700FFB800
FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FFA800FF9900FF9900FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFB800FFB800FFD700FFE600FFD700FFD700FFD700FFE600
FFE600FFF500EBFF0080FF00BDFF00DCFF00FAFF00FAFF00DCFF00FFE600FFD700FFC700
FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFA800FFA800FFB800FFA800
FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFC700FFC700FFD700DCFF008FFF00DCFF00FFF500FFD700
FFD700FFC700FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700
FFC700FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFD700
FFD700FFD700FFE600FFF500FFF500EBFF00BDFF00CCFF00EBFF00FAFF00FFF500FFF500
FFF500FFF500FFF500FFF500EBFF00EBFF00FAFF00FAFF00FFF500FAFF00FAFF00FAFF00
EBFF00EBFF00DCFF00DCFF00BDFF00AEFF008FFF0070FF0014FF0000FFD105FF0000FF19
00FF1900FF5700FF1900FF3800FF3800A3FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000AE00FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000051FF00
5100FFCCFF00FFF500FFE600FFE600FFD700FFD700FFC700FFC700FFC700FFC700FFB800
FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF9900
FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FF9900
FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFB800FFB800FFC700FFC700FAFF00FFE600FFE600FFE600FFF500
EBFF00EBFF00CCFF0070FF0000FF75AEFF00DCFF009EFF00FAFF00FFE600FFD700FFC700
FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFC700FFC700FFC700FFD700FFD700FFF500EBFF00EBFF00FFF500FFE600
FFD700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFD700FFC700FFC700FFC700FFC700FFB800FFB800FFB800FFB800FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFD700FFD700FFD700FFD700FFD700
FFD700FFE600FFE600FFF500FFF500FAFF00CCFF00BDFF00EBFF00FAFF00FAFF00FAFF00
FAFF00FAFF00FAFF00FAFF00DCFF00BDFF00EBFF00FAFF00FAFF00FAFF00FAFF00EBFF00
9EFF00CCFF00CCFF00CCFF00BDFF00AEFF008FFF0070FF0023FF000047FF00FF5700FFF0
00FF8500B3FF00FF7500FF8500FF7500FFB38000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000005FF000047FF00FF19
EBFF00FFF500FFF500FFE600FFE600FFD700FFD700FFC700FFC700FFC700FFB800FFB800
FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFB800FFB800FFB800FFB800FFC700FFD700FFE600CCFF00FFF500FFF500FAFF00
AEFF00CCFF00AEFF0000FF75FF000033FF00AEFF00CCFF00FAFF00FFE600FFD700FFD700
FFC700FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFC700FFC700FFC700FFC700FFC700FFD700FFE600FFF500EBFF00DCFF00FFF500FFE600
FFD700FFD700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700
FFD70051FF00FFD700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFD700FFD700FFE600FFD700FFD700FFD700FFD700FFD700FFE600
FFE600FFE600FFE600FFF500FAFF00EBFF00BDFF0061FF00DCFF00EBFF00EBFF00FAFF00
FAFF00FAFF00FAFF00EBFF00BDFF009EFF00EBFF00EBFF00EBFF00EBFF00EBFF00DCFF00
61FF009EFF00BDFF00BDFF00AEFF0070FF0080FF0061FF0000FF3800FFC2EB00FFFF003D
00A3FFFF00000075FFFF006B00FFE100FFFFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0ACCFF00EBFF00
FFF500FFF500FFE600FFE600FFD700FFD700FFC700FFC700FFC700FFC700FFB800FFB800
FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800
FFB800FFB800FFB800FFB800FFC700FFC700FFD700FFE600EBFF00EBFF00FAFF00EBFF00
CCFF008FFF0051FF0000FF66FF000000FF5723FF0033FF00EBFF00FAFF00FFE600FFD700
FFD700FFC700FFC700FFC700FFC700FFC700FFC700FFB800FFB800FFC700FFB800FFB800
FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFD700FFD700FFE600FFF500DCFF00DCFF00FFF500FFE600
FFE600FFD700FFD700FFC700FFC700FFC700FFD700FFC700FFC700FFC700FFD700FFD700
FFE60051FF00FFE600FFD700FFD700FFC700FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFD700FFD700FFE600EBFF00FFF500FFE600FFE600FFE600FFE600FFE600
FFF500FFF500FFF500FAFF00FAFF00EBFF00BDFF0051FF00BDFF00CCFF00BDFF00EBFF00
EBFF00FAFF00EBFF00EBFF00BDFF008FFF00DCFF00EBFF00EBFF00EBFF00DCFF00DCFF00
BDFF0000FF85AEFF00AEFF009EFF0033FF0061FF0051FF0014FF0000FF5700C2FFFF0000
FF001EFF0000FF0000FF00008F00FF00A3FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000000AFFAEFF00DCFF00FAFF00FFF500
FFF500FFE600FFE600FFD700FFD700FFD700FFC700FFC700FFC700FFB800FFB800FFB800
FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00
FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FF9900FFA800FF9900FF9900
FF9900FF9900FFA800FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFC700FFB800FFA800FFB800
FFA800FFB800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFC700FFC700FFC700FFD700FFE600FAFF008FFF00DCFF00AEFF00
51FF0033FF00FF0000FF0000FF0000FF0000FF000000FF0AAEFF00DCFF00FFE600FFD700
FFD700FFD700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFD700DCFF00FFD700FFC700FFC700FFC700FFC700
FFD700FFC700FFD700FFD700FFD700FFE600FFF500FAFF00EBFF00CCFF00FAFF00FFF500
FFE600FFE600FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFE600
FFF5008FFF00FFF500FFE600FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700
FFD700FFD700FFD700FFD700FFE6008FFF00EBFF00FFF500FFE600FFE600FFF500FAFF00
FAFF00FAFF00FAFF00EBFF00BDFF00CCFF00AEFF0000FFC2AEFF00AEFF0070FF00CCFF00
EBFF00EBFF00DCFF00DCFF00BDFF008FFF00CCFF00DCFF00DCFF00DCFF00CCFF00CCFF00
BDFF0080FF0080FF008FFF008FFF0070FF0000FFFF14FF0000FF2800FFA30075FFFF0000
FF0000FF0000FF0000FF0000FF00005100FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF000000FF5700FF85BDFF00DCFF00FAFF00FAFF00FFF500
FFF500FFE600FFD700FFD700FFD700FFC700FFC700FFC700FFC700FFC700FFB800FFB800
FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFB800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFC700FFD700FFC700FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFC700FFC700FFC700FFC700FFC700FFD700FFE600FFF500EBFF00CCFF0033FF0033FF00
70FF00FF00B8FF0000FF0000FF0000FF0000FF000000FFE19EFF00FAFF00FFF500FFE600
FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFD700FFD700FFE60051FF00FFE600FFD700FFD700FFD700FFD700
FFD700FFD700FFD700FFD700FFE600FFE60042FF00EBFF00CCFF00AEFF00CCFF00AEFF00
FFF500FFE600FFE600FFE600FFD700FFD700FFE600FFE600FFE600FFD700FFE600FFF500
FAFF0051FF00FAFF00FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD700FFD700
FFD700FFE600FFE600FFE600FFF500DCFF00DCFF00FAFF00FFF500FFF500FFF500EBFF00
BDFF00EBFF00EBFF00EBFF00BDFF009EFF009EFF0042FF0061FF0080FF009EFF00CCFF00
DCFF00CCFF00CCFF00CCFF00AEFF0051FF00AEFF00CCFF00BDFF00BDFF00CCFF00BDFF00
AEFF0042FF0000FF1970FF0042FF0051FF0000FF0A00FFB300FF7500E1FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF000000FF75AEFF00CCFF00DCFF00EBFF00FAFF00FFF500FFF500
FFE600FFE600FFD700FFD700FFD700FFD700FFC700FFC700FFC700FFB800FFB800FFB800
FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00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FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00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FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900
FFA80000C2FF00C2FF00A3FF00A3FF0085FF0085FF0094FF00B3FF0075FF00A3FF0094FF
0057FF0057FF0075FF0075FF6100FF0019FF0057FF1400FF0066FF1400FF0057FFFF0000
000AFF0057FF0028FF000AFF5100FF0500FF0038FF0028FF2300FF0500FF3300FF7000FF
4200FF8000FF6100FF0500FF000AFF8F00FFFF00D7FA00FFFF00C7FF00E6CC00FF6100FF
6100FF3300FF7000FF8F00FF9E00FF4200FFAE00FF8000FFAE00FFEB00FF8000FF4200FF
FF0000EB00FFBD00FF6100FFFF005CFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF002EFF0000FF007AAE00FF
FF0000EB00FFBD00FFFF00A8AE00FFEB00FFFF005CFF0099DC00FF6100FFCC00FFFF00D7
FA00FFFF007AFA00FFCC00FFFF006BFF004CFF0000FF00D7FF0000FF00A8FF0000FF006B
FF0000EB00FFFF0000FF005CFF0000FF005CFF0000FF0000FF0000FF0000FF0000FF003D
FF006BFF00B8FF002EFF0000FF0000FF002EFF002EFF008AFF0000FF002EFF000FFF007A
FF0000FF0000FF002EFF000FFF001EFF001EFF003DFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00006100FF00FFC200FF3814FF00
42FF0070FF008FFF009EFF00AEFF00BDFF00CCFF00DCFF00DCFF00EBFF00EBFF00FAFF00
FAFF00FFF500FFF500FFF500FFE600FFE600FFE600FFE600FFD700FFD700FFD700FFD700
FFD700FFC700FFC700FFC700FFC700FFC700FFC700FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00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FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00
FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFB800FFC700FFC700FFB800FFB800FFA800FFB800
FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFD700FFE600FFD700FFC700FFC700
FFC700FFC700FFB800FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFD700FFD700FFD700FFE600FAFF00EBFF00BDFF009EFF0000FFA300F0FF
00FFE1FF0000FF0000FF0000FF0000FF0000FF0000FF00009EFF00EBFF00FFF500FFE600
FFE600FFE600FFE600FFD700FFD700FFD700FFE600FFE600FFD700FFD700FFD700FFD700
FFD700FFD700FFD700FFD700FFE600FFF50080FF00FFF500FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFF500EBFF008FFF0005FF0051FF008FFF00CCFF00
FAFF00FFF500FFE600FFE600FFE600FFE600FFF500FAFF00FFF500FFF500FFF500FFF500
EBFF0070FF00EBFF00FFF500FFF500FFE600FFF500EBFF00FFF500FFE600FFE600FFE600
FFE600FAFF00FFF500FFF500FAFF00DCFF00CCFF00EBFF00FAFF00FAFF00FAFF00DCFF00
AEFF00DCFF00DCFF00DCFF00BDFF0080FF0061FF0000FF2800FF8533FF009EFF00BDFF00
BDFF00AEFF00AEFF00AEFF0070FF0000FFA38FFF00AEFF008FFF009EFF00AEFF0070FF00
8FFF0070FF000019FF42FF0014FF0033FF0000FF0A00FFC200B3FF0047FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000057FF8FFF00BDFF00CCFF00DCFF00EBFF00FAFF00FAFF00FFF500FFF500
FFE600FFE600FFD700FFD700FFD700FFC700FFC700FFC700FFC700FFC700FFB800FFB800
FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFB800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFC700FFD700FFC700FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFC700FFC700FFC700FFC700FFC700FFD700FFE600FFF500EBFF00CCFF0033FF0033FF00
70FF00FF00B8FF0000FF0000FF0000FF0000FF000000FFE19EFF00FAFF00FFF500FFE600
FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFD700FFD700FFE60051FF00FFE600FFD700FFD700FFD700FFD700
FFD700FFD700FFD700FFD700FFE600FFE60042FF00EBFF00CCFF00AEFF00CCFF00AEFF00
FFF500FFE600FFE600FFE600FFD700FFD700FFE600FFE600FFE600FFD700FFE600FFF500
FAFF0051FF00FAFF00FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD700FFD700
FFD700FFE600FFE600FFE600FFF500DCFF00DCFF00FAFF00FFF500FFF500FFF500EBFF00
BDFF00EBFF00EBFF00EBFF00BDFF009EFF009EFF0042FF0061FF0080FF009EFF00CCFF00
DCFF00CCFF00CCFF00CCFF00AEFF0051FF00AEFF00CCFF00BDFF00BDFF00CCFF00BDFF00
AEFF0042FF0000FF1970FF0042FF0051FF0000FF0A00FFB300FF7500E1FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF000000FF75AEFF00CCFF00DCFF00EBFF00FAFF00FFF500FFF500
FFE600FFE600FFD700FFD700FFD700FFD700FFC700FFC700FFC700FFB800FFB800FFB800
FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00
FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FF9900FFA800FF9900FF9900
FF9900FF9900FFA800FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFC700FFB800FFA800FFB800
FFA800FFB800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFC700FFC700FFC700FFD700FFE600FAFF008FFF00DCFF00AEFF00
51FF0033FF00FF0000FF0000FF0000FF0000FF000000FF0AAEFF00DCFF00FFE600FFD700
FFD700FFD700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFD700DCFF00FFD700FFC700FFC700FFC700FFC700
FFD700FFC700FFD700FFD700FFD700FFE600FFF500FAFF00EBFF00CCFF00FAFF00FFF500
FFE600FFE600FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFE600
FFF5008FFF00FFF500FFE600FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700
FFD700FFD700FFD700FFD700FFE6008FFF00EBFF00FFF500FFE600FFE600FFF500FAFF00
FAFF00FAFF00FAFF00EBFF00BDFF00CCFF00AEFF0000FFC2AEFF00AEFF0070FF00CCFF00
EBFF00EBFF00DCFF00DCFF00BDFF008FFF00CCFF00DCFF00DCFF00DCFF00CCFF00CCFF00
BDFF0080FF0080FF008FFF008FFF0070FF0000FFFF14FF0000FF2800FFA30075FFFF0000
FF0000FF0000FF0000FF0000FF00005100FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF000000FF5700FF85BDFF00DCFF00FAFF00FAFF00FFF500
FFF500FFE600FFD700FFD700FFD700FFC700FFC700FFC700FFC700FFC700FFB800FFB800
FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800
FFB800FFB800FFB800FFB800FFC700FFC700FFD700FFE600EBFF00EBFF00FAFF00EBFF00
CCFF008FFF0051FF0000FF66FF000000FF5723FF0033FF00EBFF00FAFF00FFE600FFD700
FFD700FFC700FFC700FFC700FFC700FFC700FFC700FFB800FFB800FFC700FFB800FFB800
FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFD700FFD700FFE600FFF500DCFF00DCFF00FFF500FFE600
FFE600FFD700FFD700FFC700FFC700FFC700FFD700FFC700FFC700FFC700FFD700FFD700
FFE60051FF00FFE600FFD700FFD700FFC700FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFD700FFD700FFE600EBFF00FFF500FFE600FFE600FFE600FFE600FFE600
FFF500FFF500FFF500FAFF00FAFF00EBFF00BDFF0051FF00BDFF00CCFF00BDFF00EBFF00
EBFF00FAFF00EBFF00EBFF00BDFF008FFF00DCFF00EBFF00EBFF00EBFF00DCFF00DCFF00
BDFF0000FF85AEFF00AEFF009EFF0033FF0061FF0051FF0014FF0000FF5700C2FFFF0000
FF001EFF0000FF0000FF00008F00FF00A3FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000000AFFAEFF00DCFF00FAFF00FFF500
FFF500FFE600FFE600FFD700FFD700FFD700FFC700FFC700FFC700FFB800FFB800FFB800
FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFB800FFB800FFB800FFB800FFC700FFD700FFE600CCFF00FFF500FFF500FAFF00
AEFF00CCFF00AEFF0000FF75FF000033FF00AEFF00CCFF00FAFF00FFE600FFD700FFD700
FFC700FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFC700FFC700FFC700FFC700FFC700FFD700FFE600FFF500EBFF00DCFF00FFF500FFE600
FFD700FFD700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700
FFD70051FF00FFD700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFD700FFD700FFE600FFD700FFD700FFD700FFD700FFD700FFE600
FFE600FFE600FFE600FFF500FAFF00EBFF00BDFF0061FF00DCFF00EBFF00EBFF00FAFF00
FAFF00FAFF00FAFF00EBFF00BDFF009EFF00EBFF00EBFF00EBFF00EBFF00EBFF00DCFF00
61FF009EFF00BDFF00BDFF00AEFF0070FF0080FF0061FF0000FF3800FFC2EB00FFFF003D
00A3FFFF00000075FFFF006B00FFE100FFFFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0ACCFF00EBFF00
FFF500FFF500FFE600FFE600FFD700FFD700FFC700FFC700FFC700FFC700FFB800FFB800
FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF9900
FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FF9900
FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFB800FFB800FFC700FFC700FAFF00FFE600FFE600FFE600FFF500
EBFF00EBFF00CCFF0070FF0000FF75AEFF00DCFF009EFF00FAFF00FFE600FFD700FFC700
FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFC700FFC700FFC700FFD700FFD700FFF500EBFF00EBFF00FFF500FFE600
FFD700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFD700FFC700FFC700FFC700FFC700FFB800FFB800FFB800FFB800FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFD700FFD700FFD700FFD700FFD700
FFD700FFE600FFE600FFF500FFF500FAFF00CCFF00BDFF00EBFF00FAFF00FAFF00FAFF00
FAFF00FAFF00FAFF00FAFF00DCFF00BDFF00EBFF00FAFF00FAFF00FAFF00FAFF00EBFF00
9EFF00CCFF00CCFF00CCFF00BDFF00AEFF008FFF0070FF0023FF000047FF00FF5700FFF0
00FF8500B3FF00FF7500FF8500FF7500FFB38000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000005FF000047FF00FF19
EBFF00FFF500FFF500FFE600FFE600FFD700FFD700FFC700FFC700FFC700FFB800FFB800
FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FFA800FF9900FF9900FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFB800FFB800FFD700FFE600FFD700FFD700FFD700FFE600
FFE600FFF500EBFF0080FF00BDFF00DCFF00FAFF00FAFF00DCFF00FFE600FFD700FFC700
FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFA800FFA800FFB800FFA800
FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFC700FFC700FFD700DCFF008FFF00DCFF00FFF500FFD700
FFD700FFC700FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700
FFC700FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFD700
FFD700FFD700FFE600FFF500FFF500EBFF00BDFF00CCFF00EBFF00FAFF00FFF500FFF500
FFF500FFF500FFF500FFF500EBFF00EBFF00FAFF00FAFF00FFF500FAFF00FAFF00FAFF00
EBFF00EBFF00DCFF00DCFF00BDFF00AEFF008FFF0070FF0014FF0000FFD105FF0000FF19
00FF1900FF5700FF1900FF3800FF3800A3FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000AE00FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000051FF00
5100FFCCFF00FFF500FFE600FFE600FFD700FFD700FFC700FFC700FFC700FFC700FFB800
FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00
FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFC700FFC700FFC700FFC700FFD700
FFE600FFF500EBFF00EBFF00FAFF00CCFF00FFE600FFE600FAFF00FFE600FFD700FFC700
FFB800FFB800FFB800FFB800FFA800FFA800FFB800FFA800FFA800FFA800FFB800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFA800FFA800FFB800
FFB800FFB800FFB800FFB800FFC700FFC700FFD700FAFF00EBFF0080FF008FFF00FFE600
FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFD700
FFD700FFD700FFE600FFE600FFF500EBFF0070FF00CCFF00FAFF00FFF500FFF500FFF500
FFE600FFE600FFE600FFF500FFF500FFF500FFF500FFF500FFF500FFF500FFF500FAFF00
FAFF00EBFF00EBFF00DCFF00CCFF00AEFF0080FF0000FF3800FF7542FF0023FF0051FF00
00FF1900FFA323FF0014FF0000FF0A00FF660094FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00002300FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF47
FF0000FF0000EBFF00FFF500FFE600FFE600FFD700FFD700FFC700FFC700FFC700FFB800
FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00
FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF8A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF9900FF8A00FF9900FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFC700FFC700FFD700
FFD700FFF500DCFF00FFF500FFE600FFE600FFD700FFD700FFE60080FF00FFD700FFB800
FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFE600FAFF00FAFF00FFE600FFD700
FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFC700FFC700FFC700
FFD700FFD700FFE600FFE600FFF500DCFF0051FF00DCFF00FAFF00FFF500FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF500FFF500FFF500FFF500FFF500
FAFF00EBFF00EBFF00DCFF00BDFF0070FF0051FF0000FF4723FF0070FF0070FF0070FF00
23FF0000FFC251FF0042FF0000FF2800C2FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000047FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF000051FF00AEFF0033FF00FAFF00FFE600FFD700FFD700FFD700FFC700FFC700FFC700
FFB800FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFC700FFC700
FFD700FFE6008FFF00FFE600FFD700FFD700FFD700FFC700FFC700FFD700FFC700FFB800
FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFB800FFA800FFB800FFB800FFB800FFC700FFD700FAFF00FFF500FFD700FFC700
FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700
FFC700FFD700FFD700FFE600FAFF00BDFF0080FF00DCFF00FFF500FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF500FFF500
FAFF00FAFF00EBFF00DCFF00CCFF009EFF0042FF0000FF1933FF008FFF008FFF0080FF00
000AFF70FF0070FF0042FF0000FF8500FF2800D1FF0066FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000094FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF006B00FF471400FFFF0000FFF500FFE600FFD700FFD700FFC700FFC700FFC700
FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900
FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFC700
FFD700FFE600EBFF00FFE600FFD700FFC700FFC700FFC700FFC700FFB800FFB800FFB800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFB800FFA800FFB800FFB800FFB800FFD700FFF500FFE600FFC700FFB800
FFB800FFB800FFB800FFB800FFB800FFA800FFA800FFB800FFA800FFA800FFB800FFA800
FFA800FFB800FFA800FFA800FFB800FFA800FFA800FFA800FFA800FFB800FFA800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700
FFC700FFD700FFD700FFE600FAFF00CCFF00BDFF00EBFF00FFF500FFE600FFE600FFE600
FFE600FFE600FFE600FFD700FFE600FFE600FFE600FFE600FFE600FFE600FFF500FFF500
FFF500FAFF00EBFF00EBFF00CCFF00AEFF0000E1FF00FF0A80FF009EFF00AEFF008FFF00
61FF0080FF0080FF0023FF0033FF0005FF0000FF5700B3FFFF0099FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF000000B3FF00B3FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF000000FFA351FF00DCFF00FFF500FFE600FFD700FFD700FFC700FFC700
FFB800FFC700FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFC700
FFD700FFF500FFF500FFD700FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFC700FFF500FFD700FFC700FFB800
FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFA800FFB800
FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700
FFC700FFD700FFD700FFF500EBFF008FFF00DCFF00FFF500FFE600FFE600FFD700FFD700
FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFE600FFE600FFE600FFE600FFF500
FFF500FAFF00EBFF00DCFF00CCFF0070FF0061FF0080FF009EFF00AEFF00BDFF00AEFF00
8FFF009EFF0080FF0070FF0051FF0000FF7500FFA3FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000AE00FF00FFF000E1FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF000080FF00BDFF0000FFB3DCFF00FFE600FFD700FFD700FFD700
FFC700FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00
FF7A00FF8A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF9900FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFB800FFB800FFC700
FFD700FFF500FFF500FFD700FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900FFA800FF9900FFA800FF9900
FF9900FF9900FF9900FFA800FF9900FFA800FF9900FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFF500FFC700FFB800FFB800
FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFC700FFC700FFD700EBFF00BDFF008FFF00EBFF00FFF500FFE600FFD700FFD700FFD700
FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFE600FFE600FFF500
FFF500FAFF00EBFF00DCFF00AEFF0061FF00AEFF00BDFF008FFF00CCFF00CCFF00BDFF00
AEFF00AEFF008FFF0070FF0033FF0000FF0A00FFE1FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF000000FFB300FFE1FF0099FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00008F00FF51FF0005FF00FF000070FF00EBFF00FFE600FFD700FFC700
FFC700FFC700FFC700FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFB800FFC700
FFD700FAFF00FFE600FFC700FFC700FFB800FFB800FFB800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FF9900FFA800FF9900FFA800FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FFA800FF9900FFA800FF9900FF9900FF9900FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFC700FFB800FFB800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800
FFC700FFC700FFD700FFE600EBFF0042FF0042FF00FFF500FFE600FFD700FFD700FFD700
FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFE600FFE600FFE600
FFF500FAFF00DCFF00BDFF0000FF19BDFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
BDFF00AEFF0080FF0033FF0000FF8500FF8500D1FFDC00FF9E00FF00A3FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FA00FF00FFA300FF8500FFB3FF00C7FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF000000E1FF00F0FF00FF66FFF500FFD700FFD700
FFC700FFC700FFB800FFB800FFB800FFB800FFA800FFB800FFA800FFA800FFA800FFA800
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFB800FFC700
FFD700CCFF00FFE600FFC700FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FF9900FFA800FF9900FFA800FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FF9900FF9900FF9900FF9900
FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFA800FFB800FFB800FFB800FFB800
FFB800FFC700FFC700FFE600CCFF00EBFF00FAFF00FFE600FFD700FFD700FFD700FFC700
FFC700FFC700FFC700FFD700FFC700FFD700FFD700FFD700FFD700FFD700FFE600FFF500
FFF500EBFF00CCFF006100FFAEFF00CCFF00DCFF00DCFF00DCFF00DCFF00DCFF00CCFF00
BDFF00AEFF008FFF0005FF0000FFB323FF0005FF000057FF00FF7500FFF0FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF000000FFC200FF8500FF5700FFD1FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF000080FF0080FF00FAFF00FFE600FFE600
FFD700FFC700FFC700FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00
FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFB800FFB800
FFD700FAFF00FFD700FFC700FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800
FFB800FFC700FFC700FFE600BDFF00FFF500FFE600FFD700FFD700FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFD700FFD700FFE600FFE600
FAFF00CCFF0070FF0070FF00CCFF00EBFF00EBFF00EBFF00EBFF00EBFF00DCFF00DCFF00
BDFF009EFF0080FF0023FF0014FF0061FF0042FF0000FF9400FF0A00D1FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF000000FF8500FF3800FF3800FF852300FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000DC00FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF000000FF288FFF00BDFF00DCFF0000FFD1DCFF00
FFE600FFD700FFC700FFC700FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800
FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00
FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFB800FFB800
FFC7009EFF00FFC700FFC700FFB800FFA800FFA800FFA800FFA800FFA800FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FFA800FF9900FFA800FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FF9900FFA800FF9900FFA800FF9900FF9900FFA800FF9900
FFA800FFA800FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800
FFB800FFC700FFC700FFE600FAFF00FFD700FFD700FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFD700FFD700FFE600
FAFF00CCFF0070FF00CCFF00DCFF00FAFF00FAFF00FAFF00EBFF00EBFF00EBFF00DCFF00
AEFF0000FF2870FF008FFF0051FF0080FF0000FF6642FF0000FF6600FF2800FF7500F0FF
9E00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF000000FF75FF000000FF1900FF2800FF85FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00004200FF9E00FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000085FF23FF009EFF0000FFB3FF0000000AFF
BDFF00FFD700FFC700FFC700FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800
FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF8A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00
FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFB800FFB800
FFD700FFF500FFC700FFB800FFB800FFA800FFA800FFA800FFA800FFA800FF9900FFA800
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FF9900FFA800
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FF9900
FF9900FF9900FF9900FFA800FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFA800FFB800
FFB800FFB800FFC700FFD700FFD700FFC700FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFE600FFE600
FAFF0061FF0042FF00EBFF00FAFF00FAFF00FAFF00FAFF00FAFF00FAFF00EBFF00DCFF00
70FF0080FF009EFF00AEFF009EFF008FFF0080FF0061FF0033FF0000FF38FF00A80085FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00F5FF000000FF4700FF0A05FF0000FF1900FF47FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000000AFFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0AFF0000FF000000FFA30028FF
05FF00FFF500FFD700FFC700FFC700FFB800FFB800FFB800FFA800FFA800FFA800FFA800
FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00
FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF8A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFB800
FFD700FFE600FFC700FFB800FFA800FFA800FFA800FF9900FFA800FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FFA800FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FFA800FF9900FF9900FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFC700FFC700FFB800FFB800FFB800
FFC700FFB800FFC700FFC700FFC700FFC700FFC700FFD700FFC700FFD700FFD700FFE600
DCFF00DCFF00EBFF00FAFF00FFF500FFF500FFF500FAFF00FAFF00FAFF00EBFF00DCFF00
AEFF00BDFF00BDFF00BDFF00AEFF009EFF0080FF0051FF0000FF0A00FF3800FFB3FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000038FF
BD00FF00FF4700FF3814FF0014FF0000FF195100FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000038FF000AFFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF38
33FF00FF0000FFE600FFC700FFC700FFC700FFB800FFB800FFB800FFA800FFA800FFA800
FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFB800
FFE600FFD700FFB800FFB800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FFA800FF9900FF9900FFA800FF9900FF9900
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFC700FFB800FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFE600
FAFF00FFF500FFF500FFF500FFF500FFF500FFF500FFF500FFF500FAFF00FAFF00EBFF00
DCFF00DCFF00CCFF00BDFF00BDFF008FFF0042FF0000FF28FF00009E00FF0066FFFF0000
FF0000FF0000FF0000FF0000EB00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000A3FFFF0000
00FF6614FF0000FF1933FF0023FF0005FF0000FF28FF0000FF002EFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000075FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00008FFF00
9EFF0051FF00FFE600FFD700FFC700FFC700FFB800FFB800FFB800FFA800FFA800FFA800
FFA800FFA800FF9900FF9900FF9900FFA800FF9900FF9900FF9900FF9900FF9900FF9900
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFB800
FFE600FFD700FFB800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FFA800FF9900FF9900FF9900FF9900FF9900FFA800FF9900FF9900
FFA800FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFC700FFD700FFD700
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF500FFF500FFF500FAFF00FAFF00
EBFF00DCFF00DCFF00CCFF00BDFF0080FF0061FF0061FF0023FF0000FF19FF00D7DC00FF
FF0000FF0000FF0000FF000000C2FFFF0000EB00FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00009E00FF2300FF00FFA3
FF000033FF0042FF0042FF0033FF0014FF0000FF1900FFB31400FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000094FF0066FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00009EFF00
BDFF00DCFF00FFF500FFE600FFD700FFC700FFC700FFB800FFB800FFB800FFA800FFA800
FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00
FF8A00FF8A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FFA800FFB800
FFE600FFC700FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF9900FF9900FF8A00FF8A00
FF9900FF9900FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FFA800FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFC700FFD700FFD700
FFD700FFD700FFD700FFE600FFE600FFE600FFE600FFE600FFF500FFF500FFF500FAFF00
EBFF00EBFF00DCFF00CCFF00BDFF00AEFF008FFF0070FF0042FF0000FF0A00FF750047FF
FF0000FF0000FF0000FF000000FFA300FFC20038FFFF00009E00FFCC00FFFF0000FF0000
FF0000FF0000FF0000FF000FFF00E6FF0000FF000000FFF000FFD10019FF1400FF23FF00
00FF4742FF0051FF0051FF0042FF0005FF0000FF94FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF000000C2FF0094FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFA342FF009EFF00
CCFF00DCFF00FAFF00EBFF00FAFF00FFE600FFC700FFC700FFB800FFB800FFA800FFA800
FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF8A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FFA800FFB800
8FFF00FFB800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF9900FF8A00FF8A00
FF9900FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF9900FF9900FF8A00FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FFA800FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFC700
FFD700FFD700FFD700FFD700FFE600FFE600FFE600FFE600FFE600FFF500FFF500FAFF00
FAFF00EBFF00DCFF00CCFF00BDFF00AEFF008FFF0070FF0033FF0005FF0000FF66FF0000
FF00008000FFEB00FF00D1FF00FF5700FF572300FF0047FF00D1FFCC00FFFF0000FF0000
FF00000094FFFF000000FFFFFF0000FF0000FF000000FFF0FF008A00FFD123FF0042FF00
33FF0014FF0061FF0061FF0051FF0000FF1900FF287000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF000000E1FF00B3FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000033FF00
BDFF00BDFF0070FF0000FFB300F0FF61FF00FFD700FFC700FFB800FFB800FFB800FFA800
FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FFA800
FFC700FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF9900
FF9900FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FFA800FF9900FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFB800FFA800FFA800FFA800FFA800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFB800FFC700FFC700FFC700FFC700
FFC700FFD700FFD700FFD700FFD700FFD700FFE600FFE600FFE600FFF500FFF500FAFF00
EBFF00EBFF00DCFF00BDFF00AEFF009EFF0080FF0061FF0014FF00CC00FF00FFB300A3FF
0047FF00D1FFDC00FFFF000005FF0000FF3800FF5700FF38FF00000085FFFF0000FF0000
FF000000E1FFFF000000FF7500FFA30028FFFF00A800FF1900FF385100FF00FF0A61FF00
70FF0070FF0070FF0070FF0061FF0042FF0014FF0000FFFF00D1FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF000000C2FF00FFFF00D1FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000023FF00
33FF0000FF2800FF380075FF00C2FF9EFF00FFF500FFD700FFC700FFB800FFB800FFA800
FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900
FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF9900FF9900FF8A00FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700
FFC700FFD700FFD700FFD700FFD700FFD700FFE600FFE600FFE600FFF500FFF500FAFF00
EBFF00EBFF00CCFF0000FFC28FFF0080FF0051FF0042FF0014FF0000FFD10066FF00D1FF
00FFD100FF5700D1FF05FF0023FF0023FF0005FF0014FF000038FF00FF940019FFFF0000
0500FF00B3FF00FF2800FF2800FF94FF00C7FF00B833FF0033FF0000FF6651FF0070FF00
80FF0080FF0080FF0080FF0061FF0042FF0014FF0000FF7500D1FFBD00FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF000000F0FF00FFE100F0FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF000000FF5700D1FF9EFF0051FF00FFE600FFC700FFB800FFB800FFB800
FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF9900FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FF9900FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700
FFC700FFC700FFD700FFD700FFD700FFD700FFE600FFE600FFE600FFF500FFF500FAFF00
EBFF00DCFF00CCFF00AEFF0000FF0A23FF005100FF00FF5700F0FF00FFF000FF4700FFE1
7000FF05FF0000FF3800FF3861FF0023FF0042FF0023FF0005FF0000FF4700FFF0FA00FF
0028FF00FF2823FF0000FF3800B3FF00FF9433FF0042FF0070FF0061FF0042FF0080FF00
8FFF008FFF008FFF0080FF0061FF0042FF0000FFD1FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF000000FFE100FFD100FFFFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFE1
FF0000FF0000FF000000FF1923FF00FF00A805FF00CCFF00FFC700FFC700FFB800FFB800
FFA800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900
FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00
FF8A00FF8A00FF9900FF9900FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FF9900FF9900FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700
FFC700FFC700FFC700FFD700FFD700FFD700FFD700FFE600FFE600FFF500FAFF00EBFF00
DCFF00CCFF00BDFF009EFF0061FF0000FFE100FF3814FF0000FFE100FFA323FF0014FF00
00E1FF42FF0061FF0051FF0080FF0070FF0061FF0042FF0014FF0000FF477000FF00F0FF
00FF8514FF0051FF003300FF00FFFF00FF1961FF0080FF008FFF0070FF0000FF198FFF00
9EFF009EFF008FFF0080FF0023FF00FF00001400FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00D700FFC200FFB300FFFFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF000080FF009EFF008FFF0005FF00FFD700FFC700FFB800FFB800
FFB800FFB800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF7A00FF7A00
FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF7A00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00
FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF9900FF9900FF8A00FF8A00FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800
FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700
FFC700FFC700FFC700FFC700FFD700FFD700FFD700FFE600FFE600FFF500FAFF00BDFF00
8FFF00AEFF0080FF0080FF0000D1FF00E1FF51FF0070FF0070FF0051FF0080FF0042FF00
14FF0080FF0080FF0000FF758FFF008FFF0070FF0000FF19FF006B00FF85FF000000FF19
05FF0051FF0070FF0042FF000057FF0038FF51FF008FFF009EFF009EFF0000E1FF9EFF00
AEFF009EFF009EFF008FFF0042FF0051FF0033FF0000FFA30085FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF007A00FFA300FF9400FFFFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000500FFAEFF00BDFF00BDFF0000FFA3FFD700FFC700FFC700FFC700
FFB800FFA800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00
FF8A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00
FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF9900
FF9900FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFC700FFC700FFC700FFD700FFD700FFD700FFD700FFD700FFE600FFF500EBFF008FFF00
80FF00AEFF0033FF0000FF470075FF00FF6600FF198FFF009EFF0042FF009EFF0070FF00
00FFB39EFF00AEFF0070FF00AEFF009EFF0033FF0000FF8500E1FF00FF280085FF51FF00
00FF1980FF008FFF0042FF0061FF0000FF2880FF009EFF00AEFF00AEFF00AEFF00AEFF00
AEFF00AEFF00AEFF009EFF008FFF0070FF0042FF0000FF280019FF00FFF0FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF000000D1FF00FF8500FF8500FFB3FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF000000A3FFBDFF00CCFF00DCFF00FAFF00FFE600FFD700FFC700FFC700
FFB800FFB800FFB800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00
FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF9900
FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FF9900
FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700
FFC700FFC700FFC700FFC700FFD700FFD700FFD700FFD700FFE600FFE600FFF500EBFF00
DCFF00CCFF00AEFF0061FF0000FF1923FF0080FF00AEFF00AEFF00AEFF00BDFF009EFF00
70FF00AEFF00BDFF00BDFF00BDFF00AEFF0080FF0000FF0AFF000033FF0061FF0080FF00
61FF009EFF009EFF009EFF008FFF0042FF009EFF00AEFF00BDFF00BDFF00BDFF00BDFF00
BDFF00BDFF00AEFF009EFF008FFF0080FF0061FF0023FF0000FF3800FFB37000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF000000FF7500FF7500FFA3FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF000042FF0080FF00BDFF00DCFF00EBFF00FFF500FFE600FFD700FFC700FFC700
FFB800FFB800FFB800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900
FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF9900FF9900FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FFA800FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800
FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFD700FFE600FFE600FFF500FAFF00
EBFF00DCFF00AEFF0080FF000075FF42FF008FFF00AEFF00BDFF00BDFF00CCFF00AEFF00
00FFB3BDFF00CCFF00CCFF00CCFF00AEFF0080FF0000FF855100FF00FF2870FF009EFF00
AEFF00AEFF00BDFF00AEFF009EFF000500FF9EFF00BDFF00BDFF00CCFF00CCFF00CCFF00
BDFF00BDFF00AEFF009EFF008FFF0070FF0042FF0000FF38FF001EFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000CC00FF00FF8500FF6600FF6600FF94BD00FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF000000FF191400FFBDFF00DCFF00EBFF00FAFF00FFF500FFE600FFE600FFD700
FFC700FFB800FFB800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FFA800FF9900FF9900FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFC700FFC700FFC700FFC700FFD700FFD700FFD700FFD700FFE600FFE600FFF500FAFF00
EBFF00DCFF0000FF1942FF000094FF00FF0A61FF00AEFF00CCFF00DCFF00DCFF00CCFF00
00FF0ACCFF00DCFF00DCFF00CCFF00AEFF0080FF0070FF0014FF0000FFB361FF00AEFF00
BDFF00CCFF00CCFF00BDFF008FFF00000AFF8FFF00BDFF00CCFF00CCFF00CCFF00CCFF00
CCFF00BDFF00AEFF009EFF008FFF0070FF0000FF85FF00996100FFFF002EFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF000000FF6600FF4700FF5700FF75FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF000070FF00CCFF00DCFF00EBFF00EBFF00BDFF0033FF00CCFF00
FFD700FFC700FFB800FFB800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800
FFB800FFC700FFC700FFC700FFC700FFD700FFD700FFD700FFE600FFE600FFF500FAFF00
EBFF00DCFF00BDFF0080FF0000FF0A42FF009EFF00AEFF00DCFF00EBFF00EBFF00DCFF00
00FF38DCFF00EBFF00EBFF00DCFF00CCFF00BDFF009EFF0051FF00FF005C00FFE1AEFF00
CCFF00CCFF00CCFF00CCFF00AEFF0000FF389EFF00CCFF00CCFF00DCFF00DCFF00CCFF00
CCFF00CCFF00AEFF008FFF0061FF0042FF0000FF94DC00FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000BD00FF00FF4700FF3800FF4700FF85FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF000042FF00AEFF00AEFF00BDFF0023FF0000C2FF0085FF00FF0A
FAFF00FFD700FFB800FFB800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800
FFB800FFC700FFC700FFC700FFC700FFD700FFD700FFD700FFE600FFE600FFF500FAFF00
EBFF00CCFF009EFF0023FF0000FFFF23FF00BDFF00DCFF00EBFF00EBFF00EBFF00EBFF00
EBFF00EBFF00EBFF00EBFF00EBFF00DCFF00CCFF009EFF0000F0FF70FF00AEFF0080FF00
CCFF00DCFF00DCFF00DCFF00CCFF0070FF00BDFF00DCFF00DCFF00DCFF00DCFF00DCFF00
CCFF00CCFF00AEFF0000FF0A00FFB351FF00CC00FFFF0000FF00000075FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF000000FF8500FF3800FF2800FF3800FF57FA00FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF000061FF0000FF6600E1FF61FF0005FF0000F0FF00FFE100FF28
00FF7561FF00FFC700FFB800FFB800FFA800FFA800FFA800FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF8A00FF8A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00
FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFC700FFC700FFC700FFD700FFD700FFD700FFD700FFE600FFE600FFF500FAFF00
CCFF0005FF0000FF2800FFA361FF0000FFA3BDFF00DCFF00EBFF00FAFF00FAFF00FAFF00
FAFF00FAFF00FAFF00FAFF00EBFF00EBFF00CCFF00BDFF000075FF00FF75CCFF00DCFF00
DCFF00EBFF00EBFF00EBFF00DCFF00AEFF00CCFF00DCFF00EBFF00EBFF00DCFF00DCFF00
DCFF00CCFF008FFF0000FF7580FF008FFF0070FF0023FF00FF000000FFC200F0FF00F0FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00002300FF00FF5700FF2800FF1900FF2800FF57FF004CFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF000000FFB305FF005100FFFF000000FFE100E1FF00FFFFBD00FF61FF00
CCFF00FAFF00FFD700FFB800FFB800FFA800FFA800FFA800FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF7A00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00
FF7A00FF8A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF8A00FF8A00FF7A00
FF7A00FF7A00FF8A00FF8A00FF8A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF9900FF9900FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800
FFB800FFC700FFC700FFC700FFC700FFD700FFD700FFD700FFE600FFF500FFF500FAFF00
DCFF008FFF0070FF00AEFF00BDFF00BDFF009EFF00DCFF00FAFF00FAFF00FAFF00FFF500
FFF500FFF500FAFF00FAFF00FAFF00EBFF00DCFF00BDFF0080FF00BDFF00DCFF00DCFF00
EBFF00EBFF00EBFF00EBFF00EBFF00EBFF00EBFF00EBFF00EBFF00EBFF00EBFF00EBFF00
DCFF00CCFF00BDFF00AEFF00AEFF009EFF0080FF0033FF000019FF00FF9400FF47FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF000000FF4700FF1900FF0A00FF1900FF38FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF000FFF0000FF0000FF0000FF0000FF000000FF190066FF00D1FF
BDFF00EBFF00FFE600FFC700FFB800FFA800FFA800FFA800FFA800FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF8A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF8A00FF8A00FF7A00
FF7A00FF7A00FF8A00FF8A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF7A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00
FF8A00FF9900FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800
FFB800FFC700FFC700FFC700FFC700FFD700FFD700FFE600FFE600FFF500FAFF00EBFF00
9EFF0070FF009EFF00DCFF00DCFF00DCFF0070FF00CCFF00FAFF00FFF500FFF500FFF500
FFF500FFF500FFF500FAFF00FAFF00EBFF00DCFF0000FF0A80FF00CCFF00DCFF00EBFF00
EBFF00FAFF00FAFF00FAFF00FAFF00EBFF00EBFF00FAFF00EBFF00EBFF00EBFF00DCFF00
DCFF00DCFF00CCFF00BDFF00BDFF00AEFF008FFF0061FF0014FF0000FF0AFF00000038FF
AE00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF000000FF1900FF0A00FF0A00FF0A00FF38FF00B8FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FA00FF00FF1961FF001400FF
00FF3800FF19AEFF00FFC700FFB800FFB800FFA800FFA800FFA800FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF7A00FF7A00
FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF9900FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800
FFB800FFC700FFC700FFC700FFD700FFD700FFD700FFE600FFF500FFF500FAFF00DCFF00
70FF00AEFF008FFF00EBFF00FAFF00FAFF00DCFF00DCFF00FFF500FFF500FFF500FFF500
FFF500FFF500FFF500FFF500FAFF00EBFF00CCFF0023FF0061FF00CCFF00EBFF00EBFF00
FAFF00FAFF00FAFF00FAFF00FAFF00FAFF00FAFF00FAFF00FAFF00FAFF00EBFF00EBFF00
EBFF00DCFF00DCFF00CCFF00BDFF00AEFF009EFF0080FF0061FF0033FF0000FF0A00FF66
00E1FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF000000FF0A05FF0005FF0005FF0000FF28FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00004200FF42FF0080FF0000FF94
00FF5770FF00CCFF00FFD700FFB800FFB800FFB800FFA800FFA800FFA800FF9900FF9900
FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00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FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00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FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00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FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00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FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00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FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00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FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800
FFC700FFC700FFD700FFE600FFE600FFF500EBFF0051FF0014FF00CCFF00FAFF00FFF500
FFE600FFE600FFE600FFE600FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700
FFD700FFD700FFD700FFD700FFD700FFE600FFF500DCFF00FFF500FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF500FFF500FAFF00FAFF00
CCFF00AEFF0051FF0000FF6680FF0000FF5700FF7523FF0000FF850028FF00C2FF00FFB3
FF005C000AFF00FFD1FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000CC00FFFF00F5
000AFF33FF0042FF0051FF0051FF0051FF0042FF0033FF0000FF660094FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000094FFFF0000AE00FF00FF94DCFF00FAFF00
FFF500FFF500FFE600FFD700FFD700FFC700FFC700FFB800FFB800FFA800FFA800FFA800
FFA800FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00
FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00
FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800
FFC700FFD700FFD700FFE600FFF500DCFF00DCFF00AEFF009EFF00DCFF00FAFF00FFF500
FFE600FFD700FFD700FFD700FFD700FFD700FFC700FFC700FFD700FFC700FFC700FFD700
FFC700FFC700FFD700FFD700FFD700FFD700FFE600FFF500FFE600FFE600FFE600FFE600
FFE600FFD700FFE600FFE600FFE600FFE600FFE600FFE600FFF500FFF500FFF500FAFF00
DCFF0000FF7500FFD180FF00AEFF00AEFF0000FF1980FF0000FF5700FF85EB00FF00FF38
FF000000FF6600FF57FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000C2FF00B3FF
14FF0042FF0051FF0051FF0061FF0051FF0042FF0033FF0000FF4700F0FFEB00FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000C2FFFF0000CCFF00EBFF00
FAFF00FFF500FFE600FFE600FFD700FFD700FFC700FFC700FFB800FFB800FFA800FFA800
FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00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FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF9900FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFB800FFB800FFB800
FFE600BDFF0061FF00AEFF009EFF0023FF00AEFF0070FF00DCFF0080FF0000FFFFFFF500
FFD700FFD700FFD700FFD700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFD700FFD700FFD700FFD700FFD700
FFD700FFD700FFD700FFD700FFD700FFD700FFE600FFE600FFE600FFF500FFF500EBFF00
BDFF00BDFF00CCFF00DCFF00DCFF00DCFF00CCFF00BDFF008FFF0000FFF000FF4705FF00
42FF0023FF000057FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000005FF00
42FF0061FF0061FF0070FF0070FF0061FF0061FF0042FF0000FF19CC00FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000DC00FF33FF0080FF00AEFF00CCFF00
00FFB3CCFF00EBFF0000FF85BDFF0070FF00AE00FFEBFF009EFF00FFC700FFB800FFB800
FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF9900
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFC700
FFC700FFE600FAFF00EBFF00BDFF0000FF28CCFF00EBFF00FAFF00FAFF00EBFF00FFE600
FFD700FFD700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFD700FFD700FFD700
FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFE600FFE600FFE600FFF500FAFF00
FAFF00EBFF00EBFF00EBFF00EBFF00DCFF00CCFF00BDFF0000FF7580FF0061FF0070FF00
61FF0014FF00FF0000FF00005100FF0057FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000085FFFF000023FF00
61FF0070FF0070FF0070FF0070FF0070FF0061FF0051FF0014FF0000C2FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000080FF009EFF0000FF66
FF000000FF949EFF0033FF0000FFB300FFE100FFE105FF00CCFF00FFD700FFC700FFB800
FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FFA800FF9900FFA800FFA800FFA800FFA800FFA800FFB800FFB800
FFC700FFD700FFE600FFF500EBFF0000FF28DCFF00FAFF00FFF500FFF500FFE600FFD700
FFD700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFD700FFD700
FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFE600FFE600FFE600FFF500FFF500
FAFF00FAFF00FAFF00EBFF00EBFF00EBFF00DCFF00BDFF009EFF00AEFF009EFF008FFF00
70FF0023FF0033FF00000AFF00C2FF0038FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00008000FF00FFE100B3FF42FF00
61FF0070FF0080FF0070FF0070FF0070FF0061FF0051FF0000FF0A00FF94FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF1951FF001400FFFF0000
00FFB314FF0080FF0000FF0A00FF0AFF00C700FF6661FF00CCFF008FFF00FFE600FFB800
FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFB800FFB800
FFC700FFD700FFD700FFF500EBFF0000FF0ABDFF00FAFF00FFE600FFE600FFD700FFD700
FFD700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFB800FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFE600FFE600FFE600FFF500
FFF500FFF500FAFF00FAFF00FAFF00EBFF00DCFF00DCFF00CCFF00BDFF00AEFF008FFF00
80FF0061FF0042FF0014FF0000FF2800FFF00057FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF94FF000000FF47
70FF0070FF0080FF0080FF0080FF0080FF0070FF0042FF00FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0057FF00FFB30075FF00FF380094FF00FFA300FF85CC00FF00FF28AEFF0000FF85FFC700
FFB800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFB800FFB800
FFC700FFC700FFD700FFF500EBFF0080FF00CCFF00FFF500FFE600FFE600FFD700FFD700
FFC700FFC700FFC700FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFD700FFC700FFD700FFD700FFD700FFD700FFD700FFD700FFE600FFE600FFE600
FFF500FFF500FFF500FAFF00FAFF00EBFF00EBFF00DCFF00CCFF00BDFF00AEFF009EFF00
80FF0061FF0042FF0014FF0000FF2800FF6600FFF0FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF002E23FF0051FF00
80FF0080FF0080FF0080FF0080FF0080FF0070FF0061FF0023FF00FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFB3FF0000FF0000FF0000
FF0000000AFFFF00006100FF0094FF0094FF00FF9470FF0080FF00EBFF00BDFF00FFC700
FFB800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF8A00FF8A00FF8A00FF8A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFB800FFB800
FFC700FFC700FFE600FFF500EBFF00AEFF00EBFF00FFF500FFE600FFD700FFD700FFC700
FFC700FFC700FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFD700FFD700FFD700FFD700FFD700FFD700FFE600FFE600FFE600
FFF500FFF500FFF500FAFF00FAFF00EBFF00EBFF00DCFF00CCFF00BDFF00AEFF0061FF00
61FF0051FF0000FF3800FF0AFF000000FFD10094FF000AFFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00004200FF5100FF61FF0080FF00
80FF008FFF008FFF008FFF008FFF0080FF0070FF0070FF0042FF00FF000000E1FF6100FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000075FFFF0000FF0000FF0000
FF0000FF0000FF0000FF000000FF1933FF0000FF8500C2FFCCFF00FAFF00FFE600FFC700
FFB800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFB800FFB800
FFC700FFD70033FF00DCFF00BDFF008FFF00BDFF00FFF500FFE600FFD700FFC700FFC700
FFC700FFB800FFB800FFB800FFB800FFC700FFB800FFB800FFB800FFB800FFB800FFB800
FFC700FFB800FFC700FFB800FFC700FFB800FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFD700FFD700FFD700FFD700FFD700FFE600FFE600FFE600
FFE600FFF500FFF500FAFF00FAFF00FAFF00EBFF00DCFF00CCFF00BDFF00AEFF0014FF00
05FF0000FF19FF000000FF66FF002EFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00A800FFC200FFF023FF0070FF0080FF00
8FFF008FFF008FFF008FFF008FFF0080FF0080FF0070FF0051FF000500FF00FFC2FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF000000D1FF0028FF70FF0000FF3805FF0042FF00EBFF00FFF500FFD700
FFB800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFB800FFB800
FFC700FFD700FFF500CCFF00BDFF00EBFF00DCFF00EBFF00FFE600FFD700FFC700FFC700
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFB800FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFD700FFD700FFD700FFE600FFE600
FFE600FFF500FFF500FFF500FAFF00EBFF00EBFF00CCFF00CCFF00BDFF00AEFF008FFF00
61FF0000FFB3FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF000000FFF000FF85FF000033FF0070FF008FFF00
8FFF009EFF009EFF008FFF008FFF008FFF0080FF0070FF00CC00FFEB00FF00FFE1FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00006100FF00FF3861FF008FFF0080FF00FF0000FF00009EFF0070FF00EBFF00
FFC700FFB800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFB800FFB800
FFC700FFD700EBFF008FFF00FAFF00FFF500FFF50070FF00FFF500FFC700FFC700FFC700
FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFB800FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFD700FFD700FFE600FFE600FFE600
FFE600FFF500FFF500FFF500FAFF00EBFF00DCFF00CCFF00BDFF00AEFF009EFF008FFF00
61FF008F00FFFF00A8FA00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000000AFF00FF3800FFF000FFC280FF008FFF00
9EFF009EFF009EFF009EFF009EFF008FFF008FFF0061FF00FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF000023FF0080FF00AEFF008FFF0000FF94FF00F500FFA300FF0A33FF00
FFD700FFB800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFB800FFB800
FFD700FFF50051FF00FAFF00FFE600FFD700FFD700FFE600FAFF00FFC700FFC700FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFD700FFD700FFE600FFE600
FFE600FFF500FFF500FAFF00FAFF00EBFF00BDFF0000FFC28FFF009EFF0080FF0080FF00
42FF0000B3FF7000FFFF00D7FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00006100FF51FF0070FF008FFF009EFF00
9EFF009EFF009EFF009EFF009EFF009EFF008FFF0080FF0051FF00FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF000000E1FF00FF19BDFF00BDFF00AEFF0000FF0A80FF0080FF00DCFF00
FFE600FFB800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFB800FFC700
FFF50033FF00FFF500FFD700FFD700FFC700FFC700FFD700FFC700FFC700FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFC700FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFD700FFD700FFE600FFE600
FFE600FFF500FFF500FFF500FAFF00EBFF00CCFF0033FF0061FF0042FF0000FF0A51FF00
42FF0000FF0A00FF85FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000038FFFF0000FF007A4200FF80FF008FFF009EFF009EFF00
AEFF00AEFF00AEFF00AEFF009EFF009EFF009EFF008FFF0070FF00FF000000F0FFFF00B8
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000038FFFF0000FF0000
FF00000066FFFF00000085FF00FFC2DCFF00DCFF00EBFF00DCFF00DCFF0070FF009EFF00
FFD700FFB800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFB800FFC700
FFF500FFF500FFD700FFC700FFC700FFC700FFC700FFC700FFB800FFB800FFB800FFB800
FFB800FFB800FFA800FFB800FFA800FFA800FFA800FFA800FFB800FFA800FFA800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFC700FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFD700FFE600FFE600FFE600
FFE600FFF500FFF500FFF500FAFF00EBFF00DCFF00BDFF009EFF0000E1FF00FF4700FF0A
23FF0000FF66FF0000FF00D7FF0000FF0000FF0000FF0000FF0000FF0000FF00006100FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF000000FFA300FF9400E1FF33FF008FFF009EFF009EFF00AEFF00
AEFF00AEFF00AEFF00AEFF00AEFF009EFF009EFF008FFF0070FF0000FF0A00FFC200FFB3
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00006100FF
FF005CFF000000FF0A0047FF80FF00EBFF00EBFF00FAFF00EBFF00EBFF00CCFF0042FF00
FFD700FFB800FFB800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00
FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFB800FFC700
9EFF00FFF500FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFA800FFA800FFB800
FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFC700FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFD700FFE600FFE600
FFE600FFF500FFF500FFF500FAFF00EBFF00DCFF00CCFF009EFF0000FF0A0019FF00D1FF
00FF2800FF75FF00E6FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF001E0066FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00006100FF5100FF00FF5700FF8500FFE170FF008FFF009EFF00AEFF00AEFF00
AEFF00AEFF00AEFF00AEFF00AEFF00AEFF009EFF008FFF0070FF0042FF0000FF4700FF94
0047FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF1923FF00
FF000061FF0000FF1942FF00CCFF00EBFF00FAFF00FAFF00FAFF00FAFF00DCFF008FFF00
FFD700FFB800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF9900FF9900FF9900FF9900FFA800FF9900FFA800FFA800FFB800FFF500
FFD700FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFC700FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFD700FFE600FFE600
FFE600FFF500FFF500FAFF00FAFF00EBFF00DCFF00CCFF009EFF0000FF5700FF1900B3FF
00FF8500FF85FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFC2
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF000000FF3800A3FF0028FF4200FF8FFF00AEFF00AEFF00BDFF00
BDFF00BDFF00BDFF00AEFF00AEFF00AEFF009EFF008FFF0023FF00FF006BFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000051FF00
80FF009EFF0080FF000066FFEBFF00FAFF00FFF500FFF500FFF500FFF500CCFF00DCFF00
FFC700FFB800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFB800
FFB800FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFC700FFB800FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFD700FFE600FFE600
FFF500FFF500FFF500FAFF00EBFF00EBFF00CCFF00BDFF009EFF0070FF0023FF0000FFB3
EB00FF00C2FFFF00F5FF0000FF0000000AFFFF0000FF0000FF000FDC00FF00C2FF00FF85
FF0000FF00E6FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000DC00FF00FF2800FFA300FF949EFF00AEFF00BDFF00BDFF00
BDFF00BDFF00BDFF00BDFF00BDFF00AEFF00AEFF008FFF0000FF75FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF94FF0000
8FFF00AEFF009EFF00DCFF00FAFF00FFF500FFF500FFE600FFE600FFE600FFF500FFD700
FFC700FFB800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFD700FFE600FFE600
FFF500FFF500FAFF00EBFF00EBFF00DCFF00AEFF008FFF0080FF0033FF0005FF0000FF57
00A3FFFF0000FF000000D1FFFA00FF00FFD1FF00009E00FFFF0000FF006B00FF3800FF28
00FFB3FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
3300FFFF0000FF00B89E00FFFF000070FF0080FF008FFF00AEFF00BDFF00BDFF00BDFF00
BDFF00BDFF00BDFF00BDFF00BDFF00AEFF00AEFF009EFF0000E1FF00E1FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
8FFF00BDFF00DCFF00EBFF00FAFF00FFF500FFE600FFE600FFE600FFD700FFD700FFC700
FFB800FFB800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF9900FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFC700FFC700FFC700FFD700FFD700FFD700FFE600FFE600FFF500
FAFF00FAFF00EBFF00EBFF00DCFF00CCFF00AEFF0000FF4742FF0000F0FF4200FF8000FF
00E1FFFF000000FFB30066FF00FFD100FF470085FFFF002E00F0FF00FF2805FF0000FF19
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
00E1FFFF000000FFFF2300FFFF000080FF009EFF00AEFF00BDFF00BDFF00BDFF00BDFF00
BDFF00BDFF00BDFF00BDFF00BDFF00BDFF00AEFF009EFF008FFF0033FF00FF000000D1FF
FF00992300FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000E1FF00FFC2
80FF00AEFF00DCFF00EBFF00FAFF00FFF500FFE600FFE600FFD700FFD700FFC700FFC700
FFB800FFB800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFD700FFD700FFE600FFE600FFF500
DCFF00EBFF00CCFF00BDFF00BDFF00AEFF0080FF0005FF0000F0FF00FFB300FF2805FF00
FF00990075FFFF000000FF280057FF00FF28FF00001400FFFF000000FF5733FF0005FF00
4200FFFF00000057FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
00FF7500FF5700FF94FF0000FF00008FFF00AEFF00BDFF00BDFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00BDFF00BDFF00BDFF00AEFF009EFF00FF00000085FF00FF85
00FF85FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
05FF0042FF009EFF00EBFF00FAFF00FFF500FFE600FFE600FFD700FFD700FFD700FFC700
FFB800FFB800FFA800FFA800FFA800FFA800FF9900FFA800FF9900FF9900FF9900FF9900
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00
FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FFA800FF9900FFA800FF9900FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFA800FFA800FFB800FFB800FFB800
FFB800FFB800FFC700FFC700FFC700FFC700FFC700FFD700FFE600FFE600FFF500FAFF00
BDFF00AEFF008FFF0000FFC261FF0000FF6600FF7505FF0000FFD151FF0070FF0033FF00
0085FF00FF2800D1FF00FF6633FF0005FF0023FF00CC00FF42FF0042FF0051FF0000FF28
14FF0000FF3800FF7500E1FF9E00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
00FF3800FF2800FF5700FFC270FF009EFF00BDFF00BDFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00BDFF00BDFF00AEFF009EFF0080FF0000A3FFFF0000
00FF57FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000038FFCCFF00FAFF00FFF500FFE600FFE600FFD700FFD700FFC700FFC700
FFB800FFB800FFB800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FFA800FF9900FF9900FF9900FFA800FF9900FFA800FF9900FF9900
FFA800FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFD700FFE600FFF500FAFF00DCFF00
AEFF0005FF0033FF0080FF00BDFF00BDFF0080FF0000FF3800C2FF8FFF009EFF000038FF
00FFF000FF2800FFA300FF9442FF0070FF0061FF0051FF0070FF0080FF0070FF0061FF00
33FF0000FF2800FFD1AE00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000EB00FF
00FF1900FF190038FF00F0FF80FF009EFF00BDFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00BDFF00BDFF00AEFF009EFF0080FF0042FF0000FF0A
00FF6600E1FFFF003DFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000066FF00E1FF70FF00FAFF00FFF500FFE600FFE600FFD700FFD700FFC700FFC700
FFB800FFB800FFB800FFB800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FF9900FF9900
FF9900FF9900FF9900FFA800FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFC700FFC700FFD700FFD700FAFF0051FF00DCFF009EFF00
8FFF0033FF0000FF94CCFF00DCFF00DCFF00DCFF00CCFF0070FF00BDFF00BDFF0080FF00
9EFF0070FF0005FF0000E1FF05FF0080FF0080FF0000FF288FFF008FFF0080FF0051FF00
14FF0000FF38FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00005100FF
00FF0A14FF0000FFB300FF19FF0000AEFF00BDFF00CCFF00CCFF00DCFF00DCFF00DCFF00
DCFF00CCFF00DCFF00CCFF00CCFF00CCFF00BDFF00AEFF008FFF0000FF3800FFE10019FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
00D1FFFF000000FF8500FFC2EBFF00FFF500FFE600FFE600FFD700FFD700FFC700FFC700
FFC700FFB800FFB800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900
FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800
FFB800FFB800FFB800FFB800FFC700FFC700FFD700FFD700FFF500EBFF0005FF0061FF00
00FF758FFF00BDFF00DCFF00EBFF00EBFF00EBFF00EBFF00AEFF00DCFF00DCFF00CCFF00
BDFF0061FF0000FF6600FFA31400FF9EFF009EFF008FFF009EFF009EFF0080FF000019FF
00FFC2FF000000FFF0FF003DFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF005C
00FFC251FF00FF00008000FF00FF38AEFF00CCFF00CCFF00DCFF00DCFF00DCFF00DCFF00
DCFF00DCFF00DCFF00DCFF00CCFF00CCFF00BDFF00AEFF0005FF000075FFFF00008F00FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFD1
CC00FFFF000070FF0000FF0AEBFF00FFF500FFE600FFE600FFE600FFD700FFC700FFC700
FFC700FFB800FFB800FFB800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FFA800FF9900FF9900FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800
FFB800FFB800FFB800FFB800FFC700FFC700FFD700FFE600FFE600FAFF00AEFF0070FF00
05FF0070FF00DCFF00EBFF00FAFF00FAFF00FAFF00FAFF00EBFF00EBFF00EBFF00DCFF00
CCFF009EFF0000FFA361FF0051FF00AEFF00BDFF00BDFF00BDFF00AEFF008FFF0070FF00
0075FF00B3FF0057FFFF0000FF0000FF00000057FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF009900B3FFFF0000FF0000FF0000BD00FF
9E00FF80FF008FFF0000FF948FFF00BDFF00CCFF00CCFF00DCFF00DCFF00DCFF00DCFF00
DCFF00DCFF00DCFF00DCFF00DCFF00CCFF00CCFF00AEFF00FF007A00FF47FF0000DC00FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF57
51FF0070FF00AEFF0042FF00EBFF00FFF500FFF500FFE600FFE600FFD700FFD700FFC700
FFC700FFC700FFB800FFB800FFA800FFA800FFA800FFA800FFA800FF9900FF9900FF9900
FF9900FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF8A00FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFB800FFB800FFB800FFC700FFC700FFC700FFD700FFD700FFF500EBFF00BDFF0000FF57
AEFF009EFF00EBFF00FAFF00FFF500FFF500FAFF00FFF500FAFF00FAFF00FAFF00EBFF00
CCFF0042FF0080FF00AEFF0070FF00CCFF00CCFF00CCFF00BDFF00AEFF009EFF0080FF00
33FF00FF0000FF0000FF000000A3FFFF000000FF94FF00007000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF005C00FFC20028FFFF000000FFFFFF0000
00FFFF80FF00AEFF00BDFF00CCFF00CCFF00DCFF00DCFF00DCFF00DCFF00DCFF00DCFF00
DCFF00DCFF00DCFF00DCFF00DCFF00CCFF00CCFF00BDFF009EFF0080FF00FF0000FF0000
00A3FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
00FF668FFF00BDFF00CCFF00EBFF00FAFF00FFF500FFF500FFE600FFE600FFD700FFD700
FFC700FFC700FFC700FFB800FFB800FFA800FFA800FFA800FF9900FF9900FF9900FF9900
FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FF9900FF9900
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFB800FFB800FFB800FFB800FFC700FFC700FFD700FFE600FFF500BDFF009EFF008FFF00
DCFF00AEFF00FAFF00FFF500FFF500FFF500FFF500FFF500FFF500FFF500FAFF00EBFF00
BDFF00BD00FFBDFF00DCFF00DCFF00DCFF00DCFF00CCFF00CCFF00BDFF009EFF0070FF00
00FFF0FF0000FF00F5FF0000FF000000FF6600FF3800FFB3FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000038FFFF000000FF4700FF4700FF388000FFFF0099
00FF479EFF00BDFF00CCFF00CCFF00DCFF00DCFF00DCFF00DCFF00DCFF00EBFF00EBFF00
EBFF00DCFF00DCFF00DCFF00DCFF00DCFF00CCFF00CCFF00BDFF009EFF0000FF85FF0000
00FFB3FF000000B3FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF000080FF00BDFF00CCFF00DCFF00EBFF00EBFF00FAFF00FFF500FFE600FFE600FFD700
FFD700FFD700FFC700FFC700FFC700FFB800FFA800FFA800FFA800FF9900FFA800FF9900
FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900
FF9900FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800
FFB800FFB800FFB800FFB800FFC700FFC700FFD700FFE600FAFF00BDFF0000FF668FFF00
EBFF00FAFF00FFF500FFF500FFE600FFE600FFE600FFE600FFF500FFF500FFF500FAFF00
AEFF0070FF00DCFF00EBFF00EBFF00DCFF00DCFF00DCFF00CCFF00AEFF0042FF0000FF85
FF000F00FF0A0094FFFF000000FFE123FF0000FF19FF0000CC00FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000047FF00FFD1FA00FF05FF0005FF0000FF0A00FF3800A3FF
70FF00AEFF00BDFF00CCFF00DCFF00DCFF00DCFF00EBFF00EBFF00EBFF00EBFF00EBFF00
EBFF00EBFF00DCFF00DCFF00DCFF00DCFF00CCFF00CCFF00BDFF00AEFF00FF0000FF0000
00FF4700FF4700FFB3FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0500FFFF0000AEFF00BDFF00CCFF00AEFF0051FF0005FF00DCFF00FAFF00FFF500FFF500
FAFF00FFE600FFE600FFD700FFC700FFB800FFB800FFA800FFA800FFA800FF9900FF9900
FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900
FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFB800FFB800FFB800FFB800FFC700FFD700DCFF008FFF0080FF008FFF0023FF00
FAFF00FFF500FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF500FFF500FAFF00
BDFF0061FF00EBFF00EBFF00EBFF00EBFF00EBFF00DCFF00CCFF008FFF009E00FF8FFF00
80FF0080FF0042FF00FF00F542FF0051FF0023FF0000A3FFFF00003300FF00E1FFFF00E6
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF000000FF85FF000023FF0014FF0000FF0A00FF3800E1FF
9EFF00BDFF00CCFF00DCFF00DCFF00EBFF00EBFF00EBFF00EBFF00EBFF00EBFF00EBFF00
EBFF00EBFF00EBFF00DCFF00DCFF00DCFF00DCFF00CCFF00BDFF00AEFF0080FF00FF0000
00FF4700FF19FA00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000AE00FF
42FF0070FF008FFF000038FF80FF0000FF47FF00003300FF00FF5780FF00FAFF00DCFF00
33FF00DCFF00FAFF00AEFF00FFE600FFC700FFB800FFB800FFA800FFA800FF9900FF9900
FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FFA800FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFB800FFB800FFB800FFB800FFB800FFC700FFE60061FF00FAFF00FFF500FFF50070FF00
FFF500FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF500
EBFF00FAFF00FAFF00FAFF00FAFF00FAFF00EBFF00EBFF00CCFF0061FF0042FF009EFF00
AEFF009EFF00DC00FF70FF0070FF0061FF0023FF00FF00A8FF003D00FFF000FFE1FF0099
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF000014FF0033FF0023FF00FF002E00FF7542FF00
AEFF00CCFF00DCFF00DCFF00EBFF00EBFF00EBFF00EBFF00EBFF00EBFF00EBFF00EBFF00
EBFF00EBFF00EBFF00EBFF00EBFF00DCFF00DCFF00CCFF00CCFF00AEFF009EFF0051FF00
05FF0005FF0000FF4700E1FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
00FFC261FF005100FFFF000023FF00FF00000057FFFF00006100FFBDFF00DCFF00BDFF00
61FF00CCFF00AEFF00CCFF00FFF500EBFF00FFD700FFB800FFA800FFA800FFA800FF9900
FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFB800FFB800FFB800FFC700FFE600FFE600FFE600FFD700FFE600FFE600
FFE600FFE600FFD700FFD700FFD700FFD700FFD700FFD700FFE600FFE600FFE600FFE600
FFF500FFF500FFF500FAFF00FAFF00FAFF00FAFF00EBFF00CCFF0000FFE1AEFF00BDFF00
BDFF00AEFF0070FF008FFF008FFF0070FF0005FF0023FF00FF000000FFD100FF38FF0000
0038FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000057FF00FF6651FF0042FF0000FF85000AFF51FF00
42FF00BDFF00DCFF00DCFF00EBFF00EBFF00EBFF00EBFF00EBFF00FAFF00EBFF00EBFF00
EBFF00EBFF00EBFF00EBFF00EBFF00DCFF00DCFF00CCFF00CCFF00AEFF008FFF0061FF00
33FF0000FF0AFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
05FF00FF0000FF00000066FFFF0000FF000000FF2800D1FF70FF00AEFF00BDFF00AEFF00
23FF0033FF0080FF0000E1FFDCFF0000FFA380FF00FFC700FFB800FFA800FFA800FF9900
FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFD700FFD700FFD700FFD700
FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFE600FFE600FFE600FFE600
FFE600FFF500FFF500FFF500FFF500FAFF00FAFF00EBFF00DCFF00CCFF00CCFF00CCFF00
CCFF00BDFF00AEFF00AEFF009EFF0061FF0061FF0061FF0033FF0033FF0000FF3800FF66
00FF75FF0000FF0099FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0085FFFF0000FF0000FF0000FF0000FA00FFFF000061FF0070FF0000D1FF00FF191400FF
00FF47BDFF00DCFF00EBFF00EBFF00EBFF00EBFF00FAFF00FAFF00FAFF00EBFF00FAFF00
FAFF00EBFF00EBFF00EBFF00EBFF00EBFF00DCFF00CCFF00BDFF009EFF0000FFC2FA00FF
00FFFF00D1FFFF00D7FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0094FFFF0000FF0000FF0000FF0000FF000000FFD105FF0070FF0061FF0051FF0080FF00
51FF0000FFFF33FF0080FF0000FFD1CCFF00FFF500FFC700FFB800FFA800FFA800FF9900
FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FFA800FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFC700FFC700
FFD700FFC700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFE600FFE600
FFE600FFE600FFE600FFF500FFF500FFF500FAFF00FAFF00EBFF00EBFF00DCFF00DCFF00
CCFF00CCFF00BDFF00AEFF00AEFF009EFF0080FF0070FF0061FF0042FF0023FF0005FF00
00FFB30085FF00B3FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00996100FF
FF0000FF0000FF0000FF0000FF0000FF0000FF00C7FF00008FFF0080FF000047FF0085FF
00FF75CCFF00DCFF00EBFF00EBFF00EBFF00FAFF00FAFF00FAFF00FAFF00FAFF00FAFF00
FAFF00FAFF00FAFF00EBFF00EBFF00EBFF00DCFF00CCFF00BDFF000094FF6100FF9E00FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000D1FF
FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFC205FF008000FF00FF6651FF00
00FF8500FF2800FFC200FF3880FF00DCFF00FFF500FFE600FFC700FFB800FFB800FFA800
FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFD700FFD700FFD700FFD700FFE600
FFE600FFE600FFE600FFE600FFF500FFF500FFF500FAFF00FAFF00EBFF00EBFF00DCFF00
DCFF00CCFF00BDFF00BDFF00AEFF009EFF008FFF0080FF0061FF0042FF0033FF0005FF00
00FF2800FF5700FF9400FFF00028FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFD1
00FF85FF006BFF000000C2FF00FFF0FF0000CC00FF00FFC2AEFF00BDFF00AEFF00BDFF00
AEFF00DCFF00EBFF00EBFF00FAFF00FAFF00FAFF00FAFF00FAFF00FAFF00FAFF00FAFF00
FAFF00FAFF00FAFF00FAFF00EBFF00EBFF00DCFF00DCFF008FFF0000FF0A000AFFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000000AFF
FF0000FF0000FF0000FF0000FF0000FF0000FF00000094FFFF0000FF000000FF4700F0FF
00FF570094FF9E00FF14FF008FFF00BDFF00DCFF00AEFF00DCFF00FFB800FFA800FFA800
FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00
FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFD700FFE600FFD700
FFE600FFE600FFE600FFE600FFF500FFF500FFF500FAFF00FAFF00FAFF00EBFF00EBFF00
DCFF00CCFF00CCFF00BDFF00AEFF009EFF008FFF0070FF0023FF0033FF0023FF0000B3FF
00FF4700FFA300FFC200E1FF0038FF2300FFFF00D7FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000085FFFF000000FFB3
FF000000FF5700FF3800FF6600FFC2FF0000FF00006100FFBDFF00CCFF00DCFF00DCFF00
DCFF00EBFF00EBFF00EBFF00FAFF00FAFF00FAFF00FAFF00FAFF00FAFF00FAFF00FAFF00
FAFF00FAFF00FAFF00FAFF00EBFF00EBFF00EBFF00CCFF00FF000000FF5700FFC2FF00F5
FF0000FF0000FF00F5FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00E6FF00A8
00FFA305FF000028FF00FF4700FFD100FF0A7000FFAEFF00CCFF00FFC700FFB800FFA800
FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00
FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFC700FFC700FFC700FFC700FFC700FFC700FFD700FFC700FFD700FFD700FFD700FFD700
FFD700FFE600FFE600FFE600FFE600FFF500FFF500FFF500FAFF00FAFF00EBFF00EBFF00
DCFF00DCFF00BDFF00AEFF009EFF008FFF0080FF0070FF0000FF3800C2FF00FF0A00FF38
00E1FFFF007AFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000BD00FF00FFE1FF000005FF00
14FF0014FF0014FF0000A3FF0085FF00FFF000FF0A9EFF00CCFF00DCFF00EBFF00EBFF00
EBFF00FAFF00FAFF00FAFF00FAFF00FAFF00FAFF00FAFF00FAFF00FAFF00FAFF00FAFF00
FAFF00FAFF00FAFF00FAFF00FAFF00EBFF00EBFF00DCFF00CCFF00AEFF008FFF00EB00FF
FF000000FFF0000AFFFF0000FF00000047FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00007000FF00FF38
00FF0A33FF00000AFF70FF009EFF008FFF00DCFF00FAFF00DCFF00FFE600FFB800FFA800
FFA800FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FFA800FF9900FF9900FF9900FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFC700FFB800
FFB800FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFD700
FFD700FFD700FFE600FFE600FFE600FFF500FFF500FFF500FAFF00FAFF00EBFF00EBFF00
DCFF00CCFF00BDFF0051FF0061FF0070FF0080FF0061FF0042FF000085FF00FF7500FFE1
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF000000D1FF00FFB300FF66EB00FF33FF00
42FF0042FF0033FF0014FF0000FF5700FFC20066FF0047FFDCFF00EBFF00EBFF00EBFF00
FAFF00FAFF00FAFF00FAFF00FAFF00FFF500FAFF00FFF500FFF500FFF500FFF500FAFF00
FAFF00FAFF00FAFF00FAFF00FAFF00FAFF00EBFF00EBFF00DCFF00CCFF00AEFF0000FF47
FF0000FF00F5FF00B8FF000000FFF0FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFC223FF00
70FF0061FF0005FF009E00FFBDFF00DCFF00FAFF00FFF500FFF500FFC700FFB800FFA800
FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00
FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFC700FFB800FFC700FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFD700
FFD700FFD700FFE600FFE600FFF500FFF500FFF500FFF500FAFF00FAFF00EBFF00EBFF00
DCFF00CCFF0000FF4700FF380028FF00FF3861FF0051FF0023FF0000FFA3FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000A3FF00FF19FF007A51FF00
51FF0051FF0033FF0014FF000057FF00FFE1AEFF00CCFF00DCFF00EBFF00EBFF00FAFF00
FAFF00FAFF00FAFF00FFF500FFF500FFF500FFF500FFF500FFF500FFF500FFF500FAFF00
FFF500FAFF00FAFF00FAFF00FAFF00FAFF00EBFF00EBFF00DCFF00DCFF00BDFF0000C2FF
7000FF00FF3800FF1900FF0A00FF47FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000057FF0066FF0047FF00FF19
8FFF0014FF0000FFB35100FF9EFF00EBFF00FFF500FFE600FFD700FFC700FFB800FFA800
FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFD700FFD700
FFD700FFE600FFE600FFE600FFE600FFF500FFF500FFF500FAFF00FAFF00EBFF00EBFF00
DCFF00CCFF00BDFF0080FF0070FF0000FFC205FF0014FF0000FF0A00FFFF0057FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF2851FF0061FF00
61FF0051FF0023FF0005FF0000FF5761FF00BDFF00DCFF00EBFF00EBFF00FAFF00FAFF00
FAFF00FFF500FFF500FFF500FFF500FFF500FFF500FFF500FFF500FFF500FFF500FFF500
FFF500FFF500FAFF00FAFF00FAFF00FAFF00FAFF00EBFF00EBFF00DCFF00BDFF0000FF66
5100FF00FF2814FF0014FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFB305FF005100FF42FF00
9EFF009EFF000094FF00FF5700FF75BDFF00FFF500FFE600FFD700FFB800FFB800FFA800
FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FF9900FF9900FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800
FFB800FFB800FFC700FFB800FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFD700
FFD700FFD700FFE600FFE600FFE600FFF500FFF500FAFF00FAFF00FAFF00EBFF00EBFF00
DCFF00CCFF00BDFF00AEFF008FFF002300FF00FFC200FF380075FFBD00FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF005CFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000038FFFF0000FF0000FF0000FF0000FF0000000AFF00FF9451FF0070FF00
70FF0051FF0000FFB3FF0000FF00009EFF00CCFF00DCFF00EBFF00EBFF00FAFF00FAFF00
FFF500FFF500FFF500FFF500FFF500FFF500FFF500FFF500FFF500FFF500FFF500FFF500
FFF500FFF500FFF500FAFF00FAFF00FAFF00FAFF00EBFF00EBFF00DCFF00CCFF00AEFF00
FF00D700FF6623FF0033FF0005FF008000FF0066FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00E642FF0000FFD1AEFF00
BDFF00BDFF00AEFF0080FF000085FFAEFF00FAFF00FFE600FFD700FFC700FFB800FFA800
FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFD700
FFD700FFD700FFD700FFE600FFE600FFF500FFF500FAFF00FAFF00EBFF00EBFF00DCFF00
CCFF00CCFF00BDFF00AEFF009EFF0061FF0000FFF0FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00001400FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF000000FFE100D1FFFF0000FF0000FF0000FF0000FF000000FFE100FF6600FF1980FF00
8FFF0051FF0000FF380028FF51FF008FFF00BDFF00DCFF00EBFF00FAFF00FAFF00FFF500
FFF500FFF500FFF500FFF500FFF500FFF500FFF500FFF500FFF500FFF500FFF500FFF500
FFF500FFF500FFF500FAFF00FAFF00FAFF00FAFF00EBFF00EBFF00DCFF00CCFF00BDFF00
9EFF0061FF0051FF0042FF0014FF0000E1FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000094FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00E600FFC270FF009EFF00BDFF00
CCFF00CCFF00AEFF0080FF00FF000005FF0000FF75EBFF00FFE600FFC700FFB800FFA800
FFA800FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800
FFB800FFB800FFB800FFC700FFB800FFB800FFC700FFC700FFC700FFC700FFC700FFD700
FFD700FFD700FFD700FFE600FFF500FFF500FAFF00FAFF00EBFF00EBFF00DCFF00DCFF00
CCFF00CCFF00BDFF00AEFF0080FF0023FF0000FF75BD00FF00B3FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000066FF0094FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000C2FF
FF000000FF75FF0000FF00C7FF0000FF0000FF0000FF0000FF004C00FF3851FF008FFF00
9EFF0080FF000066FF23FF0051FF0000FF8514FF00DCFF00EBFF00FAFF00FFF500FFF500
FFF500FFF500FFF500FFF500FFF500FFF500FFF500FFF500FFF500FFF500FFF500FFF500
FFF500FFF500FFF500FFF500FAFF00FAFF00FAFF00FAFF00EBFF00DCFF00CCFF00BDFF00
9EFF0080FF0061FF0033FF00EB00FF00FF9400FFFFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000D1FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000005FF000500FF61FF00CCFF00
DCFF00DCFF00AEFF003300FF00FFC200C2FFAEFF00AEFF00AEFF00FFE600FFB800FFA800
FFA800FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00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FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00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FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFD700
FFD700FFD700FFE600FFE600FFF500DCFF009EFF0000FF66EB00FF00FF0A05FF009EFF00
9EFF008FFF0000FFA380FF0070FF0000FF7505FF0000D1FF00F0FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF000000FF5700FF6600FF9400FFC2FF0000FF0000FF00B8FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF004C1400FF0094FF00FFE18F00FF00FF66FF00006100FF0094FF
33FF001400FF00FF2800FF0AFF000000FF1900FF5700A3FFFF00E60075FF000AFFBDFF00
DCFF00DCFF00DCFF00AEFF00CCFF00BDFF0014FF00FAFF00FFF500FFF500FFF500FFF500
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF500
FFE600FFF500FFF500FFF500FFF500FAFF00FAFF00FAFF00EBFF00CCFF0000FFB3FF0000
FF0000FF002E00D1FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
23FF0051FF0051FF0000FF388000FF0085FF51FF0014FF0000FFFFBD00FF51FF00FAFF00
FFF500FFF500FFF500FAFF00FAFF00EBFF00DCFF00AEFF0000FF19FAFF00FFD700FFA800
FFA800FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FF9900FF9900FF9900FF9900
FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800
FFB800FFB800FFB800FFB800FFB800FFC700FFB800FFB800FFC700FFC700FFC700FFC700
FFD700FFD700FFE600FFF500FAFF00DCFF0023FF0023FF0000FF5761FF008FFF0051FF00
00FF4751FF0000FF7551FF0051FF0000FF0A00FFA30038FFFF003DFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF000000FFE100FF3800FF2800FF1900FFD1FF0000FF0000FF00000019FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF000000FF7500FFB300FF1900FF38FF000000FF75
61FF0023FF0005FF0051FF0033FF0000FFC200FF660085FF00FF75FF000033FF00BDFF00
DCFF00EBFF00EBFF00EBFF00FAFF00EBFF00EBFF00FAFF00FFF500FFF500FFF500FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFF500FFF500FFF500FFF500FFF500FAFF00EBFF00EBFF00BDFF0014FF00FF0000
FF0099FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF000070FF0070FF000047FFFF00009EFF0070FF0000FFD100B3FF00FF19EBFF00FFF500
FFF500FFF500FFF500FFF500FFF500FAFF00EBFF0023FF00EBFF00FFE600FFC700FFA800
FFA800FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFA800FFA800
FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFC700
FFD700FFD700FFE600FAFF00EBFF0080FF0023FF0061FF0061FF00BDFF00BDFF0061FF00
00FFA3FF000000D1FF00FF4723FF0000FF38FF00C7FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF000000FF2814FF0005FF0000FF660094FFFF000000FF75FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00008F00FF00FFB300FF0A14FF000094FF23FF0070FF00
70FF0070FF0070FF0061FF0051FF0000FFB30057FFFF000014FF0014FF0042FF00CCFF00
EBFF00EBFF00FAFF00FAFF00FAFF00FFF500FFF500FFF500FFF500FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFF500FFF500FFF500FFF500FAFF00FAFF00DCFF0000FF4700E1FF0057FF
FF0000FF00000500FF4200FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00007000FF
00FF1980FF009EFF00AEFF00BDFF00BDFF0080FF00BD00FFAEFF00DCFF00FFF500FFF500
FFE600FFE600FFE600FFE600FFE600FFF500FAFF00BDFF00BDFF00FFE600FFB800FFA800
FFA800FFA800FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800
FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFC700
FFD700FFD700FFF50080FF0061FF0000FF579EFF00AEFF00CCFF00DCFF00CCFF00BDFF00
51FF0000FF1900FFD100FF3800FF0A00D1FFFF00D7FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF000000FFF000FF8523FF0023FF000038FF23FF0005FF0000FF66FF004C
FF0000FF000000FFD1FF000000A3FF0028FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF008AFF00000028FF0047FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF9433FF000075FFDC00FF80FF00
8FFF0080FF0080FF0070FF0061FF0033FF0000FFE1FF005C42FF0023FF009EFF00DCFF00
FAFF00FAFF00FFF500FFF500FFF500FFF500FFF500FFF500FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFF500FFF500FFF500FAFF00DCFF008FFF0005FF0051FF00
FF008AFF00D7FF000000E1FFFF0000FF002EFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF000061FF00AEFF00BDFF00CCFF00CCFF00AEFF0000FF19DCFF00FFF500FFF500FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFF500EBFF0080FF00CCFF00FFB800FFA800
FFA800FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFD700
FFD700FFD700FFE600FAFF00EBFF00BDFF00CCFF00DCFF00EBFF00EBFF00DCFF00CCFF00
80FF0080FF0005FF000047FF00F0FF0038FF0038FF1400FFFF003DFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF000000FFFF33FF0051FF0033FF0042FF0000FF28FF0000FF00C7
FF005C0066FF00FF5700FF6600D1FFFF0000FF0000FF0000FF00009E00FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000CC00FFFF000000FFC20066FFFF0000
FF0000FF0000FF0000FF0000FF0000FF00006100FFFF000051FF0061FF0070FF008FFF00
8FFF008FFF008FFF0080FF0061FF0042FF0005FF0000B3FF51FF008FFF0061FF00EBFF00
FAFF00FFF500FFF500FFF500FFF500FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFF500FFF500FFF500FFF500FAFF00EBFF00DCFF00AEFF00AEFF00
00FF5700FFF0FF000000FF9400FF94FF004CFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
4200FFFF00B8AEFF00CCFF00DCFF00DCFF0000FF19CCFF00FAFF00FFF500FFE600FFE600
FFD700FFD700FFD700FFD700FFD700FFE600FFF500EBFF00DCFF00FFF500FFB800FFA800
FFA800FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF7A00FF7A00FF7A00
FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF8A00
FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFC700
FFD700FFD700FFE600FFE600FFF500DCFF00FAFF00FAFF00FAFF00EBFF00EBFF00DCFF00
CCFF009EFF0070FF0000FF2800F0FF0094FF00FF470094FF00B3FF0028FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000028FFEB00FF00FF2842FF0061FF0061FF0061FF0042FF0000FF850066FF
7000FFFF000000FF0A00FF284200FFFF0000FF0000FF0000FF0000FF000000E1FFFF0000
0066FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00F500FFD13300FFFF000000FF4700FF85FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00007000FF51FF0080FF009EFF009EFF00
9EFF009EFF008FFF0070FF0061FF0042FF0000FF1900FFFF0066FFCCFF00DCFF00FAFF00
FFF500FFF500FFF500FFF500FFE600FFF500FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFD700FFD700FFD700FFE600FFD700FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFF500FFF500FFF500FFF500FAFF00EBFF00DCFF00CCFF00
FF002E05FF006100FF00FFE100FF28FF0000FF000000FFC200FF75FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0028FFFF0000AEFF00CCFF00DCFF00EBFF00EBFF00FAFF00FFF500FFE600FFE600FFD700
FFD700FFD700FFD700FFD700FFD700FFE600FFF500CCFF00BDFF00FFC700FFB800FFA800
FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700
FFC700FFD700FFD700FFE600FFE600FFF500FFF500FFF500FAFF00FAFF00EBFF00EBFF00
DCFF00BDFF008FFF0042FF0000FF4700D1FF00FF0A00FF2800FF6600B3FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000038FF00FF3833FF0070FF0080FF0061FF0000FF28FF000033FF00
00B3FF00FF3833FF0000FF38FF00E6FF0000FF0000FF0000FF00006100FF00FF8500FF75
00FFFFFF0000FF000000FFFFFF002EFF0000FF00000075FFFF00002300FFFF0000FF0000
FF0000FF0000FF0000FF00008F00FF0047FF0066FFFF0000FF000000C2FFFF00007000FF
00FFC2FF0099FF0000FF0000FF000000FF5700FFD100FF1900FF2800FFD1FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF000000C2FF00E1FF00A3FF8FFF00AEFF00AEFF00
AEFF009EFF008FFF0000FF1933FF0033FF0000FF3861FF008FFF00EBFF00FAFF00FAFF00
FFF500FFF500FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD700FFE600FFD700
FFD700FFD700FFD700FFD700FFD700FFD700FFE600FFD700FFD700FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFF500FFF500FFF500FAFF00FAFF00EBFF00DCFF00
BDFF0051FF00FF000000FF7514FF00FF000014FF0000FF1900FF4700E1FFFF00A8FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF000000FF0AAEFF00CCFF00EBFF00FAFF00FAFF00FFF500FFE600FFE600FFD700FFD700
FFD700FFD700FFD700FFC700FFC700FFD700FFE600DCFF00FFC700FFB800FFA800FFA800
FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FFA800FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700
FFC700FFD700FFD700FFD700FFE600FFE600FFF500FFF500FFF500FAFF00FAFF00EBFF00
DCFF00BDFF008FFF000047FF00FF9405FF0033FF0014FF0000FF47FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF000000FFD133FF0061FF0080FF008FFF0070FF000028FF61FF0070FF00
70FF0061FF0051FF0023FF0000FF6600B3FFFF0000FF0000FF0000FF0000FF000000FF47
EB00FFFF0000FF000000FF75FF00000066FF00FFB300FFB3FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF000000FFE100FFA300FFF000FFC2FF0000CC00FF
00FF5700FFD15100FFFF000000A3FFFF003D00FFE123FF0005FF0000FF28FF0000FF0000
FF0000FF0000FF0000FF0000FF0000000AFF00FF8500FF5733FF008FFF00AEFF00BDFF00
BDFF00AEFF0080FF0000FFE100FF6605FF0000FFD1AEFF00DCFF00EBFF00FAFF00FFF500
FFF500FFF500FFE600FFE600FFE600FFE600FFE600FFE600FFD700FFD700FFE600FFD700
FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFF500FFF500FAFF00FAFF00FAFF00EBFF00
BDFF000019FFFF00E6FF000033FF0042FF0042FF0014FF008F00FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
23FF0080FF00AEFF00DCFF00EBFF00FAFF00FFF500FFF500FFE600FFE600FFE600FFD700
FFD700FFD700FFC700FFC700FFC700FFC700FFC700FFC700FFB800FFB800FFA800FFA800
FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800
FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFB800
FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700
FFC700FFC700FFD700FFD700FFE600FFE600FFE600FFF500FFF500FFF500FAFF00EBFF00
DCFF0051FF0000FF1900FFB333FF0051FF0051FF00AE00FF0094FF00A3FF00D1FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF002E3300FF0085FF00FF0A80FF008FFF009EFF008FFF00FF000080FF008FFF00
8FFF0070FF0042FF0000FF0A00FF9400FFD1FF0000FF000000E1FFFF000005FF0000FF38
00FF38FF0000FF001E00FF1900FF3800FF1900FF5700FFB3FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF5700FF2800FF47FF000005FF00
00FF28FF0000FF0000FF00000028FF00FFA342FF0042FF0023FF0000FF0A00FF660047FF
FF0000FF0000FF0000FF0000FF0000FF000000FF3814FF0000FF2800FFE1BDFF00CCFF00
BDFF00BDFF007000FF00FFD100E1FF00FFA361FF00BDFF00DCFF00EBFF00FAFF00FFF500
FFF500FFE600FFE600FFE600FFE600FFE600FFD700FFD700FFD700FFD700FFD700FFD700
FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFE600FFD700FFD700FFD700
FFD700FFE600FFE600FFE600FFE600FFE600FFF500FFF500FFF500FAFF00FAFF00EBFF00
9EFF0070FF0000C2FF00FF0A33FF0051FF0051FF0000FF38FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00C700FF47
33FF0080FF008FFF009EFF00EBFF00FAFF00FFF500FFE600FFE600FFD700FFD700FFD700
FFC700FFC700FFC700FFC700FFC700FFC700FFB800FFB800FFB800FFB800FFA800FFA800
FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700
FFC700FFD700FFD700FFD700FFD700FFE600FFE600FFE600FFF500FFF500FAFF00FAFF00
BDFF0070FF00AEFF0033FF008FFF0080FF0070FF0042FF0005FF0000FF85EB00FF0085FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
1400FF00FFB3FF00A80094FF00D1FF00F0FF9EFF00AEFF00AEFF0070FF009EFF009EFF00
9EFF0070FF0014FF0000E1FFFF000000C2FFFF00000047FF00FFB300FF2823FF0033FF00
00FF3800FF0A14FF0033FF0023FF0005FF0000FF7500F0FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF001E00FF8505FF000075FF14FF0033FF00
00FFB30028FF00FFF0DC00FF00E1FF51FF0061FF0051FF0014FF0000FF1900FFB30047FF
0019FF9E00FF0047FFFF0000FF00000075FFFF000023FF0070FF00AEFF00CCFF00CCFF00
CCFF00BDFF0070FF000094FF51FF0080FF009EFF00BDFF00DCFF00EBFF00FAFF00FFF500
FFE600FFE600FFE600FFE600FFE600FFD700FFD700FFD700FFD700FFD700FFD700FFD700
FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFE600FFD700
FFD700FFE600FFE600FFE600FFE600FFE600FFE600FFF500FFF500FFF500FAFF00EBFF00
DCFF00CCFF0000FFE1FF00E600F0FF70FF0061FF0051FF00FF00009E00FF00F0FFFF006B
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000DC00FF00FFF09E00FFCCFF00FAFF00FFF500FFE600FFE600FFD700FFD700FFC700
FFC700FFC700FFC700FFC700FFB800FFB800FFB800FFB800FFA800FFA800FFA800FF9900
FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFC700
FFC700FFC700FFD700FFD700FFD700FFE600FFE600FFE600FFF500FFF500FFF500FAFF00
EBFF00DCFF00CCFF00BDFF00AEFF009EFF0080FF0061FF0033FF0000FF1900FF750085FF
BD00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
00FFF000FF5700B3FF00FFFF51FF008FFF00AEFF00AEFF00BDFF00AEFF00AEFF00AEFF00
9EFF008FFF0070FF0000FF2800FF940075FFFF0000FF004CFF000000C2FF51FF0051FF00
14FF0061FF0061FF0051FF0023FF0005FF0000FF47FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00009E00FF00FF8514FF0033FF0042FF0051FF00
42FF0000FF19FF004C00FF4723FF0080FF0080FF0042FF0000FF387000FF00D1FFFF0000
8000FF00FF75DC00FFFF004CFF0000FF00B800FF7500C2FFFF0000AEFF00CCFF00DCFF00
DCFF00CCFF008FFF0000FF6651FF0080FF008FFF0080FF008FFF00EBFF00FFF500FFF500
FFE600FFE600FFE600FFE600FFD700FFD700FFE600FFD700FFD700FFD700FFD700FFD700
FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700
FFE600FFD700FFE600FFE600FFE600FFE600FFE600FFF500FFF500FFF500FAFF00FAFF00
EBFF00DCFF00BDFF0000FF6680FF0080FF0070FF0061FF0014FF0000FF66FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF000000FF8500FF4700FFFF00F0FFDCFF00FFF500FFE600FFD700FFD700FFD700FFC700
FFC700FFC700FFC700FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800FF9900
FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF9900FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700
FFC700FFC700FFD700FFD700FFD700FFD700FFE600FFE600FFF500FFF500FFF500FAFF00
EBFF00EBFF00DCFF00CCFF00BDFF009EFF0080FF0051FF0023FF0000FF0ABD00FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000DC00FFFF0000FF0000
FF000000FF1900FF0A00FF0A42FF009EFF00AEFF00BDFF00BDFF00BDFF00BDFF00BDFF00
AEFF009EFF0080FF0042FF0000D1FFCC00FFFF001EFF000000FF1900FFE180FF0080FF00
8000FF80FF0070FF0061FF000057FF00FF3800FF850057FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0A51FF0061FF0061FF00
51FF0005FF0000FFA361FF0070FF008FFF008FFF0033FF0023FF0051FF0042FF00FF0000
00FF2805FF0000FF2800FF6600FFD1FF00A8FF00000047FF23FF0000FF38DCFF00EBFF00
EBFF00DCFF00BDFF0033FF0000FF9451FF0005FF00CC00FF00FF94CCFF00FFF500FFF500
FFE600FFE600FFE600FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700
FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700
FFD700FFD700FFE600FFE600FFE600FFE600FFE600FFE600FFF500FFF500FAFF00FAFF00
EBFF00DCFF00CCFF00BDFF009EFF008FFF0080FF0051FF0023FF0000FF1900FF6600B3FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF000000FFFFFF000000D1FF00FF19FAFF00FFE600FFD700FFD700FFD700FFC700
FFC700FFC700FFB800FFC700FFB800FFB800FFA800FFA800FFA800FFA800FFA800FF9900
FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700
FFC700FFC700FFD700FFD700FFD700FFE600FFE600FFE600FFE600FFF500FFF500FAFF00
FAFF00EBFF00DCFF00CCFF00AEFF0070FF0000FF5733FF0000FF1900FF2800FFC2FF00D7
FF0000FF0000FF0000FF00006100FFAE00FFFF00F5FF0000000AFF0094FFFF0000FF0000
0075FF05FF0042FF0061FF0051FF0080FF00BDFF00CCFF00CCFF00CCFF00CCFF00BDFF00
AEFF009EFF0080FF0000FFE15100FF00FF1900FF9400FF7561FF0051FF008FFF009EFF00
8FFF008FFF0080FF0061FF0005FF00FF00000066FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF002E00FFF051FF0080FF0080FF00
33FF0014FF0070FF008FFF009EFF00AEFF009EFF0080FF00FF009980FF0070FF0070FF00
51FF0033FF0014FF00FF006B00FFA3FF004C0094FF00FF3861FF00CCFF00EBFF00EBFF00
EBFF00EBFF00DCFF00AEFF0070FF0000FF5742FF0070FF0000F0FF33FF00FFF500FFE600
FFE600FFE600FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700
FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700
FFD700FFD700FFD700FFD700FFE600FFE600FFE600FFF500FFF500FFF500FAFF00FAFF00
EBFF00DCFF00CCFF00BDFF00AEFF008FFF0070FF00EB00FF00D1FF00FF470028FF00F0FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000DC00FF0019FFFA00FF61FF00FAFF00FFE600FFE600FFD700FFD700FFC700
FFC700FFC700FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800FF9900FF9900
FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700
FFC700FFC700FFD700FFD700FFD700FFD700FFE600FFE600FFE600FFF500FFF500FAFF00
FAFF00EBFF00DCFF00CCFF009EFF0023FF0070FF00DC00FF0066FF00FFA34200FFFF0000
FF0000FF0000FF0000FF0000AE00FF0019FFFF0000FF0000FF0000FF00D700B3FF0075FF
FF005C0038FF61FF0080FF0051FF0000FF19BDFF00CCFF00DCFF00DCFF00CCFF00CCFF00
AEFF008FFF0070FF0000FF0AFF00A851FF0070FF0000FF949EFF0070FF00AEFF00AEFF00
9EFF008FFF008FFF0070FF0051FF0000FF0A8F00FF0075FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FA00FF00FF8500FF1951FF008FFF008FFF00
42FF0000FF2861FF009EFF00AEFF00AEFF00AEFF009EFF008FFF008FFF008FFF0080FF00
61FF0023FF0005FF0000FF380075FF00FFB300FF942300FF3300FFCCFF00EBFF00FAFF00
FAFF00FAFF00FAFF00EBFF0014FF0061FF00AEFF008FFF0000FF94FAFF00FFF500FFE600
FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFC700
FFD700FFC700FFC700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700
FFD700FFD700FFD700FFE600FFE600FFE600FFE600FFE600FFF500FFF500FAFF00FAFF00
EBFF00DCFF00CCFF00AEFF009EFF0080FF0061FF00FF0000FF00000075FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF000000FF94FF000000FF758FFF00EBFF00FFE600FFD700FFD700FFC700FFC700
FFC700FFC700FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800FF9900FFA800
FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700
FFC700FFC700FFD700FFD700FFD700FFD700FFE600FFE600FFE600FFF500FFF500FAFF00
FAFF00EBFF00EBFF00DCFF00BDFF009EFF008FFF0061FF0014FF007000FF6100FF0500FF
FF0000FF0000FF0000FF000000B3FF00FF5700FFA3FF00D700FF1900FF3800FF47DC00FF
FF00F523FF0070FF009EFF00AEFF00BDFF00CCFF00DCFF00DCFF00DCFF00DCFF00CCFF00
AEFF0000FF1923FF0000FF7500FF859EFF008FFF008FFF00BDFF00BDFF00BDFF00BDFF00
AEFF009EFF008FFF0070FF0061FF0033FF0000FFE100FFF0EB00FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF009900FF1970FF009EFF009EFF00
9EFF0000FF4700FF47AEFF00BDFF00BDFF00BDFF00BDFF00AEFF00AEFF009EFF008FFF00
00FFC200FF4700FF1900FF6600D1FF00FF28FF00C751FF0000FF479EFF00FAFF00FAFF00
FFF500FFF500FFF500FAFF00DCFF00EBFF00EBFF0000A3FFBDFF00FFF500FFE600FFE600
FFD700FFD700FFD700FFD700FFD700FFD700FFC700FFD700FFC700FFC700FFC700FFC700
FFD700FFC700FFC700FFD700FFC700FFC700FFD700FFD700FFD700FFD700FFD700FFD700
FFD700FFD700FFD700FFD700FFD700FFE600FFE600FFE600FFF500FFF500FAFF00FAFF00
EBFF00CCFF00AEFF0080FF0051FF0005FF000028FFFF00000019FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFD10038FF
FF0000FF003DFF0000DC00FFFF00A8AEFF00FAFF00FFE600FFD700FFD700FFC700FFC700
FFC700FFB800FFB800FFB800FFB800FFA800FFB800FFA800FFA800FFA800FF9900FF9900
FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFC700
FFC700FFC700FFD700FFD700FFD700FFD700FFE600FFE600FFE600FFF500FFF500FAFF00
EBFF00EBFF00DCFF00DCFF00CCFF00AEFF009EFF0061FF0000FF3800FF2800FF660019FF
FF0000FF0000FF0000BD00FF0066FF00FF1900FF1905FF0023FF0014FF0000FF6600FFF0
00FFE105FF0014FF009EFF00BDFF00CCFF00DCFF00EBFF00EBFF00DCFF00DCFF00CCFF00
70FF0000FFA380FF00AEFF00BDFF00BDFF00BDFF00AEFF00CCFF00CCFF00CCFF00BDFF00
AEFF009EFF0080FF0070FF0042FF0014FF0000FF7500FFF0FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FA00FF0066FFFF0000FF00000500FF9EFF00AEFF00
BDFF00AEFF0080FF00CCFF00CCFF00CCFF00CCFF00BDFF00BDFF00AEFF00AEFF008FFF00
00FF4723FF0000FFA30085FF00FFC200FF0A0094FF00FF38CCFF00EBFF00FAFF00FFF500
FFF500FFF500FFF500FFF500FFF500FFF500FAFF00DCFF0033FF00FFF500FFE600FFD700
FFD700FFD700FFD700FFD700FFC700FFD700FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFD700FFC700FFD700FFD700FFD700FFD700
FFD700FFD700FFD700FFD700FFE600FFE600FFE600FFE600FFF500FFF500FAFF00EBFF00
CCFF0000B3FF00FF57FF00D700FF38FF000000FF2800FFC2CC00FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFD100FFE1
FF000051FF00FF00004200FF14FF0000FFFFFAFF00FFE600FFD700FFD700FFC700FFC700
FFC700FFB800FFC700FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FF9900
FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700
FFC700FFC700FFD700FFD700FFD700FFD700FFE600FFE600FFF500FFF500FAFF00FAFF00
EBFF00EBFF00DCFF00DCFF00CCFF00BDFF00AEFF0080FF0061FF0033FF0000FF1900FFE1
FF00001400FF00D1FFFF000000FF5714FF0023FF0042FF0051FF0005FF0000FF5700FFB3
DC00FF0028FF00FF8500FFB3CCFF00DCFF00EBFF00EBFF00EBFF00EBFF00EBFF00DCFF00
9EFF0000FF388FFF00BDFF00CCFF00DCFF00DCFF00DCFF00DCFF00DCFF00CCFF00CCFF00
AEFF008FFF0000FF0A51FF0033FF0000FF5700FF470094FFFF0000FF00A8FF0000FF0000
FF0000FF0000FF0000FF0000FF000000F0FF00FFB36100FF00FFE123FF00AEFF00BDFF00
CCFF00CCFF00CCFF00CCFF00DCFF00CCFF00CCFF00CCFF00BDFF00BDFF00AEFF009EFF00
80FF0061FF0000FF75FF000042FF0080FF0070FF0000FFA3DCFF00FAFF00FFF500FFF500
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF500FAFF00FFE600FFD700FFD700
FFD700FFD700FFD700FFD700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFD700
FFD700FFD700FFD700FFD700FFD700FFE600FFE600FFE600FFF500FFF500FAFF00BDFF00
AEFF0000FF0A05FF00FF0000FF000000FF8500C2FF8000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000042FF00
70FF0080FF0000FF758FFF00000AFFBD00FFEBFF00FFE600FFD700FFD700FFC700FFC700
FFC700FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700
FFC700FFC700FFD700FFD700FFD700FFD700FFE600FFE600FFF500FFF500FAFF00EBFF00
EBFF00DCFF00DCFF00CCFF00BDFF00BDFF00AEFF008FFF0070FF0005FF0000FF38FF0000
00C2FFFF000000FF6600FFC200D1FF0047FF61FF0070FF0070FF0042FF0000FF5700FF47
00FF1933FF0051FF009EFF00CCFF00EBFF00EBFF00EBFF00FAFF00EBFF00EBFF00DCFF00
8FFF007000FF51FF00BDFF00DCFF00DCFF00EBFF00EBFF00EBFF00DCFF00DCFF00CCFF00
AEFF0000F0FF33FF0000FF2800FF3800B3FF00FFB3FF000000D1FF00E1FF9E00FFFF008A
FF0000FF0000FF00007000FF00D1FFFF000000FFC2FF000000FF2800A3FFAEFF00CCFF00
DCFF00DCFF00DCFF00DCFF00DCFF00DCFF00CCFF00CCFF00CCFF00BDFF00AEFF009EFF00
8FFF0061FF0000FFB300FF380094FF9EFF0070FF0000FF38EBFF00FAFF00FFF500FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD700FFD700FFD700
FFD700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFD700FFC700FFC700FFD700
FFD700FFD700FFD700FFD700FFD700FFD700FFE600FFE600FFE600FFF500FAFF0000FF47
00FF4714FF0000FFC200B3FF6100FF00FFD10075FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF38FF0000
8FFF00AEFF00AEFF00CCFF00CCFF0061FF00FAFF00FFE600FFD700FFD700FFC700FFC700
FFC700FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFC700
FFC700FFD700FFD700FFD700FFD700FFE600FFE600FFE600FFF500FAFF00EBFF00DCFF00
DCFF00DCFF00CCFF00CCFF00BDFF00AEFF009EFF008FFF0070FF0033FF0000C2FF0075FF
00F0FF00B3FF00FF0ADC00FF00FF0A00FF4780FF008FFF0080FF0042FF0000FF6600C2FF
42FF0080FF009EFF0000FF66BDFF00EBFF00FAFF00FAFF00FAFF00FAFF00FAFF00EBFF00
CCFF0061FF0000FF38BDFF00DCFF00EBFF00EBFF00EBFF00EBFF00EBFF00DCFF00CCFF00
00FF4700FFF070FF0061FF0000FFA305FF0000FFA3FF0000EB00FF00FF8500B3FF00FFFF
FF0000FF0000FF0000FF000000FFA300FF8500FF191400FF00FFF08FFF00BDFF00CCFF00
DCFF00DCFF00EBFF00EBFF00DCFF00DCFF00DCFF00CCFF00BDFF00BDFF00AEFF008FFF00
80FF0051FF0014FF0000FFC200FFFFBDFF008FFF0051FF00BDFF00FFF500FFE600FFE600
FFE600FFE600FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFD700
FFD700FFD700FFD700FFD700FFD700FFD700FFE600FFE600FFE600FFF500EBFF0000FF75
33FF00FF00E60085FFFF002E0057FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000EB00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
80FF00BDFF00CCFF00DCFF00EBFF00EBFF00FFF500FFE600FFD700FFD700FFC700FFC700
FFC700FFC700FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FF9900FF9900
FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700
FFC700FFD700FFD700FFD700FFD700FFE600FFE600FFF500FAFF00DCFF00CCFF009EFF00
BDFF00CCFF00CCFF00BDFF00BDFF0042FF0080FF0080FF0070FF0042FF0000FF758F00FF
4200FF14FF0023FF0000FF850066FF70FF009EFF009EFF0080FF0051FF0000A3FF00FF66
00FFFFAEFF00CCFF00BDFF009EFF00FAFF00FAFF00FAFF00FAFF00FAFF00FAFF00FAFF00
EBFF00CCFF0000FF75BDFF00EBFF00FAFF00FAFF00FAFF00EBFF00EBFF00EBFF00DCFF00
AEFF000057FF8FFF009EFF008FFF0070FF0000FFE100FFA30075FF00FF0A00FF2800FF94
1400FFFF0000FF0000FF00000094FF00FF3823FF0042FF0000FF198FFF00BDFF00DCFF00
DCFF00EBFF00EBFF00EBFF00EBFF00EBFF00DCFF00CCFF00BDFF00AEFF009EFF008FFF00
80FF0033FF0000FF6600FF3800FF66DCFF00DCFF00DCFF00DCFF00FFF500FFE600FFE600
FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFD700FFD700FFD700FFD700FFD700FFE600FFE600FFF500FAFF00DCFF00AEFF00
61FF0000FF470066FFFF00005100FF1400FFFF0000DC00FFFF0000FF0000FF0000FF0000
FF0000FF00000066FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00008F00FF
00FFF0BDFF00DCFF00EBFF00FAFF00FAFF00FFF500FFE600FFD700FFD700FFC700FFC700
FFC700FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FF9900FF9900
FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900
FF9900FFA800FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFC700
FFD700FFD700FFD700FFD700FFE600FFE600FFE600FFF500FAFF009EFF0000FF280094FF
00FF199EFF00BDFF00BDFF00AEFF0080FF0000FF1961FF0033FF0023FF0000C2FF8F00FF
00C2FF42FF0061FF0051FF0051FF009EFF00AEFF00AEFF009EFF008FFF0080FF0005FF00
14FF00BDFF00DCFF00EBFF00EBFF00FAFF00FAFF00FFF500FFF500FFF500FFF500FFF500
FAFF00BDFF00DCFF00EBFF00FAFF00FAFF00FAFF00FAFF00FAFF00FAFF00EBFF00DCFF00
80FF0000C2FFAEFF00BDFF00AEFF0042FF0051FF0042FF000038FF33FF0000FF28FF0000
FF0000FF0000FF000000B3FF1400FF9E00FF61FF0070FF0000FF3880FF008FFF00DCFF00
EBFF00EBFF00FAFF00EBFF00EBFF00EBFF00DCFF00CCFF00BDFF0033FF0000FF3870FF00
61FF0033FF0000FF6661FF00CCFF00EBFF00FAFF00FFF500FFF500FFE600FFE600FFD700
FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFC700FFC700FFD700FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFD700FFD700FFD700FFD700FFD700FFD700FFE600FFE600FAFF0023FF0000FFA3
0075FF00FF47FF0000FF0000FF000000E1FF00FFC2FF00000038FFFF0000FF0000FF0000
FF0000FF000000FFF0FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF003D0057FFFF0000
FF0000BDFF00DCFF00EBFF00FAFF00FFF500FFF500FFE600FFD700FFD700FFD700FFC700
FFC700FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800
FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFD700
FFC700FFD700FFD700FFD700FFE600FFE600FFF500FFF500FAFF008FFF009EFF009EFF00
80FF0033FF00AEFF009EFF009EFF0080FF0014FF0000FF6614FF0000FF2800C2FF00FF47
23FF0000FF8580FF0070FF0051FF008FFF00BDFF00BDFF00BDFF00BDFF009EFF0023FF00
70FF009EFF00EBFF00FAFF00FAFF00FFF500FFF500FFF500FFF500FFF500FFF500FFF500
FFF500FAFF00FAFF00FAFF00FFF500FFF500FFF500FAFF00FAFF00FAFF00EBFF00EBFF00
CCFF00CCFF00CCFF00CCFF00BDFF00AEFF009EFF0051FF0070FF0014FF0014FF0000FF57
FF00000066FFFF00000019FF00FF7505FF0070FF008FFF0042FF0000FF2842FF00DCFF00
EBFF00FAFF00FAFF00FAFF00FAFF00EBFF00EBFF00CCFF0023FF0000FF7523FF0023FF00
42FF0000FFB30019FFAEFF00CCFF00FAFF00FFF500FFF500FFE600FFE600FFD700FFD700
FFD700FFD700FFD700FFD700FFD700FFC700FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700
FFD700FFC700FFD700FFD700FFD700FFD700FFE600FFE600FFE600FAFF0033FF0000FF75
61FF008FFF00BD00FF0094FF00FFF00085FF00FF8500FF7500FF6600FFF0FF0000FF0000
FF00007000FF00FF940019FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF66FF0000FA00FF
00A3FFCCFF00DCFF00EBFF00FAFF00FFF500FFF500FFE600FFE600FFD700FFD700FFC700
FFC700FFC700FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800FF9900FF9900
FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFC700
FFD700FFD700FFD700FFD700FFE600FFE600FFF500FFF500FAFF00EBFF00DCFF00CCFF00
9EFF0033FF008FFF0080FF008FFF0061FF0014FF0000FF5700FFB300FF9400D1FF00FF0A
51FF0070FF008FFF008FFF0051FF0000FF47CCFF00CCFF00CCFF00CCFF00AEFF0042FF00
9EFF00DCFF00EBFF00FAFF00FFF500FFF500FFF500FFF500FFF500FFF500FFE600FFF500
FFF500FFF500FFF500FFF500FFF500FFF500FFF500FAFF00FAFF00FAFF00FAFF00EBFF00
EBFF00DCFF00DCFF00DCFF00CCFF00BDFF00AEFF009EFF008FFF0070FF0051FF0033FF00
00FF0A00E1FFFF0000000AFF00FF1923FF0070FF008FFF00BDFF00BDFF00DCFF00EBFF00
FAFF00FAFF00FAFF00FAFF00FAFF00FAFF00EBFF00CCFF0000FFE123FF0061FF0000FFB3
00FF7580FF00BDFF00EBFF00FAFF00FFF500FFF500FFE600FFE600FFD700FFD700FFD700
FFD700FFD700FFC700FFD700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFD700FFD700FFD700FFD700FFD700FFE600FFE600FFF500FAFF00CCFF00
00FFE1CCFF001400FFFF000000FF57FF0000FF000000FF1900FF190057FFBD00FF0066FF
00FF7500FF28FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFFF42FF0061FF00
70FF00CCFF00DCFF00EBFF00FAFF00FAFF00FFF500FFE600FFE600FFE600FFD700FFC700
FFC700FFC700FFC700FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FF9900
FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800
FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFC700FFD700
FFD700FFD700FFD700FFE600FFE600FFE600FFF500FFF500FAFF00EBFF00DCFF00CCFF00
9EFF0000FF4761FF0042FF0061FF0033FF0000D1FF1400FF00FF0A33FF0000FF0A00FF57
33FF0070FF009EFF00AEFF00BDFF00BDFF00DCFF00DCFF00DCFF00CCFF0080FF008FFF00
BDFF00DCFF00EBFF00FAFF00FFF500FFF500FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFF500FFF500FFF500FFF500FFF500FFF500FFF500FFF500FAFF00FAFF00
EBFF00EBFF00EBFF00DCFF00CCFF00CCFF00BDFF00AEFF008FFF0080FF0061FF0042FF00
14FF0000FF3800F0FF00FFA300FF1923FF0000FF478FFF00BDFF00DCFF00EBFF00FAFF00
FAFF00FFF500FFF500FAFF00FAFF00FAFF00EBFF000047FF05FF0005FF0080FF008FFF00
9EFF00BDFF00DCFF00EBFF00FAFF00FFF500FFE600FFE600FFD700FFD700FFD700FFD700
FFD700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFB800FFC700FFB800FFB800FFC700FFC700FFB800
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFD700FFD700FFD700FFE600FFE600FFE600FFF500FAFF00
EBFF00EBFF00BDFF0000FFD123FF00FF00A800FF94FF000023FF00FF0000FF00000047FF
00FF9405FF0000FF288F00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF758FFF00
AEFF00CCFF00DCFF00EBFF00FAFF00FAFF00FFF500FFF500FFE600FFE600FFD700FFD700
FFC700FFC700FFC700FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFD700FFD700
FFD700FFD700FFE600FFE600FFE600FFE600FFF500FFF500FAFF00EBFF00DCFF00CCFF00
9EFF0014FF0000FF4700FF5733FF0000FF3805FF000066FF23FF0070FF0014FF006100FF
00FF2823FF009EFF00BDFF00BDFF00DCFF00DCFF00EBFF00EBFF00DCFF0061FF0070FF00
BDFF00DCFF00EBFF00FAFF00FFF500FFF500FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFF500FFF500FFF500FFF500FAFF00FAFF00
FAFF00EBFF00EBFF00DCFF00DCFF00CCFF00BDFF009EFF008FFF0070FF0061FF0000FFA3
00FF2800FF7500C2FFDC00FFCC00FF00FFE15100FF0047FFCCFF00EBFF00FAFF00FAFF00
FFF500FFF500FFF500FFF500FFF500FAFF00EBFF00CCFF0000FFB342FF008FFF00AEFF00
BDFF00CCFF00EBFF00FAFF00FFF500FFF500FFE600FFE600FFD700FFD700FFD700FFD700
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFB800FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFC700FFC700FFB800FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFD700FFD700FFD700FFD700FFD700FFE600FFE600FFF500
FFF500FAFF00DCFF0000FFB370FF0000FF19FF0000FF002E51FF0000FF3800FFFF51FF00
33FF0023FF0000FF5700FFA3FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000F0FFFF00001400FF8FFF00
AEFF00BDFF00CCFF00DCFF00DCFF00EBFF00FAFF00FAFF00FFF500FFF500FFE600FFD700
FFD700FFC700FFC700FFC700FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800
FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFB800
FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFD700FFD700FFD700
FFD700FFE600FFE600FFE600FFE600FFF500FFF500FAFF00FAFF00EBFF00DCFF00BDFF00
8FFF0000FF0A0075FFFF00006100FF00FF6661FF0000FF388FFF008FFF0061FF0023FF00
00FF1961FF009EFF00BDFF00CCFF00DCFF00EBFF00EBFF00EBFF00EBFF008FFF0023FF00
80FF00CCFF00EBFF00FAFF00FFF500FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF500FFF500FFF500FFF500FAFF00
FAFF00EBFF00EBFF00EBFF00DCFF00CCFF00AEFF0080FF0042FF0061FF0051FF0023FF00
FF000000D1FF00FF9400FF9400FF3800FFD142FF0000FF94CCFF00EBFF00FAFF00FFF500
FFF500FFF500FFF500FFF500FFF500FFF500FAFF00DCFF008FFF00AE00FF8FFF00AEFF00
BDFF00DCFF00EBFF00FAFF00FFF500FFF500FFE600FFD700FFD700FFD700FFD700FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFB800FFC700FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFC700FFB800FFB800FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFD700FFC700FFD700FFD700FFD700FFD700FFE600FFE600FFF500
FFF500FAFF00EBFF00CCFF008FFF0000FF1900E1FF33FF0061FF0070FF0070FF0070FF00
61FF0033FF00FF00002300FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000DC00FF14FF0042FF008FFF00
9EFF00AEFF00AEFF00AEFF00CCFF00DCFF00DCFF0080FF00CCFF0000FF47FAFF00FFE600
FFD700FFC700FFC700FFC700FFB800FFB800FFB800FFA800FFA800FFA800FFA800FF9900
FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800
FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFD700FFD700FFD700FFE600
FFE600FFE600FFE600FFF500FFF500FFF500FAFF00FAFF00EBFF00EBFF00CCFF0080FF00
61FF0000FF28FF0000FF000033FF0000FF0A70FF00AEFF00AEFF00AEFF008FFF0033FF00
00FF7505FF0005FF00AEFF00CCFF00EBFF00FAFF00FAFF00FAFF00FAFF00DCFF00AEFF00
14FF0042FF00CCFF00FAFF00FFF500FFE600FFE600FFD700FFD700FFD700FFD700FFD700
FFE600FFD700FFE600FFE600FFE600FFE600FFE600FFE600FFF500FFF500FFF500FAFF00
FAFF00EBFF00EBFF00EBFF00DCFF00CCFF009EFF0000FF2823FF0033FF0033FF0014FF00
1400FF00FFFF00FF28FF000033FF0000FF198FFF0051FF00CCFF00EBFF00FFF500FFF500
FFE600FFE600FFE600FFE600FFE600FFF500FAFF0000FF0A51FF0000FF1970FF009EFF00
BDFF00CCFF00DCFF00EBFF00FAFF00FFF500FFE600FFD700FFD700FFD700FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFB800FFC700FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFC700FFC700FFB800FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFD700FFD700FFD700FFE600FFE600
FFF500FFF500FAFF00DCFF0000FFE100FFFFFF000042FF0070FF0080FF008FFF0080FF00
70FF00DC00FFFF008AFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000033FF0061FF0080FF00
70FF0080FF0000A3FF00A3FF0094FFAEFF00AEFF0000FF0A70FF0000FFA300FF0A8FFF00
FFE600FFD700FFC700FFC700FFC700FFB800FFB800FFB800FFA800FFA800FFA800FFA800
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800
FFB800FFB800FFC700FFB800FFC700FFC700FFC700FFD700FFD700FFE600FFE600FFE600
FFF500FFF500FFF500FFF500FFF500FAFF00FAFF00EBFF00DCFF00DCFF00CCFF009EFF00
00FF1923FF0000FF3800FF2814FF009EFF009EFF00CCFF00CCFF00BDFF0080FF0000FF57
00FF57FF000000D1FF8FFF00BDFF00EBFF00FAFF00FAFF00FFF500FAFF00FAFF0061FF00
80FF0042FF00CCFF00FFF500FFE600FFE600FFD700FFD700FFD700FFD700FFD700FFD700
FFD700FFD700FFD700FFD700FFE600FFE600FFE600FFE600FFF500FFF500FFF500FFF500
FAFF00FAFF00EBFF00EBFF00DCFF00CCFF009EFF0070FF0051FF0000FF6600FF0A00FF28
00FFB323FF0033FF0000FF7500FF0A8FFF00AEFF0000FF9461FF00EBFF00FFF500FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFF500EBFF008FFF0000FFB300FF858FFF00
AEFF00AEFF00CCFF009EFF00EBFF00FFF500FFE600FFD700FFD700FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFB800FFC700FFB800FFB800FFB800FFB800FFB800
FFB800FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFC700FFB800FFB800FFB800FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFD700FFC700FFD700FFD700FFD700FFE600FFE600FFE600
FFE600FFF500FAFF00DCFF0000FF2800FFA3BD00FF42FF0070FF008FFF009EFF008FFF00
80FF00FF0000FF0000FA00FF8000FFDC00FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF3823FF0042FF0023FF00
FF000014FF00FF0000000AFF0075FF8FFF0023FF0033FF0000FF6600FFE100FF0ADCFF00
FAFF00FFE600FFD700FFD700FFC700FFC700FFB800FFB800FFB800FFA800FFA800FFA800
FFA800FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00
FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800
FFB800FFB800FFB800FFC700FFC700FFC700FFD700FFD700FFE600DCFF00FAFF00FFF500
FFF500EBFF00FAFF00FAFF00FAFF00FAFF00EBFF00BDFF0000FF28BDFF00BDFF0000FF0A
00FF2870FF0070FF0023FF0080FF00CCFF00CCFF00DCFF00DCFF00BDFF0070FF008FFF00
33FF0023FF0000FF4770FF0033FF00EBFF00FAFF00FFF500FFF500FFF500FFF500FAFF00
FAFF00CCFF00EBFF00FFE600FFE600FFD700FFD700FFD700FFD700FFD700FFD700FFD700
FFD700FFD700FFD700FFD700FFD700FFE600FFE600FFE600FFE600FFF500FFF500FFF500
FAFF00FAFF00EBFF00EBFF00DCFF00CCFF00BDFF009EFF0070FF0000FF85FF000000F0FF
00FF3870FF0033FF000085FFFF000061FF00CCFF00DCFF00DCFF00EBFF00FFF500FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF500EBFF00BDFF0000E1FF51FF00
42FF0000F0FF70FF0051FF0005FF00FFF500FFE600FFD700FFD700FFC700FFC700FFC700
FFC700FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFD700FFD700FFD700FFE600
FFE600FFF500FFF500EBFF00CCFF0080FF00CC00FF00FF0A00FFF09EFF00AEFF009EFF00
8FFF0042FF000075FFFF0000FF000000FFC22300FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF3800FF0AFF0000FF0000
00FFFFFF00B88000FF00FF4714FF0005FF0000FF57FF00C700FFC2FF006B00FF6670FF00
00FFF0EBFF00FFE600FFD700FFC700FFC700FFC700FFB800FFB800FFB800FFA800FFA800
FFA800FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFB800
FFB800FFB800FFC700FFC700FFD700FFD700FFD700FFD700FFE600FAFF009EFF00EBFF00
EBFF0000FFB3DCFF00EBFF00EBFF00EBFF00DCFF00BDFF0061FF009EFF009EFF0042FF00
23FF009EFF009EFF0051FF00AEFF00DCFF00EBFF00EBFF00EBFF00CCFF0080FF00BDFF00
AEFF0061FF000066FF9EFF00DCFF00FAFF00FFF500FFF500FFE600FFE600FFE600FFE600
FFF500FAFF00FAFF00FFE600FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700
FFD700FFD700FFD700FFD700FFD700FFD700FFE600FFE600FFE600FFF500FFF500FFF500
FAFF00FAFF00EBFF00EBFF00DCFF00CCFF00BDFF00AEFF0061FF0005FF00FF000000FFA3
00FF389EFF0000FF4780FF0042FF0000FF0ADCFF00EBFF00FFF500FFF500FFE600FFE600
FFD700FFD700FFD700FFE600FFD700FFE600FFE600FFF500FAFF00AEFF0080FF0000D1FF
80FF0023FF0033FF0005FF0000FF28FFF500FFE600FFD700FFC700FFC700FFC700FFC700
FFC700FFB800FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFB800FFB800FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFD700FFD700FFE600
FFE600FFE600FFF500FAFF00EBFF00DCFF0000FF0A80FF009EFF00AEFF00AEFF00AEFF00
9EFF0080FF0000A3FF0085FF00FF280019FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFF000FF668000FFFF0000FF0000
FF0000FF0000FF000000FFFF00D1FFFF006BFF00000057FF00FFC2FF000000FF7523FF00
9EFF00BDFF00FFE600FFD700FFD700FFD700FFC700FFC700FFB800FFB800FFA800FFA800
FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900
FF9900FF9900FFA800FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFB800
FFB800FFB800FFC700FFD700FFD700FFD700FFD700FFE600FFF500FAFF0080FF00CCFF00
9EFF0000FFA370FF00AEFF00DCFF00DCFF00CCFF00AEFF0000FF6670FF0042FF0000FF47
80FF00AEFF00BDFF0000FFC2BDFF00DCFF00FAFF00FAFF00FAFF00EBFF00DCFF00DCFF00
CCFF008FFF000085FF23FF00AEFF00FAFF00FFF500FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFD700FFD700FFD700FFD700FFC700FFD700FFC700FFC700FFD700
FFD700FFD700FFD700FFD700FFD700FFD700FFE600FFE600FFE600FFE600FFF500FFF500
FAFF00FAFF00EBFF00DCFF00DCFF00CCFF00BDFF00AEFF0080FF0000FFF000FF940066FF
9EFF00BDFF00BDFF00AEFF0033FF0042FF00DCFF00FFF500FFF500FFE600FFE600FFD700
FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFE600FAFF00AEFF00FF000000FF75
CCFF00CCFF00AEFF0051FF0080FF0000FF19FFD700FFD700FFC700FFC700FFC700FFC700
FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFD700FFD700FFE600
FFE600FFE600FFF500FFF500FAFF00EBFF00DCFF00CCFF00CCFF00BDFF00BDFF00AEFF00
9EFF008FFF0061FF000075FF14FF00FF0000FF00006100FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFE1FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000038FFFF0000FF000000FF2833FF0014FF0033FF0000FF94
DCFF00EBFF00FFF500FFE600FFE600FFE600FFF500FFF500FFC700FFB800FFB800FFA800
FFA800FFA800FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFB800FFB800
FFB800FFC700FFE600FFE600FFF500FFE600FFE600FFF500FAFF00EBFF008FFF0000FFE1
00FFA3AEFF00BDFF0080FF009EFF009EFF009EFF0000FF7505FF0061FF0070FF0042FF00
8FFF00CCFF00DCFF00CCFF0000FF0ADCFF00FAFF00FFF500FFF500FAFF00FAFF00EBFF00
CCFF0070FF0042FF009EFF00AEFF00FAFF00FFE600FFE600FFD700FFD700FFD700FFD700
FFD700FFD700FFD700FFD700FFD700FFC700FFC700FFC700FFD700FFC700FFC700FFD700
FFC700FFD700FFD700FFD700FFD700FFD700FFD700FFE600FFE600FFE600FFF500FAFF00
FAFF00EBFF00EBFF00DCFF00CCFF00CCFF00BDFF009EFF0080FF0000FF3842FF0014FF00
00FF57CCFF00CCFF00BDFF0080FF009EFF00FAFF00FFF500FFE600FFE600FFD700FFD700
FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFE600FFF500FAFF00FFF500FAFF00
FAFF00DCFF00AEFF0005FF00FAFF00FFE600FFD700FFC700FFC700FFC700FFC700FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFB800
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFD700FFD700
FFE600FFE600FFF500FFF500FAFF00FAFF00EBFF00DCFF00DCFF00CCFF00BDFF00AEFF00
9EFF008FFF0070FF0042FF0023FF0000FF0A00FFA3FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000051FF0061FF008FFF0023FF00
DCFF00FAFF00FFF500FFF500FFF500FAFF0070FF00CCFF00BDFF00FFC700FFB800FFB800
FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFB800FFB800FFB800
FFB800FFC700FFE600AEFF00BDFF00FAFF00FFF500FAFF00BDFF00CCFF00AEFF0080FF00
BDFF00DCFF00EBFF00DCFF008FFF0061FF0023FF008FFF0000FFC2BDFF00BDFF0042FF00
00FF38DCFF00EBFF00EBFF00EBFF00FAFF00FFF500FFF500FFF500FFF500FAFF00EBFF00
DCFF00AEFF0000FF38DCFF00EBFF00FAFF00FFE600FFD700FFD700FFD700FFD700FFD700
FFD700FFD700FFD700FFC700FFC700FFC700FFC700FFC700FFD700FFC700FFC700FFC700
FFC700FFC700FFD700FFD700FFD700FFD700FFD700FFE600FFE600FFF500FAFF00FAFF00
EBFF00DCFF00DCFF00CCFF00CCFF00BDFF009EFF0000FF7551FF0000FF1923FF009EFF00
CCFF00DCFF00DCFF00AEFF0051FF00DCFF00FAFF00FFE600FFE600FFD700FFD700FFD700
FFD700FFC700FFC700FFC700FFD700FFD700FFD700FFD700FFE600FFE600FFE600FFE600
FFF500CCFF0000FFF0CCFF00FFE600FFD700FFD700FFC700FFC700FFC700FFB800FFC700
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFD700FFD700
FFD700FFE600FFE600FFF500FFF500FAFF00FAFF00EBFF00DCFF00CCFF00CCFF00BDFF00
9EFF0070FF0061FF0042FF0005FF0000FF2800FF57FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000AE00FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF000000B3FF00FF4742FF008FFF009EFF00BDFF00
DCFF00EBFF00FAFF00FAFF00FAFF009EFF0023FF0023FF00EBFF00FFD700FFC700FFB800
FFB800FFA800FFA800FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800
FFC700FFC700FFD700FFF500DCFF00DCFF00EBFF00EBFF00AEFF0023FF0033FF00BDFF00
EBFF00EBFF00FAFF00FAFF00BDFF00DCFF00BDFF00BDFF00DCFF00DCFF00DCFF00BDFF00
00FF47DCFF00FAFF00FFF500FFF500FFF500FFF500FFE600FFF500FFF500FFF500EBFF00
DCFF009EFF0070FF00EBFF00FFF500FFE600FFE600FFD700FFD700FFD700FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFD700FFD700FFD700FFE600FFE600FFE600FFF500FFF500FAFF00
DCFF008FFF00AEFF00AEFF00BDFF00AEFF009EFF0042FF0000FF0A00FF1923FF0000FFA3
DCFF00FAFF00EBFF00BDFF0080FF00BDFF00FAFF00FFE600FFD700FFD700FFD700FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFD700FFD700
FFE6009EFF00BDFF00FAFF00FFE600FFD700FFC700FFC700FFC700FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFD700
FFD700FFE600FFF500FFF500FFF500FAFF00EBFF00EBFF00DCFF00CCFF00BDFF00AEFF00
51FF0000FF7500FF6605FF00FF00000066FFFF000000E1FF0075FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF8500FF479EFF00BDFF00
DCFF00EBFF00EBFF00FAFF00EBFF0005FF0051FF00DCFF00FFF500FFE600FFD700FFC700
FFB800FFB800FFA800FFA800FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFB800FFB800FFB800
FFC700FFC700FFD700FFE600FAFF0080FF0080FF00CCFF0000FF4742FF0080FF00DCFF00
FAFF00FAFF00FFF500FFF500FAFF00FAFF00CCFF00EBFF00FAFF00FAFF00FAFF00DCFF00
61FF00FAFF00FFF500FFF500FFE600FFE600FFE600FFE600FFE600FFE600FFF500FAFF00
AEFF0070FF00EBFF00FFF500FFE600FFE600FFD700FFD700FFD700FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFD700FFD700FFD700FFD700FFE600FFE600FFF500FAFF00DCFF00
CCFF0014FF0000FF5700FF199EFF009EFF0080FF0000FF4761FF0070FF0000FF19BDFF00
FAFF00FAFF00FFF500FAFF0061FF009EFF00EBFF00FFE600FFD700FFD700FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFD700FFD700
FFE600EBFF00BDFF00DCFF00FFD700FFC700FFC700FFC700FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFC700FFB800FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFD700
FFE600FFE600FFE600FFF500FFF500FAFF00FAFF00EBFF00DCFF00CCFF00BDFF00AEFF00
23FF00FF00000085FFFF00000038FFFF0000FF0000FF0000FF0000FF00B8FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF751400FF8FFF0070FF00
AEFF00CCFF00DCFF00EBFF00DCFF0061FF0014FF00DCFF00FFF500FFE600FFE600FFF500
FFE600FFB800FFA800FFA800FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFB800FFB800FFB800FFB800
FFC700FFC700FFD700FFE600FAFF00CCFF0033FF0080FF009EFF00BDFF0080FF00CCFF00
FAFF00FFF500FFF500FFF500FFF500FFF500FAFF00FFF500FFF500FFF500FFF50080FF00
DCFF00FAFF00FFE600FFE600FFD700FFD700FFD700FFD700FFE600FFE600FFF500EBFF00
33FF00CCFF00FAFF00FFF500FFE600FFD700FFD700FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFD700FFD700FFD700FFE600FFE600FFF500EBFF000066FF
80FF0000FF1980FF0080FF0061FF0051FF0000FF0A00FF47AEFF00AEFF0000FF57EBFF00
FFF500FFF500FFF500FFF500FFF500EBFF00FFF500FFD700FFD700FFD700FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700
FFD700FFD7009EFF00FFE600FFD700FFC700FFC700FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFA800FFA800FFB800
FFB800FFA800FFA800FFB800FFB800FFA800FFA800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFD700
FFD700FFE600FFE600FFF500FFF500FAFF00EBFF00EBFF00DCFF00CCFF00BDFF009EFF00
FF0000FF00000019FFFF0000CC00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00E600FF9433FF0051FF00FF0000
00FF0A8FFF0042FF00CCFF00CCFF009EFF0000FF0A8FFF00FAFF00FAFF00FAFF008FFF00
8FFF00FFD700FFB800FFA800FFA800FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800
FFC700FFC700FFD700FFE600FFF500FAFF00CCFF0080FF00BDFF00DCFF00EBFF00FAFF00
FFF500FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE6008FFF00
00FF38FFF500FFE600FFD700FFD700FFD700FFD700FFD700FFD700FFE600FFE600EBFF00
42FF00CCFF00FAFF00FFF500FFE600FFD700FFD700FFD700FFC700FFC700FFC700FFC700
FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFE600FFE600FFF500EBFF0070FF00
00FF0A00FFB3AEFF00AEFF0051FF000085FF8FFF008FFF00DCFF00CCFF0070FF00FAFF00
FFF500FFE600FFE600FFE600FFE600FFE600FFE600FFD700FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFB800FFC700FFC700FFB800FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFD700FFD700FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFB800FFA800FFA800FFB800
FFA800FFA800FFA800FFB800FFA800FFA800FFA800FFA800FFB800FFB800FFA800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFD700
FFD700FFE600FFE600FFF500FFF500FAFF00EBFF00DCFF009EFF0042FF009EFF0061FF00
0075FFDC00FF00E1FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFA39E00FF00FFB300FF94
FF0099DC00FF8FFF00BDFF00BDFF0070FF0005FF009EFF00DCFF00EBFF0080FF00BDFF00
8FFF00AEFF00FFB800FFA800FFA800FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFC700
FFC700FFC700FFD700FFE600FFF500FAFF00DCFF008FFF00BDFF00EBFF00FAFF00FFF500
FFF500FFE600FFE600FFE600FFE600FFD700FFD700FFD700FFD700FFD700FFE600FFE600
8FFF00FFE600FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFE600FFF500
BDFF0080FF00EBFF00FFF500FFE600FFD700FFC700FFC700FFC700FFC700FFC700FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFD700FFE600FAFF00EBFF0023FF00
00FF289EFF00BDFF00CCFF00CCFF00CCFF00CCFF00CCFF00FAFF00FAFF00EBFF00FFF500
FFE600FFE600FFD700FFD700FFD700FFD700FFD700FFC700FFC700FFC700FFC700FFC700
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFB800FFB800FFC700
FFC700FFC700FFC700FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFA800FFA800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFA800FFA800FFA800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFC700FFC700FFD700FFD700
FFD700FFE600FFE600FFF500FAFF00EBFF00CCFF00CCFF0051FF00FF005C80FF0000FFC2
FF000000FF8500FFFFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000094FF6100FF4200FFFF0000
05FF0051FF008FFF009EFF009EFF0070FF000094FF9EFF00CCFF008FFF0000FF85EBFF00
FFF500FFF500FFB800FFA800FFA800FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900
FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFC700
FFC700FFC700FFD700FFE600FFF500EBFF00DCFF008FFF00CCFF00FAFF00FFF500FFF500
FFE600FFE600FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700
FFE600FFD700FFD700FFC700FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFF500
00FF2823FF00AEFF00FAFF00FFE600FFD700FFC700FFC700FFC700FFC700FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700
FFB800FFC700FFC700FFC700FFC700FFC700FFD700FFE600FFF500FAFF00DCFF009EFF00
00FF0A8FFF00CCFF00DCFF00EBFF00EBFF00EBFF00FAFF00FFF500FFF500FFF500FFE600
FFE600FFD700FFD700FFD700FFD700FFC700FFC700FFC700FFC700FFC700FFC700FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFC700FFB800FFB800FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFA800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFB800FFB800FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFD700
FFD700FFE600FFF500FFF500FAFF0000FF0A000AFF9EFF004200FF0057FF42FF0042FF00
14FF0000FF47FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000E1FF
00E1FF51FF0070FF0061FF0070FF0070FF0000FF4780FF008FFF0000FF9470FF00FAFF00
FFE600FFD700FFB800FFB800FFA800FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900
FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFB800FFB800FFB800FFC700FFC700
FFC700FFD700FFE600FFF500EBFF00DCFF008FFF00AEFF00DCFF00FAFF00FFF500FFE600
FFE600FFD700FFD700FFD700FFD700FFD700FFD700FFC700FFC700FFC700FFD700FFD700
FFD700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFD700FFE600
FFF500EBFF009EFF0070FF00FFE600FFD700FFC700FFC700FFC700FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFC700FFC700FFC700FFD700FFD700FFE600DCFF0005FF00BDFF0080FF00
42FF00AEFF00CCFF00DCFF00EBFF00FAFF00FAFF00FFF500FFF500FFE600FFE600FFD700
FFD700FFD700FFD700FFD700FFC700FFC700FFC700FFC700FFC700FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFA800FFB800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFB800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFC700FFC700FFD700FFD700
FFD700FFE600FFF500FAFF00EBFF0042FF0000FF9470FF0023FF00FF000000FF0A23FF00
FF00006100FF00B3FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000DC00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00008000FF
CC00FF00FF1900FF856100FF42FF0051FF003300FF51FF0000FF949EFF00BDFF00FFF500
FFE600FFD700FFC700FFB800FFA800FFA800FF9900FF9900FF9900FF8A00FF8A00FF9900
FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900
FF9900FF9900FF9900FFA800FFA800FFA800FFB800FFB800FFB800FFC700FFC700FFC700
FFD700FFD700FFE60023FF00AEFF008FFF0000FF47BDFF00DCFF00FAFF00FFF500FFE600
FFE600FFD700FFD700FFD700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFD700
FFD700FFF500CCFF00FFF500FFD700FFC700FFC700FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFC700FFC700FFC700FFC700FFD700FFE600FFF500DCFF0023FF0000FF38
80FF00BDFF00CCFF00EBFF00FAFF00FAFF00FFF500FFF500FFE600FFE600FFD700FFD700
FFD700FFD700FFC700FFC700FFC700FFC700FFC700FFC700FFB800FFC700FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFB800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFC700FFD700FFD700
FFE600FFE600EBFF00CCFF00CCFF0061FF0000B3FF33FF0000FFA300FFC200FF19FF00F5
FF00999E00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000038FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00B800B3FF00E1FF00FFFF00FF5700FF2800E1FF00FFC270FF00BDFF00DCFF00FAFF00
FFE600FFD700FFC700FFB800FFB800FFA800FF9900FF9900FF9900FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900
FF9900FF9900FF9900FFA800FFA800FFA800FFB800FFB800FFC700FFC700FFC700FFD700
FFD700FFD700FFF500EBFF00AEFF0051FF008F00FF8FFF0070FF00DCFF00FFF500FFE600
FFD700FFD700FFD700FFC700FFC700FFD700FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFB800FFB800FFC700FFB800FFB800FFB800FFB800FFC700FFC700FFC700
FFD700FFE60014FF00FFD700FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFD700FFE600FAFF00BDFF0000FF38
33FF00AEFF00DCFF00EBFF00FAFF00FAFF00FFF500FFE600FFE600FFE600FFD700FFD700
FFD700FFC700FFC700FFC700FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFB800FFA800FFA800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFC700FFD700FFD700
FFE600FFF50000FF8500FFA38FFF0080FF000028FF00FF2800FF667000FF00FF4700FF75
00F0FFFF003DFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF000000D1FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00003300FF
00E1FF00FFF000FF6600FF380075FF14FF004200FF00FF4770FF00AEFF00CCFF00EBFF00
FFF500FFF500FFF500FFD700FFB800FFA800FF9900FF9900FF9900FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF9900FF9900FF9900
FF9900FF9900FF9900FFA800FFA800FFB800FFB800FFC700FFD700FFD700FFD700FFD700
FFE600FFE600FFF500FAFF00CCFF0080FF0061FF0000FF1900FFFFCCFF00FFF500FFE600
FFD700FFD700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFB800
FFB800FFB800FFB800FFB800FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFC700
FFC700FFD70005FF00FFD700FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFA800FFB800FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFD700FFE600FFF500BDFF00AEFF00
00FF8580FF00AEFF00EBFF00FAFF00FFF500FFF500FFE600FFE600FFE600FFD700FFD700
FFC700FFC700FFC700FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFA800FFB800FFA800FFB800FFA800FFB800
FFA800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFC700FFB800FFC700FFC700FFC700FFC700FFD700FFD700
FFE600FFF500EBFF0000C2FF00FFC233FF0000FF0A0047FF00FFE100FFE1FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
00B3FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF000000FFC2FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000500FFFF0000FF0000FF0000FF004C
6100FF33FF0000B3FF00FF5761FF0042FF0000F0FF33FF0000FF4700FF1970FF0061FF00
80FF009EFF00CCFF0051FF00FFD700FFA800FFA800FF9900FF9900FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900
FF9900FF9900FFA800FFA800FFA800FFB800FFC700FFD700AEFF00FFF500FFF500FFE600
FFE600FFF500FFF500EBFF009EFF0080FF00CCFF0080FF00EBFF00FAFF00FFE600FFD700
FFD700FFD700FFC700FFC700FFC700FFC700FFC700FFC700FFB800FFC700FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFC700FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFA800FFA800
FFA800FFA800FFA800FFB800FFA800FFA800FFA800FFA800FFB800FFA800FFB800FFB800
FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFD700FFE600FFF500FAFF00CCFF00
00FFE100FF19BDFF00EBFF00FAFF00FFF500FFF500FFE600FFE600FFD700FFD700FFD700
FFC700FFC700FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFA800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFA800FFB800
FFA800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFB800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFD700FFD700
FFE600FFF500DCFF0070FF0051FF000038FF00FF7500A3FF0094FF00F0FF00C2FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
00FFB3FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF000000FF75FA00FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF006BFF00000094FF00F0FF
14FF0070FF0080FF008FFF0080FF0014FF0000FF6680FF0080FF0061FF008FFF0061FF00
0075FF00FF0ABDFF00BDFF00FFF500FFB800FFA800FF9900FF9900FF9900FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900
FF9900FF9900FF9900FFA800FFB800FFD700FFD700FFF500CCFF0080FF008FFF00FAFF00
FFF500FAFF00EBFF00CCFF009EFF00DCFF00EBFF00FAFF00FFF500FFE600FFE600FFD700
FFD700FFC700FFC700FFC700FFC700FFC700FFC700FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFD700FFE600FFF500FAFF00CCFF00
70FF0000F0FFCCFF00DCFF00EBFF00FAFF00FFF500FFE600FFE600FFD700FFD700FFD700
FFC700FFC700FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFD700FFD700
FFE600FFF500EBFF00BDFF008FFF0000FF380019FFFF00001400FFFF0000FF0000FF0000
FF000000B3FFFF0000FF00000094FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF000000FF28DC00FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000000AFF00FF660085FF00FFB30094FF
00FF5780FF00AEFF00AEFF009EFF000085FF00FF759EFF00BDFF00CCFF00CCFF0070FF00
42FF00FAFF00FAFF008FFF00FFE600FFB800FFA800FF9900FF9900FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900
FF9900FF9900FF9900FFA800FFB800FFE600DCFF00CCFF009EFF00FFF500DCFF00CCFF00
DCFF00AEFF00CCFF00BDFF00AEFF00DCFF00FAFF00FFF500FFE600FFE600FFD700FFD700
FFD700FFC700FFC700FFC700FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFB800FFA800FFA800FFA800FFA800FFA800FFA800
FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFD700FFE600FFF500EBFF00DCFF00
80FF008FFF00AEFF00DCFF00EBFF00FAFF00FFF500FFE600FFE600FFD700FFD700FFC700
FFC700FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFA800
FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFB800FFA800FFA800FFA800FFA800FFB800FFA800FFA800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFD700FFD700
FFE600FAFF00CCFF00AEFF0070FF0005FF0000F0FFFF0000FA00FFFF000000FFF000FF85
00FF576100FFFF0000FF0000FF0000FF0099FA00FFFF00000019FFFF00000028FFFF001E
00FF2800FFC27000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF000005FF0000FF28FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00005100FF00FF2842FF0051FF0005FF0000FFF0
05FF00AEFF00BDFF00BDFF009EFF0080FF001400FF61FF00CCFF00DCFF00EBFF00DCFF00
FFF500FFE600FFE600FFF50042FF00FFB800FFA800FF9900FF9900FF9900FF8A00FF8A00
FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900
FF9900FF9900FF9900FFA800FFA800FFB800FFD700FFF500FFD700FFE600FFF500CCFF00
AEFF0042FF009EFF0061FF009EFF00DCFF00FAFF00FFF500FFE600FFD700FFD700FFD700
FFC700FFC700FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFB800FFA800FFB800FFA800FFA800
FFA800FFB800FFB800FFA800FFA800FFA800FFB800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFA800FFA800FFA800FFA800
FFA800FFB800FFB800FFB800FFB800FFB800FFC700FFD700FAFF0061FF00CCFF0061FF00
80FF0000FF3823FF00BDFF00CCFF00DCFF00FAFF00FFF500FFE600FFD700FFD700FFC700
FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFA800FFB800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFA800FFA800FFA800FFA800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFD700FFD700
FFF50061FF0033FF0000FF19FF00008F00FF14FF000019FF0028FF00F0FF4200FF00FF85
00FF2800FF2800FF94FF000000FF3800FFA3FF0000FF000000C2FFFF000000FF2814FF00
00FF28FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF000000FF3833FF0000FF38FF00000500FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000075FF0085FF00F0FF70FF0061FF0000FF6642FF00
8FFF00BDFF00CCFF00BDFF008FFF0000FFFF00FFE133FF00DCFF00EBFF00FAFF00FFF500
FFE600FFD700FFD700FFE60061FF00FFB800FFA800FF9900FF9900FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900
FF9900FF9900FF9900FFA800FFA800FFB800FFB800FFC700FFC700FFD700FFE600EBFF00
EBFF00EBFF00DCFF00DCFF0000FF19CCFF00FAFF00FFF500FFE600FFD700FFD700FFD700
FFC700FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFB800FFB800FFB800FFB800FFC700FFD700FAFF00CCFF0061FF0070FF00
9EFF0051FF009EFF008FFF0061FF00AEFF00EBFF00FFF500FFE600FFD700FFD700FFC700
FFC700FFB800FFC700FFB800FFB800FFB800FFB800FFA800FFB800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFD700
AEFF0042FF000047FF42FF009EFF009EFF00FF006B00FF1900D1FF00FFC200FFC200D1FF
00FF4714FF0033FF0033FF0000FFE1FF0000FF0000AE00FF00FF8500FF0A33FF0033FF00
FF0000FF0000FF0000DC00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF000042FF0051FF0023FF00FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00001400FF00FF3800FF0A23FF008FFF008FFF0000FF75AEFF00
CCFF00DCFF00DCFF00CCFF00AEFF0061FF000047FF00FF75BDFF00FAFF00FFF500FFE600
FFD700FFD700FFC700FFC700FFC700FFB800FFA800FF9900FF9900FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900
FF9900FF9900FF9900FFA800FFA800FFA800FFB800FFC700FFC700FFC700FFD700FFE600
FFE600FFF500FAFF00EBFF00BDFF0000FF47DCFF00FFF500FFE600FFD700FFD700FFC700
FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFD700EBFF00FFF500FFF500FAFF00
CCFF0051FF00DCFF0000FF75FF000023FF00DCFF00EBFF00FAFF00FFE600FFD700FFC700
FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFA800
FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFD700FFD700
FAFF00CCFF0051FF0000FFA3AEFF00CCFF00AEFF008000FF14FF0000FF7500FF66FF0000
00FFA323FF0042FF0051FF00BD00FFCC00FFFF00000057FFFF0000FF000042FF0051FF00
23FF00FF0000FF00007000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF000000C2FFFF000061FF0070FF0014FF00FF000000F0FFFF0000FF00000047FF
FF0000FF0000FF0000FF00000047FFFF00D742FF0061FF009EFF00AEFF0000E1FFDCFF00
DCFF00EBFF00EBFF00DCFF00CCFF0051FF0000FFD100F0FF9EFF00EBFF00FFF500FFD700
FFD700FFC700FFC700FFB800FFB800FFA800FF9900FF9900FF9900FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900
FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFB800FFB800FFC700FFC700FFD700
FFE600FFE600FFF500FAFF00DCFF00AEFF00FAFF00FFE600FFE600FFD700FFD700FFC700
FFC700FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFC700FFD700FFD700FFD700FFE600
80FF00FAFF00FAFF00CCFF0033FF009EFF00AEFF0005FF008FFF00FFF500FFD700FFC700
FFC700FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFA800FFA800
FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFD700
FFD700FFE600FAFF000038FF00F0FFEBFF00DCFF0023FF0000FF6600A3FF33FF0000E1FF
00FF3805FF0042FF0070FF0042FF005100FF1400FF00FF9400FF4700FF3861FF0061FF00
51FF0000FF0A00FF3800FFC21400FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF000000FF7523FF0080FF008FFF0061FF004200FF00E1FF0066FF0019FF00C2FF
FF000000FF85FF0000FF00000500FF0085FF61FF008FFF00AEFF00CCFF00DCFF00EBFF00
EBFF00EBFF00EBFF00EBFF00DCFF00CCFF009EFF0014FF0000FF38AEFF00FFF500FFD700
FFC700FFC700FFB800FFB800FFA800FFA800FF9900FF9900FF9900FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900
FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFC700FFC700
FFD700FFD700FFF500FAFF009EFF00DCFF00FAFF00FFE600FFE600FFD700FFD700FFC700
FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFA800FFB800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFC700FFC700FFC700FFC700FFD700
FFE600FFE600FFF500FAFF00DCFF00BDFF0000FFB38FFF00EBFF00FFE600FFD700FFC700
FFC700FFB800FFB800FFB800FFA800FFA800FFA800FFB800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FF9900FF9900FFA800FFA800FF9900FF9900FF9900
FFA800FFA800FF9900FF9900FF9900FFA800FFA800FF9900FF9900FF9900FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700
FFD700FFD700FFE600FAFF00FFF500FFF500FAFF00CCFF0000FF0A70FF0061FF0000A3FF
6100FFFF002E51FF0080FF008FFF0033FF00FF00F58FFF008FFF008FFF008FFF0080FF00
42FF0000FF0AFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF000080FF009EFF009EFF008FFF0070FF0000FF6600C2FF00FF75
14FF00FF00F500FFC2FF007A00F0FF14FF0042FF0033FF009EFF00CCFF00EBFF00FAFF00
FAFF00FAFF00FAFF00EBFF00EBFF00CCFF00BDFF008FFF0000FF1970FF00FFF500FFD700
FFC700FFC700FFB800FFB800FFA800FFA800FF9900FF9900FF9900FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00
FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900
FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFC700
FFC700FFD700FFE600EBFF009EFF00EBFF00FAFF00FFF500FFE600FFD700FFC700FFC700
FFC700FFB800FFC700FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900FFA800FF9900FF9900FFA800
FF9900FF9900FFA800FFA800FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFC700FFC700FFC700
FFD700FFD700FFE600FFF500FAFF00DCFF0070FF0000FF4700FF75FFF500FFD700FFC700
FFC700FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900FFA800
FFA800FF9900FF9900FFA800FFA800FF9900FF9900FF9900FFA800FF9900FF9900FF9900
FFA800FF9900FF9900FF9900FF9900FFA800FF9900FF9900FF9900FF9900FFA800FFA800
FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFB800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700
FFC700FFD700FFD700FFE600FFE600FFE600FFF500DCFF0023FF0080FF009EFF0051FF00
FF0000FF00C761FF008FFF009EFF009EFF009EFF00AEFF00AEFF00AEFF009EFF0080FF00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00004200FFFF00008FFF00AEFF00AEFF00AEFF0042FF0000FF0AFF000000C2FF
4200FF61FF006100FF00FFD1AE00FF00FF285100FF00FF8500FF2805FF00FAFF00FAFF00
FAFF00FFF500FAFF00FAFF00EBFF00CCFF00AEFF0070FF0000FF38DCFF00FFF500FFD700
FFC700FFC700FFB800FFA800FFA800FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFB800FFB800FFB800FFC700
FFD700FFD700FFF500EBFF0042FF00EBFF00FAFF00FFF500FFE600FFD700FFD700FFC700
FFC700FFC700FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FF9900FF9900FFA800FF9900FF9900FF9900FF9900FFA800FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FFA800FF9900FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFB800FFA800FFB800FFB800FFB800FFB800FFB800FFC700
FFC700FFD700FFE600FFF500FAFF00DCFF0000FF57DCFF00AEFF00FAFF00FFD700FFC700
FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FF9900FF9900FFA800FF9900FF9900FF9900
FFA800FF9900FF9900FF9900FFA800FF9900FF9900FF9900FFA800FF9900FF9900FF9900
FFA800FF9900FF9900FF9900FF9900FFA800FF9900FF9900FF9900FF9900FFA800FF9900
FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700
FFC700FFC700FFD700FFD700FFE600FFE600FFE600FFF500EBFF00DCFF00AEFF0061FF00
00FF190066FF61FF009EFF00AEFF00BDFF00BDFF00BDFF00BDFF00AEFF009EFF0033FF00
00FF0A8000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF000000FF57CC00FFFF0000AEFF00BDFF00BDFF00BDFF0023FF0014FF0014FF00FF00F5
00FF948FFF00FF006B23FF005100FF00FF94FF00D751FF009EFF00DCFF00FAFF00FFF500
FFF500FFF500FFF500FAFF00DCFF00CCFF009EFF0000FFC200FFC28FFF00CCFF00FFE600
FFD700FFC700FFB800FFA800FFA800FFA800FF9900FF9900FF9900FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFB800FFB800FFC700
FFC700FFD700FFF500BDFF0070FF00DCFF00EBFF00FFF500FFF500FFD700FFD700FFC700
FFC700FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900FFA800FF9900FF9900
FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFB800FFA800FFA800FFB800FFB800FFB800FFC700
FFC700FFD700FFE600FFF500FAFF00DCFF0000FF38FAFF00FAFF00EBFF00FFD700FFC700
FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FF9900FF9900FFA800FF9900FF9900FF9900FFA800FF9900FF9900FF9900
FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FFA800FF9900FF9900FF9900FF9900FFA800FF9900
FF9900FF9900FF9900FF9900FFA800FFA800FF9900FF9900FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700
FFC700FFC700FFD700FFD700FFD700FFD700FFE600FFE600FFF500EBFF009EFF000019FF
2300FF00FFC261FF009EFF00BDFF00BDFF00CCFF00CCFF00CCFF00BDFF009EFF0042FF00
00A3FFFF0000FF0000FF0000FF0000FF0000000AFFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
00E1FF00FF0A42FF008FFF00AEFF00CCFF00CCFF00CCFF00BDFF00BDFF00AEFF00BDFF00
BDFF00AEFF008FFF0070FF0033FF0000FF4700D1FF00FFB3CCFF00FAFF00FFF500FFF500
FFE600FFF500FFF500FAFF00CCFF00BDFF0000FFE100A3FFFF000000FF0AAEFF00FFF500
FFD700FFC700FFB800FFA800FFA800FFA800FF9900FF9900FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFB800FFB800FFB800FFC700
FFC700FFD700FFF500EBFF0061FF0080FF00BDFF00DCFF00DCFF00FFE600FFD700FFC700
FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800
FFC700FFC700FFE600FAFF00DCFF00BDFF0061FF00FFF500FFD700FFD700FFC700FFB800
FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900
FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FFA800FF9900FF9900FF9900
FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FFA800FF9900FF9900FF9900FF9900FFA800FF9900
FF9900FF9900FF9900FF9900FFA800FF9900FF9900FF9900FF9900FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFC700FFC700FFC700FFC700FFD700FFD700FFD700FFE600FFF500EBFF0051FF00FF008A
0038FF42FF0080FF009EFF00BDFF00CCFF00CCFF00CCFF00CCFF00BDFF00AEFF0000FF94
FF0000FF0000FF0000FF0000FF0000FF000000FFF0FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF000070FF00AEFF00CCFF00DCFF00DCFF00DCFF00DCFF00DCFF00DCFF00
CCFF00BDFF008FFF0042FF0000FF1900FF0A2300FF80FF0000FFC2FFF500FFE600FFE600
FFE600FFE600FFE600FFF50070FF0000FFB351FF0000FF0A1400FF9EFF00DCFF00FFF500
FFF500FFE600FFC700FFB800FFA800FFA800FF9900FF9900FF9900FF8A00FF8A00FF8A00
FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFB800FFB800FFB800
FFC700FFE600FFF500DCFF0000FF19FF000042FF0080FF00DCFF00FFF500FFD700FFC700
FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800
FFC700FFC700FFE600BDFF009EFF008FFF00EBFF00FFD700FFC700FFC700FFB800FFB800
FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900FF9900
FF9900FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFC700FFC700FFC700FFC700FFD700FFD700FFD700FFE600FFE600EBFF0051FF000057FF
00FF5700B3FF05FF0080FF00BDFF00CCFF00DCFF00DCFF00DCFF00CCFF00AEFF00FA00FF
FF0000FF004CFF0000FF000000FF8500FF6600FF750066FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000000AFF4200FF0047FF8FFF00CCFF00DCFF00EBFF00EBFF00EBFF00EBFF00DCFF00
DCFF0005FF0061FF00FF00000057FF9EFF00FF004CDCFF00FAFF00FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFF50000FF4780FF00AEFF0051FF00AEFF00DCFF00EBFF00
CCFF00EBFF00FFC700FFB800FFA800FFA800FF9900FF9900FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFB800FFB800FFC700
FFD700CCFF00CCFF00BDFF00FF001EFF000080FF00DCFF00DCFF0023FF00FFD700FFC700
FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FF9900FF9900FFA800
FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800
FFB800FFC700FFF5009EFF00EBFF00FFF500FFD700FFC700FFC700FFB800FFB800FFB800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900
FF9900FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FFA800FF9900FF9900FF9900FF9900FF9900FFA800FFA800FF9900
FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFC700FFC700FFC700FFC700FFD700FFD700FFD700FFE600FAFF0000FF758FFF00
00FF384200FF00FF2800FF47CCFF00DCFF00DCFF00DCFF00DCFF00DCFF00BDFF006100FF
23FF0000E1FFEB00FF0085FF00FF8505FF00FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00004200FF0028FF00FFA3DCFF00EBFF00EBFF00FAFF00FAFF00FAFF00FAFF00
EBFF00BDFF0000FF0A61FF0080FF00DCFF0070FF00FAFF00FFE600FFE600FFD700FFD700
FFD700FFD700FFD700FFE600FFE600FFF500FAFF00CCFF0000FF7500FF389EFF00CCFF00
61FF00EBFF00FAFF00FFB800FFA800FFA800FF9900FF9900FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFB800FFB800
FFC700FFE600FAFF00CCFF00AEFF0051FF009EFF00FAFF00FFF500FFE600FFD700FFC700
FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900
FF9900FFA800FF9900FF9900FF9900FF9900FF9900FFA800FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800
FFB800FFC700FAFF0033FF00EBFF00FFE600FFC700FFC700FFB800FFB800FFB800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FF9900FF9900
FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFC700FFC700FFC700FFC700FFD700FFD700FFE600FFF500EBFF00FAFF00
EBFF0000FF1933FF00AEFF00DCFF00EBFF00EBFF00EBFF00DCFF00DCFF00CCFF00BDFF00
AEFF0061FF00FF001E05FF0033FF0023FF00FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00003300FFFF000000FF85DCFF00EBFF00FAFF00FAFF00FAFF00FAFF00FAFF00
EBFF00CCFF0061FF0000FF66DCFF00FAFF00FAFF00FFE600FFE600FFE600FFD700FFD700
FFD700FFD700FFD700FFD700FFD700FFE600FFF50000FF8570FF009EFF0000FF5780FF00
33FF00AEFF00FAFF00FFC700FFA800FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFB800FFB800FFB800
FFC700FFD700FFF500FAFF00EBFF00CCFF00BDFF00FAFF00FFE600FFD700FFC700FFC700
FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FFA800FF9900FFA800FFA800FFA800FFA800FFA800FFA800
FFB800FFC700FFD700FFF50080FF00FFE600FFC700FFB800FFB800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FF9900FF9900FFA800FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFE600FFE600FFF500
FAFF00EBFF00EBFF00EBFF00EBFF00FAFF00EBFF00EBFF00EBFF00DCFF00DCFF00CCFF00
BDFF00FF000000D1FF51FF0061FF0033FF00FF0000FF00000075FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF000000FFF000FFD19EFF00EBFF00FAFF00FAFF00FFF500FFF500FFF500FFF500
FAFF00CCFF0061FF0023FF00FFF500FFE600FFE600FFE600FFD700FFD700FFD700FFD700
FFD700FFD700FFD700FFD700FFD700FFD700FFE600FFF500FAFF00EBFF00DCFF00AEFF00
61FF009EFF00FFE600FFC700FFA800FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFB800FFB800FFB800
FFC700FFD700FFD700FFF500FAFF00DCFF00AEFF00CCFF00FFD700FFD700FFC700FFB800
FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800
FFB800FFB800FFC700FFF50061FF00EBFF00FFB800FFB800FFB800FFA800FFB800FFA800
FFA800FFA800FFA800FF9900FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FF9900FF9900FF9900
FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFD700FFD700FFD700FFE600FFE600
FFE600FFF500FFF500FAFF00FAFF00FAFF00FAFF00FAFF00EBFF00EBFF00DCFF00DCFF00
CCFF00AEFF00FF006B80FF0070FF0051FF0000F0FFFF000000FF75FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000028FF05FF00
23FF0000A3FF33FF00FF001EBDFF00EBFF00FAFF00FFF500FFF500FFF500FFF500FFF500
FFF500AEFF00EBFF00FFF500FFE600FFD700FFD700FFD700FFD700FFC700FFD700FFC700
FFC700FFC700FFC700FFC700FFD700FFD700FFD700FFE600FFF500FFF500EBFF00BDFF00
CCFF00BDFF00DCFF00FFC700FFA800FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFB800FFC700
FFC700FFC700FFD700FFE600FAFF00DCFF00DCFF00FFF500FFD700FFD700FFC700FFB800
FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800
FFA800FFB800FFB800EBFF00FFD700FFC700FFB800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FFA800FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFA800FFB800FFB800FFB800FFB800
FFB800FFB800FFC700FFB800FFC700FFC700FFC700FFD700FFD700FFD700FFD700FFE600
FFE600FFE600FFF500FFF500FFF500FAFF00FAFF00FAFF00EBFF00EBFF00DCFF00DCFF00
CCFF00BDFF00AEFF008FFF0080FF0070FF0042FF0000FF5700FF19FF00000019FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000075FF
61FF00FF002E9EFF008FFF00DCFF00FAFF00FAFF00FFF500FFF500FFF500FFE600FFE600
FFE600FFE600FFE600FFE600FFD700FFD700FFD700FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFD700FFE600FFF500EBFF00BDFF00
00FF66FFF500FAFF00FFD700FFA800FFA800FF9900FF9900FF9900FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800
FFC700FFC700FFD700FFE600EBFF00BDFF00FAFF00FFE600FFD700FFC700FFC700FFB800
FFB800FFA800FFA800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FFA800FF9900FF9900FF9900FFA800FFA800FFA800
FFA800FFA800FFB800FFE600FFC700FFB800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FF9900FF9900FF9900FF9900FFA800FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFB800FFA800FFA800FFA800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFD700
FFE600FFE600FFE600FFF500FFF500FFF500FAFF00FAFF00FAFF00EBFF00EBFF00DCFF00
CCFF00BDFF00AEFF009EFF008FFF0070FF0051FF0033FF0005FF00FF000000FFD1FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFD1FF000051FF00
80FF009EFF00BDFF00CCFF00EBFF00FAFF00FFF500FFF500FFE600FFE600FFE600FFE600
FFE600FFD700FFD700FFD700FFD700FFC700FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFE600FFF50080FF0061FF00
FFF500FFD700FFD700FFB800FFA800FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFB800FFB800FFB800
FFC700FFD700FFD700FFF500DCFF00DCFF00FAFF00FFE600FFD700FFC700FFC700FFB800
FFB800FFA800FFA800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FF9900FFA800
FFA800FFA800FFA800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FFA800FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFD700FFD700FFD700
FFE600FFE600FFE600FFF500FFF500FFF500FAFF00FAFF00FAFF00EBFF00DCFF00CCFF00
CCFF00BDFF00AEFF009EFF0080FF0061FF0042FF0023FF0005FF0000FF3800FF7500E1FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000023FF0061FF00
8FFF00AEFF00CCFF00DCFF00EBFF00FAFF00FFF500FFF500FFE600FFE600FFE600FFD700
FFD700FFD700FFD700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700
FFB800FFB800FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFE6009EFF00AEFF00
FFE600FFC700FFB800FFA800FFA800FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00
FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFB800FFB800FFC700
FFC700FFD700FFD700FFF500EBFF0070FF00FAFF00FFF500FFD700FFC700FFC700FFB800
FFB800FFB800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900FFA800FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFA800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFC700FFD700FFD700
FFD700FFE600FFE600FFE600FFF500FFF500FAFF00FAFF00FAFF00EBFF00DCFF00CCFF00
BDFF00AEFF009EFF008FFF0000FFC2FF0000CC00FF00FF19FF000000FF6600D1FF00FFE1
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFF0FF0000FF000000FF19
51FF009EFF00BDFF00DCFF00EBFF00FAFF00FFF500FFE600FFE600FFE600FFD700FFD700
FFD700FFD700FFC700FFC700FFC700FFC700FFC700FFC700FFB800FFB800FFC700FFB800
FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFC700FFD700FFE60000FF28CCFF00
DCFF00FFC700FFB800FFA800FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF6B00
FF6B00FF6B00FF6B00FF6B00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFB800FFB800FFB800FFC700
FFC700FFD700FFE600FAFF00CCFF00BDFF00BDFF00EBFF00FFF500FFD700FFC700FFB800
FFB800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF8A00FF8A00FF9900FF9900FF8A00FF8A00FF8A00FF9900FF9900FF8A00FF8A00
FF8A00FF9900FF9900FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FF9900
FF9900FFA800FFA800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FF9900FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFD700FFD700
FFD700FFD700FFE600FFE600FFE600FFF500FFF500FAFF00FAFF00EBFF00DCFF00AEFF00
9EFF0070FF0061FF0070FF0000FFC2FF000000E1FF0094FF7000FF5100FFFF0000FF0000
0038FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000047FFFF0000
FF0000CC00FFAEFF00CCFF00DCFF00FAFF00FFF500FFF500FFE600FFD700FFD700FFD700
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFD700FFE600FAFF0014FF00
DCFF00FFB800FFA800FFA800FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFB800FFC700FFC700FFC700
FFD700FFD7009EFF00CCFF00EBFF00FAFF00DCFF00BDFF00FFF500FFD700FFC700FFB800
FFB800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF9900FF9900
FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF9900FF9900FF8A00FF8A00
FF8A00FF9900FF9900FF8A00FF8A00FF8A00FF9900FF9900FF8A00FF8A00FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FFA800FF9900FF9900FF9900FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFD700FFD700
FFD700FFD700FFE600FFE600FFF500FFF500FFF500FAFF00FAFF00DCFF00BDFF009E00FF
FF000000FF28000AFF33FF00FF0000FF002EFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF000000FF288FFF000500FF23FF00DCFF00FFF500FFE600FFE600FFD700FFD700FFD700
FFD700FFC700FFC700FFC700FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFD700FFE600EBFF0000FF94
FFF500FFB800FFA800FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFB800FFC700FFC700FFD700
FFD700FFE600EBFF0070FF00FFF500FFE600FFE600FAFF00FAFF00FFD700FFC700FFB800
FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF9900
FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FFA800FF9900FF9900FF9900FF9900FF9900FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFA800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFC700FFD700
FFD700FFD700FFE600FFE600FFE600FFF500FFF500FAFF00FAFF00DCFF00FF0000FF00B8
0057FF00B3FF00FF2800FFC200FF6600FFF0FA00FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00008F00FF
00FF75FF000070FF00DC00FF3300FF51FF00FAFF00FFE600FFE600FFD700FFD700FFC700
FFC700FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFD700FFF500CCFF00FFE600
FAFF00FFB800FFA800FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900
FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFB800FFB800FFC700FFD700FFD700
FFE600FFF500DCFF00EBFF00FFE600FFE600FFD700FFF500EBFF00FFE600FFD700FFB800
FFB800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF9900
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF9900
FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFC700FFD700
FFD700FFD700FFE600FFE600FFE600FFF500FFF500FAFF00EBFF00DCFF0070FF0000FFD1
FF00002300FF0038FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
00FF9414FF0033FF00FF000042FF00CCFF00FAFF00FFE600FFE600FFD700FFC700FFC700
FFC700FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFA800FFB800FFB800FFA800FFB800FFB800FFB800FFC700FFE6009EFF0000FF0AFFC700
FFB800FFA800FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF9900FF9900FF9900FFA800FFA800FFB800FFB800FFC7009EFF00FAFF00FFF500
FFF500CCFF00DCFF00FFE600FFD700FFC700FFC700FFD700DCFF0051FF00FAFF00FFB800
FFA800FFA800FF9900FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF8A00FF8A00FF9900FF9900FF9900FF8A00FF8A00FF8A00FF9900FF9900FF9900FF8A00
FF8A00FF8A00FF8A00FF9900FF9900FF9900FF8A00FF8A00FF8A00FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFC700FFD700FFD700
FFD700FFD700FFE600FFE600FFF500FFF500FAFF00FAFF00EBFF00DCFF00AEFF00FF008A
FF000000B3FFEB00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00004200FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0099DC00FF00FF0ABD00FF70FF00CCFF00FAFF00FFE600FFD700FFD700FFC700FFC700
FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFA800FFB800
FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFC700FFB800FFB800
FFA800FFA800FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF9900FF9900FF9900FF9900FFA800FFA800FFC700FFD700FFD700EBFF00EBFF00BDFF00
8FFF00FAFF0061FF00FFD700FFC700FFC700FFC700FFC700FFD700FFD700FFE600FFB800
FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF9900FF9900FF9900FF8A00
FF8A00FF8A00FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00
FF8A00FF8A00FF8A00FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900
FF9900FF9900FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FF9900
FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFD700
FFD700FFD700FFE600FFE600FFF500FFF500FAFF00FAFF00EBFF00DCFF008FFF0000FFFF
00D1FF00D1FF00FFB3FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF000000F0FFFF0000FF0000FF0000FF0000FF0000FF0000
FF000000FFD100FF47FF000000FF478FFF0000FF38FFF500FFD700FFD700FFC700FFC700
FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFA800FFA800
FFA800FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF9900FF9900FF9900FFA800FFA80070FF00DCFF00FFF500BDFF00FFE600FFE600
FFF500FFD700FAFF00FFC700FFB800FFB800FFB800FFB800FFB800FFC700FFD700FFB800
FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF9900FF9900
FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF8A00FF8A00FF9900FF9900FF8A00FF8A00FF8A00FF9900FF9900FF8A00
FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00
FF8A00FF8A00FF8A00FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900
FF9900FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFC700FFD700
FFD700FFD700FFE600FFE600FFF500FAFF00FAFF00EBFF00DCFF0080FF0023FF000500FF
4200FF00FF9400FF751400FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000AE00FF00FF85FF0000FF0000FF0000FF0000FA00FFFF0000
FF0000FF00000094FFFF000000FFF00066FF0057FFFFF500FFD700FFD700FFC700FFC700
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF9900FF9900FF9900FFA800FFB800FFC700FFF500AEFF00FFE600FFD700FFC700
FFC700FFC700FFC700FFB800FFB800FFB800FFA800FFA800FFB800FFA800FFA800FFA800
FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF9900
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00
FF8A00FF9900FF9900FF8A00FF9900FF9900FF8A00FF8A00FF9900FF9900FF8A00FF8A00
FF9900FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00
FF8A00FF8A00FF8A00FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900
FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFD700FFD700
FFD700FFE600FFE600FFF500FAFF00FAFF00EBFF00EBFF00DCFF00AEFF00EB00FF00FF75
00FF4700FF2800FF4700FFFFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF000000FF28FF00000075FFFF00000057FF00FFE10057FF
00F0FFFF00998000FF7000FF00FFFF05FF00DCFF00FFF500FFE600FFD700FFC700FFC700
FFC700FFB800FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF9900FF9900FFA800FFA800FFB800FFD7009EFF00FFD700FFC700FFC700
FFB800FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF9900FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF9900FF8A00FF8A00FF8A00
FF9900FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900
FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF8A00FF8A00FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FF9900FF9900FF9900FF9900
FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFC700FFD700
FFD700FFE600FFE600FAFF00DCFF0042FF00DCFF00DCFF00CCFF00AEFF0061FF0000FF57
00FFE114FF0000FFB3FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF000005FF0023FF0000FF38FF000000A3FF00FF2800FF38
00FF3800FF57FF001E9E00FF0019FF33FF00BDFF00FFF500FFD700FFD700FFC700FFC700
FFB800FFB800FFB800FFB800FFB800FFA800FFB800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FF9900FFA800FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF9900FF9900FF9900FFA800FFB800FFB800FFD700AEFF00FFD700FFC700FFB800
FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF9900FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF8A00FF8A00FF8A00FF8A00
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFA800
FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFD700
FFD700FFE600FFF500EBFF0000D1FF33FF00CC00FFBDFF00BDFF00AEFF008FFF0070FF00
51FF0023FF000066FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000075FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF000014FF0051FF00FF00000038FFFF0000FF000042FF00
05FF001400FF0500FF3300FF0075FF33FF0023FF0080FF00FFD700FFC700FFC700FFB800
FFB800FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FF9900FFA800FF9900FFA800FF9900FF9900FF9900FF9900FF9900
FF9900FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00
FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF9900FF9900FFA800FFA800FFB800FFD700DCFF00FFD700FFB800FFB800
FFA800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FFA800FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFD700FFD700
FFE600FFE600FFF500EBFF001400FF00FF7561FF00AEFF00AEFF009EFF008FFF0070FF00
42FF0005FF0000FF94FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF000000D1FF0094FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF000000F0FFFF000023FF0080FF0061FF0033FF0042FF0080FF0061FF00
00FFB300FFFF05FF00FF000051FF0070FF00DCFF00FFF500FFD700FFC700FFC700FFB800
FFB800FFB800FFB800FFB800FFA800FFB800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FF9900FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF9900FF9900FFA800FFB800FFC700FFD700EBFF00FFC700FFB800FFA800
FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800
FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFD700FFD700
FFE600FFE600FAFF00BDFF0033FF0000FF0A00FF1923FF008FFF009EFF008FFF00FF006B
00FF757000FF0085FF00F0FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00F5FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF000000FF2805FF0070FF009EFF009EFF00AEFF00AEFF009EFF0061FF00
000AFF00FF4761FF009E00FF9EFF00DCFF00FFF500FFE600FFD700FFC700FFC700FFB800
FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF9900FF9900FFA800FFC700FFE600EBFF00FFF500FFC700FFB800FFA800
FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF9900FF9900FF9900FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFC700FFC700FFD700FFD700FFE600
FFE600FFF500FAFF0061FF0000FF6651FF0000FF2800FF3870FF008FFF0080FF0000FF28
FF000000F0FF0075FFFF00E6FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00008000FF00FF75FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF000042FF0070FF009EFF00BDFF00CCFF00CCFF00AEFF0000FF94
00FFB305FF008FFF0000FFA380FF00DCFF00FFE600FFD700FFC700FFC700FFC700FFB800
FFB800FFB800FFA800FFA800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF9900FF9900FFA800FFD700FFE600FFE600FFC700FFC700FFA800FFA800
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00
FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFD700FFE600FFF500
FFF500FAFF00EBFF00CCFF009EFF0070FF00FF000000FFE161FF0070FF000038FF00FF38
0047FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF000000FF6600FF38FF0000000AFFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00B800FF280047FF61FF00CCFF00DCFF00DCFF00BDFF00EB00FF
FF00E6BDFF00BDFF0023FF0014FF00BDFF00FFE600FFD700FFC700FFC700FFB800FFB800
FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF9900FF9900FFA800FFE600FFC700FFB800FFA800FFA800FFA800FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FFA800FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFE600EBFF000057FF
CCFF00DCFF00DCFF00CCFF00AEFF0000FF6600FFC205FF0051FF0051FF0000FF38FF0000
00FF9400D1FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000BD00FFFF000000FF0AFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000066FF00FF570057FF0066FFCCFF00DCFF00DCFF00DCFF00DCFF00
DCFF00EBFF00CCFF0042FF0000FF578FFF00FFE600FFD700FFC700FFC700FFB800FFB800
FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF9900FFA800FFB800FFA800FFA800FFA800FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFC700FFC700FFD70061FF0080FF00
0057FFAEFF00BDFF00BDFF00AEFF000085FF00FF6600FFE114FF0042FF0023FF0000FF0A
00FFA31400FFFF0000FF0000FF0000FF0000FF004CFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00008000FFFF000005FF0023FF000028FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF000000FFF0FF00009EFF00DCFF00EBFF00EBFF00FAFF00FAFF00
FAFF00FAFF00EBFF00BDFF0000FF38EBFF00FFD700FFC700FFC700FFB800FFB800FFB800
FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF8A00FF9900FF8A00FF9900FF8A00FF9900FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFD700FAFF0000FF57
00FF2800FF0A33FF008FFF009EFF0000A3FF05FF00FF00C74200FF23FF0000FF0A00FF75
00FFC20019FFFF0000FF0000FF0000FF00002300FFAE00FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF000000FF2823FF0042FF0000FF0A0094FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000B3FF
FF0000FF00006100FFFF00004200FF7000FF00FF57DCFF00EBFF00FAFF00FAFF00FFF500
FFF500FFF500FAFF00EBFF0000FFC2FFE600FFD700FFC700FFC700FFB800FFB800FFB800
FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF8A00
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFB800FFB800FFB800FFC700FFC700FFC700FFD700FFF5009EFF00
23FF0000FFA3FF000042FF0070FF0061FF0000FF2800B3FF00FF3800FF0A00FFD10057FF
FF0000FF0000FF0099FF0000FF0000FF000000C2FF0066FFFF00F5FF0000FF0000FF0000
FF00005100FFFF000000B3FFFF0000FF000000FF0A51FF0042FF0014FF0000FF57FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
00FF66FF000000FF6600E1FFEB00FFFF009951FF00EBFF00FAFF00FAFF00FFF500FFF500
FFF500FFF500FFF500FAFF00FAFF00FFD700FFC700FFC700FFB800FFB800FFB800FFB800
FFB800FFA800FFA800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF8A00FF8A00FF8A00
FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FFA800FF9900FF9900FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFC700FFC700FFD700FFF50000FF28
AEFF00AEFF0033FF0000FFF005FF0033FF0014FF00FF00001400FF00FF3800FFC2FF0000
9E00FF00FFC2FF000000F0FFFF00004200FF00FF758000FFFF008AFF00000085FFFF0000
FF0000FF000000FF94FF0000FF000023FF0061FF0070FF0051FF0000FFB3FF003DFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000E1FF00FF47
23FF0042FF0000A3FFFF0000FF00C700FFFFFF00B8EBFF00FAFF00FFF500FFF500FFE600
FFE600FFE600FFE600FFE600FFD700FFD700FFC700FFC700FFB800FFB800FFB800FFB800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FFA800FF9900FF9900FF9900FF9900FFA800FFA800FFA800
FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFC700FFC700FFD700FFF50061FF00
CCFF00CCFF0080FF0000D1FF00FF570019FF00FF1900FFB300FF9400D1FFFF000000D1FF
0028FFFA00FF00FF4700FFA3FF000000FFB300FF3800FF28FF000000FF94FF001EFF0000
FF00000094FF00FF28FF001E0057FF61FF0080FF0080FF0061FF0000FFF0FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF94
FF000070FF0061FF0000FF3800FF1951FF00CCFF00FAFF00FAFF00FFF500FFE600FFE600
FFE600FFE600FFD700FFD700FFD700FFC700FFC700FFB800FFB800FFB800FFB800FFB800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00
FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800
FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFC700FFC700FFD700FFE600FAFF00
EBFF00DCFF00BDFF0005FF0051FF009E00FF7000FF00FFA300FFF0FF00A8FF000000FFE1
00C2FF05FF0000FF28BD00FFFF004CFF000F0066FF23FF0014FF0000FF1900FF6600FFFF
FF00000066FF14FF0042FF0070FF008FFF008FFF008FFF0005FF000028FFFF0000AE00FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000066FF
FF00008FFF009EFF000066FF70FF007000FFDCFF00FAFF00FFF500FFF500FFE600FFE600
FFE600FFD700FFD700FFD700FFC700FFC700FFC700FFB800FFB800FFB800FFB800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00
FF7A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00
FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF7A00
FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800
FFA800FFB800FFA800FFA800FFB800FFB800FFB800FFC700FFD700FFD700FFE600FAFF00
EBFF00DCFF00BDFF009EFF0070FF0023FF0000FF3800FFE1FF00D700FFC200FF5700FF19
14FF0033FF0000FF2800FF28FF000014FF0014FF0051FF0023FF0000FF3800FFB300FFD1
FF000000FF6614FF0051FF0080FF009EFF009EFF009EFF0080FF00FF0000FF00000047FF
FF000000FF57FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF004CFF0000
FF0000AEFF00AEFF00BDFF00AEFF0000FF75EBFF00FFF500FFF500FFE600FFE600FFE600
FFD700FFD700FFD700FFD700FFC700FFC700FFC700FFC700FFB800FFB800FFB800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00
FF7A00FF7A00FF8A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF8A00FF8A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00
FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FF9900FF9900FFA800FFA800
FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFC700FFD700FFE600FFF500FAFF00
EBFF00CCFF009EFF0080FF0000FF2800FF6600FFFF00FFA3FF00C76100FF00FFA300FF19
14FF0042FF0051FF0051FF0000FF7580FF0080FF0061FF0000FF0ACC00FFEB00FF0028FF
FF00F500FF571400FFFF00A880FF009EFF00AEFF00AEFF009EFF0080FF0023FF0000FF38
FF000000FF0A00FF75FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFA300FF28FF0000FF0000
00FFE1BDFF00CCFF00CCFF00DCFF00DCFF00FAFF00FFF500FFF500FFE600FFE600FFE600
FFD700FFD700FFD700FFC700FFC700FFC700FFC700FFB800FFB800FFB800FFB800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF8A00FF7A00FF7A00FF8A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF7A00FF7A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF9900FF9900FF9900FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800
FFA800FFA800FFA800FFA800FFB800FFB800FFC700FFC700FFD700FFF50080FF00EBFF00
DCFF0014FF0000FF5700FFA300FF38FF000014FF00FF000000FFC200FF475100FFFF0000
00FF0A42FF0061FF0070FF0080FF008FFF008FFF0061FF0000FF7500FF47FF0000FF0000
FF0000FF000000FF19FF00000028FFAEFF00BDFF00BDFF00AEFF009EFF0070FF0042FF00
42FF0023FF0000FF2800FFB3FF00008F00FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000033FF0000FF38FF008A
9EFF00CCFF00CCFF00DCFF00EBFF00EBFF00FAFF00FFF500FFE600FFE600FFE600FFD700
FFD700FFD700FFC700FFC700FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFA800
FFA800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF6B00FF6B00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF8A00FF8A00
FF7A00FF7A00FF8A00FF8A00FF7A00FF8A00FF8A00FF7A00FF7A00FF7A00FF8A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800
FFA800FFA800FFA800FFB800FFB800FFB800FFC700FFD70033FF00DCFF0051FF00AEFF00
51FF000047FF00FF2814FF0080FF0070FF0000FF1900FF471400FF00FF0A00FF0A7000FF
00FFF033FF0070FF0080FF008FFF009EFF009EFF008FFF0005FF00FF00A800FF75FA00FF
00C2FF51FF000028FF00FFA3AEFF00BDFF00CCFF00BDFF00BDFF00AEFF008FFF0080FF00
51FF00FF0000CC00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF000000A3FFFF0000FF000061FF0070FF0000FF0A
AEFF00CCFF00DCFF00EBFF00EBFF00FAFF00FAFF00FFF500FFE600FFE600FFE600FFD700
FFD700FFD700FFC700FFC700FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFA800
FFA800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00
FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF8A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00
FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFB800FFB800FFC700FFD700BDFF0000FF8500FF3861FF00
00FF1980FF0033FF00BDFF00BDFF0000FF0A00F0FF51FF000085FF14FF0033FF008F00FF
FF0000EB00FF61FF0080FF009EFF00AEFF00AEFF00BDFF00AEFF0000FF9442FF0000FF38
70FF00AEFF00BDFF00AEFF00CCFF00CCFF00CCFF00CCFF00BDFF00AEFF008FFF0070FF00
51FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF000000A3FFFF002EFA00FF80FF008FFF009EFF00
BDFF00CCFF00DCFF00EBFF00EBFF00FAFF00FFF500FFF500FFE600FFE600FFE600FFD700
FFD700FFD700FFC700FFC700FFC700FFC700FFB800FFB800FFB800FFB800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00
FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800
FFA800FFA800FFA800FFA800FFB800FFB800FFC700FFE600EBFF009EFF0000FFA351FF00
AEFF00CCFF00DCFF00EBFF00CCFF0033FF0070FF0080FF0000FF3842FF0070FF0042FF00
00FF57000AFF51FF0070FF008FFF00AEFF00BDFF00CCFF00BDFF008FFF00AEFF00FF005C
AEFF00DCFF00DCFF00DCFF00DCFF00DCFF00DCFF00CCFF00BDFF009EFF0070FF0033FF00
23FF006100FF0019FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00E6000AFF33FF0000E1FF80FF009EFF00AEFF00
BDFF00CCFF00DCFF00EBFF00EBFF00FAFF00FFF500FFF500FFE600FFE600FFE600FFD700
FFD700FFD700FFC700FFC700FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFA800
FFA800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800
FFA800FFA800FFA800FFA800FFB800FFB800FFC700BDFF0080FF00CCFF0061FF0061FF00
BDFF00DCFF00FAFF00FAFF00EBFF0000FF85AEFF009EFF0000B3FF0085FF8FFF0005FF00
00C2FF05FF0033FF0033FF0070FF00BDFF00CCFF00CCFF00DCFF00CCFF00CCFF006100FF
DCFF00EBFF00EBFF00EBFF00EBFF00EBFF00DCFF00DCFF00CCFF00FF0000FF000000FF47
05FF000075FFFF0099FF0000FF0000FF0000FF0000FF00008000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF000000FF6600FF2851FF0070FF008FFF009EFF00AEFF00
BDFF00CCFF00DCFF00EBFF00EBFF00FAFF00FAFF00FFF500FFE600FFE600FFE600FFE600
FFD700FFD700FFC700FFC700FFC700FFC700FFB800FFB800FFB800FFB800FFA800FFA800
FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF6B00
FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800
FFA800FFA800FFA800FFA800FFB800FFB800FFC700FFE60000FF94FFF50023FF00CCFF00
80FF00DCFF00FFF500FFF500FFF500FAFF00EBFF00BDFF0000C2FF9EFF00AEFF0000FF75
AE00FFEB00FF1400FF00F0FF00E1FFBDFF00CCFF00DCFF00DCFF00DCFF00DCFF00EBFF00
EBFF00EBFF00EBFF00EBFF00EBFF00EBFF00EBFF00DCFF00CCFF009EFF000066FF00A3FF
00FF8500FF941400FFFF0000FF0000FF0000FF0000FF00000038FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF000005FF0033FF0061FF0070FF008FFF009EFF00AEFF00
BDFF00CCFF00DCFF00DCFF00EBFF00FAFF00FAFF00FFF500FFF500FFE600FFE600FFD700
FFD700FFD700FFD700FFC700FFC700FFC700FFB800FFB800FFB800FFB800FFA800FFA800
FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF8A00FF8A00FF8A00FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FFA800FFA800FFA800FFA800FFB800FFB800FFC700FFD700FFD700FFE600FAFF00
00FFF000FF47FFE600FFE600FFE600FFE600FAFF0033FF0042FF00BDFF00CCFF00AEFF00
80FF0023FF00FF000000FFB380FF00BDFF00CCFF00DCFF00EBFF00EBFF00EBFF00EBFF00
FAFF00FAFF00FAFF00FAFF00FAFF00FAFF00EBFF00DCFF00CCFF00AEFF0000FF19FF00D7
00FFB300C2FFFF0000FF0000FF0000FF0000FF0000FF00D700F0FFFF001EFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF000000FF2814FF0042FF0051FF0070FF0080FF008FFF009EFF00
AEFF00AEFF00BDFF00DCFF00DCFF00EBFF00FAFF00FAFF00FFF500FFE600FFE600FFE600
FFD700FFD700FFC700FFC700FFC700FFC700FFC700FFB800FFB800FFB800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFC700FFC700FFC700FFE600
DCFF00FFE600FFD700FFD700FFD700FFE600FFF50000FFC200F0FFAEFF00EBFF00DCFF00
BDFF0000FFE10085FF00A3FF00FF28AEFF00DCFF00EBFF00EBFF00FAFF00FAFF00FAFF00
FAFF00FAFF00FAFF00FAFF00FAFF00FAFF00EBFF00DCFF00CCFF009EFF00FF001E00FFC2
FF00B800E1FFFF00B8FF0000FF0000FF0000FF000000D1FF00FF47FF0000FF0000FF008A
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF000000FF5700FF1905FF0023FF0005FF00000AFF0038FFFF000061FF00
51FF0005FF008FFF00AEFF00CCFF00DCFF00DCFF00EBFF00FAFF00FFF500FFE600FFE600
FFD700FFD700FFD700FFC700FFC700FFC700FFB800FFB800FFB800FFB800FFA800FFA800
FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FF9900FF9900FF9900FF9900
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFC700FFC700
FFD700FFD700FFC700FFC700FFD700FFD700FFE600FFF500FAFF00FAFF00FAFF00EBFF00
CCFF008FFF0051FF0000FFFF5100FF23FF00DCFF00EBFF00EBFF00FAFF00FAFF00FFF500
FFF500FFF500FFF500FFF500FAFF00FAFF00FAFF00EBFF0070FF0000FF3800FF0AFF0000
FF0000FF0000FF00B83300FF6100FFFF0000FF0000FF000000FF0A0019FFFF000000B3FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF000000FF9400FF66FF000000FFB300FFB30028FF00FF66FF00990047FF23FF00
00FF280028FF00FF4780FF00BDFF009EFF0000FF19CCFF00DCFF00FFF500FFF500FFE600
FFE600FFD700FFD700FFC700FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFA800
FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800
FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFD700FFE600FFE600FFF500EBFF00
8FFF008FFF0051FF0014FF0000FF19BDFF00DCFF00EBFF00FAFF00FAFF00FFF500FFF500
FFF500FFF500FFF500FFF500FFF500FFF500FAFF00EBFF00BDFF0000FF856100FF0094FF
FF005CFF000000B3FF00FFFF00FF576100FFFF00B805FF0023FF0014FF0000FF47FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF000000F0FF00E1FFFA00FFFF0000FF0000FF0000FF00D7FF0000FF000F00FFA38F00FF
8000FFFF0000FF000070FF008FFF0070FF002300FF61FF00AEFF00EBFF00FFF500FFE600
FFE600FFD700FFD700FFD700FFC700FFC700FFC700FFB800FFB800FFB800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00
FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800
FFB800FFB800FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFE600FFE600FAFF00
05FF000075FF23FF0033FF008FFF00BDFF00CCFF00EBFF00FAFF00FFF500FFF500FFF500
FFF500FFF500FFF500FFF500FFF500FFF500FAFF00EBFF00DCFF009EFF00FF0000DC00FF
FF0000FF006B7000FF00FFF00066FF14FF0042FF0051FF0051FF00FF000000FF57FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0028FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000CC00FFFF0000
FF000000FF4705FF0000FF5700FFA300FFD100FFFF00FF7580FF003300FFDCFF00FFF500
FFE600FFE600FFD700FFD700FFD700FFC700FFC700FFC700FFB800FFB800FFB800FFA800
FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00
FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFD700FFD700FFE600EBFF00
8FFF000066FF00FF6642FF0061FF008FFF00BDFF00CCFF00FAFF00FFF500FFF500FFF500
FFE600FFE600FFE600FFF500FFF500FFF500FFF500FAFF00DCFF000500FF00F0FF00FFF0
FF0000FF000000FFB3AE00FF0047FF000AFF61FF0080FF0051FF00FF000000FFD1FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
000AFFDC00FF00FF668000FFFF000000FF940094FF00E1FF23FF0070FF00BDFF00FAFF00
FFF500FFF500FFE600FFE600FFD700FFC700FFC700FFC700FFB800FFB800FFB800FFA800
FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00
FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900
FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFD700FFE600CCFF00
8FFF000019FF00FF6633FF0000FF8500C2FF61FF0051FF00FAFF00FFF500FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFF500FFF500FAFF00CCFF0000B3FF61FF0014FF00
000AFF00FFA300FFD105FF00FA00FF00FFFF80FF008FFF0070FF0000E1FFFF0000FF0000
FF0000FF00000075FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000500FF00FF3800FF3800D1FF0057FF00FF57DCFF00FAFF00
FAFF00FFF500FAFF00FAFF00FFE600FFD700FFC700FFC700FFB800FFB800FFB800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00
FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFD700FFF500
CCFF0070FF0080FF0080FF00CCFF0005FF0051FF00EBFF00FFF500FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFF500FFF500FFF500CCFF0070FF00BDFF00BDFF00
FF007A61FF000500FF42FF0061FF0070FF009EFF009EFF0080FF0014FF005100FFFF0000
FF0000FF0000FF0000FF00005100FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000BD00FF00FF7523FF0033FF0061FF009EFF00DCFF00EBFF00
EBFF00EBFF009EFF008FFF00DCFF00FFD700FFD700FFC700FFC700FFB800FFB800FFB800
FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFD700FFE600
00FF94BDFF00EBFF00EBFF00FAFF00BD00FFDCFF00FFF500FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF500FAFF00EBFF00EBFF00EBFF00
CCFF009EFF0000FFC200FF859EFF00AEFF00BDFF00AEFF008FFF0000FF66FF0000FF0000
FF00F5BD00FF00FF2800FFF0FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000075FF0019FF33FF0061FF008FFF00AEFF00CCFF00DCFF00
DCFF00BDFF0000FFB3AEFF00FAFF00FFE600FFD700FFC700FFC700FFB800FFB800FFA800
FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF7A00FF7A00FF7A00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFC700FFB800FFC700FFC700FFE600
42FF0061FF00FFE600FFE600FFE600FFF500FFF500FFE600FFD700FFD700FFE600FFD700
FFD700FFD700FFD700FFD700FFE600FFE600FFE600FFE600FFF500FFF500FAFF00FAFF00
EBFF00AEFF000500FF0075FFAEFF00BDFF00BDFF00BDFF00AEFF0000FF75DC00FFFF00C7
EB00FF05FF0005FF00FF0000FF0000FF0000CC00FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF005C51FF0080FF008FFF0000FF758FFF00
BDFF00AEFF0000FF388FFF00EBFF00FAFF00FAFF00FFD700FFC700FFC700FFB800FFB800
FFA800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF7A00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFD700
FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700
FFD700FFD700FFE600FFD700FFD700FFE600FFE600FFE600FFE600FFF500FFF500FAFF00
FAFF00CCFF00BDFF009EFF00CCFF00CCFF00CCFF00CCFF00BDFF0042FF00CC00FF00FF94
00B3FF51FF0042FF00FF0000FF00000047FF00E1FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00006100FF00FFB314FF0000FF5700FF280057FF00FF94
9EFF008FFF0070FF0042FF00BDFF009EFF0014FF00EBFF00FFD700FFC700FFB800FFB800
FFB800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFC700FFC700
FFC700FFC700FFC700FFC700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700
FFD700FFD700FFD700FFD700FFD700FFD700FFE600FFE600FFE600FFE600FFF500FFF500
FAFF00FAFF00EBFF00DCFF00DCFF00DCFF00DCFF00CCFF00CCFF00BDFF00AEFF00FF004C
23FF0070FF0061FF00FF0000FF0000FF0000FF0000FF0000FF00D7FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000057FF0066FFFF00F500FF578F00FF23FF00
33FF0042FF0051FF0000FF949EFF0005FF00BDFF00EBFF00FFD700FFC700FFB800FFB800
FFA800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800
FFA800FFB800FFA800FFA800FFA800FFB800FFA800FFB800FFB800FFB800FFB800FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFD700FFD700
FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFE600FFE600FFE600FFF500FFF500
FFF500FAFF00FAFF00EBFF00EBFF00EBFF00DCFF00DCFF00CCFF00CCFF00BDFF009EFF00
8FFF008FFF0080FF0051FF00FF000014FF00FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000094FFFF0000FF00005100FFFF004C00B3FF
1400FF00D1FF00FFC2FF00D770FF000094FFDCFF00FFF500FFD700FFC700FFB800FFB800
FFB800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF7A00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00
FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FF9900FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800
FFB800FFB800FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFD700
FFC700FFD700FFD700FFD700FFD700FFD700FFE600FFD700FFE600FFE600FFE600FFF500
FFF500FAFF00FAFF00FAFF00EBFF00EBFF00EBFF00DCFF00DCFF00CCFF00BDFF00AEFF00
9EFF009EFF008FFF0070FF0051FF0042FF0014FF00FF00B800FF66FF0000FF00F5FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00005100FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF9400FFA3
00FF1905FF0000FF9400FF382300FF8FFF00CCFF00FFF500FFD700FFC700FFC700FFB800
FFB800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FF9900FF9900FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFD700FFD700FFD700FFD700FFD700FFE600FFE600FFE600FFE600FFF500
FFF500FFF500FAFF00FAFF00FAFF00EBFF00EBFF00DCFF00DCFF00CCFF00BDFF00BDFF00
9EFF009EFF008FFF0070FF0061FF0051FF0033FF0005FF0000FF1900FFF0FF0000FF00B8
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFC2FF0000
42FF0033FF00FF008A05FF0061FF00BDFF00DCFF00FAFF00FFE600FFD700FFC700FFB800
FFB800FFA800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFD700FFD700FFD700FFD700FFE600FFE600FFE600FFE600
FFF500FFF500FFF500FAFF00FAFF00EBFF00EBFF00DCFF00DCFF00CCFF00BDFF00AEFF00
AEFF009EFF008FFF0070FF0061FF0042FF0023FF0014FF0000FF1900FF4700FF85FF007A
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF000000D1FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00006100FF51FF00
70FF0061FF00FF000000FF0A80FF00AEFF00BDFF0051FF00DCFF00FAFF00FFD700FFB800
FFB800FFB800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFD700FFD700FFD700FFD700FFD700FFD700FFE600FFE600FFE600
FFF500FFF500FFF500FAFF00FAFF00FAFF00EBFF00DCFF00DCFF00CCFF00BDFF00AEFF00
9EFF008FFF0070FF0051FF0051FF00FF00005100FF00FF19FF0000FF000000FF9400FFC2
00E1FF0500FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF000000FFFF00B3FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00005100FF0057FF00FFD100FFFF0094FF
8FFF0080FF00FF000000FF8500FF5723FF0000FF280094FF61FF0000FF19FFE600FFC700
FFB800FFB800FFA800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900
FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFB800FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFD700FFD700FFE600FFE600FFE600
FFE600FFF500FFF500FAFF00FAFF00FAFF00EBFF00DCFF00CCFF00BDFF00AEFF009EFF00
9EFF0051FF0000FF0A0019FF05FF00FF0000EB00FFFF0000FF00E6FF0000FF0000FF0000
FF00000028FF4200FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF000000F0FF00FF85FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFA300FF2800FF6661FF00
9EFF009EFF0080FF0000FF2814FF0000FF0A9EFF00CCFF00AEFF00AEFF00FFE600FFC700
FFB800FFB800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FFA800FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700
FFC700FFC700FFC700FFC700FFD700FFD700FFD700FFD700FFD700FFE600FFE600FFE600
FFE600FFF500FFF500FAFF00FAFF00EBFF00EBFF00DCFF00BDFF00AEFF0042FF008FFF00
80FF0005FF00FF00C70047FFFF00002300FF3300FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0075FF00FF5700FF66FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFA314FF0000FFA38FFF00
AEFF00AEFF0070FF0080FF00AEFF0033FF0061FF00EBFF00DCFF00DCFF00EBFF00FFC700
FFB800FFB800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FFA800FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFD700FFD700FFE600FFE600
FFE600FFF500FFF500FAFF00FAFF00EBFF00EBFF00BDFF0014FF0080FF0000FF8551FF00
61FF00FF00004200FF0047FFFF0000FF0099FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000028FF
FF000000FF1900FF66FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFA314FF0061FF008FFF00
AEFF00CCFF00CCFF00CCFF00CCFF0000FF75CCFF00FFF500FFF500FFF500FFF500FFC700
FFB800FFB800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800
FFA800FFA800FFB800FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFC700FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFD700FFD700FFE600FFE600
FFF500FFF500FFF500FAFF00FAFF00EBFF00DCFF00BDFF0000FF190057FF00FF5723FF00
00FF9400FF2800FFA3FF004CFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
05FF0005FF0000FF66FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000038FF42FF0042FF00
BDFF00CCFF00DCFF00DCFF00EBFF00CCFF00FAFF00FFF500FFE600FFD700FFD700FFC700
FFB800FFB800FFB800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00
FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FFA800FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFC700FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFD700FFE600FFE600FFE600
FFF500FFF500FAFF00FAFF00EBFF00EBFF00DCFF00BDFF0014FF0000B3FFFF00F5FF0000
FF00008000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF005CFF006B
23FF0014FF0000FFC2FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF2823FF00
BDFF00DCFF00EBFF00EBFF00FAFF00FAFF00FFF500FFE600FFE600FFD700FFC700FFC700
FFB800FFB800FFB800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900
FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FFA800FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFD700FFD700FFE600FFE600
FFF500FFF500FAFF00EBFF00EBFF00DCFF00CCFF00AEFF00FF0000FA00FFFF00000075FF
FF0000FF00008F00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000057FF33FF00
42FF0023FF000047FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00004200FF00E1FF00FF5700FFC2
AEFF00DCFF00EBFF00EBFF00FAFF00FFF500FFE600FFE600FFD700FFD700FFC700FFC700
FFB800FFB800FFB800FFA800FFA800FFA800FFA800FF9900FFA800FF9900FF9900FF9900
FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFD700FFD700FFE600FFE600
FFF500FAFF00EBFF00DCFF00DCFF00DCFF00BDFF0000FFF000FF3800FFE1FF000000FF94
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFFFAE00FFFF004C51FF00
51FF0014FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000DC00FF00FF7505FF0014FF00FF005C
70FF00DCFF00EBFF00FAFF00FAFF00FFF500FFE600FFE600FFD700FFD700FFC700FFC700
FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FFA800FF9900FF9900FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800
FFC700FFB800FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFE600FFE600FFF500
FAFF00BDFF00AEFF00AEFF00CCFF00CCFF00BDFF0070FF0000FF8500FFB300FF57FF0000
2300FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00B8FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF2833FF0061FF0070FF00
61FF0042FF00FF005C0085FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFC223FF0061FF0000FF47
8FFF00CCFF00EBFF00FAFF00FFF500FFF500FFE600FFE600FFD700FFD700FFC700FFC700
FFC700FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800FF9900FF9900FF9900
FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFC700FFC700FFC700FFD700FFD700FFD700FFD700FFE600FFE600FFF500
FAFF00AEFF000019FF80FF00AEFF00BDFF00AEFF008FFF0042FF0014FF0000FF0A00FF66
00B3FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00004200FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000051FF0080FF0080FF00
70FF0051FF00FF00B8FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000038FF00FF7523FF0070FF008FFF00
AEFF00CCFF00DCFF00EBFF00FAFF00FFF500FFE600FFE600FFD700FFD700FFC700FFC700
FFC700FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800FF9900FF9900FF9900
FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800
FFB800FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFD700FFE600FFF500FAFF00
EBFF0014FF0000FF280075FF51FF009EFF008FFF0080FF0051FF0023FF0000FF19FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF000000FF9400B3FFFF0000FF000042FF008FFF008FFF00
80FF0042FF000028FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000000AFF00FF1923FF0061FF008FFF00
AEFF00BDFF0000FF19DCFF00FAFF00FFF500FFE600FFE600FFD700FFD700FFC700FFC700
FFC700FFC700FFB800FFB800FFB800FFB800FFA800FFA800FFA800FF9900FF9900FF9900
FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FF9900FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFD700FFE600FFE600FAFF00FAFF00
DCFF00BDFF0061FF0000FFC270FF0080FF0033FF00CC00FF14FF0000D1FF00FF6600F0FF
FF003DFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
00E1FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF000000FF7500FF386100FF00FFC2FF00008FFF009EFF009EFF00
8FFF000019FF0028FF00FFF0FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFA300FF3805FF0000FFB342FF00
8FFF008FFF0005FF00CCFF00EBFF00FAFF00FFF500FFE600FFD700FFD700FFD700FFD700
FFC700FFC700FFC700FFB800FFB800FFB800FFB800FFA800FFA800FFA800FF9900FF9900
FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800
FFB800FFB800FFC700FFC700FFC700FFC700FFD700FFD700FFE600FAFF000057FFDCFF00
CCFF009EFF0000D1FF05FF0051FF0051FF00FF00F5FF000000FF85FF004CFF008AFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF000000FFB3FF0000FF002EFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF000023FF0014FF0070FF008FFF00AEFF00AEFF00AEFF00
9EFF0070FF000038FF00FF850028FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000028FF0075FFFF00E600FF752300FF00FFFF
61FF0070FF0000FFA38FFF0033FF00FAFF00FFF500FFE600FFE600FFD700FFD700FFD700
FFC700FFC700FFC700FFC700FFC700FFC700FFB800FFB800FFA800FFA800FF9900FF9900
FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800
FFB800FFB800FFB800FFC700FFC700FFC700FFD700FFD700FFE60000FF0A00FFB342FF00
8FFF008FFF005100FF05FF0023FF0000FFE100FF38FF00000019FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF000000FF8500FF85FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF000000F0FFFF000061FF009EFF00AEFF00AEFF00BDFF00AEFF00
AEFF008FFF0042FF0000FF66FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000085FF00FF0A
14FF0023FF006100FF00FF66AEFF00EBFF00FAFF00FFF500FFE600FFE600FFD700FFD700
FFD700FFD700FFD700FFD700FFD700FFE600FFC700FFC700FFB800FFA800FFA800FF9900
FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFC700FFC700FFC700FFD700FFD700FFE600FAFF0000FF8570FF00
00FF5770FF0000FFA300FF1900FF47FF003DFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF000000FF47DC00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
00FFC2FF0000FF0000FF00001400FFFF000005FF009EFF00BDFF00BDFF00BDFF00BDFF00
AEFF008FFF0061FF00AE00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000DC00FF
00A3FF0028FF00FFC242FF008FFF009EFF00CCFF00FFF500FFE600FFE600FFE600FFD700
FFD700FFD700FFE600FFE600FFE60000FF38FFE600AEFF00FFC700FFA800FFA800FF9900
FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FF9900FF9900
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800
FFB800FFB800FFB800FFC700FFC700FFC700FFD700FFD700FFE600FFF50042FF00BDFF00
00FF4714FF0000FF7500FFB30066FFFF00000500FF00FFF0FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF000000FF2800FF19DC00FFFF00000019FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
00FFB3FF0000FF005CFF002EFF0000FF000000FF75AEFF00CCFF00CCFF00CCFF00CCFF00
AEFF0042FF0023FF001400FF00FFB3DC00FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000BD00FF
6100FF00FFC233FF0000C2FF00FFE161FF0070FF00FAFF00FFF500FFE600FFE600FFE600
FFE600FFF500FAFF00DCFF00FAFF00CCFF00DCFF00EBFF00FFD700FFB800FFA800FFA800
FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800
FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFD700FFD700FFE600FAFF00DCFF00
61FF0000FFFF00FF660047FF00FFE100FF38FF000000FF85FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF000000FF0A05FF00FF00A800FF85FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFA3FF0000
05FF0005FF0000FF85FF0000FF0000FF001E05FF00BDFF00CCFF00DCFF00DCFF00CCFF00
BDFF007000FF00FF6600E1FF00FF7500FF570047FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000E1FF
00FF1923FF0070FF0070FF0000FFE1BDFF00DCFF00FAFF00FFF500FFF500FFF500FFF500
FFF500FAFF009EFF008FFF00BDFF0000FFD180FF00FFF500FFD700FFB800FFA800FFA800
FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800
FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFD700FFD700FFE600FFF500EBFF00
AEFF0051FF0000FF470038FF0019FF00FF1905FF0000FF190094FF0075FFFF0000EB00FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF000000FF0A23FF0023FF0005FF00FF0000FF0000FF00001400FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF3814FF00
51FF0014FF0000E1FF00FF0AFF000000FF5700FFF0CCFF00DCFF00DCFF00DCFF00DCFF00
CCFF00AEFF0061FF00FF004CFF000F00FF0A00FFA3FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000DC00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
00FF1951FF0080FF009EFF00AEFF00CCFF00EBFF00FAFF00FFF500FFF500FFF500FFF500
FAFF00DCFF008FFF0000FF2800E1FFCCFF0005FF00EBFF00CCFF00FFC700FFA800FFA800
FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800
FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFD700FFD700FFE600FFF500EBFF00
00C2FF00F0FF00E1FF00FF28CC00FF00FF5733FF0005FF00EB00FF00FFC20066FFFF000F
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF000033FF0042FF004200FFFF0000FF00000075FF00FFE10019FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0A
61FF0070FF00FF00008FFF0000FFC2FF0099CCFF00DCFF00DCFF00DCFF00EBFF00DCFF00
DCFF00CCFF0061FF00FF000005FF0023FF00FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000066FF0019FFFF0000FF0000FF0000FF0000FF0000FF0000FF000000F0FF
00FF3800FFB380FF00AEFF00BDFF00CCFF00EBFF00EBFF00FAFF00FAFF00FAFF00FAFF00
EBFF0080FF0005FF00AEFF00DCFF00FAFF00DCFF00EBFF00DCFF00FFE600FFB800FFA800
FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800
FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFD700FFD700FFE600FFF500FAFF00
CCFF008FFF0051FF0000FF196100FF14FF0042FF0042FF0000FF0A00FF7500B3FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
EB00FF5100FF00FFD142FF0051FF0051FF0000FFA300FFB3FF001E00FF66FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
70FF008FFF009EFF00BDFF00AEFF00CCFF00DCFF00EBFF00EBFF00EBFF00EBFF00EBFF00
DCFF00DCFF00CCFF009EFF0080FF0000FFC20500FFFF0000FF00000047FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF000000FFA3000AFFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00F5
FF006B00B3FF00FFE19EFF00BDFF00CCFF00DCFF00EBFF00FAFF00FAFF00FAFF00EBFF00
DCFF0051FF00FF000014FF00FAFF00FFF500FFF500FFE600FFE6009EFF00FFB800FFA800
FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF8A00
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800
FFB800FFB800FFB800FFC700FFC700FFC700FFD700FFD700FFD700FFE600FFF500FAFF00
DCFF008FFF0005FF000094FF0028FF00FF8561FF0061FF0033FF0000FF0A00FF940028FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00D7FF00B800FF1951FF0070FF0070FF0061FF0042FF0014FF00AE00FF8F00FFFF0000
FF0000000AFFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF000000B3FFFF0000FF0000FF0000FF0000FF00000085FFFF0000
61FF009EFF00BDFF00CCFF00DCFF00DCFF00EBFF00EBFF00FAFF00EBFF00FAFF00EBFF00
EBFF00DCFF00CCFF00BDFF008FFF00FF00D7FF0000FF0000FF009900FFC2FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00F5
FF000000FF8500FF3800FF94FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
00FF9414FF0061FF008FFF009EFF00BDFF00DCFF00DCFF00EBFF00EBFF00EBFF00CCFF00
CCFF009EFF0014FF00CCFF00FFF500FFE600FFD700FFD700FFD700FFC700FFA800FFA800
FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00
FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FFA800FFA800FFA800FFB800FFA800FFA800FFA800FFA800FFB800FFB800
FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFD700FFD700FFE600FFF500EBFF00
9EFF0000FF1900FF8500FF7542FF0070FF0080FF0061FF0023FF0000FF198F00FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00A823FF0051FF0070FF0080FF0070FF0061FF00FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF000000FF94FF0000FF0000FF0000FF0000FF000000FFF000FFB3
42FF0061FF00BDFF00CCFF00EBFF00EBFF00FAFF00FAFF00FAFF00FAFF00FAFF00FAFF00
EBFF00DCFF00CCFF00AEFF008FFF0005FF00FF000000FFFF00FFA3FF007AAE00FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFD1
00FFE1FF000005FF00FF000000E1FFFF0000FF0000FF0000FF00000085FFFF00002300FF
0500FF00FF0A42FF0051FF0051FF0080FF00BDFF00DCFF00DCFF00DCFF00CCFF0070FF00
9EFF0051FF0051FF0005FF00FFF500FFE600FFD700FFC700FFC700FFB800FFA800FFA800
FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800
FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFD700FFD700FFE600FFF50000FF19
00FFB361FF0061FF0000C2FF61FF008FFF008FFF0080FF000028FF00FF75FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF000000FFA300FF1980FF008FFF008FFF0061FF00FF00D7FF00E6FF00001400FF
FF000000FF57FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00002300FFFF0000FF000000FF28FF0000FF0000FF0000FF0000FF0000FF000000FF38
FF0000AE00FFAEFF00DCFF00EBFF00FAFF00FAFF00FAFF00FAFF00FAFF00FAFF00FAFF00
FAFF00DCFF00CCFF0080FF0080FF00FF00B80028FF00FF2814FF0023FF0000FF8500C2FF
00FF75FF0000FF0000FF0000FF0000BD00FFFF0000FF000000FFFFFF00006100FF00FF57
00FF190057FF42FF0005FF000047FFFF0000FF0000EB00FF00FFF000FF8500A3FF00FF57
00FF660085FF00FF2814FF0000FF8533FF0051FF00BDFF00CCFF00CCFF009EFF0005FF00
00FF579EFF0051FF00EBFF00FFE600FFD700FFC700FFC700FFB800FFB800FFA800FFA800
FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00
FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800
FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800
FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFD700FFD700FFE600FFF500EBFF00
70FF008FFF00AEFF0080FF008FFF00AEFF009EFF0080FF000057FF0028FF00FFA300FFFF
8000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
00FFFF0019FF0075FF70FF008FFF009EFF009EFF008FFF0042FF00FF0000FF0000FF0000
FF000000FF1900FF1900FF75FF000FFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF000000FF5705FF0000FF0A00F0FFAE00FFFF0000FF0000FF00000019FF00FF94
0085FF14FF0080FF00CCFF00EBFF00FAFF00FAFF00FFF500FFF500FFF500FFF500FAFF00
FAFF00DCFF00AEFF0000FF5723FF0023FF0000FFA300FF8514FF0051FF0042FF0000FFF0
00FF66FF00D7FF0000FF0000FF0000FF000000FF8500FFA300FF47FF006BBD00FF00FFE1
42FF0061FF0061FF001400FF00FFD100FF190075FF00D1FF00FF4705FF0000FF5705FF00
23FF0000FFFF00F0FF0094FF00FF0A42FF008FFF00BDFF00BDFF00BDFF0061FF00FF0000
61FF00CCFF009EFF0000FF0AFFE600FFD700FFC700FFB800FFB800FFA800FFA800FFA800
FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00
FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800
FFB800FFB800FFB800FFC700FFC700FFC700FFD700FFD700FFD700FFE600FFF500FAFF00
00E1FFBDFF00CCFF00BDFF00BDFF00BDFF00AEFF008FFF0051FF00CC00FF00FF3800FF85
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000019FF
00FF940038FF00C2FF70FF009EFF009EFF00AEFF009EFF000075FF0019FFFF00A823FF00
DC00FF33FF0000FF38FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF000023FF0042FF00FF0000CC00FF00FFA3FF00000038FFFF000000FFFF
00FFD100FF47FF0000FF00B8FAFF00FAFF00FFF500FFF500FFF500FFF500FFF500FFF500
FAFF009EFF00FF008A0085FF00FFC200FF280057FF00FF8500FF4770FF0070FF0042FF00
00FFE1FF00A8FF0000FF0000FF0000FF000000FF4705FF0014FF00FF00D7FF000000FF28
23FF0080FF0080FF0070FF0033FF0042FF0000FF195100FF00FF5733FF0000FF1942FF00
61FF0042FF0000FFB3FF00D700FF3851FF008FFF009EFF00AEFF0080FF0000FF6600FFB3
9EFF00EBFF00EBFF00DCFF00FFE600FFD700FFC700FFB800FFB800FFA800FFA800FFA800
FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800
FFB800FFB800FFC700FFC700FFC700FFC700FFD700FFD700FFD700FFE600FFE600FFF500
EBFF00EBFF00DCFF00DCFF00CCFF00BDFF00AEFF009EFF0051FF0000D1FF05FF00FF00E6
00A3FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
00FF850057FF05FF008FFF00AEFF00AEFF00AEFF00AEFF009EFF009EFF00FF006B70FF00
70FF0051FF000094FFFF002EFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000066FF0038FF
FF0000FF0000FF000051FF0070FF0051FF0000FFD100FF1900FF4700FFB3AE00FFFF0000
FF002E00FF0A1400FF00FF75FAFF00FFF500FFF500FFF500FFF500FFF500FFF500FFF500
FFF500FAFF00CCFF0000C2FF80FF0070FF0000FF0A05FF0000FF5780FF008FFF0000FF75
2300FF00FFF0FF0000FF0000FF000000C2FF00FF5700F0FF61FF0051FF0005FF0000FFC2
00FFF09EFF009EFF009EFF0080FF0061FF000085FF00FFE123FF0070FF0080FF008FFF00
80FF0042FF0000FF1900FF3800FF7500FFFF00FF289E00FF8FFF0000FF0A51FF0000FFF0
CCFF00EBFF00FAFF00FFE600FFD700FFC700FFC700FFB800FFB800FFA800FFA800FFA800
FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF9900FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800
FFB800FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFD700FFE600FFE600FFF500
FAFF00FAFF00EBFF00DCFF00CCFF00BDFF00AEFF008FFF0070FF0051FF0023FF0000FF28
00FF850094FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF009923FF0070FF009EFF00AEFF00BDFF00BDFF00BDFF00BDFF00AEFF00AEFF008FFF00
80FF0051FF0000FF75FF0000FF0000FF0000FF0000FF0000FF000000FFE1FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF28
FF0000FF00003300FF33FF008FFF0080FF0061FF0014FF0000FFB3FF0000FF0000FF0000
000AFF14FF00CCFF00EBFF00FFF500FFF500FFF500FFE600FFE600FFE600FFE600FFE600
FFF500FFF500FAFF00FAFF00EBFF0000FF6600FF9442FF0023FF009EFF00AEFF0080FF00
4200FF5100FFFF0000FF000F00FFD100FF9400FFC242FF0080FF0070FF0000FFE151FF00
9EFF00BDFF00AEFF00AEFF008FFF0070FF0033FF0000FF3851FF008FFF009EFF00AEFF00
8FFF0000FFC200FF1900FF3870FF0000FF750057FF51FF0061FF0000FFB38FFF00BDFF00
DCFF00FAFF00FFF500FFE600FFD700FFD700FFC700FFC700FFB800FFB800FFA800FFA800
FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800
FFB800FFB800FFC700FFC700FFC700FFD700FFD700FFD700FFE600FFE600FFF500FFF500
FAFF00FAFF00EBFF00DCFF00DCFF00BDFF0070FF0070FF0070FF0051FF0000FF3800FF47
FF00A8FF00004200FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0066FFFF00C751FF008FFF00AEFF00BDFF00CCFF00CCFF00BDFF00BDFF00AEFF009EFF00
61FF0000FFC200FF2800FFC2FF0000FF0000FF0000FF0000FF001E00FF75FF000000D1FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF4700A3FF00FF1923FF00
5100FFFF000000FF759EFF009EFF008FFF0023FF00FF000FCC00FF00FF940085FFDC00FF
00FFF042FF00DCFF00FAFF00FFF500FFF500FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFF500FFF500FFF500FAFF00CCFF00DCFF008FFF0000D1FFCCFF00BDFF008FFF00
33FF0000FFFFFF000000FF9400FF1923FF0000B3FF80FF009EFF008FFF0000FFF0AEFF00
BDFF00CCFF00BDFF00AEFF008FFF0033FF0000FF6600FF6600F0FF00FF94BDFF00BDFF00
00FFB39EFF00AE00FF00FFD19EFF0080FF0051FF0000FF3800FF6670FF00AEFF00CCFF00
DCFF00FAFF00FFF500FFE600FFD700FFD700FFC700FFC700FFB800FFB800FFA800FFA800
FFA800FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800
FFB800FFC700FFC700FFC700FFD700FFD700FFD700FFD700FFE600FFE600FFF500FFF500
FFF500FAFF00EBFF00DCFF00CCFF00BDFF009E00FF6100FF42FF0033FF00FF000000FFE1
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000E1FFFF000000FFD1
0057FFFF0000FA00FF00FFB3BDFF00CCFF00CCFF00CCFF00CCFF00CCFF00BDFF009EFF00
70FF00FF00000075FF9E00FFFF0000FF0000FF00F5FF00D7FF000000FF4700FF47FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00002300FF00C2FF00FFA300FF4705FF0023FF0051FF0061FF00
61FF00FF007A9EFF00AEFF00BDFF009EFF00DC00FF0075FF14FF0005FF0000FF7500FF57
00FF0A33FF0000D1FFFFF500FFF500FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFF500FFF500FFF500FAFF00FAFF00EBFF00DCFF00DCFF00BDFF006100FF
00FF4700FF8500F0FF00FFA300FFF051FF0042FF008FFF009EFF00AEFF00BDFF00CCFF00
DCFF00DCFF00CCFF0000A3FF61FF0000FF5761FF00FF004C70FF0033FF00BDFF00CCFF00
CCFF00CCFF00CCFF00BDFF00AEFF009EFF0080FF0000FFD100FF0A33FF008FFF00BDFF00
DCFF00EBFF00FAFF00FFF500FFE600FFD700FFC700FFC700FFB800FFB800FFA800FFA800
FFA800FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800
FFC700FFC700FFD700FFD700FFD700FFD700FFD700FFE600FFE600FFE600FFF500FFF500
FAFF00FAFF00EBFF00DCFF00CCFF009EFF0061FF000500FF23FF0000FF0A00FFA3FF005C
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFB300FF4700FF75
00FFFF00FFB36100FFFF00C7BDFF00CCFF00DCFF00DCFF00CCFF00CCFF00BDFF00FF00E6
33FF0000FF384200FF00C2FFFF0000FF00E63300FFFF0000FF000023FF00FF0000FF003D
FF0000FF000000F0FFFF0000FF008AFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000BD00FF00FF3833FF0061FF0080FF00
8FFF009EFF00BDFF00BDFF00CCFF00BDFF0061FF00FF002E00FF4770FF0051FF0005FF00
00F0FFDCFF00FAFF00FFF500FFE600FFE600FFE600FFD700FFD700FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFF500FFF500FFF500FAFF00EBFF00EBFF00DCFF009EFF00
FF007A33FF0000FF47AE00FF0047FF61FF0080FF009EFF00BDFF00CCFF00CCFF00DCFF00
EBFF00EBFF00DCFF00AEFF0000FF5700FFFF9EFF0000FFFFBDFF0005FF00DCFF00DCFF00
DCFF00DCFF00DCFF00CCFF00BDFF00AEFF0080FF0000FF4770FF0051FF0000FF2880FF00
00FFD1CCFF00EBFF00FAFF00FFF500FFE600FFD700FFC700FFC700FFC700FFB800FFA800
FFA800FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800
FFC700FFC700FFD700FFD700FFD700FFD700FFE600FFE600FFE600FFF500FFF500FFF500
FAFF00FAFF00EBFF00DCFF00AEFF0000E1FF14FF007000FF00FF19FF000000C2FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000047FF0066FF00FF4700FF1900D1FF
1400FF00A3FF70FF00AEFF00CCFF00DCFF00DCFF00DCFF00DCFF00DCFF00BDFF0000D1FF
FF00E64200FF0094FF0038FFFF002EFF000000FF8500FF3823FF0042FF000075FFFF0000
FF0000EB00FF00FF66FF000000E1FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00E600FF2833FF0080FF00
9EFF00AEFF00CCFF00CCFF00DCFF00CCFF00AEFF00BDFF00CCFF00BDFF0061FF0005FF00
DCFF00FAFF00FFF500FFE600FFE600FFE600FFD700FFD700FFD700FFD700FFD700FFE600
FFD700FFE600FFE600FFE600FFE600FFF500FFF500FAFF00FAFF00EBFF00DCFF00CCFF00
00FFFF70FF000085FF00F0FF05FF0061FF0080FF009EFF00BDFF00CCFF00DCFF00EBFF00
EBFF00EBFF00EBFF00BDFF0000FF19CCFF00DCFF0000FF47DCFF00EBFF00EBFF00EBFF00
EBFF00EBFF00DCFF00DCFF00CCFF009EFF0070FF0014FF009EFF0080FF0061FF0014FF00
42FF0070FF00BDFF00DCFF00AEFF00FAFF00FFF500FFE600FFD700FFC700FFC700FFB800
FFA800FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00
FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFC700
FFC700FFD700FFD700FFE600FFE600FFE600FFE600FFE600FFF500FFF500FAFF00FAFF00
FAFF00FAFF00EBFF00DCFF00CCFF008FFF0000FF381400FF00FFFF0057FF0038FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00008000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00C700FF5705FF0005FF000038FF
FF00D70047FF8FFF00CCFF00DCFF00DCFF00EBFF00EBFF00EBFF00DCFF00CCFF009EFF00
00F0FF00FF38FF0000FF00F5FF0000FA00FFFF000000FF7533FF0070FF0061FF008000FF
FF0000FF000005FF0000FF8500FF6600FFD1FF00000028FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000070FF00
9EFF00BDFF00CCFF00DCFF00DCFF00EBFF00EBFF00EBFF00EBFF00DCFF0070FF000057FF
EBFF00FFF500FFE600FFE600FFE600FFD700FFD700FFD700FFD700FFD700FFD700FFD700
FFD700FFD700FFD700FFE600FFE600FFE600FFF500FFF500FAFF00EBFF00DCFF00CCFF00
BDFF008FFF00FF00998F00FF05FF0042FF000019FF05FF009EFF00CCFF00EBFF00EBFF00
FAFF00FAFF00FAFF00AEFF0000FF0AFAFF00FAFF00EBFF00FAFF00FAFF00FAFF00FAFF00
FAFF00EBFF00EBFF00DCFF00CCFF0000FF0A00FF0A05FF00AEFF00BDFF00BDFF0061FF00
61FF0023FF0000FF289EFF00BDFF00CCFF00CCFF00FAFF00DCFF00FFD700FFE600FFD700
FFA800FFA800FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFB800FFB800FFC700FFC700
FFD700FFD700FFF500BDFF00FFF500FFF500FFF500FFF500FFF500FFF500FAFF00FAFF00
FAFF00EBFF00EBFF00DCFF00CCFF0070FF0000FFA300FFC200FF66FF00000500FFFF00A8
FF0000FF0000FF0000FF0000FF0000FF0000FF000000D1FFFF003DFF0000AE00FFFF0000
FF0000FF0000FF00000047FFFF0000FF0000FF0000FF00B8FF000000FF3842FF0000FFE1
05FF0000FF9400FF85DCFF00DCFF00EBFF00EBFF00EBFF00EBFF00EBFF00DCFF00CCFF00
AEFF0000FF28FF0000FF0000FF000000FFC200FF94FF0000FF000080FF0080FF0061FF00
FF000042FF0033FF0005FF0000FF3800FFA3000AFFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000A3FF0047FF51FF00
80FF00AEFF00CCFF00DCFF00EBFF00EBFF00FAFF00FAFF00FAFF00FAFF00AEFF00DCFF00
FFF500FFE600FFE600FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700
FFD700FFD700FFD700FFD700FFE600FFE600FFE600FFF500FAFF00EBFF00DCFF00CCFF00
BDFF009EFF0070FF0000FF8500FF3800F0FF00FFE100FF2880FF009EFF00DCFF00FAFF00
FAFF00FFF500FFF500FFF500FFF500FFF500FFF500FFF500FFF500FFF500FFF500FAFF00
FAFF00EBFF00EBFF00DCFF00CCFF0070FF0000FF3842FF00BDFF00DCFF00DCFF0000FF75
9EFF00AEFF00AEFF0042FF0000FF1900FFF070FF00BDFF00EBFF00FFF500BDFF00FFD700
FFB800FFA800FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFC700FFD700
FFE600FFE60000FF1951FF00EBFF00FAFF00FAFF00FAFF00FAFF00FAFF00FAFF00FAFF00
EBFF00EBFF00EBFF00DCFF00CCFF009EFF0033FF001400FF00FF0A00FF7500B3FF8F00FF
FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFF000FF94FF0000EB00FFFF0000
FF000000FFFF0085FFFF0000FF0000FF0000FF0000FF004CFF000033FF0070FF0061FF00
00FFC2AEFF00FF003DDCFF00EBFF00EBFF00FAFF00EBFF00FAFF00EBFF00EBFF00DCFF00
AEFF0023FF0000FFB3FF00009E00FF00FFFF42FF00FF0000FF00009EFF009EFF008FFF00
80FF0061FF0033FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF001EFF000000FFD1FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF7533FF00
0075FF00E1FFCCFF00DCFF00EBFF00FAFF00FAFF00FAFF00FFF500FAFF00FAFF00FFF500
FFF500FFE600FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFC700FFD700FFD700
FFD700FFD700FFD700FFD700FFD700FFE600FFE600FFF500FAFF00EBFF00DCFF00BDFF00
AEFF009EFF0080FF0042FF0000FFA33300FF42FF0000FF1900FF5700FF47EBFF00FAFF00
FFF500FFF500FFF500FFF500FFF500FFE600FFF500FFF500FFF500FFF500FFF500FFF500
FAFF00FAFF00EBFF00DCFF00CCFF00AEFF0023FF008FFF00CCFF00EBFF00EBFF00EBFF00
EBFF00EBFF00CCFF0033FF00AEFF0000FF47AEFF0000FFD170FF0000FF7500FF0AFFF500
51FF00FFA800FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFB800FFB800FFF500FAFF00
FAFF00FAFF00DCFF0061FF00DCFF00EBFF00EBFF00EBFF0005FF00EBFF00EBFF00EBFF00
EBFF00EBFF00DCFF00DCFF00AEFF0000FF4700FFA305FF0023FF0000FF1900FFA30094FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00D700FF470047FF00FF57FF0000
FF000000FFC200FF4700FFC28F00FFFF0000FF0000FF000000B3FF8000FF80FF009EFF00
AEFF00CCFF00DCFF00DCFF00EBFF00FAFF00FAFF00FAFF00FAFF00FAFF00EBFF00DCFF00
80FF0000FF9470FF0051FF0014FF0033FF009EFF003300FFAEFF00AEFF00AEFF009EFF00
80FF0061FF0000FF2800C2FF0066FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000047FFFF000000FF6600FFFFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFF0
FF00C770FF00CCFF00EBFF00EBFF00FAFF00FFF500FFF500FFF500FFF500FFF500FFE600
FFE600FFD700FFD700FFD700FFD700FFD700FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFD700FFD700FFD700FFD700FFE600FFE600FFF500EBFF00BDFF00BDFF008FFF00
8FFF0080FF0042FF0000FF7500FF8500FF0A70FF0070FF0000FFE19EFF00DCFF00FFF500
FFF500FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF500FFF500FFF500
FAFF00FAFF00EBFF00DCFF00BDFF00AEFF0000FF758FFF00CCFF00EBFF00FAFF00FFF500
FFF500FAFF00EBFF0033FF00EBFF00AEFF00FAFF0051FF00FAFF00DCFF00BDFF00CCFF00
FFF500FFB800FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFB800FFC700FFD70033FF00
00FF57DCFF00AEFF008FFF00BDFF00CCFF0000FF0A9EFF0000D1FFCCFF00DCFF00DCFF00
EBFF00DCFF00DCFF00CCFF00AEFF0042FF0000FF2851FF0042FF0000FF38FF007AFF0000
FF0000FF0000FF0000FF0000FF0000FF00D7FF000000FF8500FF1905FF0000FF4700FFD1
00FFB300FF0A000AFFFF0000FF007A00FFC200F0FF0038FF00FFC22300FF8FFF00AEFF00
BDFF00DCFF00EBFF00EBFF00FAFF00FAFF00FAFF00FAFF00FAFF00FAFF00FAFF00EBFF00
00FF3800FF38CCFF00CCFF000066FF00D1FFBDFF00BDFF00BDFF00BDFF00AEFF009EFF00
70FF0051FF00000AFFCC00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000075FF3300FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF28FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00008000FF
00FFC200FFB39EFF00EBFF00FAFF00FAFF00FFF500FFF500FFF500FFE600FFE600FFE600
FFD700FFD700FFD700FFD700FFD700FFC700FFC700FFD700FFC700FFC700FFC700FFC700
FFC700FFC700FFD700FFD700FFD700FFD700FFE600FFF500EBFF0061FF0000FF198F00FF
42FF0000FF6600FF8505FF0080FF0023FF0042FF00BDFF0080FF0070FF0000FF38FFF500
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF500
FFF500FAFF00EBFF00AEFF0080FF0080FF0051FF0033FF00CCFF00FAFF00FFF500FFF500
FFF500FFF500FAFF0080FF00FFF500FFE600FFE600FFE600FFE600FAFF008FFF00FFE600
FFC700FFA800FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFB800FFB800FFC7008FFF00
DCFF0080FF008FFF0070FF0061FF009EFF0000FF1900FF0A8FFF009EFF00BDFF00CCFF00
DCFF00DCFF00DCFF00CCFF00BDFF009EFF008FFF0070FF0051FF0000B3FF00FFC2000AFF
FF0000FF0000FF0000FF00B8FF00006100FF00FFF0FF000023FF0033FF00FF000000C2FF
AE00FF14FF0033FF0005FF000019FF00FF6600A3FF0066FF00FF1900FFD18FFF00AEFF00
BDFF00DCFF00EBFF00FAFF00FAFF00FAFF00FFF500FFF500FFF500FFF500FAFF00FAFF00
EBFF00EBFF00EBFF00EBFF00AEFF00BDFF00CCFF00CCFF00CCFF00BDFF00BDFF0042FF00
00FFF033FF00FF000000A3FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF000000FFC2FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF000000FFF0FF0000FF0000FF000014FF0000FF28FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFF0
FF000000FFE19EFF00EBFF00FAFF00FFF500FFF500FFF500FFE600FFE600FFD700FFD700
FFD700FFD700FFD700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFD700FFD700FFD700FFE600FFF500EBFF0000FF2800FF2805FF00
23FF002300FF9EFF00AEFF00AEFF0000FF85AEFF00DCFF00CCFF008FFF0070FF00FFF500
FFE600FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFE600FFE600FFE600FFE600
FFF500FAFF00EBFF0042FF0000FFC200FF2800FFB380FF0051FF00FAFF00FFF500FFE600
FFE600FFE600FFF500FFE600FFD700FFD700FFD700FFD700FFD700BDFF00AEFF00FFD700
FFB800FFA800FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFB800FFB800FFC700FFE600
FFF500BDFF0000FF1905FF0051FF0000FF9400FFC223FF0000FF3861FF0000FF66BDFF00
CCFF00CCFF00CCFF00CCFF00BDFF00AEFF008FFF0070FF0042FF0000FFB300FF570047FF
FF008AFF006B00E1FF00E1FF000AFF3300FF00FF4700FF0A51FF0061FF0042FF0000FF66
51FF0000FF4761FF0042FF0023FF0000FF0A00D1FF0075FF00FF0A61FF008FFF009EFF00
BDFF00DCFF00EBFF00FAFF00FAFF00FFF500FFF500FFF500FFF500FFF500FFF500FFF500
FAFF00FAFF00FAFF00FAFF00EBFF00EBFF00DCFF00DCFF00DCFF00CCFF00BDFF008FFF00
9E00FF00FF47000AFF0038FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF000000FF9400FF8500FFE1FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF000000FF1900FFD105FF0042FF0014FF00FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000B3FFFF000000FFD1
0094FFFF00F59EFF00DCFF00FAFF00FFF500FFF500FFE600FFE600FFE600FFD700FFD700
FFD700FFD700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFD700FFD700FFE600FFF500EBFF008FFF0042FF00AEFF00
CCFF0023FF00BDFF00DCFF00BDFF0014FF008FFF00FAFF00FAFF009EFF00FFF500FFE600
FFE600FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFE600FFE600FFE600
FFF500FFF500FAFF00DCFF00AEFF0005FF0000D1FF14FF00DCFF00FFF500FFE600FFE600
FFD700FFD700FFD700FFD700FFD700FFC700FFC700FFC700FFC700FFD700FFF500DCFF00
FFC700FFA800FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFB800FFB800FFC700FFD700
FFE60061FF0051FF0000FF759EFF0000FF198FFF0042FF00FF000000FF1980FF00AEFF00
BDFF00BDFF00BDFF00BDFF00AEFF009EFF008FFF0051FF0000FF5705FF0000FFA3EB00FF
00FFF08F00FF00FF7500FF663300FF0028FF00FF0A33FF0061FF0080FF0080FF0080FF00
8FFF0080FF0070FF0051FF0033FF0000FF0A00FF47FF005C00FFB351FF0070FF0051FF00
00FF28CCFF00EBFF00FAFF00FFF500FFF500FFF500FFF500FFF500FFF500FFF500FFF500
FFF500FFF500FAFF00FAFF00FAFF00EBFF00EBFF00EBFF00DCFF00CCFF00BDFF008FFF00
FF005C00FFA3FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF000000FF19FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00004200FFFF0000FF0000
FF000FFF0000FF000000FFFF00D1FF51FF0061FF0061FF0000FFE13300FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00004200FF00FF380085FF
00FFA300FF8500F0FFDCFF00FAFF00FFF500FFF500FFE600FFE600FFD700FFD700FFD700
FFD700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFD700FFE600FAFF00CCFF008FFF0000FF8542FF00
EBFF00FAFF00FFF500FAFF0061FF0000FF0AEBFF00FFF500FFE600FFE600FFE600FFD700
FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFE600FFE600FFE600
FFE600FFF500FAFF00DCFF0051FF0033FF0070FF0000FF3870FF00FFF500FFE600FFE600
FFD700FFD700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFD700BDFF00
FFD700FFA800FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900
FF9900FFA800FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFB800FFB800FFC700
FFD700FAFF00CCFF0005FF00BDFF00CCFF00AEFF000066FFFF000000FFE180FF009EFF00
AEFF00AEFF00AEFF00AEFF00AEFF009EFF0070FF0000FF3800E1FF00FF470028FF00FFB3
00FF3800FFFFFA00FF00FF190038FF8000FF00FF1905FF000085FF80FF009EFF009EFF00
9EFF008FFF0070FF0023FF0000FF1900FF5700FF660047FF05FF0033FF00000AFF00FF94
33FF0000FF38DCFF00FAFF00FFF500FFF500FFF500FFF500FFF500FFF500FFF500FFF500
FFF500FFF500FFF500FFF500FAFF00FAFF00FAFF00EBFF00DCFF00DCFF0000FF28FF0000
0500FFFF0000FF002EFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF000005FF0014FF00FF000000FF38FF0000FF0000FF00000075FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF008A0047FFFF000000FFB3FF0000FF0000
00FF5700A3FFFF0000FF000000FF4751FF0080FF0070FF0000FF661400FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000014FF0000FF28
00FF5751FF00BDFF00DCFF00FAFF00FFF500FFF500FFE600FFE600FFD700FFD700FFD700
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFB800FFC700FFB800FFB800FFB800
FFB800FFC700FFC700FFC700FFC700FFD700FFF500CCFF008FFF000085FF42FF0061FF00
FFF500FFE600FFE600FFF500DCFF00CC00FFEBFF00FFE600FFD700FFD700FFD700FFD700
FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFD700FFD700FFD700FFD700FFE600
FFE600FFF500FFF500EBFF00CCFF0033FF0051FF00BDFF00EBFF00FFF500FFE600FFD700
FFD700FFC700FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFC700FFD700DCFF00
FFB800FFA800FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFB800FFB800FFB800FFC700
FFD700FAFF0080FF0000FFFFDCFF00DCFF00BDFF0023FF0000FF0A23FF0070FF0080FF00
70FF0042FF008FFF009EFF009EFF008FFF0070FF003300FF00FFFF0500FF0047FF0085FF
14FF0000FFC233FF0023FF0000FF280075FF00FFE100FFFF0094FF80FF00AEFF00AEFF00
AEFF008FFF0070FF0000FF94FF000000C2FFFF000000FFF000FF195100FF5100FF61FF00
00FF6600FF47DCFF00FFF500FFF500FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFF500FFF500FFF500FFF500FAFF00FAFF00EBFF00EBFF00DCFF00BDFF0051FF00
8000FFFF000000FFF0FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF000014FF0042FF0033FF00FF00002300FFFF00008F00FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000E1FF00FF3800FF3823FF00
00FFE1FF0000FF0000FF00000019FF70FF008FFF0080FF0042FF00FF00C700FFB33300FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000075FF0038FF23FF0061FF00
00FFC28FFF00CCFF00DCFF00EBFF00FAFF00FFF500FFE600FFE600FFD700FFD700FFC700
FFC700FFC700FFC700FFC700FFC700FFB800FFC700FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFC700FFC700FFC700FFC700FFD700FAFF0000FF0AFAFF00AEFF00FFF500
FFE600FFD700FFD700FFE600CCFF00EBFF00FFE600FFD700FFD700FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFD700FFD700FFD700FFE600
FFE600FFF500FFF500FAFF00DCFF00BDFF0042FF00AEFF00DCFF00FAFF00FFE600FFD700
FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFD700
FFA800FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFC700
FFD700CCFF009EFF00DCFF00FAFF00EBFF00DCFF00BDFF0070FF0000FF4700FF7533FF00
00FFA300FF1942FF008FFF008FFF0080FF000038FF0066FFCC00FFFF00000019FF00FF19
23FF0051FF0051FF0023FF007000FF00FFF000FF8561FF0000FF948FFF00BDFF00BDFF00
BDFF008FFF0000FF8500FFA300FFC200FF470028FFFF000000FF4751FF0000FF858FFF00
00FF479EFF00FAFF00FFF500FFF500FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFF500FFF500FFF500FAFF00FAFF00EBFF00EBFF00DCFF00CCFF008FFF00
FF000000F0FFFF00C700FFB3FF001EFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF000000A3FFFF000033FF0061FF0005FF00FF0000FF0000FF0000FF000FFF0000
9E00FFFF006B00FFA30019FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000000AFFFF0000FF0000FF0000FF0000FF0000FF0000FF000023FF0051FF00
42FF0000FF288000FFFF00008FFF009EFF00AEFF008FFF0080FF00FF000000FF57FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000CC00FF00FF750085FF70FF00
8FFF00AEFF00CCFF00DCFF00EBFF00FAFF00FFF500FFE600FFE600FFD700FFD700FFC700
FFC700FFC700FFC700FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFC700FFB800FFC700FFC700FFC700FFD700FFD700FFE600FFE600FFD700
FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFD700FFE600
FFE600FFE600FFF500FAFF00EBFF00CCFF0033FF008FFF0051FF0042FF00FFE600FFD700
FFC700FFC700FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFB800FFB800FFC700
FFD700FAFF0033FF00FAFF00FFF500FAFF00EBFF008FFF0000D1FF00FF7533FF00FF00E6
00FF190038FF0066FF70FF0080FF0070FF0051FF0014FF0000FF850075FFFF000000FFC2
00D1FF70FF0070FF0000E1FF0066FF00FF9442FF008FFF00BDFF00BDFF00CCFF00CCFF00
BDFF0080FF0000A3FFFF000033FF0000FF9400FF380094FF33FF009EFF00DCFF00DCFF00
DCFF009EFF00FFF500FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFF500FFF500FAFF00FAFF00EBFF00EBFF00DCFF00CCFF0000C2FF
00F0FFFF00001400FF00FF47BD00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF000000FFC20057FF51FF0070FF0061FF00FF0000FF00C7FF0000FF000005FF00
14FF0000FF287000FFFF0000FF0000FF0000FF0000FF0000FF00A8FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF000000FFD1FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF003D0066FF61FF00
80FF0000FFC200FF3880FF00AEFF00BDFF00BDFF009EFF0070FF0033FF00FF000FFF0000
FF00000094FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000A3FF70FF00
9EFF00AEFF00BDFF00CCFF00DCFF00BDFF00EBFF00FFE600FFD700FFD700FFC700FFC700
FFC700FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFE600
FFE600FFF500FFF500FAFF00EBFF00DCFF00AEFF0000FF0AAEFF00FAFF00FFE600FFC700
FFC700FFB800FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800
FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFB800FFB800FFB800
FFC700FFD700FFE600FFF500FFF500FFF500FAFF00DCFF00BDFF0070FF0061FF0080FF00
0057FF00FFB314FF0023FF0061FF0061FF0042FF0000FF283300FF00FF2800B3FF00FF47
70FF008FFF008FFF0042FF0014FF0000FF0A00FFA3BDFF00CCFF00CCFF00DCFF00DCFF00
CCFF00AEFF0061FF000019FF70FF0000FF2800FF0A33FF0023FF0005FF00EBFF00FAFF00
FAFF00FFF500FFE600FFE600FFE600FFD700FFD700FFD700FFE600FFD700FFD700FFE600
FFE600FFE600FFE600FFE600FFF500FFF500FAFF00EBFF00EBFF00DCFF00CCFF00AEFF00
80FF000019FF14FF0000FF1900B3FF0094FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF000005FF0051FF008FFF008FFF0070FF0000FF9400F0FF5100FF51FF00
14FF0000FF57FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFF0FF00000028FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFF0
FF000000FF75FF00B8FF0000FF0000FF0000FF0000FF0000FF00009E00FF0094FF70FF00
8FFF009EFF0000FF38BDFF00BDFF00CCFF00BDFF009EFF0000FFE1FF00C700FFD1FF0000
FF000000FF751400FF00FFD100D1FFFF0000FF0000FF0000FF0000FF0000FF000023FF00
8FFF009EFF00AEFF009EFF00AEFF000075FFDCFF00FFF500FFE600FFD700FFC700FFC700
FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFB800FFC700FFC700FFC700
FFB800FFC700FFC700FFB800FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFC700FFB800FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFE600
FFE600FFF500FFF500EBFF00DCFF00CCFF009EFF0061FF0070FF00CCFF00FFE600FFC700
FFC700FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FF9900FF9900
FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFB800FFB800FFB800
FFC700FFD700FFD700FFD700FFE600FFF500FFF500FAFF00EBFF0070FF009EFF009EFF00
000AFF0066FF00FFA300D1FF00FF0A42FF0023FF0000F0FF00FF5723FF000085FF00FFF0
8FFF009EFF009EFF0070FF009EFF009EFF0005FF00CCFF00DCFF00DCFF00EBFF00DCFF00
CCFF009EFF0061FF0000FF859EFF0070FF0000FF858FFF00BDFF00CCFF00FAFF00FFF500
FFF500FFE600FFE600FFE600FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700
FFE600FFE600FFE600FFE600FFF500FFF500FAFF00EBFF00DCFF00CCFF00BDFF00AEFF00
8FFF0051FF0042FF00FF001E00FFB3FF0000FF0000FF0000FF0000FF00008000FFFF0000
FF0000FF0000FF0000FF00000500FF9EFF009EFF009EFF008FFF0070FF0070FF0061FF00
CC00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFD100FF75FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF000000F0FFFF00000057FFFF0000FF0000
00FF0A0019FFFA00FFFF0000FF0000FF0000FF0000FF0000FF00000019FFFF000061FF00
9EFF00AEFF00BDFF00CCFF00CCFF00CCFF00CCFF00BDFF0042FF0000D1FF0094FF00E1FF
00FF8500FF1900FF2800FF664200FFFF0000FF0000FF0000EB00FF00FF75FF004C51FF00
80FF0080FF0042FF0000FFFF33FF0033FF0000A3FFEBFF00FFE600FFD700FFC700FFC700
FFC700FFB800FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFD700FFD700FFE600
FFE600FFF500FAFF00EBFF0061FF00BDFF0023FF00AEFF00DCFF00EBFF00FFE600FFC700
FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900
FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF8A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFB800FFB800
FFC700FFC700FFD700FFD700FFE600FFE600FFF500FFF500EBFF00CCFF00CCFF00BDFF00
9EFF0042FF0051FF0000FFA300FF3823FF0000FF0A00FFB300FF1951FF0061FF0080FF00
9EFF00AEFF00AEFF00BDFF00BDFF00CCFF00CCFF00DCFF00EBFF00EBFF00EBFF00EBFF00
DCFF0000F0FF00FFC28FFF00CCFF0070FF0051FF0042FF00CCFF00FAFF00FFF500FFE600
FFE600FFE600FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700
FFD700FFE600FFE600FFE600FFF500FFF500FAFF00BDFF0051FF00BDFF00AEFF009EFF00
8FFF0070FF0051FF00FF0000FF0000FF0000FF0000FF0000FF00000066FFFF00000066FF
00FF9400B3FFFF00003300FF61FF009EFF00AEFF00AEFF00AEFF009EFF008FFF0080FF00
00FF47FF0000AE00FFFF0000FF0000FF0000FF0000FF0000FF0000FF000000FF28FF0000
FF0000FF000000FFB3FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF5700FF57FF000000FF0A
33FF0000FF19FF0000FF0000FF0000FF0000FF0000FF0000FF00004200FFFF00B8FF004C
9EFF00BDFF00CCFF00DCFF00DCFF00DCFF00DCFF00CCFF008FFF0005FF00BD00FFFF0000
FF000000FF1933FF0000FF3800FFA3FF000FFF0000FF00B800B3FF00FF4705FF0051FF00
70FF0051FF0000FFA300FF1900FF2800FF7500FFC2CCFF00FFE600FFD700FFC700FFC700
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFD700FFD700FFE600
FFF500FFF500FAFF00DCFF0051FF008FFF0070FF00AEFF00FAFF00FFF500FFD700FFC700
FFB800FFB800FFB800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFB800FFB800
FFB800FFC700FFC700FFD700FFE600FFE600FFE600FFF500FAFF00EBFF00DCFF00CCFF00
BDFF009EFF0080FF0042FF0000FF3800FF4700FFA300FF0A42FF0061FF0080FF008FFF00
9EFF00AEFF00BDFF00CCFF00CCFF00DCFF00DCFF00EBFF00EBFF00FAFF00FAFF00FAFF00
EBFF00CCFF00AEFF0061FF00EBFF00DCFF00AEFF0033FF00CCFF00FAFF00FFE600FFE600
FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700
FFD700FFD700FFE600FFE600FFE600FFF500EBFF0000FF6651FF009EFF008FFF0080FF00
80FF0070FF0051FF000085FF0028FF0038FFFF0000FF0000FF00000500FF00FF5700FF19
FF00F59E00FFFF00000094FFFF0000AEFF00BDFF00BDFF00BDFF00AEFF009EFF0080FF00
33FF00FF00E600B3FFFF0000FF0000FF0000FF0000FF0000FF0000FF000023FF0005FF00
FF000000FF19FF0000FF0000FF0000FF0000FF0000FF000000A3FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF007AFF0000
FF002EFF000000FFB3FF0000FF0000FF0000FF0000FF0000FF000023FF00FF000061FF00
51FF00FF0000FF0000FF0000FF0000FF0000FF0000EB00FF00FFC200FFB300FF1980FF00
9EFF00BDFF00CCFF00DCFF00EBFF00EBFF00EBFF00CCFF0000FFE151FF0000FFA35100FF
FF00000057FF61FF0033FF0000C2FFFA00FF00FF9400F0FFFF00C74200FF14FF0042FF00
14FF000094FF00FF5700FFC270FF0023FF0070FF00FFF500FFD700FFD700FFC700FFC700
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFA800FFB800FFA800
FFA800FFA800FFA800FFA800FFB800FFA800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFD700FAFF00
FAFF00EBFF00DCFF00AEFF0033FF00FF000000FF38BDFF00FAFF00FFE600FFD700FFD700
FFB800FFB800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFB800FFB800FFB800
FFC700FFC700FFC700FFD700FFD700FFE600FFE600FFF500FAFF00EBFF00DCFF00CCFF00
BDFF009EFF0080FF0061FF0023FF0000FF5700FF7505FF0042FF0061FF0080FF008FFF00
AEFF00BDFF00BDFF00CCFF00DCFF00DCFF00EBFF00EBFF00FAFF00FAFF00FAFF00FAFF00
FAFF00EBFF00FAFF00FAFF00FAFF00FAFF0000FF6600FF859EFF00FFF500FFE600FFD700
FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700
FFD700FFD700FFE600FFE600FFE600FFF500EBFF0000FFD10094FF61FF00FF004C42FF00
05FF0051FF0042FF0000FF19FF0000FF0000FF0000FF0000FF00000075FF0075FF14FF00
0094FF00FF8500D1FFFF0000AEFF00CCFF00CCFF00CCFF00BDFF00AEFF008FFF0080FF00
42FF0000FF5700FF9400B3FFFF0000FF0000FF0000FF0000FF0000FF000042FF0051FF00
42FF0014FF00FF001EFF0000FF0000FF0000FF0000000AFF00E1FFFF000000FFE1FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF000000A3FFFF0000FF0000FF00000094FF
FF003D00FF3800FF75FF0000FF0000FF0000FF0000FF0000FF000051FF0070FF0080FF00
70FF000075FFFF000000A3FF00B3FFFF0000FF0000FF00007000FF05FF0042FF0070FF00
80FF009EFF00DCFF00EBFF00EBFF00EBFF00EBFF00EBFF00DCFF00CCFF0000FFB38FFF00
33FF0014FF0080FF0061FF0000FF0A00FF6600FF28FF00F5FF00000094FF00FF3814FF00
0075FF00FF94FF0000AEFF00AEFF0070FF009EFF00EBFF00FFD700FFC700FFC700FFC700
FFB800FFB800FFB800FFB800FFB800FFB800FFA800FFA800FFB800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFB800FFA800FFA800FFB800FFA800FFA800FFB800FFA800FFB800FFA800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFD700FFF500
23FF00CCFF00AEFF0000FFF000FFD1FF0000FF000014FF00EBFF00FFF500FFD700FFC700
FFB800FFB800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFB800FFB800
FFC700FFC700FFC700FFD700FFD700FFE600FFE600FFF500FAFF00EBFF00DCFF00CCFF00
AEFF008FFF0000FF0A23FF000066FF00FF3800FF389E00FF00FFFF00FF0A70FF008FFF00
9EFF00AEFF00BDFF00CCFF00DCFF00EBFF00EBFF00FAFF00FAFF00FAFF00FAFF00FFF500
FFF500FFF500FFF500FFF500FFF500FFF500FAFF0051FF00FFF500FFE600FFD700FFD700
FFD700FFD700FFD700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFD700FFD700
FFD700FFD700FFD700FFE600FFE600FAFF00CCFF0023FF0000FF1900FF280066FF0057FF
00FF8533FF0033FF0014FF0000FF3800FFE1FF0000FF000000FFFFFF00000019FF42FF00
00FF0A33FF0061FF005100FFCCFF00CCFF00CCFF00CCFF00CCFF00AEFF0000FFD161FF00
42FF0014FF0000FF28FF0000FF0000FF0000FF000000FFC2FF0000FF002E70FF0070FF00
51FF0023FF00FF0000FF00A8FF0000FF0000FF0000FF000000FF0A00FF2800FF75FF0000
FF0000FF000000C2FFFF0000000AFFFF0000FF00004200FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000028FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
00FF0A14FF008000FFFF0000FF007AFF0000FF0000FF00005100FF42FF0070FF008FFF00
8FFF0070FF0000FF66FF000000FFB3FF0000FF0000FF0000EB00FF05FF0000FF8500D1FF
33FF000066FFDCFF00EBFF00FAFF00FAFF00FAFF00FAFF00EBFF00EBFF00DCFF00CCFF00
8FFF009EFF009EFF008FFF0070FF0000FF0A23FF0000FF380085FF0019FF00FF3800FF75
FF009942FF0070FF00CCFF00DCFF00EBFF00FAFF00FFF500FFD700FFC700FFC700FFB800
FFB800FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFD700FFE600
FAFF0023FF0014FF009EFF0000FF19FF0000FF000042FF00AEFF00CCFF00FFD700FFC700
FFB800FFB800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFB800FFB800
FFB800FFC700FFD700FFD700FFD700FFE600FFE600FFF500FAFF00EBFF00DCFF009EFF00
00FF3861FF0000FFFF0057FF33FF0014FF0005FF0023FF0000FF8500FFC233FF0070FF00
42FF00AEFF00CCFF00CCFF00DCFF00EBFF00EBFF00FAFF00FAFF00FFF500FFF500FFF500
FFF500FFF500FFE600FFE600FFE600FFE600FFF500EBFF00FFE600FFD700FFD700FFD700
FFD700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700
FFD700FFD700FFD700FFD700FFE600AEFF000057FF05FF0000B3FF00FF0A14FF00FF0000
00FF3800FFA305FF0005FF00FF00B80028FF0019FF00FFFF000AFFFF000051FF0070FF00
51FF008FFF00AEFF00BDFF00DCFF00DCFF00DCFF00DCFF00CCFF000094FF00FFB323FF00
00FF380075FF00FF380075FFFF0000FF0000FF000000FF38FF000061FF0080FF0080FF00
00FF0A05FF0000FF3800FFB3FF0000FF000000F0FF00FF1923FF0000FF1900FF66FF0000
FF0000FF0000FF000000FF66FF0000FF0000FF000000FFC200D1FFFF0000FF00000038FF
FF00004200FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF005CFF0000FF0000FF0000FF000000D1FFFF0000
FF000000FFD14200FFFF00D7FF0000FF000000FF4700FF280085FFFF00000094FF00FF75
00FF2842FF0042FF00FF0000FF0000FF0000FF000000FF7500FF2805FF0051FF009EFF00
9EFF009EFF0070FF0005FF0000FF19FF00000038FFFF004C00FF7500FF4700D1FF00FFA3
FF00000019FFDCFF00FAFF00FAFF00FAFF00FAFF00FAFF00FAFF00FAFF00EBFF00DCFF00
CCFF00BDFF00AEFF009EFF0080FF0061FF0042FF0014FF0000FF66FF009900FF85BD00FF
00FF0A61FF009EFF00CCFF00FAFF00FFF500FFE600FFD700FFC700FFC700FFB800FFB800
FFB800FFB800FFB800FFB800FFA800FFA800FFB800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFD700
EBFF00CCFF00DCFF00BDFF0000FF75FF000014FF008FFF00CCFF00BDFF00FFD700FFC700
FFB800FFB800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00
FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFB800FFB800FFB800
FFB800FFC700FFC700FFD700FFD700FFE600FFF500FAFF00EBFF00DCFF00CCFF0070FF00
42FF0000FF2814FF0070FF0070FF00EB00FF05FF0061FF00FF002E00FF2814FF0033FF00
23FF009EFF00BDFF00CCFF00DCFF00EBFF00EBFF00FAFF00FFF500FFF500FFF500FFF500
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD700FFD700FFD700FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFD700
FFC700FFD700FFD700FFD700FFE600FFF500CCFF0000FFC200FF6600A3FF70FF0000FFF0
00F0FF0047FFFF000000FF3800FF750085FF1400FF00FF6600FF2833FF0061FF0080FF00
9EFF00AEFF00CCFF00DCFF00DCFF00EBFF00EBFF00EBFF00DCFF00BDFF0014FF0000FF75
0075FF00FFF0FF002E00FFB3FF0000FF005CFF000000FF2833FF0080FF009EFF008FFF00
1400FF00FF94FF000000F0FF0066FFFF000000FFFF8F00FF51FF001400FFFF00000075FF
FF00000019FF00FF19FF00004200FFFF0000CC00FF00FF47FF0000FF003D3300FF0066FF
FF000000FFE1FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000BD00FFEB00FFFF00F5FF003DFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000AE00FFFF00003300FFFF0000FF0000FF0000
FF0000FF0000FF00C7FF0000FF00008000FFFF0000FF0000BD00FFFF0000FF0000FF0000
FF00005100FF00FF289E00FFFF0000FF00006100FF14FF00FF0000FF00002300FFFF0000
FF000061FF0051FF0000FFF000FFF0FF000000B3FFFF00008000FF00FFC200D1FFAEFF00
BDFF00AEFF0070FF0033FF0000FF1900FF75FF00004200FF00FFC2FF00000500FF33FF00
00E1FF0085FFEBFF00FAFF00FFF500FFF500FFF500FFF500FFF500FAFF00FAFF00EBFF00
DCFF00CCFF00AEFF008FFF0070FF0061FF0000FF0A00FF0A00FF4700FF9400F0FF00FF85
00FFB300FF0A00FF9461FF00FFF500FFE600FFD700FFD700FFC700FFC700FFB800FFB800
FFB800FFB800FFB800FFA800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700
FFE600FFF500FAFF00DCFF0042FF0042FF0000FF28DCFF00FAFF00FAFF00FFD700FFC700
FFB800FFB800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900
FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800
FFC700FFC700FFC700FFD700FFE600FFF500FAFF00EBFF0000FF47BDFF0000FFE105FF00
0094FF14FF0080FF009EFF008FFF0023FF0042FF0080FF0080FF0051FF0000FFF000FF57
14FF0070FF00AEFF00CCFF00DCFF00EBFF00EBFF00FAFF00FFF500FFF500FFF500FFE600
FFE600FFE600FFE600FFD700FFD700FFD700FFD700FFD700FFD700FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700
FFD700FFC700FFD700FFD700FFE600FFE600FFF500DCFF0051FF0000FFC2AEFF0070FF00
00FF8500FF280047FFFF008A00FF850047FFFF000000FF2805FF0033FF0051FF0070FF00
9EFF00BDFF00CCFF00DCFF00EBFF00EBFF00EBFF00EBFF00EBFF00BDFF0000FF94CC00FF
00FF0AFF008AFF000000A3FF000AFFFF000000FFB3FA00FFFF002E80FF00AEFF00AEFF00
80FF00FF002E00FF47FF0000FF00007000FF5100FF14FF0070FF0051FF009E00FF00D1FF
FF0000FF00E600FF0A42FF000094FFFF00B8FF000005FF0000FF0AFF0000FF000014FF00
00F0FFCC00FF00FF19FF007A00FF3800FF5700FF5700FF7500FF9400FFC200FFF000D1FF
0085FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000066FF00C2FF00FFFF00FFC2
00FF9400FF8500FF5700FF389E00FF00FF19FF000005FF00FF00D700FF0A14FF00FF0000
DC00FF23FF0014FF00FF0000FF004C00FF6661FF0033FF00FF0000FF00002300FF00FF0A
00FF0A8FFF0080FF0000FF85FF00008000FFFF000000FF9405FF00FF0000AEFF00CCFF00
CCFF00AEFF00FF00C700FFE1FF0000FF000000FFFFFF0000FF00C700FF7542FF009EFF00
0094FF51FF00FAFF00FAFF00FFF500FFF500FFF500FFF500FFF500FFF500FAFF00EBFF00
DCFF00CCFF009EFF0061FF0000FF6642FF00FF000000FFA3FF0000FF00003300FF00FF94
00FFD100FF578FFF0080FF00FFF500FFE600FFD700FFC700FFC700FFB800FFB800FFB800
FFB800FFA800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFC700FFC700
FFD700FFE600FFF500FAFF0070FF00AEFF00BDFF00FAFF00FFF500FFE600FFD700FFC700
FFB800FFB800FFA800FFA800FFA800FF9900FF9900FF9900FF8A00FF9900FF8A00FF8A00
FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFB800FFB800FFB800
FFC700FFC700FFD700FFE600FFE600EBFF00EBFF00DCFF0080FF0080FF0042FF0023FF00
00FF57AEFF00AEFF00AEFF008FFF007000FF00D1FF9EFF009EFF0023FF0000FFA300A3FF
00FFF00047FF9EFF00BDFF00CCFF00DCFF00EBFF00FAFF00FFF500FFF500FFE600FFE600
FFE600FFE600FFD700FFE600FFD700FFD700FFD700FFD700FFD700FFD700FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFD700FFD700FFE600FFE600FAFF0070FF00DCFF00CCFF00AEFF00
70FF0033FF0000D1FF0019FF00FFE1FF000000FF8500FF473300FF05FF000028FF00FFC2
80FF009EFF00CCFF00EBFF00FAFF00FAFF00FAFF00FAFF00EBFF00FF00000500FF00FF19
80FF0023FF0000FF75FF00003300FF3300FF8000FFFF009900A3FF9EFF00BDFF00BDFF00
23FF0000FF19FF00001400FFFF0000FF000FFF000000FFA38FFF008FFF0080FF00FF0000
FF0000FF000000FF0A80FF0070FF003300FF00FF8542FF0061FF00FF000000C2FF42FF00
33FF0023FF0014FF0005FF0000FF0A00FF2800FF3800FF5700FF9400FFD1FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000075FF00FFE1
00FF9400FF6600FF3800FF1900FF0A05FF0014FF0033FF0005FF0051FF0051FF00FF0000
51FF0070FF0000FF19AE00FF00FF8580FF008FFF0042FF000066FFFF000000FFA38FFF00
AEFF00AEFF0080FF0000D1FFFF0000FF005CFF000000FF479EFF000047FFCCFF00DCFF00
DCFF00CCFF0014FF00FF006BFF003DFF0000FF00008000FFFF000000F0FF00FF85CCFF00
DCFF00EBFF00FFF500FFF500FFE600FFF500FFE600FFE600FFF500FFF500FAFF00EBFF00
CCFF00BDFF000038FFEB00FF00FFFF00FF0A9E00FF0019FF00FF1900FF6600FF9400FF75
00FF1970FF00BDFF00EBFF00FFF500FFE600FFD700FFC700FFC700FFB800FFB800FFB800
FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFC700
FFC700FFD700FFE600FAFF00BDFF00AEFF00DCFF00FAFF00FFF500FFE600FFD700FFC700
FFB800FFB800FFA800FFA800FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900
FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFC700
FFC700FFD700FFD700FFE600FFF50033FF00AEFF00BDFF009EFF0000FF3833FF009EFF00
BDFF00CCFF00CCFF00CCFF009EFF0000FF0A42FF00AEFF00BDFF009EFF0080FF000038FF
00FF0A33FF009EFF00BDFF00BDFF00BDFF00EBFF00FAFF00FFF500FFF500FFE600FFE600
FFE600FFD700FFD700FFD700FFD700FFC700FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFB800FFC700FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFD700FFD700FFD700FFE600FFE600FFF500FAFF00DCFF0000FF85
00FF3800FF1900FFA300FFF0FF00A800B3FF0075FF0094FFFF000000FF75FF0000FF0000
05FF0051FF00AEFF00EBFF00FAFF00FAFF00FAFF00FAFF00FAFF00EBFF00DCFF00CCFF00
AEFF0000FFE100FFB30028FFFF00000047FF00FFC200FF1961FF00AEFF00CCFF00CCFF00
CCFF00BDFF009EFF0005FF00FF00005100FF2300FFFF0000AEFF00AEFF00AEFF0000FF75
FF000000FF8570FF008FFF008FFF0080FF0070FF0080FF0070FF0070FF0061FF0061FF00
51FF0042FF0033FF0014FF0005FF0000FF2800FF47FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00E600FF4700FF1905FF0014FF0033FF0042FF0051FF0061FF0061FF0070FF00
80FF0080FF0080FF00FF001E8FFF009EFF009EFF000085FF00FF4733FF0000F0FFBDFF00
BDFF00BDFF009EFF0023FF00FF00C7FF0000FF000051FF00CCFF00DCFF00DCFF00EBFF00
DCFF00DCFF00BDFF0070FF0023FF0000FF66FF0000FF0099FF0000FA00FF9EFF00EBFF00
FAFF00FFF500FFF500FFE600FFE600FFE600FFE600FFE600FFF500FFF500FFF500FAFF00
8FFF0080FF000057FF00FF282300FF00FFA300FF1951FF0033FF00FF000000FF1905FF00
00FFA300FF199EFF00DCFF00FAFF00FFE600FFC700FFC700FFC700FFB800FFB800FFB800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FF9900FFA800FFA800FF9900FFA800FFA800FF9900FFA800
FFA800FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFC700
FFC700FFD700FAFF00CCFF00AEFF009EFF00DCFF00FAFF00FFF500FFE600FFD700FFC700
FFB800FFB800FFA800FFA800FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFB800FFC700FFC700
FFD700FFD700FFE600FFE600FAFF00AEFF0000FF1961FF0033FF0042FF0000FFC2BDFF00
DCFF00EBFF00EBFF00CCFF008FFF00FA00FF8FFF00BDFF00CCFF00CCFF00BDFF008FFF00
0047FF23FF008FFF009EFF009EFF0023FF00BDFF00EBFF00FAFF00FFF500FFE600FFE600
FFD700FFD700FFD700FFD700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFD700FFD700FFD700FFE600FFF500FAFF00CCFF0000FFB3
00FF4700FFF000FFFF00FFB3FF0000FF000000FFA30075FF00FF66FF00C700FF2823FF00
00FFD100FF28BDFF00FAFF00FAFF00FFF500FFF500FFF500FAFF00FAFF00FAFF00EBFF00
CCFF008FFF00FF000000B3FFFF0000FF000000FF8500FF66FF0000BDFF00DCFF00DCFF00
DCFF00CCFF00AEFF0000FF19FF000014FF00FF00008FFF00BDFF00BDFF00BDFF009EFF00
9EFF009EFF009EFF00AEFF009EFF009EFF008FFF008FFF0080FF0080FF0070FF0061FF00
51FF0042FF0033FF0014FF0000FF1900FF38FF00002300FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF000000FF4700FF0A14FF0033FF0042FF0051FF0061FF0070FF0080FF00
8FFF008FFF008FFF009EFF00AEFF00AEFF00AEFF00AEFF000094FF9EFF00BDFF00CCFF00
CCFF00CCFF009EFF000019FF14FF0014FF00FF002ECC00FFDCFF00EBFF00EBFF00EBFF00
EBFF00DCFF00AEFF0033FF00FF001E00FFF000FF660057FF00FF94FF000F8FFF00EBFF00
FFF500FFF500FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF500EBFF00
AEFF0000FF1900FFA351FF0061FF0005FF0061FF0080FF0014FF006100FF42FF0000FF38
8FFF0023FF00FF000051FF0000FF19FFE600FFC700FFC700FFB800FFB800FFB800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FF9900FF9900FFA800FF9900FF9900FFA800FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FFA800FF9900FF9900FFA800FF9900FF9900FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800
FFC700FFC700FFE600EBFF00BDFF00AEFF0061FF0061FF00FFF500FFE600FFE600FFD700
FFC700FFB800FFA800FFA800FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF7A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFB800FFB800FFD700FFD700
FFD700FFE600FFE600FAFF00EBFF00AEFF0000FFD1FF00009EFF008FFF00BDFF009EFF00
EBFF00FAFF00EBFF00DCFF0070FF0000FF3851FF00BDFF00DCFF00DCFF00CCFF00AEFF00
61FF0000FF0A80FF0000FF7500FF4700FF4780FF00EBFF00FFF500FFF500FFE600FFE600
FFD700FFD700FFD700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700
FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFE600FFE600FFF500EBFF0051FF00
80FF0051FF0000FF19FF00D7FF005C00FFFF2300FF00FF1933FF0051FF0080FF0051FF00
0066FF61FF00EBFF00FAFF00FFF500FFF500FFF500FFF500FFF500FFF500FAFF00FAFF00
DCFF009EFF0000FF6600FF4700FFF0CC00FF00FFE161FF009EFF00CCFF00EBFF00DCFF00
EBFF00DCFF00CCFF00FF0000AEFF00BDFF00FF0000BDFF00CCFF00CCFF00CCFF00BDFF00
BDFF00BDFF00BDFF00AEFF00AEFF00AEFF009EFF009EFF008FFF0080FF0070FF0061FF00
51FF0042FF0023FF0000FF0A00F0FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00009E00FFFF000000FF2823FF0042FF0061FF0070FF0080FF008FFF00
8FFF009EFF00AEFF00AEFF00AEFF00BDFF00BDFF00BDFF00BDFF00CCFF00CCFF00DCFF00
DCFF00DCFF00CCFF00BDFF00FF0000FF00B8CCFF00DCFF00EBFF00FAFF00FAFF00FAFF00
FAFF00EBFF00FF00000038FF33FF0051FF0000FFFF00FF3800FF4780FF0000FF75FAFF00
FFF500FFE600FFE600FFE600FFD700FFD700FFD700FFD700FFE600FFE600FFF500CCFF00
0066FF05FF0000FFF042FF009EFF00AEFF00AEFF008FFF0000FFE100FF0A80FF0000FFB3
AEFF00CCFF00CCFF0061FF0000A3FFFFF500FFC700FFB800FFB800FFB800FFB800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FFA800FF9900FF9900FFA800FF9900FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800
FFC700FFC700FFD700FFE6009EFF00EBFF00CCFF009EFF00FAFF00FFF500FFE600FFE600
FFE600FFC700FFA800FFA800FF9900FF9900FF9900FF8A00FF9900FF8A00FF8A00FF8A00
FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFB800FFC7009EFF00AEFF00
FFF500FFF500FAFF0080FF0000FFC205FF0000FF1914FF00CCFF00EBFF00FAFF00DCFF00
FAFF00FFF500FAFF00DCFF0070FF0000FF388FFF00CCFF00EBFF00EBFF00DCFF0042FF00
00FF3800FF1905FF0000FF9400FF4761FF00AEFF00EBFF00FAFF00FFF500FFE600FFE600
FFD700FFD700FFC700FFC700FFC700FFC700FFC700FFC700FFB800FFB800FFB800FFB800
FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFE600FFF500FAFF00CCFF00
AEFF0051FF00FF008A05FF0000FFA3FF000000D1FFFF000042FF0080FF009EFF0014FF00
BDFF0070FF00FAFF00FFF500FFF500FFE600FFE600FFE600FFF500FFF500FFF500FAFF00
CCFF0033FF0000FF3842FF0000FF0A9EFF0023FF000075FFCCFF00DCFF00EBFF00EBFF00
EBFF00EBFF00DCFF00DCFF00DCFF00DCFF00CCFF00DCFF00DCFF00DCFF00DCFF00CCFF00
CCFF00BDFF00BDFF00BDFF00BDFF00AEFF009EFF009EFF008FFF0080FF0070FF0061FF00
42FF0033FF0000FF19FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF000000FF7523FF0051FF0070FF0080FF008FFF00
9EFF009EFF00AEFF00BDFF00BDFF00BDFF00CCFF00CCFF00CCFF00DCFF00DCFF00DCFF00
DCFF00DCFF00DCFF00CCFF0000FF0A9EFF00EBFF00FAFF00FAFF00FAFF00FAFF00FAFF00
FAFF00FAFF00DCFF0051FF0061FF0070FF0000FF0A9EFF008FFF00DCFF0000FF94FFF500
FFE600FFE600FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFE600FFE600EBFF00
00FF6614FF0023FF0000FF0ABDFF00CCFF00BDFF0005FF0005FF0023FF00BDFF0080FF00
61FF00EBFF00DCFF0080FF008FFF00FFE600FFC700FFB800FFB800FFB800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900FFA800FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800
FFB800FFC700FFC700FFD700FFF500FFF500CCFF0033FF00DCFF00FAFF00EBFF00DCFF00
CCFF00FFE600FFB800FFA800FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFB800FFC700FAFF0014FF00
EBFF00FAFF00EBFF00BDFF0023FF009EFF00BDFF0080FF0080FF00FFF500FFF500FFF500
FFE600FFF500FFF500EBFF00BDFF0000FF94AEFF00EBFF00FAFF00FAFF00EBFF00CCFF00
00FF5742FF0000FF190094FFFF000000FFD19EFF00CCFF00FAFF00FFF500FFE600FFE600
FFD700FFD700FFC700FFC700FFC700FFC700FFC700FFC700FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFC700FFC700FFC700FFC700FFD700FFD700FFE600FFF500EBFF00CCFF00
8FFF0000FF9433FF0033FF0000FF0A00FFD151FF0000FF0A000AFFFF0000BDFF00CCFF00
EBFF00EBFF00FFF500FFF500FFE600FFE600FFE600FFE600FFE600FFE600FFF500FFF500
DCFF00000AFF05FF00BDFF00CCFF00CCFF0000FF0A00FF85DCFF00EBFF00FAFF00FAFF00
FAFF00FAFF00FAFF00EBFF00EBFF00EBFF00EBFF00DCFF00DCFF00DCFF00DCFF00DCFF00
CCFF00CCFF00CCFF00BDFF00BDFF00AEFF00AEFF009EFF008FFF0080FF0070FF0051FF00
2300FF00FF0A00FF750075FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FA00FFFF0000FF00000094FF61FF0070FF008FFF00
9EFF00AEFF00AEFF00BDFF00BDFF00CCFF00CCFF00DCFF00DCFF00DCFF00EBFF00EBFF00
EBFF00EBFF00EBFF00EBFF00DCFF00EBFF00FAFF00FAFF00FAFF00FFF500FFF500FFF500
FFF500FAFF00FAFF00EBFF00CCFF0070FF0042FF000066FFEBFF00FFF500FFF500FFE600
FFE600FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFE600FFE600
FFF500CCFF00EBFF008FFF00EBFF00DCFF00BDFF0080FF0000F0FF33FF00DCFF0070FF00
00FF47FFF500FFF500FAFF0000F0FFFFD700FFC700FFB800FFB800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900
FFA800FF9900FF9900FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FF9900
FF9900FFA800FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800
FFB800FFC700FFC700FFD700FFD700FFF500FAFF00AEFF00BDFF00CCFF0000FF289EFF00
FFF500FFF500FFB800FFA800FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00
FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFB800FFB800FFC700EBFF00EBFF00
14FF00DCFF00DCFF009EFF009EFF0042FF00EBFF00DCFF00FAFF00FFE600FFE600FFE600
FFE600FFE600FFF500FAFF008FFF0000FF2880FF00FAFF00FFF500FFF500FFF500DCFF00
9EFF00AEFF00AEFF0005FF0000FF2833FF0051FF008FFF0061FF00FFF500FFE600FFD700
FFD700FFD700FFC700FFC700FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFC700FFC700FFC700FFC700FFC700FFD700FFE600DCFF0023FF00BDFF00
0075FF23FF008FFF0005FF0000FF2870FF0061FF008FFF0023FF0005FF00AEFF00DCFF00
FAFF00FFF500FFF500FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF500
DCFF0051FF0000FFE1EBFF00FAFF00FAFF00CCFF00DCFF00FAFF00FAFF00FAFF00FAFF00
FAFF00FAFF00FAFF00FAFF00EBFF00EBFF00EBFF00EBFF00EBFF00EBFF00DCFF00DCFF00
DCFF00CCFF00CCFF00CCFF00BDFF00AEFF009EFF009EFF008FFF0070FF0061FF0042FF00
FF00000075FFFF0000FF00A8FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000000AFF00FF1942FF0000FF2880FF00
9EFF00AEFF00AEFF00BDFF00CCFF00CCFF00DCFF00DCFF00DCFF00EBFF00EBFF00EBFF00
EBFF00FAFF00FAFF00FAFF00FAFF00FAFF00FAFF00FFF500FFF500FFF500FFF500FFF500
FFF500FFF500FAFF00FAFF00CCFF0023FF00FF0000BDFF00FFF500FFE600FFE600FFE600
FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700
FFE600FFE600FFF500FAFF00FAFF00EBFF00CCFF0000FF940094FFCCFF00FAFF00FAFF00
FFE600FFE600FFE600FFE600FFE600FFC700FFB800FFB800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FF9900FF9900FFA800FF9900FF9900FFA800FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FFA800FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFA800FFB800
FFB800FFB800FFC700FFC700FFD700FFE600FFF500EBFF00AEFF0070FF00EBFF00FFF500
FFD700FFC700FFA800FFA800FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF6B00FF6B00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF9900FF9900FF9900FF9900FFA800FFA800FFB800FFB800FFC700FFE600FFF500
9EFF00AEFF0042FF0023FF00DCFF00EBFF00FAFF00FFF500FFE600FFD700FFD700FFD700
FFD700FFD700FFE600EBFF00BDFF0080FF00DCFF00FAFF00FFF500FFE600FFF500FAFF00
FAFF00EBFF00AEFF0042FF008FFF0080FF0000FF5723FF00CCFF00FFF500FFE600FFD700
FFD700FFD700FFC700FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFD700FFE600CCFF0000FFD170FF00
14FF00AEFF00CCFF008FFF0070FF00CCFF00CCFF00CCFF008FFF0000FF4780FF00CCFF00
FAFF00FFF500FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFF500FFF500FFF500FFF500FFF500FFF500FAFF00FAFF00FAFF00FFF500FFF500FFF500
FAFF00FFF500FAFF00FAFF00FAFF00FAFF00FAFF00EBFF00EBFF00EBFF00EBFF00DCFF00
DCFF00DCFF00CCFF00CCFF00BDFF00AEFF00AEFF009EFF008FFF00FF00000094FF0038FF
00FF8500D1FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000047FFFF0000FF000000B3FF33FF00
8FFF009EFF00AEFF00BDFF00CCFF00CCFF00DCFF00DCFF00EBFF00EBFF00EBFF00EBFF00
FAFF00FAFF00FAFF00FAFF00FAFF00FFF500FFF500FFF500FFF500FFF500FFF500FFF500
FFE600FFE600FFF500FFF500EBFF0000FF2800FF66FAFF00FFE600FFE600FFD700FFD700
FFD700FFD700FFD700FFD700FFC700FFC700FFC700FFC700FFD700FFD700FFD700FFD700
FFD700FFE600FFE600FFE600FFF500FAFF00DCFF0051FF0070FF00DCFF00FAFF00FFE600
FFE600FFD700FFC700FFC700FFC700FFB800FFB800FFB800FFB800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FFA800FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFB800
FFB800FFB800FFC700FFC700FFD700FFE600FFF500EBFF00CCFF00BDFF00BDFF00FFF500
FFC700FFB800FFA800FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF9900FF9900FF9900FF9900FFA800FFA800FFB800FFC700FFC700FFE600FFF500
DCFF0000FF3842FF00CCFF00EBFF00FFF500FFE600FFE600FFE600FFD700FFD700FFD700
FFD700FFD700FFE60080FF0070FF0000FF57CCFF00FFF500FFE600FFE600FFE600FFE600
FFF500FFF500EBFF009EFF00BDFF0080FF0051FF0000FFF0DCFF00FFF500FFE600FFE600
FFD700FFD700FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFD700FFE600FAFF0080FF000057FF
80FF00CCFF00EBFF00AEFF0000FF57FAFF00FAFF00DCFF0080FF0000FF1900FF85CCFF00
FAFF00FFE600FFE600FFE600FFE600FFD700FFD700FFD700FFD700FFD700FFE600FFE600
FFE600FFE600FFE600FFF500FFF500FFF500FFF500FFF500FFF500FFF500FFF500FFF500
FFF500FFF500FFF500FFF500FAFF00FAFF00FAFF00FAFF00EBFF00EBFF00EBFF00DCFF00
DCFF00DCFF00CCFF00BDFF00BDFF00AEFF009EFF008FFF0080FF0023FF000047FFFF0000
FF0000AE00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFFF0085FF51FF00
80FF008FFF00AEFF00BDFF00CCFF00CCFF00DCFF00DCFF00EBFF00EBFF00EBFF00FAFF00
FAFF00FAFF00FAFF00FFF500FFF500FFF500FFF500FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFF500FAFF0051FF00FFF500FFE600FFE600FFD700FFD700FFD700
FFD700FFD700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFD700
FFD700FFD700FFD700FFE600FFF500FAFF00DCFF0000FF2870FF00CCFF00EBFF00FFE600
FFD700FFC700FFC700FFC700FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFB800
FFB800FFB800FFC700FFC700FFD700FFE600FFF500EBFF0061FF00FAFF00EBFF00FAFF00
FFD700FFB800FFA800FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900
FF8A00FF9900FF9900FF9900FF9900FFA800FFA800FFC700FFD700FFE600FFF500EBFF00
AEFF0042FF0061FF00BDFF00EBFF00FFF500FFE600FFD700FFD700FFC700FFC700FFC700
FFC700FFC700FFD700FFF5000500FFAEFF0014FF00FFE600FFD700FFD700FFD700FFE600
FFE600FFF500FAFF00EBFF00CCFF0042FF0080FF00BDFF00EBFF00FFF500FFE600FFE600
FFD700FFC700FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFA800FFB800FFB800FFA800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFD700FFE600EBFF0051FF0000A3FF
80FF00EBFF00FFF500FAFF00FFF500FFF500FFF500CCFF009EFF0000FF2833FF0000D1FF
FFF500FFE600FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF500FFE600FFF500FFF500
FFF500FFF500FFF500FFF500FFF500FAFF00FAFF00FAFF00FAFF00EBFF00EBFF00EBFF00
DCFF00DCFF00CCFF00CCFF00BDFF00AEFF0080FF0080FF0070FF00DC00FFFF00D700E1FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFFF00FF85FF0000
51FF0000FFE19EFF00BDFF00BDFF00CCFF00DCFF00DCFF00EBFF00EBFF00EBFF00FAFF00
FAFF00FAFF00FFF500FFF500FFF500FFF500FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD700FFD700FFD700FFD700FFD700
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFD700FFD700FFE600FFF500EBFF00BDFF0080FF0061FF0051FF0000FFA3FFE600
FFC700FFC700FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800
FFB800FFB800FFC700FFC700FFD700FFE600FFF500DCFF00EBFF00FFF500FFF5000075FF
FFE600FFC700FFA800FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00
FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00
FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF9900FF9900FF9900FFA800FFA800FFC7008FFF00EBFF0042FF00AEFF00
CCFF00BDFF00BDFF0080FF00EBFF00FFF500FFE600FFD700FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFE6008FFF00FFE600FFD700FFD700FFD700FFD700FFD700FFD700
FFD700FFE600FFF500EBFF00DCFF009EFF0023FF00CCFF00EBFF00FAFF00FFF500FFE600
FFD700FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFA800
FFA800FFB800FFA800FFA800FFA800FFA800FFB800FFA800FFA800FFB800FFA800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFE60023FF00CCFF00BDFF00
00FF38FFF500FFE600FFE600FFE600FFE600FFE600FFE600FAFF0000FFD1BDFF00FFF500
FFE600FFE600FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700
FFD700FFD700FFD700FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFF500FFF500FFF500FFF500FFF500FFF500FAFF00FAFF00FAFF00EBFF00EBFF00EBFF00
DCFF00DCFF00CCFF00CCFF00BDFF009EFF0000FFB333FF0000C2FFDC00FF00FFA30094FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF007A
00D1FF00FFFF00C2FFAEFF00BDFF00CCFF00DCFF00DCFF00EBFF00EBFF00FAFF00FAFF00
FAFF00FFF500FFF500FFF500FFF500FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFD700FFD700FFE600CCFF0042FF0005FF0000FFA38FFF00FAFF00FFD700
FFC700FFC700FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FF9900FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800
FFB800FFB800FFB800FFC700FFD700FAFF00EBFF0061FF00FAFF00FFD700FFD700FFE600
8FFF00FFE600FFA800FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF9900FF9900FF9900FF9900FFA800FFB800FFF500DCFF00AEFF00FAFF00FFE600
FFF500CCFF00FAFF00EBFF0070FF00FFF500FFE600FFD700FFC700FFC700FFB800FFC700
FFB800FFB800FFC700FFC700FFD700FFC700FFC700FFC700FFC700FFC700FFC700FFD700
FFD700FFE600FFF500EBFF00BDFF009EFF0000FFB3AEFF00DCFF00DCFF00EBFF00DCFF00
FFD700FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFD700FFF500FFE600FFE600
00D1FFFFE600FFD700FFD700FFD700FFD700FFD700FFD700FFF50042FF00FFF500FFE600
FFD700FFD700FFD700FFD700FFD700FFD700FFC700FFD700FFD700FFD700FFD700FFD700
FFD700FFD700FFD700FFD700FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFF500FFF500FFF500FFF500FFF500FAFF00FAFF00FAFF00EBFF00EBFF00
DCFF00DCFF00CCFF00BDFF00AEFF009EFF00FF005CFF0000FF007AFF00A8FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFFF
00FFB300B3FF00FFA39EFF00BDFF00CCFF00DCFF00DCFF00EBFF00EBFF00FAFF00FAFF00
FFF500FFF500FFF500FFF500FFF500FFE600FFE600FFE600FFE600FFE600FFD700FFD700
FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFD700FFE600FFF500CCFF0080FF0000E1FFCCFF00FFE600FFC700
FFC700FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FFA800FF9900FFA800FFA800FFA800FFA800
FFB800FFB800FFB800FFC700FFD700DCFF009EFF00FAFF00FFD700FFC700FFC700FFC700
FFF500FFC700FFA800FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF8A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF9900FF9900FF9900FFA800FFB800FFF500FFE600DCFF00FFE600FFD700
FFD700BDFF00FFE600FFF50070FF00FAFF00FFF500FFC700FFC700FFB800FFB800FFB800
FFB800FFB800FFB800FFC700FFB800FFB800FFB800FFC700FFB800FFC700FFC700FFC700
FFD700FFE600EBFF00CCFF0033FF0000FF197000FF8FFF009EFF0061FF009EFF00BDFF00
FFE600FFC700FFB800FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFA800FFA800FFA800FFA800FFB800
FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFD700FFD700
FFD700FFD700FFD700FFC700FFC700FFD700FFD700FFD700FFD700FFE600FFD700FFD700
FFD700FFD700FFC700FFC700FFC700FFC700FFC700FFC700FFD700FFC700FFC700FFD700
FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFE600FFE600FFE600
FFE600FFE600FFF500FFF500FFF500FFF500FAFF00FAFF00FAFF00FAFF00EBFF00EBFF00
DCFF00CCFF00CCFF00BDFF00AEFF0000FF940094FFFF007A00FFC2FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00995100FF
00FF6600FF4761FF008FFF00AEFF00AEFF00CCFF00DCFF00EBFF00EBFF00FAFF00FAFF00
FFF500FFF500FFF500FFF500FFE600FFE600FFE600FFE600FFE600FFD700FFD700FFD700
FFD700FFD700FFD700FFD700FFD700FFD700FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFB800FFC700FFB800FFB800FFB800FFB800FFC700FFB800FFB800
FFC700FFC700FFC700FFC700FFD700FFF500DCFF00BDFF0000FF5780FF00FFD700FFC700
FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800
FFB800FFB800FFB800FFC700FFE6009EFF0000FF28FFD700FFC700FFB800FFB800FFB800
FFF500FFB800FFA800FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF9900FF9900FF9900FF9900FFA800FFB800FFB800FFE600FFD700FFC700
FFC700FFC700FFC700FFE600BDFF00AEFF00CCFF00FFC700FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700
FFD700FFF50000FFD170FF00AEFF0061FF0023FF008FFF0051FF00DCFF0000FF578FFF00
FFD700FFC700FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFB800FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFD700
FFC700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFE600FFE600
FFE600FFE600FFE600FFF500FFF500FFF500FFF500FAFF00FAFF00FAFF00EBFF00EBFF00
DCFF00CCFF00BDFF00AEFF009EFF0080FF00FF000000FFA300FF94000AFFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
5100FF00FF8500FFF000FFB370FF0000FFC2BDFF00DCFF00EBFF00EBFF00FAFF00FAFF00
FFF500FFF500FFF500FFE600FFE600FFE600FFE600FFE600FFD700FFD700FFD700FFD700
FFD700FFD700FFD700FFC700FFC700FFD700FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFC700FFC700FFC700FFD700FFF50061FF008FFF00FFE600FFD700FFC700FFB800
FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FF9900FFA800FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF9900FF9900FF9900FF8A00
FF8A00FF9900FF9900FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FF9900FFA800FFA800FFA800
FFA800FFB800FFB800FFD700DCFF00DCFF00FFF500FFC700FFC700FFB800FFA800FFA800
FFA800FFA800FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00
FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00
FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF9900FF9900FF9900FFA800FFA800FFA800FFB800FFB800FFB800
FFB800FFB800FFB800FFC700FFF500FFE600FFC700FFB800FFB800FFB800FFB800FFA800
FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700
FFC700FFE600DCFF00EBFF00DCFF0000FF5770FF00BDFF00FAFF00FFF500DCFF0070FF00
FFC700FFB800FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFB800FFA800FFB800FFB800FFB800FFB800FFB800FFC700FFB800
FFB800FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFE600FFE600
FFE600FFE600FFE600FFE600FFF500FFF500FFF500FFF500FAFF00FAFF00EBFF00EBFF00
DCFF0000FF75000AFF8FFF0080FF0051FF0014FF0000FF3800FFD1FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000EB00FF00FFFF00FF94AEFF00CCFF00EBFF00EBFF00FAFF00FAFF00
FFF500FFF500FFF500FFE600FFE600FFE600FFE600FFD700FFD700FFD700FFD700FFD700
FFD700FFD700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFB800FFC700
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFC700FFC700BDFF00EBFF00FFE600FFC700FFC700FFB800FFB800
FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF9900FF8A00FF8A00
FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800
FFA800FFB800FFC700FFD700FAFF00CCFF00FFE600FFC700FFB800FFA800FFA800FFA800
FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00
FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800
FFA800FFA800FFB800FFB800FFE600FFC700FFB800FFB800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFC700FFC700FFD700FFE600AEFF009EFF00DCFF008FFF00FFE600FFD700FFD700FFD700
FFC700FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFD700FFD700FFD700FFD700FFD700FFE600FFD700FFE600
FFE600FFE600FFE600FFE600FFF500FFF500FFF500FFF500FAFF00FAFF00EBFF00EBFF00
CCFF0000FFC200FF6651FF0033FF00FF0000FF0000FF00000094FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF000000E1FF00FF750047FF00FFD1FF006B9EFF00DCFF00EBFF00FAFF00FAFF00
FFF500FFF500FFF500FFE600FFE600FFE600FFD700FFD700FFD700FFD700FFD700FFD700
FFD700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFB800FFB800FFB800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF8A00FF8A00FF8A00FF9900FF9900FF8A00FF8A00FF8A00FF9900FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF9900FF8A00
FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800
FFA800FFB800FFC700FFD700FFF500BDFF00FAFF00FFD700FFB800FFA800FFA800FF9900
FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF9900FF8A00FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFA800FFB800FFB800
FFB800FFC700FFC700FFE600FAFF0051FF00FFF500FFF500FFD700FFC700FFC700FFC700
FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFA800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700
FFB800FFB800FFC700FFB800FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFD700FFC700FFD700FFD700FFD700FFD700FFD700FFD700FFD700
FFE600FFE600FFE600FFE600FFF500FFF500FFF500FFF500FAFF00FAFF00EBFF00EBFF00
CCFF008FFF0000FF3800FF660057FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF000000FFC200FF38CC00FF00FF750028FFAEFF00DCFF00EBFF00FAFF00FAFF00
FFF500FFF500FFE600FFE600FFE600FFE600FFD700FFD700FFD700FFD700FFD700FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFA800FFA800
FFA800FFA800FFA800FFA800FF9900FFA800FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF9900
FF9900FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00
FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800
FFA800FFB800FFC700FFE600FAFF00AEFF00FFF500FFD700FFA800FFA800FF9900FF9900
FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800
FFB800FFB800FFC700FFD700EBFF0000FF0AFFE600FFD700FFC700FFC700FFB800FFB800
FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFB800FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFD700FFD700FFD700
FFE600FFE600FFE600FFE600FFE600FFF500FFF500FAFF00FAFF00EBFF00EBFF00DCFF00
CCFF009EFF0000FFA300B3FF00FF750085FFFF008AFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000047FFFF005C00FF1900FF0A00FFFF70FF00BDFF00DCFF00EBFF00EBFF00FAFF00
FFF500FFF500FFE600FFE600FFE600FFD700FFD700FFD700FFD700FFD700FFD700FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFB800FFC700FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00
FF9900FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF9900FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800
FFA800FFC700FFE600EBFF00FFE600FFE600FFE600FFB800FFA800FF9900FF9900FF9900
FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FFA800FFA800FFA800FF9900FF9900FFA800FF9900FF9900
FFA800FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFB800FFB800FFD700DCFF009EFF00FFF500FFC700FFB800FFB800FFB800FFB800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFA800FFB800
FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFB800FFC700FFC700
FFC700FFC700FFC700FFC700FFD700FFC700FFC700FFD700FFD700FFD700FFD700FFD700
FFD700FFE600FFE600FFE600FFE600FFF500FFF500FAFF00FAFF00EBFF00EBFF00DCFF00
BDFF0000FF1900FF4700F0FF00FF3800FF669E00FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF000000FF4723FF0051FF008FFF00BDFF00CCFF00DCFF00EBFF00FAFF00
FAFF00FFF500FFE600FFE600FFE600FFE600FFD700FFD700FFD700FFD700FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFB800FFC700FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFA800FFA800FFB800FFA800FFB800FFA800
FFB800FFA800FFA800FFB800FFB800FFA800FFA800FFA800FFB800FFA800FFA800FFA800
FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF9900FF9900FF9900FF9900FF9900FFA800
FFA800FAFF009EFF00DCFF00FFC700FFC700FFD700FFA800FF9900FF9900FF9900FF9900
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FF9900FF9900
FFA800FF9900FF9900FF9900FF9900FFA800FF9900FFA800FFA800FFA800FFA800FFA800
FFA800FFB800FFB800FFC700BDFF00FFE600FFD700FFB800FFB800FFB800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900FFA800
FFA800FF9900FF9900FFA800FFA800FF9900FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFD700FFD700
FFE600FFE600FFE600FFE600FFF500FFF500FFF500FAFF00FAFF00EBFF00EBFF00DCFF00
BDFF0000FFE100FFC21400FF00FF0A00FF4700F0FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF000000FFB300FF758000FF0057FF42FF00BDFF00BDFF00BDFF00DCFF00
FAFF00FFF500FFE600FFE600FFE600FFD700FFD700FFD700FFD700FFD700FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FF9900FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900
FFA800FFA800FFB800FFB800FFA800FFA800FFA800FF9900FF9900FF9900FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FFA800FF9900FFA800FF9900FFA800FFA800FFA800
FFA800FFA800FFB800FFB800FFC700FFC700FFB800FFB800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900FF9900FFA800FF9900FF9900
FFA800FF9900FF9900FFA800FF9900FF9900FF9900FFA800FF9900FF9900FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFB800FFB800FFB800FFB800
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFD700FFD700
FFD700FFD700FFE600FFE600FFF500FFF500FAFF00FAFF00EBFF00DCFF00DCFF00CCFF00
BDFF009EFF0070FF0033FF0005FF0000FF66FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000EB00FF0038FF8000FF2300FF00FF0A8FFF0070FF0005FF0070FF00
FAFF00FFF500FFF500FFE600FFE600FFD700FFD700FFD700FFD700FFC700FFC700FFC700
FFC700FFC700FFC700FFB800FFB800FFC700FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFA800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900
FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00
FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900
FF9900FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF7A00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800
FFA800FFA800FFA800FFA800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FF9900FFA800FF9900FF9900FF9900FF9900FF9900
FFA800FF9900FF9900FF9900FF9900FF9900FF9900FFA800FF9900FF9900FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFB800FFB800
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFD700
FFD700FFD700FFE600FFE600FFF500FFF500FAFF00EBFF00DCFF00BDFF00CCFF00BDFF00
8FFF0080FF0042FF0014FF0000FF19AE00FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF000000E1FF00FF1951FF0000B3FFCCFF00
EBFF00FFF500FFF500FFE600FFE600FFE600FFD700FFD700FFD700FFD700FFC700FFC700
FFC700FFC700FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFA800FFA800FFA800FFA800FFA800FFB800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900FFA800FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF8A00FF8A00FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FF9900FF9900FF9900FF9900FFA800FF9900FF9900FF9900FF9900FF9900
FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFD700
FFD700FFD700FFE600FFE600FFF500FFF500FAFF0000FF0A8FFF0014FF00AEFF00AEFF00
00FFA30075FFFF000000FFC2FF000000FFFFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000047FFFF000000FF4700FF57FF0000FF001EBDFF00
EBFF00FAFF00FFF500FFE600FFE600FFD700FFD700FFD700FFD700FFC700FFC700FFC700
FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900FFA800FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900FFA800FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FF9900
FF9900FF9900FFA800FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800
FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFD700FFD700
FFD700FFD700FFE600FFE600FFE600FFF500FAFF0051FF0023FF0000FFC28FFF0080FF00
23FF002300FFFF00C7FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF000000FF2805FF0000FF47FF0000FF009970FF00
9EFF00EBFF00FFF500FFE600FFE600FFD700FFD700FFD700FFD700FFD700FFC700FFC700
FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FF9900FFA800FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FFA800FF9900FF9900FF9900FFA800FF9900FF9900FFA800FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFB800FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFC700FFB800FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFD700FFD700
FFD700FFD700FFE600FFE600FFE600FFF500FAFF00BDFF0061FF0000FF4761FF0000FF19
FF00B83300FF0085FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF006BFF000000A3FF00FF0A23FF0000FF9400FF5723FF000085FF
00FF0ABDFF00FFF500FFE600FFE600FFD700FFD700FFD700FFC700FFC700FFC700FFC700
FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FF9900FF9900FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00
FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00
FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF9900FF8A00
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FFA800FF9900FF9900FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFB800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFC700FFC700FFD700FFD700
FFD700FFD700FFE600FFE600FFE600FFF500FAFF00DCFF0000FF3805FF00FF00A800FF94
00FF470019FF00FFA3FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF000000FFE1FF000014FF0042FF000038FFBD00FF00FF9400FF19
BDFF00DCFF00FFF500FFE600FFE600FFD700FFD700FFD700FFC700FFC700FFC700FFC700
FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFA800FFA800FFB800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FF9900FF9900FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00
FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF9900FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FFA800FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FF9900FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFD700FFD700
FFD700FFD700FFE600FFE600FFE600FFF500FAFF00EBFF00AEFF0000FF94DC00FF00FF57
00FF0A00FF0A00FF66FF002EFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00005100FF23FF0051FF0061FF0061FF0000FFE1FA00FF
DCFF00FAFF00FFF500FFF500FFE600FFE600FFD700FFD700FFC700FFC700FFC700FFC700
FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF8A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FF9900FF9900FF9900
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFD700FFD700FFD700
FFD700FFD700FFE600FFE600FFE600FFF500FAFF00DCFF009EFF000057FF00FFF0000AFF
14FF0014FF0000FF6600F0FF000AFFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000019FF61FF0080FF009EFF00AEFF00CCFF00
EBFF00FAFF00FFF500FFF500FFE600FFE600FFD700FFD700FFC700FFC700FFC700FFC700
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFA800FFB800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900FFA800FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FFA800FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFB800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFC700FFC700FFD700
FFD700FFD700FFE600FFE600FFF500FFF500FAFF00FF000000FF0A14FF0000FF28FA00FF
33FF0033FF0000FF0A00FFB3FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000000AFF00FF940085FF51FF0070FF009EFF00BDFF00CCFF00
EBFF00FAFF00FFF500FFF500FFE600FFE600FFD700FFD700FFD700FFC700FFC700FFC700
FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFA800FFA800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFC700FFD700FFD700
FFD700FFD700FFE600FFE600FFF500FFF500FAFF00CCFF009EFF0000FF0A00FF5700FF57
51FF0042FF0014FF0000FF660047FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF000000FFB300FF1900FF0ADC00FF80FF009EFF00BDFF00
DCFF00EBFF00FAFF00FFF500FFF500FFE600FFD700FFD700FFD700FFC700FFC700FFC700
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00
FF7A00FF8A00FF8A00FF8A00FF7A00FF7A00FF8A00FF8A00FF8A00FF7A00FF8A00FF8A00
FF7A00FF7A00FF8A00FF7A00FF7A00FF8A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF9900FF9900FF8A00FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FF9900FF9900FF9900FFA800
FF9900FF9900FF9900FFA800FFA800FF9900FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFD700FFD700
FFD700FFD700FFE600FFE600FFF500FFF500FAFF00EBFF00CCFF008FFF0080FF0080FF00
70FF0042FF0000FF19FF00E6FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF000000E1FF0075FFFF007A00FF578000FFFF00A89EFF00
BDFF00EBFF00FAFF00FAFF00FFF500FFF500FFE600FFD700FFD700FFC700FFC700FFC700
FFB800FFB800FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FFA800FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF7A00
FF7A00FF7A00FF8A00FF8A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF8A00
FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF9900FF9900
FF8A00FF9900FF9900FF9900FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FFA800FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFC700FFD700FFD700
FFD700FFE600FFE600FFE600FFF500FFF500FAFF00EBFF00DCFF00BDFF00AEFF008FFF00
70FF0051FF0000E1FF00FFD1FF004CFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF005CFF0000FF0000DC00FF0500FFFF000000FF4700FF28
00FF19CCFF00EBFF00EBFF00DCFF00FAFF00FFF500FFD700FFD700FFC700FFC700FFC700
FFB800FFB800FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00
FF7A00FF7A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF7A00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00
FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF9900FF9900FF8A00FF8A00FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFA800FFA800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFD700FFD700
FFD700FFE600FFE600FFE600FFF500FFF500FAFF00EBFF00DCFF00CCFF00AEFF008FFF00
51FF0042FF0000FF6600FF85FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00D733FF00
80FF00BDFF00DCFF00BDFF0061FF008FFF00FAFF00FFE600FFD700FFC700FFC700FFC700
FFB800FFB800FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FFA800FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00
FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF8A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00
FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF9900
FF9900FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FF9900FF9900FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFD700FFD700
FFE600FFE600FFE600FFF500FFF500FAFF00FAFF00DCFF00CCFF00BDFF0080FF0061FF00
00FF280085FF00FF472300FF0047FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFF0FF0000FF00F5
0019FF80FF00BDFF009EFF0042FF0000FF288FFF00FFE600FFD700FFC700FFC700FFC700
FFB800FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FF9900FF9900FFA800FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00
FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF8A00FF8A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF8A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00
FF8A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF9900
FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FFA800FF9900FF9900FF9900FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFD700FFE600
FFE600FFF500FFF500FFF500FAFF00FAFF00EBFF00CCFF009EFF008FFF0000A3FF14FF00
00FF75FF00E60019FF000AFF1400FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000D1FF00FF4700FF945100FF
0019FF51FF009EFF008FFF000019FFCCFF00FAFF00FFE600FFD700FFD700FFC700FFC700
FFC700FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FF9900FF9900FF9900FFA800FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00
FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF9900
FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF8A00FF8A00FF8A00FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFD700FFD700FFE600
FFE600FFF500EBFF00FAFF00EBFF00EBFF00DCFF00BDFF0042FF0000D1FF00FF9400FF85
00C2FFEB00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0AFF00D714FF00
00A3FF00FFD161FF0070FF0000B3FFBDFF00FFF500FFE600FFD700FFC700FFC700FFC700
FFB800FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF9900FF9900FF8A00FF8A00
FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFD700FFE600FFF500
FFF500EBFF0005FF00DCFF00EBFF00DCFF00DCFF0061FF000057FF00FF38FF00000500FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000EB00FFFF000000F0FF00FF7533FF0033FF0042FF00
33FF0000FF0A00FF0A33FF0000FFA3BDFF00FFF500FFE600FFD700FFC700FFC700FFC700
FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF9900FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF6B00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900
FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FF9900FF9900
FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFD700FAFF00BDFF00
DCFF00BDFF0033FF0000FF75CCFF00DCFF00CCFF009EFF0061FF0000FF0AFF009900A3FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF000000FFB300FF9400FF6600FF1951FF0070FF0061FF00
33FF0000FFB300FF2800FFA342FF00DCFF00FAFF00FFE600FFD700FFC700FFC700FFC700
FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00
FF7A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF8A00
FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFD700FFF500BDFF00
8FFF0042FF000057FF61FF00BDFF00BDFF00AEFF0080FF0000FF19FF006B00FFFF00FFA3
FF008AFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF000000C2FF00FF1900F0FFFF000061FF0080FF0070FF00
23FF0000FF1900FF9470FF00BDFF00CCFF00DCFF00FFF500FFD700FFD700FFC700FFC700
FFB800FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00
FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00
FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFA800
FFA800FFA800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFD700FFE600FAFF00
00FF5780FF0080FF0000FF289EFF00AEFF0080FF0000FF28EB00FFFF001E00FF9400FF38
00FFC2FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF000000FFB305FF0023FF0000FF6680FF008FFF008FFF00
42FF0000FFF051FF0080FF009EFF008FFF0051FF00EBFF00FFE600FFD700FFC700FFC700
FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FF9900FF9900FF9900FF9900
FF9900FFA800FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFD700FAFF00
51FF00CCFF009EFF0033FF008FFF009EFF0000FF1900FFFF0085FF00FF0A0085FF05FF00
00F0FFFF00D75100FFAE00FF0057FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF000000A3FF6100FF51FF0080FF009EFF009EFF009EFF00
00FF4700FFF000FF4714FF0014FF0005FF008FFF0051FF00FAFF00FFD700FFC700FFC700
FFB800FFC700FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900
FF9900FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF9900FF9900FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFB800FFB800FFB800FFB800FFC700FFB800FFC700FFC700FFC700FFD700FFE600
FAFF00EBFF0000FF5700FF2861FF0070FF0023FF0000FF5723FF0033FF0042FF0042FF00
00FF28FF000000FF850066FF00F0FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF000033FF0080FF009EFF00AEFF00AEFF00
9EFF0080FF0000FF4742FF0000FF3800FFB3BDFF0080FF00FAFF00FFD700FFC700FFC700
FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00
FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF8A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFD700FFD700
FFE600FAFF0080FF0070FF0000FF0A51FF0000FFD100FF0A42FF0061FF0061FF0061FF00
14FF00000AFF00FF3800FF3800D1FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00002300FFEB00FF23FF0000FF579EFF00BDFF00BDFF00
BDFF008FFF0033FF00AEFF0014FF00DCFF00EBFF00DCFF00BDFF00FFD700FFC700FFC700
FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFD700
FFE600FFF500EBFF00BDFF0033FF0000FF2800FF1900FF6614FF0070FF0080FF0070FF00
00FF0A00FF2800FF1900FF28FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF000000FFFFFF00A800FF2800FF9470FF00AEFF00BDFF00CCFF00
CCFF00DCFF00DCFF00CCFF008FFF00FAFF00FFF500FFE600FFE600FFD700FFC700FFB800
FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00
FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00
FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFD700
FFD700FFE600FAFF00EBFF00AEFF0061FF0000FFB305FF0000D1FF80FF008FFF008FFF00
80FF00FF000033FF0005FF0000FF940038FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF000000FF1914FF00FF001EEB00FFAEFF00CCFF00CCFF00
DCFF00EBFF00EBFF00EBFF00FAFF00FFF500FFE600FFE600FFD700FFC700FFC700FFB800
FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900FF9900
FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00
FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF8A00FF8A00FF8A00
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FFA800FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFD700
FFD700FFE600FFF500EBFF00BDFF009EFF0061FF0000FF2800FF2880FF009EFF009EFF00
8FFF0070FF0051FF000057FF0028FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00004200FF00E1FF00FF8542FF0051FF0080FF00AEFF00CCFF00DCFF00
EBFF00EBFF00FAFF00FAFF00FFF500FFE600FFE600FFD700FFD700FFC700FFC700FFB800
FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00
FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF6B00FF6B00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00
FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FFA800FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFD700
FFD700FFE600FFF5009EFF008FFF0051FF0000FFF000A3FF61FF009EFF00AEFF00AEFF00
9EFF0080FF0051FF0000FFD1FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF000000FF6600FF3842FF0070FF008FFF00AEFF00BDFF00DCFF00
EBFF00FAFF00FAFF00FFF500FFF500FFE600FFD700FFD700FFC700FFC700FFC700FFB800
FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00
FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFC700
FFD700FFE600EBFF0042FF0023FF0000FF190094FF14FF0000FF28BDFF00BDFF00AEFF00
9EFF0023FF0033FF00FF007AFF00004200FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF000000E1FF00FF7500FF3800FF4742FF0070FF008FFF0080FF00CCFF00
EBFF00FAFF00FAFF00FFF500FFE600FFE600FFD700FFD700FFC700FFC700FFC700FFB800
FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700
FFD700FFE6009EFF0000FF47BDFF0061FF0061FF00AEFF00BDFF00CCFF00CCFF00BDFF00
9EFF0033FF0000FF2800FF4700FF8500FF75FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000BD00FF6100FFFF0000FF000000F0FF00FF8505FF0061FF00FF00F5BDFF00
DCFF00FAFF00FFF500FFF500FFE600FFE600FFD700FFD700FFC700FFC700FFC700FFB800
FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF9900FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700
FFD700FFE600FFF50070FF00EBFF00CCFF008FFF00CCFF00DCFF00DCFF00CCFF00CCFF00
AEFF008FFF0014FF0000FF8514FF0000FF47FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00002300FF00FFB39E00FF00FF0A00FF57
DCFF00EBFF00FAFF00FFF500FFE600FFE600FFD700FFD700FFC700FFC700FFC700FFC700
FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00
FF8A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF9900FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800
FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700
FFD700FFD700FFE600FFF500FAFF00FAFF00EBFF00EBFF00EBFF00DCFF00DCFF00CCFF00
BDFF009EFF0033FF0042FF0023FF0000A3FF0085FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF000000E1FFBD00FF23FF0000FF5761FF00
CCFF00EBFF00FAFF00FFF500FFF500FFE600FFD700FFD700FFC700FFC700FFC700FFB800
FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00
FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900
FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFC700FFC700
FFC700FFD700FFD700FFE600FFF500FFF500FAFF00FAFF00EBFF00EBFF00DCFF00CCFF00
BDFF009EFF0080FF0061FF0033FF0000D1FF00FF75FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00F500FF2833FF0070FF009EFF00
BDFF00BDFF0061FF00FAFF00FFF500FFE600FFD700FFD700FFC700FFC700FFC700FFB800
FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FF9900FF9900FFA800
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700
FFC700FFD700FFD700FFE600FFE600FFF500FFF500FAFF00FAFF00EBFF00DCFF00BDFF00
AEFF009EFF0080FF0051FF0005FF0000FF2800FF7500FFF0FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00008F00FF0094FF00FF3851FF0023FF00
05FF008FFF0023FF00EBFF00FFF500FFE600FFD700FFD700FFD700FFC700FFC700FFC700
FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FFA800FF9900FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700
FFC700FFD700FFD700FFD700FFE600FFF500FFF500FAFF00FAFF00EBFF00DCFF008FFF00
8FFF008FFF0000FFF023FF00AE00FF0085FFFF0000FF0000AE00FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00A8FF0000FF0000FF0000FF0000FF0000FF0000FF00000047FF00FF5705FF000500FF
00FF8500FF0A8FFF0080FF00FAFF00FFE600FFE600FFD700FFD700FFC700FFC700FFC700
FFC700FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF9900FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FFA800FF9900FF9900FF9900FF9900FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFC700FFC700FFC700FFC700FFC700
FFC700FFD700FFD700FFD700FFE600FFE600FFF500FFF500FAFF00EBFF00DCFF0070FF00
42FF0061FF0000FF1900FF7500FFC2FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0500FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FA00FFFF000F00FFFF00FFE1
61FF0051FF0000FF57BDFF00FAFF00FFF500FFE600FFD700FFD700FFD700FFC700FFC700
FFC700FFB800FFB800FFB800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00
FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700
FFC700FFD700FFD700FFD700FFE600FFE600FFF500FFF500FAFF00EBFF00DCFF009EFF00
05FF00BD00FF00FFA3FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
00C2FFFF0000FF0000FF0000FF0000FF00004200FFFF000000E1FF2300FF00FFA305FF00
70FF00AEFF00BDFF00DCFF00FAFF00FFF500FFE600FFE600FFD700FFD700FFD700FFC700
FFC700FFB800FFB800FFB800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700
FFC700FFD700FFD700FFD700FFE600FFF500FFF500FAFF00FAFF00EBFF00CCFF0000FF47
00FF7505FF0000F0FF00FFF0FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000E1FF
00FFA3FA00FFFF0000FF0000FF00005100FF00E1FFFF007A00FF5700FF570047FF23FF00
80FF00AEFF00CCFF00EBFF00FAFF00FFF500FFF500FFE600FFE600FFE600FFD700FFD700
FFC700FFC700FFB800FFB800FFA800FFA800FFA800FFA800FFA800FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFC700FFC700
FFC700FFD700FFD700FFD700FFE600FFE600FFF500EBFF00EBFF00DCFF00BDFF008FFF00
61FF0033FF0000FF2800B3FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00007000FF
00FF4700FF66AE00FF00B3FFFF00000057FF00FF4700B3FF14FF0000FF3800FFA300C2FF
33FF008FFF00CCFF00EBFF00FAFF00FAFF00FFF500FFF500FFF500FAFF00FAFF00FFE600
FFD700FFC700FFB800FFB800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800
FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700
FFC700FFD700FFD700FFD700FFE600FFE600FAFF00BDFF00AEFF00CCFF00AEFF009EFF00
70FF0000FF0A0085FF00FFE1FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000000AFF00F0FF
00FF0A00A3FF00FF5700FF57FF00000047FF00FFC200FFB351FF0033FF0000FF38FF0000
00FF2861FF008FFF00CCFF00EBFF00FAFF00FAFF00FAFF00FAFF00DCFF0023FF00FFF500
FFE600FFE600FFC700FFB800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00
FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800
FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700
FFC700FFD700FFD700FFD700FFE600FFE600FAFF008FFF0061FF00AEFF00BD00FF23FF00
51FF0000FF850047FF8000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000BD00FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF47
33FF0000FF3814FF0000FFFF0094FF00FF2800FF3870FF0070FF0005FF0000FF4700B3FF
00FF9400B3FF23FF0080FF00DCFF00EBFF00FAFF00EBFF00CCFF009EFF009EFF0061FF00
DCFF00DCFF00FFC700FFB800FFA800FFA800FFA800FFA800FF9900FFA800FF9900FF9900
FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00
FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700
FFC700FFD700FFD700FFD700FFE600FFF500FAFF00CCFF0005FF0033FF0000FFA30028FF
00FF0A00FF2800FFC2FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0019FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000085FFFF000014FF00
51FF0061FF0051FF0023FF0000FFC233FF0000FF758FFF0080FF0000FF4700FF2842FF00
14FF0000FFD180FF00BDFF00DCFF00EBFF00DCFF00DCFF009EFF0051FF0080FF009EFF00
80FF00FFF500FFC700FFB800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00
FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800
FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFC700
FFD700FFD700FFD700FFE600FFE600FFF500FAFF00DCFF0080FF0014FF0042FF0000FF85
00F0FF00FF85DC00FFFF006BFF00008F00FFFF0000FF0000FF0000FF0000CC00FF00E1FF
00FF85FF004CFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00E600FFFF00FFC200FF284200FF
61FF0070FF0061FF0000FFF000FF6661FF008FFF009EFF009EFF0080FF0023FF0080FF00
00FF940094FF23FF00AEFF00CCFF00DCFF00DCFF00BDFF0000FF5742FF00DCFF00CCFF00
AEFF00EBFF00FFD700FFC700FFB800FFA800FFA800FFA800FFA800FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800
FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFD700
FFD700FFD700FFD700FFE600FFE600FFF500FAFF0033FF0000D1FF80FF0080FF0000FF57
00FF75FF00E600E1FF00FFC20057FF00FFFFFF0000FF0000FF0000FF005C00B3FF00C2FF
00FF38FF00E60085FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF1923FF000028FF
80FF008FFF0000FF3800FFA305FF0000D1FF9EFF00BDFF00BDFF00AEFF00AEFF009EFF00
80FF0042FF0000FF198FFF00BDFF00CCFF00BDFF009EFF0000FF28CCFF00FAFF00FAFF00
61FF00EBFF00EBFF00FFB800FFB800FFA800FFA800FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800
FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFD700
FFD700FFD700FFD700FFE600FFE600FFF500FAFF00DCFF00BDFF00AEFF009EFF0051FF00
00FF28FF000000FF4700FFB30057FF00FF5700FFC28F00FF0066FF9E00FF5100FF00FF47
05FF0000FF38FF00F5FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000057FF42FF0080FF00
9EFF009EFF0080FF00FA00FF8FFF008FFF00AEFF00CCFF00CCFF00BDFF00BDFF00AEFF00
8FFF0070FF00AE00FF8FFF00AEFF00AEFF0000FF0A42FF008FFF00DCFF00FFF500FFF500
FFE600FFE600FAFF00FFB800FFB800FFA800FFA800FFA800FF9900FF9900FF9900FF9900
FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800
FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFC700FFC700FFD700FFD700FFD700
FFD700FFD700FFE600FFE600FFF500FFF500FAFF00EBFF00DCFF00BDFF008FFF0061FF00
00FF570094FF00FF4723FF005100FF05FF00CC00FFAE00FF00FF8500FF1900FF1900FF38
33FF0000F0FFFF003D9E00FF0085FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000A3FF00FFB300FF4780FF00
9EFF00AEFF00AEFF0061FF00AEFF00CCFF00CCFF00DCFF00DCFF00CCFF00BDFF00AEFF00
8FFF0033FF0000FFF080FF0080FF0070FF0000A3FF8FFF0033FF00EBFF00FFE600FFD700
FFD700FFC700FFC700FFB800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF7A00
FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800
FFA800FFA800FFA800FFB800FFB800FFB800FFC700FFC700FFD700FFD700FFD700FFD700
FFE600FFE600FFE600FFE600FFF500FFF500FAFF00EBFF00DCFF00BDFF0023FF0005FF00
0500FF00FF5723FF0051FF0051FF0042FF0000FFB30019FF00FFC205FF0033FF0051FF00
51FF0023FF00FF0000FF007A00FFA300A3FFFF00A8FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000028FF00A3FF7000FFFF00004200FF00D1FF00FF6661FF00
AEFF00BDFF00BDFF0000FF19CCFF00DCFF00DCFF00DCFF00DCFF00DCFF00CCFF00AEFF00
23FF0000FF2800D1FF00FF3800FF3833FF009EFF00CCFF0000FF19FAFF00FFE600FFD700
FFC700FFC700FFB800FFB800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900
FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF8A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00
FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800
FFA800FFA800FFB800FFB800FFB800FFC700FFC700FFD700FFD700FAFF00FFE600FFE600
FFE600FFE600FFE600FFF500FFF500FFF500FAFF00EBFF00BDFF00AEFF0000FF5700FF28
FF000000FF4705FF0061FF0070FF0042FF000085FF14FF0000FFA323FF0061FF0070FF00
61FF0000A3FF6100FF00FF0A00FF570057FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF000000FFF000FF5700FF94FF004C00C2FFFF0000FF000051FF0000FF28
BDFF00CCFF00DCFF00DCFF00EBFF00EBFF00EBFF00EBFF00EBFF00DCFF00CCFF009EFF00
0075FF00FF6680FF008FFF0051FF009EFF0080FF00EBFF00EBFF00FFF500FFD700FFC700
FFC700FFB800FFB800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800
FFA800FFA800FFB800FFB800FFB800FFC700FFC700FFD700FFF5008FFF00FFF500FFF500
FFF500FFF500FFF500FFF500FFF500FAFF00FAFF00EBFF00AEFF0061FF0014FF0000FF47
00FF5700FF3800FF0A42FF008FFF008FFF0080FF0061FF0000FF2800FFB351FF0080FF00
80FF0070FF0023FF0023FF0000FF85FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000085FF00FF1914FF0000FF190019FF00FFF000C2FF80FF00AEFF00
CCFF00DCFF00DCFF00EBFF00EBFF00EBFF00FAFF00EBFF00EBFF00DCFF00CCFF0000B3FF
00FF0A61FF00AEFF00BDFF00CCFF00DCFF00EBFF00FFF500FFF500FFE600FFD700FFC700
FFC700FFB800FFB800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900
FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800
FFA800FFA800FFB800FFB800FFB800FFC700FFD700FFE600EBFF00BDFF00EBFF00FAFF00
FFF500FAFF00FAFF00FAFF00FAFF00FAFF00EBFF00DCFF0070FF0051FF0000FF2800FF38
00FFB342FF0033FF0080FF00AEFF00AEFF008FFF0061FF0000FFC214FF0033FF008FFF00
9EFF008FFF0070FF0033FF0000FF470094FFFF0000FF0000FF000000F0FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
2300FF00FFC2FF0000FF008A00FF4751FF0000B3FF14FF0000FF0A0028FF70FF00AEFF00
BDFF00DCFF00EBFF00EBFF00FAFF00FAFF00FAFF00FAFF00EBFF00EBFF00DCFF008FFF00
51FF0000FF28AEFF00CCFF00DCFF00EBFF00FAFF00FFF500FFE600FFD700FFC700FFC700
FFB800FFB800FFB800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800
FFA800FFA800FFB800FFB800FFC700FFC700FFD700FFF50000FF6614FF00CCFF008FFF00
EBFF00EBFF00EBFF00FAFF00FAFF00EBFF00EBFF00DCFF00BDFF008FFF0000FF0A00FF94
70FF0070FF0014FF00AEFF00BDFF00BDFF008FFF0000FF3861FF0070FF0061FF00AEFF00
AEFF009EFF0070FF0000FF0ACC00FFDC00FFFF00008000FFFF000000FF7500E1FFFF00C7
FF0000FF004CFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000A3FFFF0000
00FF8500FF28BD00FF00FFFF51FF0070FF0051FF0070FF0051FF0000FF9461FF0000FFC2
00FFD1DCFF00EBFF00FAFF00FAFF00FAFF00FAFF00FAFF00FAFF00EBFF00DCFF00BDFF00
51FF0033FF009EFF00CCFF00DCFF00FAFF00FFF500FFE600FFE600FFD700FFC700FFC700
FFB800FFB800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800
FFA800FFB800FFB800FFC700FFD700FFD700FFE600FFF500DCFF008FFF008FFF0080FF00
BDFF0000FF38DCFF00EBFF00EBFF00EBFF00DCFF00DCFF00BDFF0080FF0000FF4700FF94
8FFF009EFF00AEFF00BDFF00CCFF00CCFF00AEFF0033FF00AEFF00BDFF009EFF00BDFF00
BDFF009EFF0000D1FF00FF380038FFFF00000066FF00FFA300FF6600FF1900FFF0000AFF
FF0000FF00000028FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF001E0047FF0075FF00A3FF00FFA300FF4700FF57
00FF1933FF0014FF0000FF1942FF008FFF008FFF008FFF0061FF0000FF7500B3FF0047FF
00FF85CCFF00FAFF00FAFF00FFF500FFF500FFF500FAFF00FAFF00FAFF00DCFF00AEFF00
70FF0000FF2851FF00BDFF00DCFF00EBFF00FFF500FFE600FFE600FFD700FFC700FFC700
FFB800FFB800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800
FFA800FFB800FFC700FFD700FFE600FFE600FFF500AEFF00BDFF0080FF0070FF0080FF00
00FF5700FF0ACCFF00DCFF00DCFF00DCFF00DCFF00CCFF00BDFF0033FF0000FF3861FF00
8FFF00AEFF00BDFF00CCFF00CCFF00CCFF00CCFF00BDFF00CCFF00CCFF00CCFF00CCFF00
BDFF00BDFF008FFF0061FF0000FFA30085FFFF0000FF000014FF0033FF000094FFFF0000
FF000000FF85FF0000FF0000FF0000FF0000FF0000FF00008000FF5100FFFF00B8FF0000
FF0000FF0000FF0000FF0000FF0000FF00001400FF00FFD100FF7500FF3805FF0000FF19
33FF0051FF0023FF0033FF0061FF009EFF00AEFF009EFF0051FF0014FF008FFF0080FF00
BDFF00DCFF00FAFF00FFF500FFF500FFF500FFF500FFF500FFF500FAFF00AEFF0070FF00
05FF0080FF0000FF2851FF00CCFF00EBFF00FAFF00FFF500FFE600FFD700FFC700FFC700
FFB800FFB800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF8A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800
FFA800FFC700FFF500FFF50000FF38FAFF00FAFF009EFF008FFF00AEFF00CCFF009EFF00
FF00000075FFAEFF00CCFF00CCFF00BDFF00CCFF00BDFF00AEFF0080FF0000FF0A70FF00
8FFF00AEFF00BDFF00CCFF00DCFF00DCFF00DCFF00DCFF00DCFF00DCFF00DCFF00DCFF00
CCFF00BDFF00AEFF008FFF0023FF009E00FF00FF1900FF4700FF9461FF0000FFD100FF75
0057FF00FF1900FF1900FFF000FF4700FFA300FFC200FFC200C2FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF006B00FFB300FF2814FF0033FF00
61FF0070FF0051FF0000FF669EFF00AEFF00BDFF00AEFF0000FFE100FFC29EFF00CCFF00
EBFF00FAFF00FFF500FFF500FFF500FFF500FFE600FFF500FFF500FFF500EBFF00CCFF00
BDFF00AEFF0000FFD180FF00AEFF0051FF00EBFF00FFF500FFF500FFE600FFD700FFC700
FFB800FFB800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF7A00FF7A00FF7A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800
FFA800FFB800FFF50005FF00CCFF00CCFF00DCFF0000FF19BDFF00DCFF00EBFF00BDFF00
9EFF0023FF0070FF009EFF008FFF0000FF0A9EFF00AEFF009EFF0080FF0000FFD100FF75
14FF00AEFF00BDFF00CCFF00DCFF00EBFF00EBFF00EBFF00EBFF00EBFF00EBFF00DCFF00
DCFF00CCFF00AEFF009EFF0042FF0000FFB323FF000057FF70FF0080FF0061FF0005FF00
05FF0033FF0000FF38FF000F00FF0A00FF2800FF5700B3FF8000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000B3FFFF004C05FF0042FF00
61FF0080FF008FFF0014FF00BDFF00BDFF00CCFF00BDFF009EFF009E00FF00FF28DCFF00
FAFF00FFF500FFF500FFF500FFE600FFE600FFE600FFE600FFE600FFF500FFF500FAFF00
EBFF00CCFF000057FF14FF0014FF0051FF008FFF00BDFF00FAFF0005FF00FFD700FFC700
FFC700FFB800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00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FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00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FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00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FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00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FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00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FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00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FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00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FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800
FFB800FFC700FFC700FFC700FFC700FFD700FFE600FFE600FFF500DCFF0014FF0000FF47
23FF009EFF00DCFF00FAFF00FFF500FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFF500FFF500FFF500FAFF00FAFF00FAFF00EBFF00EBFF00DCFF008FFF00
00A3FF0085FF51FF0000FF0A00FF577000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00008000FF00FFB300FF0A
33FF0070FF0080FF0080FF00BDFF00DCFF00EBFF00FAFF00FFF500FFF500FFE600FFE600
FFD700FFD700FFD700FFD700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFD700FFE600FAFF0000FFF0FFC700
FFB800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00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FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00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FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00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FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00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FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00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FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00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FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00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FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00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FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00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FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00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FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00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FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00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FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00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FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFC700FFC700FFC700FFD700FFF500EBFF00EBFF00FAFF00DCFF00EBFF00EBFF00
DCFF00AEFF0023FF0061FF00CCFF00CCFF00CCFF00CCFF00AEFF0000FFA351FF0000FF66
70FF0051FF0000FF1900E1FF00FF6600FF1980FF008FFF0051FF0070FF00DCFF00EBFF00
EBFF00FAFF00FAFF00EBFF00DCFF0080FF00BDFF009EFF0080FF0000E1FFFFD700FFC700
FFC700FFB800FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00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FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00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FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00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FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00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FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00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FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00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FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00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FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00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FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00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FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700
FFC700FFC700FFD700FFD700FFD700FFD700FFE600FFE600FFF500EBFF00CCFF00AEFF00
AEFF0070FF0051FF0033FF0000FF6600FF2814FF0080FF0000FFD18FFF00CCFF00FAFF00
FFF500FFE600FFE600FFD700FFD700FFD700FFC700FFC700FFC700FFC700FFB800FFB800
FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00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FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700
FFC700FFC700FFC700FFD700FFD700FFD700FFD700FFE600FFE600FFF500FFF500EBFF00
BDFF0051FF00AEFF009EFF0061FF0023FF0070FF00BDFF00BDFF00CCFF00DCFF00FAFF00
FFF500FFE600FFE600FFD700FFD700FFD700FFC700FFC700FFC700FFB800FFB800FFB800
FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00
FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00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FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00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FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00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FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00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FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00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FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00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FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00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FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800
FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFD700FFE600FFE600FFE600FFF500
FAFF00FAFF00EBFF00DCFF00BDFF009EFF0080FF00BDFF00CCFF00EBFF00EBFF00FAFF00
FFF500FFF500FFE600FFE600FFE600FFD700FFD700FFD700FFC700FFC700FFC700FFB800
FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00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FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00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FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00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FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00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FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00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FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00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FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00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FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00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FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00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FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00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FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00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FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00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FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00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FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00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FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00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FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00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FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00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FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF7A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700
FFC700FFD700FFD700FFE600FFE600FAFF00DCFF0051FF00DCFF00FAFF00FFF500FFF500
FFF500FFD700FFC700FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFC700FFE600FAFF00FFF500FFC700FFC700FFC700FFC700FFD700
FFD700FFC700FFD700FFD700FFE600FFF500DCFF009EFF00FFF500FFE600FFD700FFE600
FFF500FAFF00FFB800FFA800FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00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FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00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FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00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FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800
FFA800FFA800FFB800FFC700FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFD700
FFE600FFE600FFE600FFF500FAFF00EBFF0000FF94DCFF00FAFF00FFF500FFE600FFD700
FFC700FFC700FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFB800FFA800FFA800FFA800FFA800FFA800FFA800
FFB800FFB800FFB800FFB800FFB800FFC700FFD700FFF500EBFF00FFD700FFC700FFB800
FFB800FFA800FFA800FF9900FF9900FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800
FFA800FFA800FFB800FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFE600
FFF500FFE600FFF500FFF500FAFF00DCFF008FFF00CCFF00FAFF00FFF500FFE600FFD700
FFC700FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFB800FFB800FFB800FFC700FFD700FFF500CCFF00FFD700FFC700FFB800
FFA800FFA800FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00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FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00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FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00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FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00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FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00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FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FFA800
FFA800FFA800FFB800FFC700FFD700FFE600FFF500FAFF00DCFF00AEFF0014FF00FF0000
FF0000FF000080FF00DCFF00FAFF00FFE600FFD700FFD700FFC700FFC700FFC700FFB800
FFB800FFA800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFB800FFC700BDFF009EFF00FFC700
FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00
FF6B00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00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FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00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FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00
FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800
FFA800FFA800FFB800FFB800FFC700FFD700FFE600EBFF009EFF0033FF00FF0000FF0000
FF0000FF000051FF00CCFF00FAFF00FFD700FFC700FFC700FFB800FFB800FFB800FFA800
FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF8A00FF9900FF8A00FF9900FF9900FF8A00FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFE600FFC700FFA800FF9900
FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00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FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00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FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00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FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00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FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00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FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FFA800FFA800
FFA800FFB800FFC700AEFF008FFF00EBFF00DCFF00BDFF00FAFF00FFF500FFE600FFE600
FFD700FFD700FFD700FFD700FFE600FAFF00FFC700FFA800FFA800FFA800FF9900FFA800
FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00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FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00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FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00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FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00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FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00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FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FFA800FFA800
FFA800FFB800FFB800FFB800FFC700FFE600FAFF0061FF00FFF500FFD700FFC700FFC700
FFB800FFB800FFA800FFB800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF7A00FF7A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00
FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800
FFA800FFB800FFB800FFC700FFC700FFE60051FF0070FF0000FF75FFD700FFC700FFC700
FFB800FFB800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF8A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800
FFA800FFB800FFB800FFC700FFC700FFE600EBFF00DCFF00BDFF00FFD700FFC700FFB800
FFB800FFA800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FFA800FFA800FFA800
FFA800FFB800FFB800FFC700FFD700FFE60080FF00FAFF00FFE600FFD700FFC700FFB800
FFB800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00
FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800
FFA800FFB800FFC700FFC700FFD700FFF5009EFF00FFF500FFD700FFC700FFC700FFB800
FFB800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF9900
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF7A00FF7A00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800
FFB800FFB800FFB800FFC700FFD700FFE600AEFF00FFF500FFD700FFD700FFC700FFB800
FFB800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF8A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800
FFB800FFB800FFC700FFD700FFD700FFE6008FFF00FFF500FFE600FFD700FFC700FFB800
FFB800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF8A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF6B00FF6B00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00
FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFB800
FFB800FFB800FFC700FFD700FFE600FFF500CCFF00DCFF00FFF500FFD700FFC700FFB800
FFB800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FFA800FFA800FFB800FFB800
FFB800FFC700FFD700FFD700FAFF00DCFF00FAFF00FAFF009EFF00FFE600FFD700FFB800
FFB800FFA800FFA800FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFB800FFB800FFB800
FFC700FFC700FFD700FAFF0061FF00FFF500FFE600FFE600FFF5008FFF00FFE600FFC700
FFB800FFA800FFA800FFA800FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FFA800FFA800FFB800FFC700FFD700
FFD700FFE600FFF500CCFF00FFE600FFD700FFD700FFD700FFD700FAFF00FFF500FFC700
FFB800FFA800FFA800FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF7A00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF9900FF9900FF9900FF9900FFA800FFA800FFB800FFB800FFD700CCFF00
FFF500EBFF008FFF008FFF00FFD700FFC700FFC700FFC700FFC700FFF500BDFF00FFF500
FFC700FFB800FFA800FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF9900FF9900FF9900FFA800FFB800FFB800FFC700FFF50051FF00
BDFF00FFF500FFD700FFF500FFC700FFC700FFB800FFB800FFB800FFD700FFF500FAFF00
FFC700FFB800FFA800FFA800FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF9900FF9900FF9900FFA800FFA800FFB800FFD700FFE600DCFF00FAFF00
FFE600FFD700FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700BDFF00
FFE600FFC700FFB800FF9900FF9900FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00
FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF6B00FF6B00FF6B00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00
FF8A00FF9900FF9900FF9900FF9900FFA800FFA800FFB800FFE600FAFF00FFE600FFD700
FFC700FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFD700
DCFF00FFE600FFB800FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF9900FF9900FFA800FFA800FFB800FFC700FFE600FFE600FFC700FFC700
FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFC700
EBFF00FFB800FFA800FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF8A00FF8A00
FF8A00FF9900FF9900FFA800FFA800FFB800FFC700FFD700AEFF00FFD700FFC700FFB800
FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFB800
42FF00FFB800FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF8A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF7A00FF7A00FF7A00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00
FF8A00FF9900FFA800FFA800FFB800FFC700FFD700FFF500FAFF00FFC700FFB800FFA800
FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800
FFF500FFA800FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF7A00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00
FF8A00FF9900EBFF00FFD700FFF500FFE600FFE600FFD700FFF500FFC700FFB800FFA800
FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FFA800FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00
FF8A00FF9900FFA800FFC700FFE600FFB800FFB800FFB800FFC700FFC700FFA800FFA800
FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF6B00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00
FF8A00FF8A00FF9900FF9900FFA800FFA800FFA800FFA800FFB800FFE600FFA800FF9900
FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF6B00FF6B00FF6B00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FFA800FFA800FF9900FF9900
FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00
FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00
FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00
FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF8A00FF8A00FF7A00FF8A00
FF7A00FF8A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF7A00FF7A00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00
FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00
FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00
FF6B00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00
FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF7A00FF7A00FF6B00FF6B00FF7A00FF7A00
FF7A00FF6B00FF6B00FF7A00FF7A00FF7A00FF6B00FF6B00FF7A00FF7A00FF6B00FF6B00
FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF6B00FF6B00FF6B00FF7A00
FF6B00FF6B00FF6B00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00
FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00
FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF7A00
FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00
FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00
FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00
FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00
FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 234},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000jR000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQ
ooooo`006_ooool5o`0000?ooooo00?o0000ooooooooool00_ooool3o`0001gooooo1Ol0000Moooo
o`?o00001?ooool00ol0003oooooooooo`02ooooo`?o00007_ooool3o`0001oooooo0_l00004oooo
o`03o`000?oooooooooo00;ooooo0ol0000Looooo`;o00007oooool2o`0000Cooooo00?o0000oooo
ooooool00_ooool3o`0000oooooo000Kooooo`04o`000?ooooooooooo`0000Oooooo00Go0000oooo
ooooooooooooo`00000Mooooo`04o`000?ooooooooooo`0001kooooo00?o0000ooooooooool01ooo
ool01Ol0003ooooooooooooooooo000001kooooo00?o0000ooooooooool07Oooool01?l0003ooooo
ooooool00007ooooo`05o`000?ooooooooooooooool000006_ooool01?l0003oooooooooool0000M
ooooo`04o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`00000>ooooo`005?oo
ool5o`0000?ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Dooooo`Go00000ooo
ool00ol0003oooooooooo`0Fooooo`Go00000oooool00ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo01Cooooo1Ol00003ooooo`03o`000?oooooooooo01Kooooo1Ol00002ooooo`04o`000?oo
ooooooooo`0000_ooooo00?o0000ooooooooool06?ooool01?l0003oooooooooool0000Mooooo`04
o`000?ooooooooooo`0000_ooooo00?o0000ooooooooool03?ooool001gooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo01gooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01gooooo00Co0000oooooooo
oooo00002oooool00ol0003oooooooooo`0Hooooo`04o`000?ooooooooooo`0001gooooo00Co0000
oooooooooooo00002oooool00ol0003oooooooooo`0<ooooo`006_ooool01Ol0003ooooooooooooo
oooo000000Oooooo1?l0000Mooooo`05o`000?ooooooooooooooool000007_ooool00ol0003ooooo
ooooo`07ooooo`Co00007oooool00ol0003oooooooooo`0Mooooo`04o`000?ooooooooooo`0000Oo
oooo1?l0000Kooooo`04o`000?ooooooooooo`0001gooooo00Co0000oooooooooooo00001oooool4
o`0000oooooo000Jooooo`05o`000?ooooooooooooooool000001oooool00ol0003oooooooooo`0N
ooooo`05o`000?ooooooooooooooool000007Oooool2o`0000Wooooo00?o0000ooooooooool07ooo
ool2o`0001oooooo00Co0000oooooooooooo00001oooool00ol0003oooooooooo`0Looooo`04o`00
0?ooooooooooo`0001gooooo00Co0000oooooooooooo00001oooool00ol0003oooooooooo`0@oooo
o`006oooool3o`0000Sooooo1Ol0000Mooooo`?o00007oooool00ol0003oooooooooo`07ooooo`Go
00007_ooool00ol0003oooooooooo`0Nooooo`;o00002?ooool5o`0001_ooooo0_l0000Oooooo`;o
00002?ooool5o`0000kooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo003ooooo
ob7ooooo003oooooob7ooooo000Koooooooo00001Ol00001ooooo`006oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`02ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool0ooooool1ooooo`7o00000Oooool0
01_ooooo00?o0000ooooooooool0ooooool1ooooo`7o00000Oooool001_ooooo0_l0003oooooo`7o
oooo0_l00001ooooo`006oooool00ol0003oooooooooo`02oooooal0ocd000<0odH00?m<003oC000
@03oC0000`3oCP00odd00?m<000=0?m<00030?m@003oD`00od`000`0od`00P3oG0000`3oF`00oe00
0?m<00060?m<00030?mG003oG000oe`001P0oe`000<0oed00?mL003oG0003P3oG0000`3oG@00oe`0
0?mL000L0?mL00030?mF003oC000od`000L0od`000<0oe@00?mC003oC000303oC0020?m=00L0od`0
1Oooool1o`00007ooooo000Kooooo`03o`000?oooooooooo00;ooooo7`3o?@000`3oA`00od`00?m<
00110?m<00030?m?003oC000od`000d0od`000<0oeT00?m>003oC0002`3oC0001@3oF@00oe`00?mL
003oF`00oe<000D0od`000<0oeD00?mL003oG0006@3oG0000`3oG@00oe`00?mL000B0?mL00030?mM
003oG000oe`001P0oe`000<0oeP00?m<003oC0001P3oC0000`3oD`00oeX00?m<000<0?m<00030?m=
003oCP00od`000L0od`01Oooool1o`00007ooooo000Kooooo`03o`000?oooooooooo00;ooooo7`3o
?@000`3oB@00od`00?m<00110?m<00030?m?003oCP00od`000d0od`000<0oe<00?mH003oC0002`3o
C0000`3oF000oe`00?mL00020?mL00050?mK003oEP00oe800?mE003oF`004P3oG0000`3oG@00oe`0
0?mL00080?mL00050?mM003oG000oe`00?mL003oG@000`3oG0001@3oGP00oe`00?mL003oG000oel0
00<0oe`000@0oel00?mL003oG000oed0103oG0001@3oG@00oe`00?mL003oG000oed001<0oe`000<0
odh00?m<003oC000103oC0000`3oE000oe`00?mB000<0?m<00030?m=003oC`00od`000P0od`01Ooo
ool1o`00007ooooo000Kooooo`03o`000?oooooooooo00;ooooo7P3o?@000`3o?P00od`00?m<000<
0?m<00030?m=003oC000od`003@0od`000<0oe400?m<003oC000303oC0000`3oCP00oe`00?mC000;
0?m<00030?mK003oG000oe`002@0oe`000H0oed00?mL003oG000oe`00?mN003oG@020?mL00050?mN
003oG000oe`00?mL003oH0000P3oG0001@3oGP00oed00?mL003oG000oeh000<0oe`000<0oed00?mL
003oG0000P3oG0000`3oG@00oe`00?mL000A0?mL00030?mI003oC@00od`00080od`000@0odl00?mH
003oG000oe/0303oC0000`3oC@00oe000?m<00090?m<00Gooooo0Ol00001ooooo`006oooool00ol0
003oooooooooo`02oooooah0ocd000<0od800?m<003oC000@`3oC0000`3oCP00oe400?m<000=0?m<
00030?mI003oG000oe0000T0od`000<0odh00?mL003oG0009@3oG0020?mM00<0oe`000D0of400?mL
003oG000of000?mN00020?mL00050?mT003oG000oe`00?mQ003oGP000P3oG0001@3oH@00oe`00?mL
003oG000oeh000<0oe`000<0oeh00?mL003oG0001`3oG0000`3oG@00oe`00?mL00090?mL00040?mK
003oEP00oeH00?mI00<0oe`000<0oeH00?m<003oC0002P3oC0000`3oD@00od`00?m<00090?m<00Go
oooo0Ol00001ooooo`006oooool00ol0003oooooooooo`02ooooo`030?m:003o@@00ocd001/0ocd0
00<0odT00?m<003oC0008P3oC0000`3oC@00od`00?m<000O0?m<00030?mD003oC@00od`000`0od`0
00@0oeD00?mL003oF`00odh0203oC0000`3oD`00oe`00?mL000Q0?mL00030?mN003oG000oe`00080
oe`001<0oel00?mL003oG000oe`00?mT003oG@00oe`00?mT003oI`00oed00?mQ003oJ`00of000?mN
003oJ@00of400?mL003oGP00of@00080oe`000<0oed00?mO003oG0000P3oG0000`3oGP00oe`00?mL
000J0?mL00030?mA003oC000od`000T0od`000<0oe@00?m=003oC0002P3oC005ooooo`7o00000Ooo
ool001_ooooo00?o0000ooooooooool00_ooool20?m<00030?m7003o?P00ocd001P0ocd000<0od<0
0?m<003oC000=@3oC0000`3oCP00od`00?m<000=0?m<00030?m?003oE000od`000`0od`000D0oe40
0?mL003oG000oe/00?m?00060?m<00030?m=003oF`00oe`001L0oe`000<0oed00?mL003oG0000`3o
G0000`3oG@00oe`00?mL00020?mL00030?mN003oG@00oe`00080oe`000P0of<00?mM003oG000oe`0
0?mX003oI`00of800?mZ00L0of/000@0ofX00?mT003oJ000ofP00P3oG0001P3oI000oeh00?mL003o
G000oel00?mM00<0oe`000<0oed00?mL003oG0000P3oG0000`3oG@00oe`00?mL000A0?mL00030?m@
003oC000od`000P0od`000<0oe@00?m?003oC0002`3oC005ooooo`7o00000Oooool001_ooooo0_l0
0003ooooo`<0od`000<0od/00?m3003o?@005P3o?@000`3o?`00od/00?m<000f0?m<00030?m=003o
CP00od`000h0od`000<0oeL00?m>003oC0002`3oC0001`3oD000oe`00?mL003oG000oe/00?mB003o
C@000`3oC0000`3oCP00oeX00?mL000I0?mL00030?mM003oG000oe`000<0oe`000<0oed00?mL003o
G0000P3oG000203oH@00oe`00?mL003oG000of000?mW003oH000of403`3oJ`00103oI000ofD00?m[
003oGP020?mL00040?mS003oG000oe`00?mL0080oed0603oG0000`3oD000od`00?m<00070?m<0003
0?mD003oE@00od`000`0od`01?ooool2o`00007ooooo000Kooooo`03o`000?oooooooooo00;ooooo
1@3oC0000`3oB`00od<00?ln000C0?lm00030?ln003oB@00od`002L0od`000<0odd00?m<003oC000
3P3oC0000`3oC`00odd00?m<000=0?m<00030?mB003oF000od`000/0od`000<0oe000?mL003oG000
0`3oG000103oF`00oeP00?mF003oF00L0?mL00030?mM003oG000oe`000<0oe`000<0oeh00?mL003o
G0000P3oG0020?mQ0080oe`000<0of400?m[003oJ`004`3oJ`00103oI`00oel00?mW003oI0030?mL
00030?mQ003oG000oe`001L0oe`000<0oe@00?m<003oC0001P3oC0000`3oE000oeT00?m<000=0?m<
00Gooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`02ooooo`030?m2003oC000od`000@0
od`000<0od/00?m5003o?`00403o?@000`3o?`00odX00?m<000E0?m<00030?m=003oC000od`00140
od`000<0odd00?m<003oC0003P3oC0000`3oD000od`00?m<000=0?m<00030?mK003oD`00od`000X0
od`000<0oe000?mL003oG000903oG0000`3oG@00oe`00?mL00020?mL00030?mN003oG`00oe`00080
oe`000D0oed00?m[003oI000of<00?mZ000:0?m[00030?m]003oJ`00of/000/0of/000D0ofL00?mL
003oG000of@00?mO00030?mL00030?mN003oG000oe`001<0oe`000<0oe/00?m>003oC000103oC000
103oCP00oeP00?mL003oC`0>0?m<00Gooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`02
ooooo`030?lm003o@P00od`000L0od`000<0odP00?m3003o?P002`3o?@000`3o?`00odH00?m<000l
0?m<0080odl03P3oC0000`3oE@00oe`00?m@000:0?m<00030?mA003oG000oe`002@0oe`000<0oeh0
0?mL003oG0000`3oG0000`3oI000oed00?mL00020?mL00T0of/000P0of`00?m[003oK@00of`00?m_
003oL000ofh00?m]00`0of/00P3oJ0001P3oJ`00oe`00?mL003oG000oel00?mN00<0oe`000<0oed0
0?mL003oG000403oG0001P3oFP00oe800?m=003oC000oe000?mF0080oe`000<0oeL00?m<003oC000
303oC0000`3oC`3oooooooooo`03ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool00_oo
ool20?lm00030?m3003oC000od`000P0od`000D0odP00?m5003o@P00od000?lo00020?lm00040?lo
003o@@00od@00?m802l0od`000<0odd00?m<003oC0003P3oC0000`3oDP00od`00?m<000<0?m<0004
0?m?003oG000oe/00?m?00T0od`000<0oeH00?mL003oG0005`3oG0000`3oG@00oe`00?mL00040?mL
00030?mM003oG000oe`000<0oe`000<0oed00?mN003oG0000`3oG0001@3oH@00ofT00?mO003oG000
of@000P0of/000@0ofd00?m^003oL`00ogH0103oN@00103oMP00og800?m_003oK@0<0?m[00040?mP
003oG000oel00?mU00@0oe`000<0oeh00?mL003oG000603oG0000`3oD000od`00?m<000:0?m<0003
0?m=003oC`00od`000Gooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`02ooooo`<0ocd0
00<0odH00?m<003oC000@P3oC0000`3oC@00od`00?m<000=0?m<00030?m=003oE000od`000d0od`0
00@0oe/00?mL003oF`00oe401`3oC0000`3oCP00oe/00?mL000P0?mL00030?mM003oG000oe`000<0
oe`000<0of400?mL003oG0000P3oG0000`3oG@00of/00?m[00090?m[00050?m]003oL000ogT00?mj
003oN`000P3oO0020?mk0080ogX000L0ogT00?mf003oLP00of/00?m/003oJ`00of`000P0of/000<0
ofT00?m[003oI0000`3oG0000`3oG`00oe`00?mL000H0?mL00030?mK003oC000od`000X0od`000@0
odd00?mA003oC000od`01Oooool1o`00007ooooo000Kooooo`03o`000?oooooooooo00;ooooo103o
?@000`3oB000od`00?m<00110?m<00030?m>003oC000od`000h0od`000<0oe<00?m?003oC000303o
C0001P3oE`00oe`00?mL003oG000oe@00?m=00@0od`000<0odh00?mJ003oG0008@3oG0000`3oGP00
oe`00?mL00030?mL00030?mN003oIP00oe`00080oe`000<0oeh00?m[003oJ`001@3oJ`001@3oK000
of/00?m[003oK@00og000080ogX000P0oh400?n=003oTP00oh`00?n9003oQP00oh<00?mm00<0ogX0
00D0ogD00?m`003oK@00of/00?m]00090?m[00030?mT003oG000oe`00080of40103oG0000`3oGP00
oe`00?mL000C0?mL00030?mH003oC000od`000T0od`000<0odh00?mB003oC0000P3oC005ooooo`7o
00000Oooool001_ooooo0_l00003ooooo`@0ocd000<0och00?m;003oC000@P3oC0000`3oCP00od`0
0?m<000=0?m<00030?m=003oF@00odd000`0od`000<0oe@00?mL003oG0000P3oG0001@3oF`00oeL0
0?mB003oDP00oeL001h0oe`000<0oed00?mL003oG000103oG0000`3oG`00oe`00?mL00030?mL0005
0?mX003oI`00of400?mP003oI`00203oJ`00403oK000of/00?m`003oN@00ogX00?mm003nU`00ol40
0?_>003oX@00oiH00?nH003fY@00ohX00?n0003oN`020?mj00080?mi003oM`00ofd00?m`003oJ`00
of`00?m[003oK0060?m[00030?mV003oJ000ofT000@0oe`000<0oeh00?mL003oG000103oG0000`3o
G@00oe`00?mL000=0?mL00030?mH003oC000od`000P0od`000<0oe400?mE003oC0000`3oC004oooo
o`;o00000Oooool001_ooooo00?o0000ooooooooool00_ooool50?lm00030?m1003oC000od`00440
od`000<0odd00?m>003oC0003P3oC0000`3oD`00oeL00?m<000;0?m<00030?mD003oG000oe`002H0
oe`000<0oed00?mL003oG0000`3oG0000`3oH000oel00?mL00030?mL00030?mT003oJ`00of/000/0
of/00100og800?mf003oNP00ogX00?n2003oSP00oj400?gC003Zf`00n[d00?c2003id000oiH00?n:
003oP@00og/0103oNP001P3oMP00ogD00?m[003oK@00of/00?m]00L0of/000H0ofL00?mL003oG000
oe`00?mO003oGP0F0?mL00030?mJ003oC000od`000L0od`000<0oe@00?mH003oC000103oC005oooo
o`7o00000Oooool001_ooooo00?o0000ooooooooool00_ooool60?lm00030?m5003oC000od`00440
od`000<0odh00?m=003oC0003@3oC0000`3oC@00oe/00?mD000;0?m<00030?mD003oG000oe`002H0
oe`000<0oeh00?mL003oG000103oG0000`3oI`00oeh00?mL00020?mL00030?mV003oJ`00of/000T0
of/000<0ofd00?m[003oL0000`3oNP003P3oQ000oh/00?nH003oZ`00olL00>[]003cj@00ok800?nJ
003oS000ohX00?n4003oO@00og/0103oNP00103oM`00og<00?m^003oK0070?m[00050?mZ003oG`00
oed00?mR003oI0001@3oG0000`3oG@00oe`00?mL000@0?mL00030?mB003oC000od`000@0od`000@0
odh00?mI003oFP00odd01@3oC005ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool00_oo
ool60?lm00030?ln003oB`00od`00480od`000<0oe400?m<003oC0003@3oC0000`3oEP00oe`00?m@
000:0?m<00030?mH003oG000oe`002H0oe`00P3oGP050?mL00050?mS003oJP00of400?mM003oH@00
2P3oJ`00103oK000of/00?m[003oMP030?mj000?0?mk003oR000ohX00?nE003oX000ok800>KP003V
h0H0ok800?nQ003oU`00oh`00?n:003oR@00oh000080og/000L0ogX00?mk003oNP00ogX00?mh003o
K`00ofd000X0of/000<0oel00?mL003oG0000P3oG0000`3oG`00oe`00?mL000A0?mL00030?mK003o
D`00odd00080od`000D0oe000?mG003oG000oe`00?m?00060?m<00Gooooo0Ol00001ooooo`006ooo
ool00ol0003oooooooooo`02ooooo`L0ocd000<0od<00?m<003oC000@@3oC0000`3oC@00oe000?m<
000=0?m<00040?m?003oG000oe/00?m>00P0od`000<0odh00?mL003oG0006P3oG0000`3oG@00oe`0
0?mL00040?mL00030?mN003oG000oe`000@0oe`000<0of800?mM003oG0000`3oG0000`3oH000of/0
0?m[000<0?m[00040?m]003oK`00of/00?me00<0ogX000d0ogd00?n9003oRP00oi<00?nN003o[`00
omT00>[/003o_P00ojd00?nN003oU@00oh`00080ohX000D0ohT00?n3003oP000ogd00?ml00030?mj
00030?m`003oK@00of/000P0of/000H0oed00?mL003oG000oe`00?mQ003oG@0;0?mL00030?mM003o
G000oe`000d0oe`000<0oeD00?m<003oC0001@3oC005ooooo`7o00000Oooool001_ooooo00?o0000
ooooooooool00_ooool80?lm00030?m:003oC000od`00440od`000<0oe000?m>003oC0003@3oC000
103oFP00oe`00?mK003oD@070?m<00030?mH003oG000oe`00240oe`00P3oG@050?mL00030?mN003o
IP00oe`000<0oe`000<0of400?m[003oJ`003@3oJ`000`3oL000ogX00?mj00030?mj000?0?n0003o
RP00ohX00?nE003oW000ok<00>[Z003Sn@00j^X00?OU003oZ`00oi/00?nF003oS`00oh/000@0ohX0
00<0ohT00?n3003oN`000P3oNP000`3oL000ofd00?m[00070?m[00050?mT003oG@00oel00?mW003o
G`00103oG0020?mM01D0oe`000<0oe/00?m=003oC0001P3oC005ooooo`7o00000Oooool001?ooooo
0ol00005ooooo`03o`000?oooooooooo00;ooooo203o?@000`3oA000od`00?m<00120?m<00030?mE
003oC000od`000`0od`000H0oeH00?mL003oG000oe`00?mF003oC@030?m<00030?m=003oEP00oe`0
01d0oe`000<0oed00?mL003oG000103oG0000`3oG`00oe`00?mL00040?mL00030?mX003oIP00oe`0
0080oe`000<0ofL00?m[003oJ`001`3oJ`001`3oK000of/00?m[003oK000ofl00?m[003oK@00103o
NP003`3oN`00oh@00?n:003oR`00oiD00?nK003o[@00om0009G]7`2JX1D0mNP00?nh003oY@00oiX0
0?nI00020?nD00060?n@003oT`00oiL00?n]003oS`00oh<00`3oNP000`3oL000of/00?m[00090?m[
00030?mX003oG000oe`000<0oe`000<0oeh00?mL003oG000503oG0000`3oE`00od`00?m<00060?m<
00Gooooo0Ol00001ooooo`005?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;o
oooo203o?@000`3o?`00od`00?m<000a0?m<00030?m>003oC000od`000h0od`000<0odl00?mD003o
C000303oC0000`3oE000oe`00?mL00020?mL00050?mK003oF000oeH00?mH003oF`007`3oG0000`3o
G@00oe`00?mL00040?mL0080oel01@3oG0001@3oI@00of/00?mZ003oI@00ofP000L0of/000<0of`0
0?m[003oJ`00103oJ`000`3oKP00ogP00?mi00030?mj000A0?ml003oNP00ohD00?n:003oR`00oi@0
0?nK003o[000k^H00:[o1031V@d0iOD00?OL003o^000ojH00?nN003oV@000P3oVP001P3oW000ojP0
0?CI003oXP00ohX00?mn0080ogX000<0ogH00?mb003oJ`002@3oJ`000`3oI000oe`00?mL00020?mL
00030?mP003oG@00oe`001D0oe`000<0oe@00?m<003oC0001P3oC005ooooo`7o00000Oooool000co
oooo1Ol00003ooooo`03o`000?oooooooooo00Cooooo0_l00003ooooo`T0ocd000<0odT00?m<003o
C000<@3oC0000`3oC@00od`00?m<000>0?m<00030?mG003oDP00od`000/0od`000<0oe400?mL003o
G0007`3oG0000`3oG@00oe`00?mL00040?mL0080oed01P3oG0000`3oI@00oed00?mL00030?mL0003
0?mT003oJ`00of/000d0of/000@0ofd00?m^003oJ`00of/01P3oNP003P3oP000ohX00?n:003oR`00
oiH00?nI003o[@00o]P00?oM003ikP00c?`80>Wg003oaP00ok000P3oZ@00203oZP00oj/00?n^003o
a000jnT80?n]003oTP00ohL00`3oNP000`3oLP00of`00?m]00080?m[00060?mY003oG000oe`00?mM
003oI000oel0103oG0020?mM0140oe`000<0oe@00?m<003oC0001P3oC004ooooo`;o00000Oooool0
01Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`T0ocd000<0odD00?m<
003oC000<@3oC0000`3oC@00odh00?m<000>0?m<00030?m>003oF`00odl000/0od`000<0oe800?mL
003oG0009`3oG0000`3oG`00oe`00?mL00040?mL00030?mR003oI`00oed00080oe`000<0oed00?mZ
003oJ`003`3oJ`000`3oL000ogD00?mf00040?mj00030?mk003oO000ohD00080ohX001L0oh/00?nH
003oVP00ojP00?ne003o`@00om400>Wd2035n`00m>000?o0003o^P00ok/00?[G003ocP00n]T00>gZ
003Jk@00l=D00?nH003oRP00ogh00?mk00020?mj00030?mf003oJ`00of/000P0of/000@0ofP00?mV
003oJP00ofD01@3oG0000`3oGP00oe`00?mL00030?mL00030?mM003oG000oe`000X0oe`000<0oeH0
0?m<003oC0001P3oC005ooooo`7o00000Oooool001Cooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`02ooooo`T0ocd000<0od800?m<003oC000<P3oC0020?m>00l0od`000<0oeD00?mK
003oCP002P3oC0000`3oE@00oe`00?mL000H0?mL00030?mM003oG000oe`000D0oe`000<0oeh00?mL
003oG000103oG0000`3oG@00of400?mL00040?mL00060?mO003oJ`00ofX00?mT003oHP00ofP03P3o
J`00103oK@00of`00?m[003oJ`060?mj00030?mm003oN`00ohX00080ohX001L0ohh00?nI003oVP00
ojD00?n[003o^P00olP00?7_001_lQ<0c?X00?oG003oc@00omD00>?c0034oP00T=PC0=;l003oa@00
oj<00?nD003oRP00oh<00?mk00020?mj00030?mf003oKP00ofl000/0of/000<0of400?mL003oG000
0P3oG0000`3oH000oe`00?mL000A0?mL00030?mK003oCP00od`000D0od`000<0odh0ooooooooool0
0oooool1o`00007ooooo000Cooooo`;o00001_ooool00ol0003oooooooooo`02ooooo`T0ocd000<0
od400?m<003oC000803oC0000`3oC@00od`00?m<000@0?m<00030?m?003oC@00od`000d0od`000@0
odh00?mL003oF`00odl02@3oC0000`3oFP00oe`00?mL000P0?mL00030?mM003oGP00oe`000D0oe`0
00<0of<00?mN003oG0000`3oG0000`3oG@00of/00?m[000B0?m[00030?mc003oLP00og@000H0ogX0
00<0og/00?n:003oRP000P3oRP005P3oT`00oiT00?nK003oY`00ojT00?ng003o``00lNT00=kl1@2F
o`P0k_D00?g`002Zl@D0X_l50>ce303Sl`00oll00?nc003oW@00oi<00?n;003oR0020?mk0080ogX0
00@0ogT00?m/003oJ`00of`02@3oJ`001P3oHP00oe`00?mL003oG@00ofD00?mM00@0oe`000<0oed0
0?mL003oG0003@3oG000203oF`00oe800?m=003oC000odd00?mA003oEP00oe/01Oooool1o`00007o
oooo000Dooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool90?lm00030?lo
003oC000od`003@0od`000<0oe400?m<003oC0003@3oC000103oE`00oe`00?mK003oDP070?m<0003
0?mC003oG000oe`001X0oe`000<0oed00?mL003oG0001@3oG0000`3oGP00oe`00?mL00040?mL0003
0?mN003oJ@00oeh000<0oe`000<0of400?m[003oJ`002`3oJ`001@3oK000of/00?m[003oK000ofd0
0080of/000<0og000?mj003oNP001@3oNP000`3oO000ohD00?n:00020?n:000E0?n<003oV000oiT0
0?nK003oY`00ojT00?nh003o`000om<00?oX0036oP00W?l:09co002foP<0h_D00?oE003oa000ok<0
0?nW003oVP00oi800080ohX000<0ogd00?mj003oNP000P3oNP000`3oLP00og400?m]00090?m[0005
0?mZ003oH`00of<00?mZ003oH@001@3oG0000`3oGP00oe`00?mL000D0?mL00030?mK0?oooooooooo
00?ooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`02ooooo`T0ocd000<0od400?m<003o
C0008`3oC0000`3oC@00od`00?m<000?0?m<00030?mB003oC000od`000`0od`000H0oe800?mL003o
G000oe`00?mH003oC`030?m<00030?m=003oE000oe`001d0oe`000<0oed00?mL003oG0001@3oG000
0`3oH@00oe`00?mL00040?mL00060?mY003oJP00of800?mO003oH@00ofX02P3oJ`001@3oK000of/0
0?m[003oJ`00of`00080of/000@0ofl00?mc003oKP00ogH01P3oNP000`3oO@00ogh00?n:00020?n:
000F0?n;003oU@00oiT00?nI003oX000ojP00?n[003o^@00ol<00?oA003ohP00nO/007Oo2P3Po`00
onh00?oI003oaP00okP00?nZ003oXP00oiT00?nB0080ohX000<0ohD00?ml003oNP000`3oNP00103o
L`00of/00?m[003oK@0;0?m[00D0oe`000<0of000?mL003oG000103oG0000`3oG@00oe`00?mL000>
0?mL00030?mC0?oooooooooo00?ooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`02oooo
o`T0ocd000<0od400?m<003oC0008`3oC0000`3oC@00od`00?m<000?0?m<00030?m>003oD`00od`0
00`0od`000<0odh00?mL003oG0000`3oG000103oF`00oeT00?mI003oF`0G0?mL00030?mM003oG000
oe`000D0oe`00P3oG@060?mL00030?mQ003oGP00oe`000@0oe`000<0ofL00?m[003oJ`004@3oJ`00
103oKP00of/00?m[003oJ`080?mj00030?ml003oO@00ohX00080ohX001/0oh/00?nB003oV@00oiT0
0?nL003oY`00ojT00?nd003o^P00olT00?oF003ok000aol106[o3035o`00on/00?oB003o``00okL0
0?nY003oX@00oiT00?nE003oR`00ohX00?n8003oO`00103oNP000`3oMP00og400?ma00030?m[0003
0?m/003oJ`00of/000H0of/00`3oG0000`3oG@00of@00?mL000F0?mL00030?mJ003oC03ooooo00Co
oooo0Ol00001ooooo`006oooool00ol0003oooooooooo`02ooooo`T0ocd000<0od@00?m<003oC000
903oC0000`3oC@00od`00?m<000?0?m<00030?mC003oDP00od`000`0od`08@3oG0000`3oG@00oe`0
0?mL00050?mL00030?mN003oG000oe`000@0oe`000<0oed00?mX003oGP00103oG0000`3oJ@00of/0
0?m[000A0?m[00040?m/003oM@00ofd00?m^00H0ogX000<0og/00?mj003oP0000`3oRP007@3oR`00
oi400?nI003oV@00oid00?nV003oZ000ok000?nk003oaP00om/00?oW003XnP00Po@=04?D?@1ooa@0
o_000?oG003oaP00okP00?nZ003oYP00oiT00?nH003oSP00oh/00?n:003oQ000ogh000D0ogX000@0
ofd00?m[003oK000of`02@3oJ`001@3oI@00oel00?mQ003oJ@00oel000D0oe`000<0oed00?mL003o
G0003`3oG0000`3oE000od`0ooooo`04ooooo`7o00000Oooool001_ooooo0_l00003ooooo`T0ocd0
00<0odP00?m<003oC0009@3oC0020?m=0100od`000<0oeL00?mA003oC0002`3oC0000`3oF@00oe`0
0?mL000V0?mL00030?mM003oG`00oe`000D0oe`000<0ofL00?mY003oH0000P3oG0000`3oI000of/0
0?m[000;0?m[00040?m/003oK@00of/00?m[0080ofd00P3oJ`000`3oMP00ogX00?mj00070?mj000O
0?n2003oR000ohX00?n:003oR`00oi800?nH003oV`00oj400?nW003oZ@00ok400?nj003obP00oml0
0:gl1P3ToP00fOl009?b500]lT00`_l:0?cj003mk@00ln400?nm003o[`00ojP00?nM003oV@00oiL0
0?n<00020?n:00030?mn003oN`00ogX000<0ogX000<0og800?m`003oL0003@3oJ`000`3oJ@00oe`0
0?mL00020?mL00030?mM003oGP00oe`00140oe`000<0oe000?m<0?ooool00oooool2o`00007ooooo
000Kooooo`03o`000?oooooooooo00;ooooo203o?@000`3o?`00od`00?m<000W0?m<00030?m>003o
C@00od`000h0od`000<0odh00?mK003oD@002`3oC00C0?mL00030?mM003oG000oe`000D0oe`000<0
oed00?mL003oG000103oG0000`3oGP00oe`00?mL00050?mL00030?mR003oG@00oe`000@0oe`000<0
of@00?m[003oJ`000P3oJP0?0?m[00080?m]003oJ`00of/00?m[003oL`00ofl00?m/003oN@070?mj
00030?mk003oP000ohH00080ohX00200oh/00?nC003oV@00oi/00?nX003o/@00ok@00?ng003o^@00
olH00>W]002@o`T0J?hK07kl5`1doQ/08/IS04fNH`1Qoa40fOl008co3`3MhQX0olH00?ng003oZP00
ojL00?nM003oV@00oi@00?n;003oRP00ohP00?mk00H0ogX00P3oJ`020?m/00X0of/000H0ofP00?mL
003oG000oe`00?mN003oHP060?mL00030?mM003oG000oe`000X0oe`000<0oe800?m<0?ooool01?oo
ool1o`00007ooooo000Kooooo`03o`000?oooooooooo00;ooooo203o?@000`3oB000od`00?m<000X
0?m<00030?m>003oC000od`000h0od`000<0oe@00?mL003oD@002@3oC0000`3oD000oe`00?mL000Q
0?mL00030?mN003oG000oe`000@0oe`000<0oeh00?mV003oG000103oG0000`3oI000of/00?m[000:
0?m[00050?m/003oJ`00of/00?m[003oK@000`3oJ`00103oL000of/00?m[003oL0090?mj00030?mn
003oO000ohL00080ohX002<0oh`00?nE003oV@00oih00?nW003o_`00cO800?oH003oa`00olP00?oA
003oiP00kOh00;co000m`E`0MGiF0<LUD02V?TP0=^Hj05;K?@1Wo1/0aoX20?oA003o_000okH00?n/
003oZ@00oj<00?nJ003oT@00oh/00?n:003oQ000ogX00?ml00040?mj00<0og000P3oJ`020?m/00P0
of/000D0of@00?mO003oHP00ofT00?mM00040?mL00030?mM003oG000oe`000`0oe`000<0oeL00?m<
0?ooool01?ooool1o`00007ooooo000Kooooo`03o`000?oooooooooo00;ooooo1`3o?@000`3o@@00
od`00?m<000Z0?m<00030?m?003oC000od`000d0od`000@0odd00?mL003oG000oe80203oC0000`3o
EP00oe`00?mL000B0?mL00030?mM003oG000oe`000@0oe`00P3oG@060?mL00030?mO003oG000oe`0
00D0oe`000<0ofL00?mV003oG0000`3oG0000`3oJ000of/00?m[000>0?m[0080of`00P3oJ`00103o
L`00og400?m[003oMP070?mj00030?mk003oNP00ogX000<0ohX00140oh/00?nA003oV@00oj400?nY
003o]000olP00;[/0P2koP<0o^@00?oI003og`00onl00?Km002CgS@0>l1l0?8040020?l0000@0;//
GP10lCd0aol00??h003of@00olL00?nn003o_000okX00>o<103oZP00oiT00?n=003oR`00ohT00?n3
00L0ogX000@0of`00?m[003oJ`00of`0303oJ`000`3oI000oe`00?mL00020?mL00030?mN003oG000
oe`000h0oe`000<0oe80ooooooooool00oooool1o`00007ooooo000Kooooo`03o`000?oooooooooo
00;ooooo1P3o?@000`3o?`00od/00?m<000I0?m<00030?m=003oC000od`000l0od`000<0odd00?m?
003oC0003P3oC0001@3oEP00oe`00?mL003oE`00odh000D0od`000<0oe<00?mL003oG0006`3oG000
0`3oG@00oe`00?mL00050?mL00030?mQ003oG000oe`000@0oe`000H0of@00?m[003oI`00of000?mO
003oIP0B0?m[00040?m`003oJ`00of/00?m`00T0ogX000@0og/00?mj003oP@00oh400`3oRP00403o
S@00oiT00?nN003o]@00o<T00>[D103]j@00gO`006gb4`3hn000onh00>Gg0@2bo0d0f?l008We6P1R
SSl30?l0000=0<</AP0me5/0_ol60?ch003oh000om@00?o>003Qg@P0mMd00;Ch7@3l``00oi/00?nC
00020?n:00030?n4003oOP00ogX000D0ogX000<0ofl00?m]003oL@000P3oJ`000`3oK000of/00?m[
00080?m[00060?mT003oG000oe`00?mL003oH000oeh04@3oG005ooooo`7o00000Oooool001_ooooo
00?o0000ooooooooool00_ooool50?lm00030?lo003oBP00od`002d0od`000<0odd00?m@003oC000
3@3oC0000`3oC`00oe`00?mL00020?mL00050?mH003oDP00oe800?mC003oF0007P3oG0000`3oG@00
oeh00?mL00050?mL00030?mR003oG`00oe`000@0oe`000<0of@00?m[003oJ`004P3oJ`001`3oK@00
of/00?m[003oL000ogH00?ma003oN0002@3oNP020?ml00030?n0003oRP00ohX00080ohX00140oi@0
0?nJ003o]P00dNl30;ol0@2cj@d0L_l?06cb7P1glP`0i_l00?3o0033lPX0A^0b06[g8P0jmb80;mU:
0<PP?@020?l0000>09ULA01Ko`L0/_l508_b;P3fm`00onL00?kZ0030m1L0QO880:_g103o^P00oj00
0?nG003oR`020?n:00030?mo003oO000ogX000H0ogX000@0og000?m[003oK000ofd00P3oJ`000`3o
K000of/00?m[00050?m[00050?mX003oGP00oeh00?mT003oH`004P3oG005ooooo`7o00000Oooool0
01_ooooo00?o0000ooooooooool00_ooool30?lm00030?ln003oA@00od`001h0od`000<0odd00?m<
003oC0003`3oC0000`3oCP00oe400?m<000=0?m<00030?mK003oG000oe`002D0oe`000<0oeh00?mL
003oG000103oG0000`3oG@00ofX00?mN00040?mL00030?mT003oJ`00of/000l0of/000<0of`00?m[
003oJ`000P3oL0000`3oJ`00og800?mj00070?mj00050?ml003oNP00og`00?ml003oNP000`3oRP00
903oR`00ohX00?n>003oV000oih00?n^003ocP00^?X50;_m203_oP00O?l904So9P2Yo`00IOlH08km
3@1[O680OGQC0=T?;P3o0000l00S0?l0003W11/0SF=5072<<`19jCD0?>9=0:Of:03io000joh005Sk
4`3JoP00oml00?nj003oY000oiT00?n@00<0ohX000<0ogl00?mj003oNP001@3oNP000`3oMP00ofl0
0?md00020?m[00030?m]003oJ`00of/000T0of/000<0ofT00?mL003oG0004@3oG005ooooo`7o0000
0Oooool001_ooooo00?o0000ooooooooool00_ooool0103o?@00od400?m6003oB`0c0?m<00030?m@
003oDP00od`000`0od`000<0oeP00?mL003oG0007P3oG0000`3oG@00oe`00?mL00040?mL00030?mN
003oG`00oe`000D0oe`000<0ofL00?mY003oG`000P3oG0000`3oGP00ofX00?m[000@0?m[0080ofd0
00@0of/00?m/003oNP00ogP02@3oNP000`3oN`00og`00?mj00020?n500D0ohX000h0oiD00?nI003o
WP00ojT00?nj003od000omd00?kc002LoA40</EC03K2MP1=SgT0Ck5V0:hjC`P0o`0000d0^352079j
D`29m180W?0S0<go001KjC/0Lo/C0;Sj0`3ef`00oj`00?nK003oU`00oh`00080ohX000@0ohH00?n1
003oNP00og/01P3oNP00103oM`00of/00?m]003oKP0;0?m[00040?mW003oG000oe`00?mL0080oeh0
3P3oG005ooooo`7o00000Oooool001_ooooo0_l00003ooooo`030?m;003oC000od`002<0od`000<0
odh00?m<003oC0003`3oC0000`3oE000oe<00?m<000;0?m<00030?mD003oG000oe`001h0oe`000<0
oeh00?mM003oG0001@3oG0000`3oH`00oe`00?mL00040?mL00030?mT003oJ`00of/00080ofL000<0
ofX00?m[003oJ`003@3oJ`001`3oK@00of`00?m[003oJ`00ogH00?mb003oM000203oNP00103oN`00
ogX00?mm003oNP020?n100030?n9003oRP00ohX000<0ohX000h0oi800?nH003oV@00oj000?nY003o
]000ol000?o@003njP00T_8E02gHH`3J5SL0o@0=0=HI<@X0o`0000`0_bhn03?DE00ZbgL0>O/]047R
CP3No`00/oh40>7X003o[P00oih00?nI003oS`030?n:00050?n4003oO`00og/00?mj003oN`001@3o
NP001P3oN000ogT00?m^003oJ`00ofh00?m[0080of`01P3oJ`001@3oJP00of400?mO003oI000of<0
00H0oe`000<0oed00?mL003oG0001P3oG004ooooo`;o00000Oooool001_ooooo00?o0000oooooooo
ool00_ooooli0?m<00030?mH003oE000od`000X0od`000<0oeL00?mL003oG000403oG0000`3oG@00
oe`00?mL00050?mL00030?mM003oG000oe`000@0oe`000<0oeh00?mL003oG000103oG0000`3oH@00
of@00?mL00040?mL00030?mU003oJ`00of/000l0of/000P0of`00?m[003oJ`00of/00?ma003oK000
of/00?mh00P0ogX00P3oN`001@3oO000og/00?n1003oP@00ohT000H0ohX000h0oi000?nG003oV@00
oi/00?nS003oZ000ok<00?o0003oc`00onT00>on001FlSP0SVdm0>h=6@`0o`0000`0c2940>0;9P1J
P8D0C_8T0?7d003oeP00ol000?n[003oWP00oiT00?nD003oS0030?n:00030?n7003oN`00og`000P0
ogX000L0ogD00?mf003oK`00of/00?m^003oJ`00ofd000P0of/000<0ofT00?mL003oG0000`3oG000
0`3oGP00oe`00?mL00080?mL00Gooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`02oooo
obP0od`000<0odh00?m<003oC0003P3oC000103oCP00oe/00?mG003oC@090?m<00030?mK003oG000
oe`001l0oe`000<0oel00?mN003oG000103oG0000`3oG@00of/00?mT00030?mL00030?mM003oJP00
of/000d0of/000D0of`00?m[003oJ`00of/00?m^00020?m[00030?m`003oN@00ogP000H0ogX000P0
og`00?mj003oO000ogX00?n0003oO000ohL00?n900L0ohX000h0oi400?nF003oV@00oiT00?nK003o
YP00ojX00?ne003o`000nM/009og4P32o`80Q?l2056VF@d0o`0000`0o00=0;Ln<P1B_V80aol40?oX
003ob`00okT00?nX003oXP00oiX00?nI003oS`050?n:00040?mn003oO000og/00?mk00L0ogX00P3o
MP000`3oK`00of`00?m]00080?m[00070?mT003oG000oe`00?mL003oG@00of000?mM000:0?mL00Go
oooo0Ol00001ooooo`006oooool00ol0003oooooooooo`02ooooobT0od`000<0odh00?m<003oC000
3P3oC000103oD`00oe`00?mJ003oCP070?m<00030?mC003oG000oe`001T0oe`00P3oG@060?mL0003
0?mT003oG000oe`000@0oe`000<0ofT00?m[003oI`000P3oHP000`3oJ@00of/00?m[000>0?m[0007
0?m/003oJ`00of/00?m]003oL`00of`00?md00060?mj00070?mk003oO000ogX00?mn003oP@00oh<0
0?n900070?n:00040?n;003oRP00oi<00?nG0080oiT000/0oi/00?nR003oZ000ojT00?nh003oa000
mnL006Co8`1<n2<0G>HC08eCBP0>0?l0000=079nFP2CiQX0dol00>?f003jeP00okT00?nY003oYP00
oiX00?nI003oU`00ohh00?n;00030?n:00060?n9003oQ@00ogX00?mm003oNP00og/01`3oNP020?mh
00030?m/003oK@00of`000H0of/000<0ofX00?mO003oGP000P3oHP060?mL00030?mM003oG000oe`0
00<0oe`01Oooool1o`00007ooooo000Kooooo`03o`000?oooooooooo00;ooooo:P3oC0000`3oCP00
od`00?m<000>0?m<00050?mI003oG000oe`00?mF003oCP00103oC0000`3oE000oe`00?mL000K0?mL
00030?mN003oG000oe`000@0oe`000<0of<00?mQ003oG000103oG0000`3oJP00of/00?m[000?0?m[
00060?m/003oJ`00of/00?m[003oK@00of`00P3oJ`000`3oM`00ogX00?mj00040?mj0080og/000<0
og`00?mo003oP`001`3oRP001P3oR`00ohX00?n;003oSP00ohl00?nG00<0oiT000`0oi/00?nN003o
Y`00ojT00?n_003o^P00om8009Ge5@1eo`/0CL1N08M^E@3E5C<>0?l0000909iB@@1UlQP0??lf06oo
503_g`00okd00?n]003oZ000oid00080oiT000<0oiL00?n?003oRP00103oRP00103oR000oh800?ml
003oN`020?mj00030?mk003oNP00ogX000@0ogX000@0ogP00?me003oK000ofd0203oJ`000`3oI000
oe`00?mL00040?mL00030?mM003oG000oe`000@0oe`01Oooool1o`00007ooooo000Kooooo`03o`00
0?oooooooooo00;ooooo:`3oC0000`3oD000odd00?m<000=0?m<00030?mB003oG000oe`00080oe`0
00@0oeX00?mG003oF000oe/0403oG0000`3oG@00oe`00?mL00040?mL0080oed01@3oG0000`3oGP00
oel00?mL00040?mL00030?mP003oJP00of0000<0oe`000<0oel00?m[003oJ`004@3oJ`001@3oK@00
of/00?m[003oJ`00ogD00080ofl01@3oNP030?mk00030?n3003oQ`00ohX000<0ohX000<0oh/00?n:
003oRP000P3oS@00103oS000oi000?nE003oUP040?nI000=0?nK003oX000ojP00?nX003oZP00okL0
0?nk003oc@00lN/00??k0026hc40H95S0<8A>P0>0?l000070?h03@2AL4`0E/Y;08O_903oe000okd0
0?n`00020?nX00060?nL003oVP00oiT00?nH003oT`00oh`01P3oRP001P3oP000oh800?mj003oO000
og/00?mj0080og`0103oNP00103oN@00of/00?m/003oK0060?m[00030?mM003oG000oe`00080oe`0
00<0oeh00?mM003oG0001P3oG005ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool00_oo
oolH0?m<00030?m=003oC000od`00140od`000<0oe000?m=003oC0003@3oC0000`3oF`00oe`00?mL
000M0?mL00030?mM003oG000oe`000@0oe`000<0of<00?mL003oG000103oG0001P3oJ`00ofX00?mT
003oH000of800?mZ01<0of/000D0ofd00?m/003oJ`00of/00?mc00070?mj00050?mk003oP@00ohX0
0?n:003oR`000P3oRP001@3oR`00ohl00?nB003oU@00oiL00080oiP01@3oV@00103oVP00oi/00?nM
003oYP020?nX000:0?nZ003o/`00okP00?no003ob`00om`00?kc001ojR00?>Da0;<fCPh0o`0000/0
VD1F08RVBP3;oP<0o>h00?o>003o_@00okL00?nZ003oZ000ojD00?nN00030?nI00030?nE003oS`00
oh/000H0ohX000@0ohP00?n7003oQP00ohD00P3oQ0001`3oPP00ogl00?mk003oN`00ogX00?mi003o
K`000P3oK@050?m[00050?mO003oG000oe`00?mO003oH0002@3oG005ooooo`7o00000Oooool001_o
oooo00?o0000ooooooooool00_ooool]0?m<00030?mC003oCP00od`000`0od`000<0oeL00?mL003o
G0007P3oG0000`3oGP00oe`00?mL00030?mL00030?mQ003oI000oe`000<0oe`000<0oel00?m[003o
J`004`3oJ`020?m/00<0of/000@0og<00?m]003oJ`00ogD01@3oNP020?mk000=0?n6003oRP00ohX0
0?n;003oS`00oi<00?nF003oV000oiT00?nJ003oX000oil00?nM00030?nJ00050?nI003oVP00oi/0
0?nP003oYP000`3oZ0002`3o[P00okH00?nh003o^P00olH00?o<003of`00o_4006WV;@0kYgX0iQXI
00h0o`0000T0X4`i056eC02mjQ/0on000?o=003o`P00okP00?ne003oZ@000P3oZ0000`3oY000oj00
0?nJ00020?nI00030?nE003oS`00oh/000T0ohX000D0oh/00?n<003oR`00ohP00?mo00020?mj0004
0?mh003oL000of/00?m]00@0of/000@0ofX00?mX003oJ@00of402P3oG005ooooo`7o00000Oooool0
01_ooooo0_l00003ooooobh0od`000<0oe@00?m>003oC0002`3oC0000`3oE000oe`00?mL000N0?mL
00030?mP003oG000oe`000<0oe`000<0oeh00?m[003oHP000`3oG0000`3oI@00of/00?m[000@0?m[
00050?m/003oJ`00of/00?m[003oKP000`3oJ`000`3oL000ogX00?mj00050?mj00070?mk003oNP00
ohD00?n:003oS000oi<00?nI00030?nN00070?nQ003oX`00oj`00>SA0@3o_P00oj`00?nW00030?nR
000B0?nU003oZ000ojP00?nZ003o[@00ok<00?ng003o^000okT00?nn003oaP00olP00?oD003og`00
oo400>[o0022ob80?:Mi3@3o00005`3b1140H8M]08Oj6`3am`00on000?oC003oa`00ol000?ni003o
]P00ok000?n^003o[000ojd00?nY003oX@00oiX00?nI003oV000oiD00?n?003oS000oh/000@0ohX0
00P0oh/00?n@003oV@00mk`00?na003oT`00ohX00?mo0080ogX000<0ogH00?m`003oJ`001P3oJ`00
0`3oHP00oe`00?mL00040?mL00030?mM003oG000oe`00080oe`01?ooool2o`00007ooooo000Koooo
o`03o`000?oooooooooo00;ooooo703oC0000`3oCP00od`00?m<000@0?m<00030?mH003oC`00od`0
00X0od`000<0oe@00?mL003oG0004@3oG0000`3oG@00oe`00?mL00040?mL00030?mM003oG000oe`0
00<0oe`000<0oeh00?mP003oG000103oG0020?m[00030?mW003oH`00ofL001<0of/000<0ofd00?m[
003oJ`000P3oJ`00103oL`00of/00?m[003oK`080?mj000@0?n3003oRP00ohX00?nF003oZ`00okD0
0?K>003l^@00ojd00?n`003o]@00olH00:cf4`37m000i<l40?n`00@0ojP00180ojT00?nb003o^P00
okh00?o0003o`P00olD00?o6003oa`00ol/00?oE003ofP00onD00?ob003go@00TO0]08bU5`2PBT@<
0?l0000:0;Dn@`19]YH0h_l00?kg003oi000omP00?o@003ob000ol800?nk0080okP000H0okX00?3A
003ha`00ojd00?nU003oW0020?nI000@0?nH003oUP00oi@00?n?003oS@00ohh00?nA003oU`00oiX0
0?nQ003o`000k_000?nZ003oUP00ohX00?ml0080ogX000<0og000?m^003oJ`001@3oJ`000`3oH000
oe`00?mL00020?mL0080oed01@3oG005ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool0
0_ooool_0?m<00030?m>003oF`00oe4000X0od`000<0oeL00?mL003oG000603oG0000`3oGP00oed0
0?mL00040?mL00030?mX003oG@00oe`00080oe`000<0oeh00?m[003oJ`003P3oJ`001@3oK000of/0
0?m[003oJ`00of`000@0of/000P0ofd00?m[003oJ`00of/00?mc003oMP00og400?mh00H0ogX001@0
og/00?mo003oR000ohX00?n=003oW@00lML00<Wf0`3;n`00omH00?o5003?dQ40lML00?oO002goP40
XO4R0?KL003o^P00ok@00?n^0080ojl001<0okL00?nm003Qi000^>4Y0>kW102Um1D0l>8=0?oE003o
eP00om`00?oU003oj@00oo000?gi003co`00f_l009_]8P2JLf@0hQ<V00X0o`0000/0c2de04W@N032
o`00j_l00?ck003ok`00on@00?oO003fh000om400?o:00020?o500070?o<003Yk`00NOXT0?o7003o
/@00ojL00?nP00090?nI00090?nN003oZ@00okd00=_`0P3XfPd0n[h00?n>003oQ@00og/00080ogX0
00<0ofd00?m[003oK000103oJ`001P3oI000oed00?mM003oH@00of000?mM00H0oe`01Oooool1o`00
007ooooo000Kooooo`03o`000?oooooooooo00;ooooo<03oC000103oD000oe`00?mE003oC@070?m<
00030?m>003oG000oe`001<0oe`000<0oeh00?mL003oG000103oG0000`3oH@00oe`00?mL00030?mL
00030?mW003oJ@00oeh00080oe`000<0ofL00?m[003oJ`003`3oJ`001@3oK000of/00?m[003oJ`00
of`000<0of/000D0ofl00?m]003oJ`00of/00?m_00090?mj000D0?mm003oQ000ohX00?n:003oTP00
oi`00?ne003Am@00V_h:0;W]303dk`00Y?d?0=Ol002IoPT0?Ndb0;[l103of@00olD00?nm003o^@02
0?nh000D0?nn003obP00hNh;07;[7@1KbT/0JmTB0<7d3@3ok000ond00:3_802GlBT0b_LD0?7n003X
iP00g_l00<co002co`00Qnd=04Ri@@3I7b<80?l0000J0=HV8@1J^SH0VOl00<Co003Ko`00j?l00=oU
2P3jnP00n^`007;X8@2Xkb00on400?oF003og000[nXN0<7m0@1UnBd0a?<=0=;H6P3o/P00ojP00?nT
003oW@00oiX00?nK003oV@020?nJ000;0?nK003oX@00ojL00?na003oa`00go@00<gk0P3m``00oi@0
0?n;003oO@000P3oNP000`3oMP00ofh00?m[00060?m[00030?mZ003oGP00oe`000L0oe`01Oooool1
o`00007ooooo000Kooooo`03o`000?oooooooooo00;ooooo<@3oC000103oE@00oe`00?mJ003oDP05
0?m<00030?m>003oF@00oe`001D0oe`000<0oed00?mL003oG0000`3oG0000`3oGP00of800?mL0003
0?mL00050?mT003oJ`00of/00?mX003oJP003P3oJ`000`3oK@00of/00?m[00050?m[00030?m]003o
J`00of/00080of/000@0ogH00?m`003oK000ogH02@3oNP00;@3oP`00ohX00?n:003oRP00oiH00?nL
003oZ`00ol<00?3V002Jo`P0HOXX09?I9`1jl140;miH0;So003fn`00on@00?oG003oc`00olH00?o3
003oaP00ol/00?gP002VmbD08mf004j0VP0g]EL0P?8F0?7n003:iA@0M[Q@079:S@2@b2`0Ul`K08E4
J02;_bl0Oi5108bQ@`1k/240Bm0c04nc8@2KFDH0hA4c0?l03`020?l0000`0?/03@328D00S7=@04Zc
9@1/_aP0Pk<M0:6I=`1WTUP0V^H108YQH`2<`DP0`_8:07n<?`22JWd0^>lV0?o_003nl`00X>dS04[<
A@0o/eH0=?910=S/0@3o`000ok000?nY003oZ000ojL00?nV003oY000ojD00?nV003oY`00ojP00?n^
003o_@00nNP00:?o0P3ohP00ok400?nH003oS000ohL00?ml003oNP00ogT00?m^003oK@00of`01@3o
J`000`3oG`00oe`00?mL00050?mL00030?mM003oG03ooooo00Cooooo0Ol00001ooooo`006oooool0
0ol0003oooooooooo`02oooooc40od`000H0odd00?mK003oG000oe`00?mK003oEP020?mB00030?mF
003oF`00oe`001H0oe`000<0oeh00?mM003oG000103oG0000`3oI`00of400?mL00020?mL00030?mY
003oJ`00of/00100of/000D0ofd00?m[003oJ`00of/00?m/00040?m[00050?m`003oJ`00of/00?m[
003oMP00203oNP00;@3oN`00ogX00?mk003oP`00ohP00?n:003oR`00ohd00?nH003oV`00ojT00?nn
003ofP00moL00:Wo0`0Rkcl07o9708_o003>o`00kol00=oj4P3;n@D0bo<70?oI003od@00om800?oI
003Yj@d0An4m04cZ7`21CeP0Q4IZ05>iG02^abH0V_XP04K>B@3V3aX0[fHA07BV3`3V6Ah0MGY20?8:
3@3V3A80g1LS0>T36P090?l0000H0?l01@3b2`d0g0lT0?8=3P3<8bh0PGXi0?l01P23S1d0O<DD0;<j
<@1aOG40Sm0b0>go002[lRT0S<@K05;F=@15Uh/0C<e808Wm7@3le`00okX00?nd003o[P00oj/00P3o
[P003P3o[`00ok000?n`003o]@00okX00?oC002coP`0O[<D0?7V003o/@00oih00?nD003oRP00oh00
0P3oNP000`3oM000of/00?m[00050?m[00D0oe`00P3oG@030?mL00Gooooo0Ol00001ooooo`006ooo
ool00ol0003oooooooooo`02ooooob40od`000<0odd00?m?003oC0003P3oC0000`3oD`00oe`00?mL
000G0?mL00030?mM003oG000oe`000@0oe`000<0of400?mL003oG0000`3oG0001@3oI000of/00?mU
003oH@00ofH000`0of/000<0of`00?m[003oJ`001@3oJ`001@3oK000of/00?m[003oJ`00ofh000<0
of/000D0og<00?ma003oJ`00of`00?mi00090?mj000V0?ml003oNP00ohL00?n:003oR`00ohX00?n?
003oV@00oih00?n]003lcP00e_H=08_l5`12c5P0F?DR02jVPP0ec740?^9906kj>`2Qna00?<1M06KD
?P2ln@`0onD00?oQ003oj000oOP00=go001]Xf<0[dA00?T03@3V5AL0I/@J0:aIA@2FISX0lP4=0=TV
9@3b0PdF0?l0000E0>H@6P2b=D`0o`000:<oB01XfBT0[mX=06o5D@2MAT<0cb@Y0:@nG023o`X0Zo<V
0?kM003oaP00ok`00?nh003o^P00ol000>kC0@3oc000o<h00080ol8000l0olP00?oH003lm000V_l1
0=[/003o_000ojl00?nY003oU@00ohP00?ml003oNP00ogT00?ma003oK0001@3oJ`001P3oI@00oel0
0?mO003oHP00oeh00?mM00@0oe`01Oooool1o`00007ooooo000Kooooo`;o00000oooool=0?m<0003
0?m=003oC000od`001<0od`000<0oe400?m=003oC000303oC0000`3oC@00oe/00?mL000N0?mL0003
0?mM003oI000oe`000<0oe`000<0of@00?m[003oJ`004P3oJ`001@3oK000of/00?m[003oJ`00ofd0
00<0of/000H0og000?m/003oJ`00of/00?mc003oNP020?mi00P0ogX000<0og/00?mj003oO000103o
RP007P3oS000oiD00?nJ003oX000ok000<gW101[oa00EM`e0;Ko1@2do`00>OXb07UOS@1f@Z00?>0W
05CN>00WdUL0=KQ`0:;o303ln`00o_P00=kk1P3>mAX0`_l207Z1DP3S2bH0o`000?863@2MFC40lPd3
0?863A/0o`0000D0o`070=`@8`3V5A80QXXe08Ic;P020?l000060=0S7015cHT0m_/00?oT003od`00
olT00P3oaP001@3of000RoPI08SR9@2>lQ@0eO020080omT000X0on<00>[i001:oB@0jO<00?WN003o
c`00jn<00?nW003oRP00ogd00P3oNP020?m]00030?m/003oJ`00of/000@0of/000<0ofL00?mM003o
G0001@3oG004ooooo`;o00000Oooool001_ooooo00?o0000ooooooooool00_oooolT0?m<00030?mA
003oCP00od`000`0od`000<0oeP00?mL003oG0005`3oG0000`3oGP00oed00?mL00040?mL0080of@0
00@0oed00?mL003oG000ofP0503oJ`001P3oK000of/00?m[003oJ`00ofh00?m]0080of/000D0ofl0
0?mf003oK@00of`00?mf00050?mj00090?mk003oNP00ogX00?mj003oN`00ogX00?mk003oP@00oh00
00@0ohX001X0ohh00?nH003oV@00oj<00?n`003neP00fO010>oe003eoP00]_h@02NgJP2]:Ud0o`00
0;TdB`38;SL0h10S06FAEP1K_g40hOl00>Oo001aa5@0SGII07jh8P25YR40P6MD0?823B80o`0001d0
lP@=0=TV7P3o0000o`000<8b;@29jS00iOl00=km003Qi`d0omX00?oC003of000onD00>_m002Ak240
9MUZ09Wo4P3dm`00doD50?Wi003[o`00Jol:0;7o1P2Do`80WodK0=7/1P3fZP00oh/00?n400020?mj
00030?mg003oK@00of/000D0of/000<0ofP00?mL003oG0001P3oG005ooooo`7o00000Oooool001_o
oooo00?o0000ooooooooool00_oooolU0?m<0080oe40303oC0000`3oE@00oe`00?mL000A0?mL0003
0?mM003oG000oe`000@0oe`000<0of000?mM003oG0000`3oG0001@3oGP00of/00?mZ003oI@00ofP0
00h0of/00P3oK0020?m[00050?m]003oJ`00of/00?m[003oKP000`3oJ`00103oM000of/00?m[003o
L00:0?mj00070?mk003oNP00ogX00?mk003oO000ogX00?n300040?n:000>0?n<003oT`00oiT00?nI
003oY000oj`00?nk003oc@00omh00?_h003Co`00GMLd089fE@3f00d30?l000090=TU6@1ZPGh0/_8C
0<3b1@1JcDH0eaM:0<509@3V5ad0o`0702H0o`0001X0faLR07f0<@2BPS@0Po8G05:VG@1V/5<0lO<6
0?oX003lk`00^?PJ09Wm4@1KV780A;aa07Wn9@2/naT0@na;07on501elS80E>Y505co7@3TnP/0om40
0?nb003oV`00oh`00?n30080ogX000<0ogL00?m_003oK0001@3oJ`000`3oI000oe`00?mL00050?mL
00030?mN0?oooooooooo00?ooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`02ooooobH0
od`000<0oe400?mF003oC@002P3oC0000`3oF000oe`00?mL000A0?mL0080oed01P3oG0000`3oHP00
oed00?mL00030?mL00`0of/000D0of`00?m[003oJ`00of/00?m/00020?m[00040?m]003oJ`00of/0
0?m^00<0of/000P0og<00?m[003oJ`00of`00?mj003oMP00og400?mh00<0ogX000<0og/00?mj003o
NP001@3oNP001P3oN`00ogX00?mj003oP@00oh@00?n900<0ohX00P3oS@020?nI000:0?nK003oZ000
ojX00?nh003o``00omP00:Gk601Pk3X0Dm@k0:M2C0D0o`0000D0PEEj07Wo0@2SH580WDd`0?8=1`0[
0?l0000I0>L=4@2HHSd0_b@k06O6B03[lPT0no/00>?b1`1T/e<0D[mC0;I:@P3R6QL0VeaE04c4=`28
GeX0EI];02cJH`1mo`X0Xo8>08Oo1@3oe`00ok800?nG003oRP00oh@00?mk00020?mj00030?m^003o
J`00of/00080of/000T0of`00?m[003oJP00of400?mN003oG`00of000?mN003oG@000P3oG005oooo
o`7o00000Oooool001_ooooo00?o0000ooooooooool00_oooolW0?m<00030?mB003oFP00oe0000P0
od`000<0odd00?mK003oG0004`3oG0000`3oG@00oe`00?mL00040?mL00030?mN003oI`00oeh00080
oe`000<0of800?m[003oJ`003P3oJ`00103oK@00of/00?m[003oK@020?m[00040?m_003oL000of/0
0?m[0080ogH000<0ofh00?mc003oNP002@3oNP00103oN`00ogX00?mj003oN`020?mj00030?mn003o
NP00oh0000D0ohX000h0oh/00?nH003oV@00oiX00?nN003oZ000oj/00?nh003o``00omT009?j:P0Q
/HP0EIYG0>D>9`D0o`0000<0`S<W06>J?`2d;D40;`3o00001`3V6P/0L[4R09nI;03Ho`00YO8B05f>
JP3b10d00`3o00003@3:53/0o`000>8G<`1:gdl0^OlG0?cg002`l080`_/G0?K5003oUP00ohX00?n4
003oN`000P3oNP000`3oL`00ofh00?m/00070?m[00030?mT003oG@00oe`000<0oe`01Oooool1o`00
007ooooo000Kooooo`03o`000?oooooooooo00;ooooo5@3oC0000`3oC@00od`00?m<000@0?m<0004
0?mC003oG000oeL00?m>00H0od`000<0oeL00?mL003oG000503oG0000`3oGP00oed00?mL00040?mL
00040?mV003oJP00ofH00?mV00/0of/000@0of`00?m[003oJ`00of`00P3oJ`00203oK`00of/00?m[
003oL`00ofd00?m[003oL000ogT00P3oL00A0?mj00040?mk003oO000ogX00?mo00D0ohX00P3oR`00
3P3oUP00oiT00?nI003oV`00ojL00?nX003o/000okT00?o5003bh@40SOHQ03SLC@2DLT00fBHM1@3o
00000`2o?RL0o@0?0?l0000`0?l000050?8=2P21KT<0YMT:073D<`38:3401@3o0000303<5Bl0Ji=B
05?S?P3Qn000omX00?o<003^b0<0oj@00?nC003oRP00ohD00?mk0080ogX000<0ogD00?m[003oJ`00
1P3oJ`000`3oH@00oe`00?mL00040?mL00Gooooo0Ol00001ooooo`002?ooool2o`0000Cooooo00?o
0000ooooooooool00_ooool3o`0000Gooooo00?o0000ooooooooool00_oooolY0?m<00050?mG003o
G000oe`00?mH003oD@000P3oC`000`3oD@00oeT00?mL000G0?mL00030?mQ003oG000oe`000<0oe`0
00<0of@00?m[003oJ`002P3oJ`003`3oK000of/00?m[003oK@00of/00?m_003oK@00of/00?mc003o
K`00of/00?mf003oN000og400?mh000:0?mj00030?mk003oNP00ogX00080ogX000@0og/00?mj003o
NP00og`00P3oNP000`3oP@00ogl00?n400040?n:0080oh/00100oiD00?nI003oV@00oi/00?nT003o
Z000oj/00?ng003o_000olP00?oI003glP00bo@=06kR@`2Q@U40nP0=0`3o00000`3o00T0mP0=0?l0
000c0?l000030;AA<@1T`bX0lPL=00D0o`0000`0l@<J04;;A`3Co`00o_400?o@003o^000ojP00?nK
003oT@00ohX00?n5003oN`020?mj00050?mf003oL@00ofd00?m[003oK000103oJ`070?mL00Gooooo
0Ol00001ooooo`001oooool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool0
00001?ooool00ol0003oooooooooo`02oooooaP0od`000<0odd00?m<003oC0003P3oC0000`3oC@00
oe/00?mL000G0?mL00030?mN003oG000oe`000@0oe`000<0oed00?mU003oG0000`3oG0000`3oI000
of/00?m[00080?m[000=0?m/003oJ`00of`00?m]003oJ`00og<00?m[003oL@00ogL00?m_003oN@00
ogX00?mg000D0?mj00060?mk003oNP00og/00?mn003oNP00oh801@3oRP020?n;000C0?nD003oV@00
oiT00?nL003oX`00ojP00?n/003o]`00okX00?o3003obP00omT00?o[003io@00Y_DB05K_6P26>gD0
l@0_0>T26P0h0?l00003052HD`3o0000o`0000D0o`0000/0>N=20:Ko0`2OoPP0knL00?na003oX@00
oiT00?n>003oRP00ohD00?mm00030?mj00030?m^003oJ`00of/000D0of/000<0of000?mL003oG000
0P3oG0020?mM00Gooooo0Ol00001ooooo`001Ol00002ooooo`04o`000?ooooooooooo`0000_ooooo
00?o0000ooooooooool00_ooool2o`0000?ooooo6@3oC0000`3oCP00odd00?m<000>0?m<00030?mE
003oG000oe`001L0oe`000<0oed00?mL003oG000103oG0001P3oH`00ofL00?mO003oG000oeh00?mZ
00P0of/000X0of`00?m[003oJ`00ofd00?m[003oMP00ofl00?mi003oN000ogT03`3oNP000`3oN`00
ogX00?mj00040?mj00040?mk003oNP00ogX00?mn0080ogX000<0ohL00?n4003oR@001@3oRP005@3o
R`00oi800?nH003oV@00oi/00?nT003oZ@00ojh00?nj003o_`00olH00?o<003oe@00on000?ob003e
oP00f_l00:So001biP00LH`^0<`X?@0h0?l000030?8=3@3M52H0o`0000@0o`0000d0jPPJ081QM01B
_DP0PNL]0>SE0@3o[P00oil00?nI003oS000ohX00?n6003oNP00og/00080ogX000<0ofh00?m/003o
K0001P3oJ`00103oI`00ofD00?mS003oH0020?mL00Cooooo0_l00001ooooo`001oooool01?l0003o
ooooooooool0000;ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_oooolJ0?m<
00030?m=003oCP00odd000d0od`000<0odh00?mL003oG0005`3oG0000`3oG@00oeh00?mL00040?mL
00030?mM003oJ`00of/000`0of/000@0ofd00?m[003oL`00og@05@3oNP001@3oN`00ogX00?mk003o
NP00og`00080ogX000D0ogl00?mj003oP@00oh<00?n000060?n:0080oh/001@0oi800?nH003oV@00
oi/00?nT003oZP00ok<00?nn003Dh@P0g]d=0?CU003ogP00on400?C`003Nl@H0Q=lg09Ko2`2YEVh0
/T<X0?0;9400o`0000`0K7IP07?M?P1ooa<0dO000?no003oZ@00oi/00?nI003oS000ohX00?n9003o
O@030?mj00030?mi003oKP00of/000H0of/000<0ofX00?mO003oG0000`3oG005ooooo`7o00000Ooo
ool000Oooooo00Co0000oooooooooooo00001oooool4o`0000Gooooo00?o0000ooooooooool00_oo
oolL0?m<00030?m>003oD000od`000`0od`000<0oeX00?mL003oG0005`3oG0000`3oGP00of000?mL
00040?mL00030?mW003oJ`00of/000D0of/000T0of`00?m[003oJ`00of/00?m]003oJ`00og000?me
003oN@003P3oNP000`3oN`00ogX00?mj00050?mj000:0?ml003oNP00ogd00?mj003oO@00og`00?mj
003oR@00ogl00?n600L0ohX001H0oh`00?n:003oTP00oiP00?nJ003oV`00ojH00?n_003o_@00ol@0
0?oK002XhBH0?nli0=gn003ol@00oo<00;?^8`2EE5h0@WS6076b8`3<;al0lPH=?@3o00003@3<9Rh0
fBHT0<LS@`1nJE80?=1c0;GU7P3ni@00olT00?nc003oZ000oi`00?nI003oS0000P3oRP001P3oP000
og/00?mj003oNP00ogD00?m[0080of`01@3oJ`000`3oH@00oe`00?mL00030?mL00Gooooo0Ol00001
ooooo`001oooool01?l0003oooooooooool00007ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool00_oooolM0?m<00030?m=003oD@00odd000/0od`000<0oeP00?mL003oG000403oG002
0?mM00H0oe`000<0of400?mR003oG0000`3oG0000`3oJP00of/00?m[00070?m[00050?m/003oJ`00
ofd00?mc003oMP000`3oNP001P3oN`00ogX00?mm003oO@00ogX00?mk00<0ogX000<0ogh00?mj003o
O@000`3oNP003@3oO@00ogX00?mm003oNP00ogl00?mj003oPP00ogX00?n6003oO`00ohH00?n8003o
QP002@3oRP00103oS000ohX00?nC003oU`020?nI000@0?nQ003o[P00h=d809gi603Ql@L0K_5006WF
B01NfD/0eOl00>3V4@3^o`00co8004:XR03W0BX0aRI30?l01cl0o`000100KhdW077R7`2ho`00lOd0
0?oX003od@00ol000?na003oZ000oi/00?nI003oS`00oh/00?n:003oQ000og/00`3oNP000`3oMP00
ofd00?m[00050?m[00030?mQ003oG000oe`000<0oe`01Oooool1o`00007ooooo0008ooooo`;o0000
2?ooool5o`0000Cooooo00?o0000ooooooooool00_oooolO0?m<00030?mD003oD000od`000T0od`0
00<0oe/00?mL003oG0004@3oG0000`3oG@00oeh00?mL00050?mL00050?mX003oI`00of400?mP003o
I`002P3oJ`00103oK000ofd00?m[003oN0020?mj000:0?mk003oO`00oh@00?n6003oQ`00ohH00?n4
003oP`00oh400?mk0080ogl000/0ogX00?mo003oNP00oh000?mj003oP`00og`00?n6003oP@00ohT0
0?n6000=0?n:00<0oh/000<0oh`00?nB003oV0000P3oV@003`3oW000ojT00?na003Sf@L0VO@A05Kb
6@0b^HL0A[=?06_b2P1OiRT0NX]U07k3>02clP00L[HD0=4V:P110?l0000A0>H@6P2dIQl0`O8;0>Gl
1P3oi@00om400?o2003o/`00ojP00?nN003oV@00oiH00?n;003oRP00ohP00?mn003oN`000P3oNP00
103oL000of/00?m/003oK0040?m[00060?mZ003oH`00oel00?mO003oH@00oeh01Oooool1o`00007o
oooo000Kooooo`03o`000?oooooooooo00;ooooo803oC0020?mG00030?m>003oC000od`000D0od`0
00<0oe<00?mL003oG000303oG0000`3oG@00oe`00?mL00040?mL0080oeh01@3oG0000`3oHP00of/0
0?m[000:0?m[00040?m]003oJ`00of/00?mc00@0ogX000H0oh800?n=003oT@00ohh00?n<003oR`04
0?n:0080ohT000D0ohH00?n9003oQ@00ohT00?n8000?0?n:00080?n;003oRP00ohX00?n:003oR`00
ohX00?n?003oT0030?nI000?0?nK003oX@00ojP00?ne003ob000Uo`A04kC@`0c[H00EH:C0;<oB@1]
KG<0]be608Z09`0lkc00kPdD04<0o`0000`0c2TW07f;@02OYV00oOD00?kZ003bd@X0okP00?nZ003o
Y@00oiX00?nI003oTP020?n:00030?n3003oN`00ogX00080ogX000<0og400?m/003oJ`001P3oJ`00
103oI`00oel00?mL003oG005ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool00_oooolQ
0?m<00040?mE003oG000oeP00?mA00<0od`000<0odd00?mB003oG0005P3oG0000`3oH@00oeh00?mL
00030?mL00030?mP003oJ`00of/000/0of/000<0og000?m_003oM0000`3oNP002@3oO`00ohX00?nR
003mbP00oj800?nI003oU@00oi800?n<000D0?n:000;0?n<003oRP00ohX00?n;003oRP00oh/00?n<
003oRP00ohh00?n?003oU@000`3oV@003`3oVP00oih00?nW003oZ@00okL00?o8003>h1X0RoTG04;b
:`19W700fATb0?l0103o0000mP0J09E?@@150?l0000?0>HB601YfCT0`o8D08SI>P31k`L0ol400?nb
003oZ@00oj800?nJ003oV@00oi800?n:003oR@00og`00080ogX000D0ogT00?m/003oJ`00of/00?m/
00040?m[00030?mW003oG000oe`00080oe`01Oooool1o`00007ooooo000Kooooo`03o`000?oooooo
oooo00;ooooo3P3oC0000`3oC@00od`00?m<000A0?m<00040?mG003oG000oe`00?mL0080oeT000<0
oe/00?mL003oG0003`3oG0020?mM00H0oe`000<0ofL00?mP003oG0000P3oG0000`3oH`00of/00?m[
00080?m[00040?m]003oJ`00of/00?m/00@0ogX000d0og/00?n5003oRP00oil00>CS003oa@00okD0
0?nX003oY000oiP00?nB003oS000oh/00080ohX000<0oh/00?n:003oR`000P3oRP001@3oR`00ohX0
0?n;003oS`00oi400080ohl000X0ohd00?n;003oR`00ohh00?n=003oRP00ohd00?n:003oT@00oh`0
0P3oU@040?nI000<0?nJ003oV`00ojL00?nX003o[000okP00?o6003of000`NTO0<;b3@0jfDT0YdE0
0`3o00000`3I62H0o`000?l000130?l0000@0?8<3@23QBD0NWY@06EPS01ZfT`0old00?ni003o[`00
ojP00?nV003oXP00oid00?nD003oRP00oh@00?mk0080ogX000<0ogH00?m^003oJ`001@3oJ`000`3o
H000oe`00?mL00020?mL00Gooooo0Ol00001ooooo`006oooool2o`0000?ooooo3`3oC0000`3oC@00
od`00?m<000@0?m<00030?m=003oF`00oe`001H0oe`00P3oG@050?mL00050?mP003oJ`00ofL00?mR
003oI000203oJ`00103oK000of/00?m[003oJ`030?m_00<0ogX00100og/00?mm003oR@00oh`00?nN
003i`P00l^L00>;]003^i`00ok/00?nN003oV@00oiL00?nB003oS`00ohd00P3oS0001@3oS@00oh/0
0?n=003oT@00oi@000H0oiT000T0oiP00?nE003oU`00oiD00?nC003oU`00oi@00?nI003oV0001@3o
V@020?nJ000<0?nV003oZ000ojT00?nc003o^@00olH00?oE003ok000lOh007F4P`2KD4h0o`0=B@3o
00003`3Y31X0nP0=07f0F@2Zk1<0om@00?o3003o^P00ok@00?n`003o]`00gMH80?n/003oS`00ohT0
0?ml00020?mj00030?md003oJ`00of/000D0of/000<0ofL00?mM003oG0000P3oG004ooooo`;o0000
0Oooool001_ooooo00?o0000ooooooooool00_oooolA0?m<00030?m=003oC000odd000l0od`000<0
oe800?mL003oG0005P3oG0000`3oG`00oed00?mL00040?mL00030?mZ003oJ`00of/000h0of/000<0
ogH00?mj003oNP000P3oNP00303oN`00oh800?n:003oS000oi/00?n/003oa000io800?SW003o^@00
ojL00?nM00<0oiT00P3oV0020?nG000:0?nH003oV@00oiT00?nJ003oW000ojD00?jh003oYP00oil0
0?nK00d0oiT00P3oVP003P3oY@00ojP00?nY003o[@00okL00?nm003ob`00omd00?o`003fo`00a_l0
08SV5019[4l0YT1?B@3o00003P2TES40/]T?0?Oj003oh`00omD00?o9003o`P00ol000?o;0038lP80
km850?nH003oR`00oh800P3oNP000`3oN@00og000?m[00060?m[00040?mZ003oI`00of<00?mQ00Go
oooo0Ol00001ooooo`006oooool00ol0003oooooooooo`02oooooa<0od`00`3oC@0>0?m<00030?mK
003oG000oe`000l0oe`000<0oed00?mL003oG000103oG0000`3oH`00oed00?mL00030?mL00030?mY
003oJ`00of/000L0of/000P0of`00?m[003oJ`00of/00?m_003oK@00of/00?mf00@0ogX000l0og`0
0?n6003oRP00ohl00?nK003oZ`00oLT00=KE0`39mP00ol400?n]003oY`00oj400?nI003oVP001@3o
V@020?nJ00090?nQ003oZ000okP00=7e003n`P00ojh00?nV003oX000oi/00080oiT000<0oiX00?nI
003oV@00103oV@000`3oVP00oi`00?nN00030?nX000;0?nZ003o]`00okX00?o9003ng`00Un0e0;Co
1P3To`00];hZ05ng?`2o<380BP3o00003P3V3`d0P45a0<Wo3`3hn`00WO460=[M4@3og@00omP00=W/
2P2ToPd0d>`00?nN003oRP00oh@00P3oNP000`3oN@00ofd00?m[00020?m/00@0of/000@0ofT00?mO
003oG000oe`01Oooool1o`00007ooooo000Kooooo`03o`000?oooooooooo00;ooooo5@3oC0020?m>
00030?m=003oC000od`000X0od`000<0oeP00?mL003oG000403oG0000`3oG@00oe`00?mL00030?mL
00030?mN003oJ@00oel00080oe`000<0of000?m[003oJ`002@3oJ`001P3oK@00of/00?m[003oJ`00
ogL00?mi00@0ogX002/0og`00?mn003oRP00ohX00?nB003oWP00ok000?o:003;o000mnl00?o7003o
]P00ojX00?nX003oY`00oj@00?nR003oX000oih00?nM003oWP00oj800?nW003oZ`00okL00?o;003_
n000X_TI0?o3003o[000ojT00?nW003oX`00oj400?nP003oWP00oid00?nL003oW@00oiX00?nP003o
XP00oj@000<0ojP000`0ojX00?ne003o^P00olL00?oO003AmP40Ii5[097o002jlP`0Q:hR0?l0003V
3AU;0?l0000=0;M;:`2do`00Mn0a07^oC@0c_7H0a_/<0?cg0025nb/0YMhK0?o3003oX000ohd00?n5
00030?mj00030?mc003oK@00of/000D0of/000@0of000?mL003oG000oe`01Oooool1o`00007ooooo
000Kooooo`03o`000?oooooooooo00;ooooo5`3oC0000`3oC`00oe400?m=000:0?m<00030?mJ003o
G000oe`00100oe`00P3oGP050?mL00040?mV003oJ`00ofP00?mW00d0of/000@0ofd00?m[003oJ`00
og<01P3oNP003@3oQ000ohX00?n:003oUP00ojH00?KC003Rl@00]_l50?c/003ocP00okh00?ng003o
/0000`3o[@000`3oZ`00ojT00?nX00020?nY000:0?nZ003o]`00lml00:Ck0`2SlPH0iO400?o9003o
^@00ok000?nZ00`0ojP000d0ojT00?nZ003o]000okP00?o2003Wi@00L]8m056QP@0JeG80OHa<08U?
HP1M]Al0bQY004`0o`0000h0cS0E06fV7P2c:dd0lPd704j9MP1boR@0aol005SXC`3Kn0<0om@00>j`
003oS`00ohL00?mk0080ogX000<0og000?m[003oJ`001@3oJ`00103oG`00oe`00?mL003oG005oooo
o`7o00000Oooool001_ooooo00?o0000ooooooooool00_oooolI0?m<00030?mE003oD`00od`000L0
od`000<0odh00?mL003oG0004P3oG0000`3oH@00oed00?mL00030?mL00030?mT003oJ`00of/000h0
of/000@0ofh00?mf003oL`00ogT0103oNP008P3oN`00oh400?n9003oRP00oh/00?nG003oZ000kmT0
0?SW0037o@00ZndR0?oN003ob@00ol<00?nm003o^P00okT00?o4003QbP00okH00?n`003o[`00ok40
0?nh003o`000oml007Wn;03XoP00onP00?o@003o``00okP00?nf003o/@020?n`00050?n[003oZ000
ojP00?nX003oZ@00103oZ000303oZP00ok<00?nh003o^P00olL00?oR001Pkd80:8^]0:m6@03_2A00
o`000=lK6dh0o`0000d0_Ce60?l0003o0000h04P09=:K@10jE@0>=iB08Co1P2XlQ40ok800?n?003o
Q`00ogh00080ogX000<0ogL00?m^003oJ`001@3oJ`00103oJ000oeh00?mL003oG005ooooo`7o0000
0Oooool001_ooooo00?o0000ooooooooool00_oooolJ0?m<00040?mA003oFP00oe@00?m>00@0od`0
00<0odh00?mJ003oG0003@3oG0000`3oGP00oe`00?mL00030?mL00030?mM003oI@00oed000<0oe`0
00<0ofD00?m[003oJ`002`3oJ`001@3oK@00of/00?m[003oJ`00ogL000D0ogX00P3oN`003P3oO`00
ohX00?n:003oR`00oiP00?nP003o/P00olH00>Ka002mo`@0o^h00?oK003oe@00iml30P3oc`00103@
k`80jn`00?o6003o_0020?nh000A0?nn003obP00knX006oo3`37n@d0j?P00?OV003oe@00olT00?nm
003o^P00ok/00?nn003o`000okH00?nc003oZ`000`3oZ@000`3oZ`00ojl00?nd00020?nh00070?o0
003ob@00om`00=Sj0@1Y`540IimM0=TQ9P1@0?l0000<0?436P3o0000o`000?l0002S>FD0I[Ub04c/
>P2RoaH0m]400?nO003oS@00ohP00`3oNP000`3oL000of/00?m[00070?m[00030?mW003oH`3ooooo
00Cooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`02oooooa/0od`000@0odh00?mJ003o
G000oeX00P3oEP000`3oF000oe/00?mL000?0?mL00030?mN003oG000oe`000<0oe`000H0of800?mY
003oH@00oed00?mQ003oJP0:0?m[00080?m/003oJ`00of/00?m[003oL`00ofd00?m/003oN@060?mj
000F0?mm003oRP00ohX00?n:003oS000oiT00?nM003oZ`00okh00>_a002_o@@0ZolD0=Kl002ZoQ00
YOl60>Wd0@3okP00c?h00=Cg0`3oe`00old00?o:0080olT00100om@00?oV0032mPh0WOl6057o4`2>
oQ80`_d00?gW003oc@00ol`00?oE003dj000d^d<0?o4003o^P00okP0103o]`030?nh00090?nm003o
aP00old00?oL003nmP00h?l00:CI1P1MSdL0c2/_04l0o`0000d0n`0=0?l0003o0000iQHL063V903>
oP40TOl10?GS003j]000oiT00?n:003oQ@00og/00080ogX000<0ogL00?m_003oK@001P3oJ`000`3o
I000oed00?mL0005ooooo`7o00000Oooool001_ooooo0_l00003oooooa`0od`000<0odd00?mI003o
G000503oG0000`3oG@00oeh00?mL00030?mL00030?mM003oJ`00of/000d0of/000H0of`00?m]003o
J`00of/00?m`003oN`040?mj00050?mk003oNP00og/00?mo003oP@000`3oRP009P3oS`00oiT00?nL
003oZ000ok<00?o8003mg`00d?DA0>[k002go`L0H?l907[V3`3>o`00Lo8?08K_:P3mm@00bOL00?WY
003oeP00omL00?oL003oj`00o?/00=oo001UoaX0?m1D04oP6P38o0P0onD00?oR002ln0/0LNhc09Cm
0`3oe@00olH00?no003o^P00okT00`3o^0002`3o^P00okh00?o7003ob@00omH00?oW002joB80R=TW
09cV3@2:CgT0k00J04l0o`0000d0iQXG08j0602CGUT0GYiF03oVA@3Vj@`0ol`00?n_003oWP00oi<0
0?n:003oQ000og/00080ogX000<0og000?m[003oJ`001@3oJ`00103oJ000oe`00?mL003oG004oooo
o`;o00000Oooool001_ooooo00?o0000ooooooooool00_oooolM0?m<00030?m>003oF`00oe`001@0
oe`000<0oel00?mQ003oG0000P3oG0000`3oG@00of/00?m[000:0?m[00080?m/003oJ`00of/00?m[
003oL000ofd00?m[003oL0060?mj00030?ml003oN`00og/000<0ohX001<0oh`00?nB003oV@00oiX0
0?nW003o[P00okT00?o6003oe000on<00?Ck002?o`@0G=lY027XAP0VkCT0VOl40=Oo002@o`00nOX0
0080on`001l0oo000?kg003^o`00e?l008Go000efSh0<k6507oY9`3]o000no/007cY=01ioaP0h_4=
0?oR003odP00olX00?o6003oa@00ol400?o0003o`P00olD00?o7003ob000om800?oR0036nQ40J[AR
05>eAP1NXTl0[c@l0540o`0000/0Qha;0;_k3@3^nP00l>@40?o6003o/`00oj@00?nI003oS@00ohX0
0?n200030?mj00030?mi003oL000ofd000D0of/000@0ofP00?mL003oG000oe`01Oooool1o`00007o
oooo000Kooooo`03o`000?oooooooooo00;ooooo7P3oC0000`3oD`00oe`00?mL000>0?mL00030?mN
003oG000oe`000<0oe`000D0ofH00?mT003oG@00oed00?mU000=0?m[00070?m]003oJ`00of/00?m[
003oN@00ogL00?mi00040?mj00050?mk003oNP00ogX00?n0003oR0000`3oRP00903oS000oi@00?nI
003oVP00ojL00?nX003o]`00okd00?o:003ofP00n?800;[j402ko`00Hol103f>XP0ed5h0Kol0037P
H02[oaD0m_h00<Sa402ko`T0k?l009Cc=P1>nal0BJF40:llA@2>CF/0>MAH0<ko003Ro`00`?l007So
0`1?kDL0_O`;0?oU0080omd000<0oll00?o9003oa`000P3oa`002@3ob@00om400?oH003ok000H^/e
071GP`347dX0o`000>DB9P1A0?l0000?0=LN7`2XlQ80hMhJ0?o@003o_@00oj`00?nP003oV@00oh`0
0?n:003oP000ogX00?mk003oNP00og0000P0of/000<0of@00?mN003oG0001Oooool1o`00007ooooo
000Kooooo`03o`000?oooooooooo00;ooooo2`3oC0020?m=0140od`000<0odh00?mL003oG000203o
G0000`3oG@00oe`00?mL00040?mL00030?mO003oG000oe`00080oe`000<0of400?m[003oJ`002`3o
J`001P3oK000of/00?m[003oJ`00ofd00?m`0080of/000<0ogL00?mj003oNP001@3oNP000`3oN`00
ogl00?n100020?n:0080oh/003<0oh`00?nI003oV@00oi/00?nX003oZ@00okL00?nk003oa`00omP0
0?o[003fo@00^_l003oN>`2h6eT0[2UO08iQEP1WOG80JOl20=3o002Uo`X0H=M807gV8`2OlPd0F>X@
09=?L03o0000o`0=08EhAP1[o`H0S_l<09[b201GlQ<0:<Yh05^hG@3co@00Zod<08G/=@3oi000omL0
0?oB003od000om400?oF003oe`00on000?o^003Qn`d0U>HB06b6G@3<92/0DP3o0000203<:Bd0`bQ:
0:gM=P3od@00ol000?n_003oX`00oiP00P3oRP002@3oP000ogX00?mj003oNP00ogP00?m`003oKP00
of/00?m/00050?m[00030?mZ003oIP3ooooo00Cooooo0Ol00001ooooo`006oooool00ol0003ooooo
ooooo`02ooooo`h0od`00P3oC@000`3oCP00odd00?m<000<0?m<00/0oe`000<0oed00?mL003oG000
0`3oG0000`3oGP00of<00?mL00020?mL00030?mQ003oJ`00of/000`0of/00P3oK0020?m[00030?md
003oMP00ogD000@0ogX000H0og/00?mj003oNP00og`00?mj003oQP050?n:000?0?nF003oV@00oiX0
0?nO003oZ000ojX00?ng003o_@00olX00?oO003nl`00f?l005Kd;`0df4H0b2E60080o`000280cBHX
04B`O029j0l0O>l@03W:HP2g<T80DKlc05f[:02>GTl0o`000>d46P0o[WD0GY]C085_H`0TlSL0VcUP
0=L:@014fU@0_ol003[/D02Uo`d0o_@00?oT003og000omT00?oG003of@00oml00?oW003nmP00bO@=
06VlA`1P/C<0lP`KDP3o0000203b3@h0P;lm0>[h3@3of`00olX00?g4003o[000oiT00P3oRP001@3o
O`00ogX00?mj003oNP00og4000P0of/000<0ofL00?mM003oG0001Oooool1o`00007ooooo000Koooo
o`03o`000?oooooooooo00;ooooo4@3oC000103oC@00odh00?m?003oC@090?m<00030?mB003oG000
oe`000X0oe`000<0oed00?mL003oG0000`3oG0001@3oI000ofL00?mP003oH000ofT000P0of/000@0
of`00?m[003oJ`00of`00`3oJ`00103oL@00of`00?m[003oL`070?mj00040?mk003oNP00ogl00?n7
00<0ohX00P3oR`003`3oT`00oiT00?nJ003oV`00oj@00?nY003o[P00okT00?o0003od000e?L40:7o
102=lPd04>5f09XbL`040?l00006066KC@16bR`0Zc9G091DB@3j00d0iQ0J1P3o0000503b3AL0_bQ1
0>H96P3j00d0B;=G083V4`1Doa<0@kmL0<on003km`00o^h00?oV003oi000onH00?oW003ol@00god4
09:?AP2Q?UD0iQX@D`3o00002`3h00d0UJ/a0:[V6P3Ml0h0on<00>_b003]d`00oid00?n<003oRP00
ogh000<0ogX000<0og@00?m]003oJ`001P3oJ`000`3oG@00oe`00?mL0005ooooo`7o00000Oooool0
01_ooooo00?o0000ooooooooool00_oooolD0?m<00040?m@003oE000oe400?m>00D0od`000<0odl0
0?mK003oG000303oG0020?mN00<0oe`000<0of000?m[003oJ`003P3oJ`001`3oKP00of/00?m[003o
L000ogP00?me003oN@001P3oNP00103oN`00ogX00?n3003oQ@030?n:00040?n;003oRP00oi800?nH
0080oiT000`0oih00?nX003oZP00okL00?nl003oaP00om800?c/0035lQ80^Ol007So3P1WQWd40?l0
0003085VI@3R6RD0o`0900`0o`000140i`PM0<L^=@1_Led0VE/o07YFT@2;iRL0F]Pd0<Cn1@3ol`00
onh00?o]003ol`00oOT00>go002Z_aL0PX9A0?8=3@1C0?l0000;0>HB6P2mC@/0V5ML06CGD@37lA@0
ONX/0=OG0`3oW@00oh`00?n:003oO0000`3oNP000`3oL`00ofd00?m[00060?m[00030?mN003oG000
oe`000Gooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`02oooooaH0od`000@0oe000?mI
003oF`00oeP00P3oEP000`3oF@00oe`00?mL00080?mL00030?mM003oG000oe`000<0oe`000D0of80
0?mQ003oG000oe`00?mQ000:0?m[00040?m/003oJ`00of/00?m]0080of/00P3oL0000`3oJ`00og80
0?mj00060?mj00050?mk003oNP00og`00?n0003oR000103oRP000`3oS000oi@00?nH00020?nI000>
0?nM003oY`00ojT00?ng003o_000olD00?o;003of000on/00?ck003Po`00J^P/033RF02c@c@20?l0
00030?l01@3o0000o`000100o`0000h0lP<=08UPE`1RfA<0<==I0;K^6P3foP00oOT00?kh003mnP00
n_l00>;o001nXfT0LgM10?853EH0o`0000P0Fha]05WD@@36m1<0oL@00?nJ003oR`00ohT00?ml00<0
ogX000<0ofh00?m[003oJ`001P3oJ`000`3oJ@00of400?mL0005ooooo`7o00000Oooool001_ooooo
0_l00003oooooaP0od`000<0oe<00?mK003oG000203oG0000`3oG@00oe`00?mL00030?mL00030?mN
003oG000oe`00080oe`000@0ofT00?mW003oI@00ofX02P3oJ`000`3oK000of/00?m[00020?m]0004
0?m[003oK`00ogX00?mh00@0ogX000<0og/00?mj003oNP000P3oNP020?mo00@0ohX000<0oh/00?n@
003oU`000`3oV@004@3oV`00ojD00?nX003o]000olT00?oA003odP00omT00?oW003nl`00i?h;0=3o
002So`00FO8;02g5DP2K?fD0o`0;01@0o`0000`0lPL=0;LjA@2b@D@0Qk1607SG?P3[o`00mol00?Ko
003^o`00[NdB08iTK@3o01MD0?l0000;0>H;6P3I6AX0/dD`08fU=P0QhFD0X>/[0?^g003oU`00oh/0
0?n8003oN`000`3oNP000`3oMP00ofh00?m[00080?m[00030?mW0?oooooooooo00;ooooo0_l00001
ooooo`006oooool00ol0003oooooooooo`02oooooaT0od`000<0oe000?mK003oG0003@3oG0000`3o
G@00oel00?mL00020?mL00030?mW003oJ`00of/000H0of/000@0of`00?m[003oJ`00of`00P3oJ`00
1P3oKP00of/00?m[003oN000og400?mf00T0ogX000<0ogd00?mk003oP`000`3oRP000`3oR`00oi00
0?nG00040?nI000@0?nN003oYP00ojP00?n/003o_@00hO000:[l2@3nk`00o_000=;`3@3Ho`00aol0
083<8@2>Pdl0RF9O0>HH:aP0o`0000X0c20[05FX=@1TdeL0dol00>Co003Wo`00g_l00;ko001iUBP0
c2hcE03o00002P3k00d0Q[De0:W37@3HiQ40g^D00?k0003oX000oi800?n:003oQ0040?mj00T0of/0
00<0ofP00?mN003oG0001Oooool1o`00007ooooo000Kooooo`03o`000?oooooooooo00;ooooo6P3o
C0000`3oE000oe`00?mL000=0?mL00050?mP003oH`00oe`00?mM003oJP002`3oJ`001P3oKP00of/0
0?m[003oM@00of`00?m^00X0ogX00P3oN`000`3oNP00ohX00?n:00020?n:00030?n;003oT`00oiT0
0080oiX000<0oi`00?nM003oX`000P3oZ0003@3oZ@00okD00?nn003bi`00MOl70;ko2@2ana@0S_<R
03G]CP29o`<0AmA20<XU@03_1Q006P3o00002@3_2aX0R71E06k2BP3?o`00eol00=7o0027ib00VU1E
0?l0101D0?l0000:0=lP4`1V/ED0no400?oB003o^`00ojH00?nJ003oS@00ohX00?n20080og/00P3o
NP000`3oM@00ofd00?m[00060?m[00030?mO003oG000oe`000Gooooo0Ol00001ooooo`006oooool0
0ol0003oooooooooo`02oooooaX0od`000<0odd00?mL003oG0003P3oG0000`3oJ@00ofX00?mZ000:
0?m[00060?m]003oJ`00ofh00?m`003oJ`00ogL00P3oN@030?mj00030?mk003oNP00ogX000<0ogX0
00@0og/00?mj003oP`00oh@00`3oRP001P3oR`00oi800?nI003oY000ojT00?nW00@0ojP000d0ojX0
0?nc003o^@00ol<00?oG003dm000__l?057n=P16W7l0Ci:309UCF`1HXd00e1`/01`0o`0000L0]ChY
08n0E02Qoa00`ol00;oo002?hal0Z41=05D0o`0000L0fBDN0:_L3@3nl@00omH00?nb003oX@00oiL0
0080ohX000H0oh000?mj003oNP00ogX00?mi003oK`020?m[00030?m/003oJ`00of/000<0of/000<0
oeh00?mL003oG0001Oooool1o`00007ooooo000Kooooo`03o`000?oooooooooo00;ooooo6`3oC000
0`3oFP00oe`00?mL00090?mL0080oeh00P3oG0000`3oJ000of/00?m[00080?m[00070?m]003oJ`00
og800?m]003oL000ogX00?mi000:0?mj00050?mk003oNP00oh400?n1003oR0000`3oRP00203oR`00
ohl00?nH003oW`00n/H00>cJ003oa`00okL00P3o/0003@3o/@00okL00?nh003o_000olL00?oF003o
jP00n?/008Cn6`0IjU@0j`de0?l0003N4RD07P3o00001P2EBe00L[=A0:[o002Yo`00R]T60;=3@5D0
o`0000X0bRTK08=iAP39oP/0^_h10?ni003oW000oi400?n:003oR@00ogd00`3oNP000`3oM`00of/0
0?m[00070?m[00030?mW003oG@00oe`000Gooooo0Ol00001ooooo`006oooool00ol0003ooooooooo
o`02ooooo`<0od`000<0odd00?m<003oC000503oC0000`3oCP00oe`00?mL00060?mL00030?mM003o
G000oe`00080oe`00`3oIP060?m[00080?m/003oJ`00of/00?m]003oJ`00og400?m_003oM@0:0?mj
00070?mk003oNP00og/00?mk003oOP00oh400?n400050?n:00090?n=003oV000oiT00?nT003o^000
hNl00=gg003oc@00okd00080okT000/0okd00?o3003oaP00olh00?oJ003oj`00nO`00=3o001/lQL0
WFHa0=TE9P0P0?l00005079cLP1oo`00S_l008bV9P3A9Bl0E@3o00002P3V4aH0_RDf04?JC@2gg1D0
ojl00?nJ003oS`00ohX00?n8003oO0030?mj00030?mi003oL`00ofh000P0of/000<0ofX00?mV0?oo
ool01?ooool1o`00007ooooo000Kooooo`03o`000?oooooooooo00;ooooo2`3oC0020?m=0080odh0
00<0odd00?m<003oC0001`3oC0000`3oC@00oeP00?mL00080?mL00050?mM003oGP00oe`00?mL003o
H@002@3oJ`001@3oK@00of/00?ma003oLP00ogH000P0ogX000T0og/00?mj003oNP00og/00?mj003o
O000ogX00?n5003oQ0001P3oRP005`3oSP00oiT00?nI003oW000ojP00?nl003Tl`00VOd90>S[3@3o
c@00olL00?o6003ob@00oll00?oC003of@00onD00?7]303Po`00ZO8E05G^4@1VHV/0lP@=0200o`00
00@0db0/07j_401_o`00I[`SE@3o0000303m00d0TZHG06KRAP1bdF@0d]T90?nS003oV000oh`00?n:
003oP`00ogX00?mk0080ogX000<0og000?m[003oJ`00203oJ`000`3oI000oeh0ooooo`04ooooo`7o
00000Oooool001_ooooo0_l00003ooooo`l0od`000D0odh00?m?003oD@00oe400?mD00040?mB0003
0?mE003oF`00oe`000D0oe`000<0oed00?mL003oG0000P3oG000103oGP00of@00?mQ003oI`070?m[
00050?m]003oK000ofl00?mc003oMP001`3oNP00203oN`00ogX00?mj003oN`00ogd00?mk003oP@00
ogh00P3oR0050?n:0080oh/001L0ohl00?nG003oV@00oiT00?nR003oZ000okX00?oF002_oP80go/0
0?oR003of000omD00?oK003@mP40mo000?oY003olP00h?l607ko500kYW/0/SIC0>8J700R0?l00004
07mPHP13o`00Bk0l0?h03E@0o`0000/0_TLJ0;SF;P3nk@00ol<00?n[003oV`00oi<00?n;003oRP00
oh000?ml00030?mj00030?mf003oKP00of/000L0of/000<0of800?mL003oG0001?ooool2o`00007o
oooo000Kooooo`03o`000?oooooooooo00;ooooo4`3oC0000`3oC@00oe400?mH000<0?mL00050?mM
003oG000oe`00?mL003oI000203oJ`00103oK@00of/00?mh003oMP060?mj000:0?mk003oO000og`0
0?mm003oO`00ogd00?n4003oP`00ohP00?n900H0ohX000D0oh`00?n;003oR`00oi@00?nH00020?nI
000C0?nN003oY`00oj/00?nh003obP00o^P00;cn0@3RnP00koH00?o/003nl`00TOl90>Kn003ln`00
nOd00>Wo0032o`00Ao<T0:PiG`0S0?l000030?8=4@0ViPP0NX0O05D0o`0000/0h`dU07jdC`2UhB80
okH00?nQ003oV@00ohd00?n:003oR@00ogl00?mk00030?mj00030?md003oKP00ofd00080of/000<0
of`00?m[003oJ`000P3oJ`000`3oG@00oe`00?mL0005ooooo`7o00000Oooool001_ooooo00?o0000
ooooooooool00_oooolF0?m<00030?m>003oE`00oe`000X0oe`000@0oeh00?mQ003oG`00ofL01@3o
J`001@3oK000ofh00?m]003oM000ogP000D0ogX000D0og/00?mn003oQ@00ohL00?n800030?n900X0
ohX000@0oh`00?n=003oT@00oiP00P3oV@005@3oVP00oih00?nW003oZ000ok800?ni003ob@00om/0
0?Og001QnRH0X_l90=Kn0`3[o`00VOLJ0:7b7`2om@`0dol00=Co001jo`l0Q6eY0=TU7@0T0?l00003
04^V@@1oP3L0o`0005<0o`0000/0lPd:09>a:P0od7D0hmX60?nZ003oVP00oiL00?n<003oRP00ohP0
0?mk00040?mj00030?m/003oJ`00of/000L0of/000<0of@00?mL003oG0001Oooool1o`00007ooooo
000Kooooo`03o`000?oooooooooo00;ooooo603oC0000`3oE`00oe`00?mL00090?mL00030?mQ003o
J`00of/000<0of/00P3oK0000`3oL000og400?mj00040?mj00070?mk003oO000oh000?n6003oRP00
ohd00?n<00020?n;00D0ohX00P3oR`001`3oRP00oh`00?n>003oT000oi800?nE003oV0000P3oV@00
0`3oVP00oi`00?nR00020?nX000B0?n^003o]`00ol000?o<003og000h_X007?_:`1FoR`0G_hW09?o
1P1Rebh0?mln05WL=P2Ko`00X?h>08cb001MU4d0n00=903o00000`2SEeD0O81Q0?l0001C0?l0000;
0;h_:02fo`P0om800?nc003oX@00oiT00?n@003oR`00ohX00?n3003oO000103oNP00103oN000og00
0?m]003oK@070?m[00030?mW003oH@3ooooo00Cooooo0Ol00001ooooo`006oooool00ol0003ooooo
ooooo`02oooooaP0od`000<0odd00?mL003oG0001@3oG0001@3oG@00oe`00?mN003oG@00oel000@0
of/00P3oK@000`3oM000ogP00?mj00030?mj00040?mk003oO000ogl00?n60080ohX000L0oi000?ZZ
003oX@00oiP00?nD003oS`00ohd00080ohh000D0ohl00?nA003oU@00oiH00?nH00020?nI00030?nJ
003oV@00oiT00080oi/001H0oj000?nW003oZP00ojd00?nd003o^000okh00?o:003of@00onD00?[j
002io`X0FO8N03JNWP1HWf<0;JeT0:4`L01WQFd0FJMX04gb4@1Ho`40Q6iI9@3o00000`3I8bD0P6ml
0?l0001B0?l000080<9=502E[200Y=d_0?nh003oY`00oiX00?nH003oS0020?n:00030?n4003oN`00
ogX00080ogX000<0ogT00?m^003oJ`002@3oJ`000`3oJ@00of@0ooooo`04ooooo`7o00000Oooool0
01_ooooo00?o0000ooooooooool00_oooolI0?m<00030?mH003oG000oe`000L0oe`000<0of@00?m[
003oJ`000P3oJ`000`3oK000og800?mj00040?mj00040?mk003oP000oh@00?n80080ohX000L0oh`0
0?nC003oV`00okT00?[4003oXP00oi/000H0oiT000<0oi/00?nM003oWP000`3oV`00503oW@00oj00
0?nU003oY`00ojP00?n^003oa000ol<00?no003o`P00olX00?gS003Ln000o?T00>7o002Wo`80F_8=
085TM`3a2QX0oP0=0P3o0000103j00d0Vd]@01kb502[@38V0?l000030:@FIP3o0000o`000500o`00
00P0fb0=0;1?;P3Bg000okh00?n[003oX@00oiX00?nD00<0ohX000<0og`00?mj003oNP000P3oNP00
0`3oN000of/00?m[00080?m[00030?mU003oG000oe`000Gooooo0Ol00001ooooo`005?ooool2o`00
00Gooooo00?o0000ooooooooool00_oooolH0?m<00030?m=003oG000oe`000D0oe`000@0oed00?mL
003oG000of400`3oJ`000`3oKP00ogH00?mj00020?mj00040?mn003oP000oh@00?n900<0ohX000/0
oh`00?nB003oU`00oi/00?nU003o`000o=d00?nd003o[000oj@00?nQ00020?nM0080oj4000@0ojL0
0?ni003o]000ojT0103oZ000403oZP00ojd00?nc003o^`00ln800=ga003od`00om800?oH003oj`00
__8>0;Wo0035o`00Hol@052XH@3I7bH60?l0000307^0GP2d?U00o`0002D0o`0000<0o@0=0?l0003o
0000C`3o00002@3j00d0VILU0=O[403oa@00ok800?nW003oV`00oiT00?nA00020?n:00030?n9003o
OP00og/000@0ogX000D0ogL00?m`003oK000of`00?m]00050?m[00030?mM003oG000oe`000Gooooo
0Ol00001ooooo`004oooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo00;ooooo
5`3oC0000`3oC@00oeL00?mL00070?mL000;0?mN003oH@00of/00?m[003oK000ofl00?mi003oN`00
ogl00?n4003oR@000P3oRP00403oS000ohd00?nB003oU000oiL00?nJ003oV`00oih00?nW003o_000
oll00>[c003hhP00nLT00?n`003oZ`020?nZ000I0?n/003o[P00okL00?KM003ag@00ok`00?nf003o
]`00okP00?ne003o]`00okd00?o1003oc000onH00<kn003ok@00o^X00?k_003ln000h?l004kn6`1=
la/0:_lV081UH0070?l000030?893@3:5400o`0007H0o`0000L0kQ@30;Mm:`3df@00olT00?nh003o
ZP00oj@00080oiT000L0ohd00?n:003oRP00ohT00?mo003oNP00og/00080ogX000<0ogL00?m/003o
J`00203oJ`000`3oH000oe`00?mL0005ooooo`7o00000Oooool001?ooooo00Co0000oooooooooooo
00001?ooool2o`0000?ooooo5@3oC0000`3oCP00oe@00?mK000;0?mL000f0?mW003oJ`00ofd00?mg
003oP000oh`00?n@003oUP00oi`00?nK003oW000oil00?nQ003oX`00ojd00?n/003oZP00ojh00?nb
003o_000n^800<?k002_S1X0W/`@0?gP003oa`00ol800?no003o`@00mL`00?o6003oc@00kO000>gb
003od`00om000?oH003OhP00olh00?o=003oe`00m>/00?[Z003cn000Yol:0=Ko003Oo`00bol00<ko
002<o`P0?olQ079cOP2]@TT0bR8lO`3o00002`3B@140_/<F0?kX003od000okh00?nc003oZ000oj00
0?nI003oV000oh`00080ohX000<0ohD00?mj003oNP000`3oNP000`3oMP00of/00?m[00080?m[0003
0?mY003oH@00oe`000Cooooo0_l00001ooooo`004oooool01?l0003oooooooooool00004ooooo`03
o`000?oooooooooo00;ooooo4P3oE0020?mL00L0of0000<0of<00?mT003oI000103oI000=@3oJ000
ofl00?mc003oL`00ohD00;nR@02oX400_jA00<FJ@030Yd00d9@`0<BG@032VT00cYA00<jC@03gZCX0
j:8o0=bN@03QWd00jZ4`0?2X=P3M_000ZEli0?l0003_<0<0lK`H0?Bc>`3c]Bl0lZTn0?Fb;`3R^a80
n[LA0?bh5P2e_`H0aYl;0?Vj3`3g_@l0m;h<0=2n1P3^_@H0o[P00>Nn003O_`00c[l00<Ro001jP3@0
V;l709Bo4@1_ZS<0Vkl005>a:`1SLF/0k`D@07l0o`0000`0eB0P08VU4033o`00mO/00?oU003odP00
ol@00?ng003o[`00oj@00?nQ003oW@020?nB00030?nA003oS@00oh@000<0oh8000<0oh000?mn003o
O0001`3oL`001@3oL000ofl00?m_003oK`00ofh000Gooooo0Ol00001ooooo`004oooool01?l0003o
ooooooooool00004ooooo`03o`000?oooooooooo00;ooooo503oC0000`3oC`00oe400?mH000<0?mL
00090?mX003oJ`00ofd00?mi003oQ@00oi000?nE003oW000ojH00080oj4001L0ojD00?nW003oZ@00
okT00?ne003o/@00okD00?nh003o``00m^P009Wm8037FA@0Y:H@0?cV003ocP00olT00?o5003ob000
k]P00?o?003oe@00fo@00=gf00020?oJ000B0?kR003Gj`00o]X00?oE003oh@00k_<00?Cb003[n`00
QolC0<7o003>o`00]?l80;ko001^m1D0:o/h09Q=I`3P4bX0gADVOP3o0000303b10d0aG<A0=_N2`3o
i000olh00?nn003o/`00ojP00?nO003oV@00oiP00?n<0080ohX000<0ohD00?mj003oNP000`3oNP00
0`3oN000ofd00?m[00080?m[00030?mZ003oI000oeh000Gooooo0Ol00001ooooo`004oooool01?l0
003oooooooooool00004ooooo`03o`000?oooooooooo00;ooooo5`3oC0000`3oCP00oeX00?mL0008
0?mL00090?mQ003oJP00of/00?m/003oL000ogX00?ml003oPP00ohL00080oh/000D0oh`00?n?003o
T000oiD00?nG00020?nK000:0?nN003oX@00ojX00?o5003nf000doL60>k]003ic`00ok@00?n^0080
ojd000L0ojl00?na003o^`00mN800?3U003o_`00ok/00080okd00100okT00?nj003o`000olL00?o@
003oj000cOl00?kb003ll000nO@00?Kj003Jo`00E_l=037Z?`0IndD0TdmM203o00000`3G2c<0o`00
0?l0001e0?l000070<l/3P32XB80om<00?o6003o]`00ojT00?nS00020?nI00070?n<003oRP00ohX0
0?n:003oO`00ogX00?mk00020?mj00030?mf003oJ`00of/000P0of/000<0of400?mL003oG0001Ooo
ool1o`00007ooooo000Dooooo`;o00001Oooool00ol0003oooooooooo`02oooooaP0od`000<0odh0
0?mL003oG0001@3oG000103oG@00oeh00?mL003oH`030?m[00080?m`003oN@00ogX00?mj003oO000
oh000?n4003oQ`030?n:000<0?n;003oS`00oiD00?nH003oW@00ojL00?o2003kh@00okX00?n_003o
Y`00oj@00P3oX0020?nT00040?nZ003o`000okX00?n/0080ojT00180ojX00?nX003o[000ok000?nf
003o_@00m^@00=Kf003of@00omL00?oL003ok@00c?8>09Wn3@2go`00Hol@05FGLP3V5AT60?l00003
09ERG`2o>dX0o`0007L0o`0000T0k@dE0:2_8`3[h@D0ol000?na003oY`00oiX00?nI003oT0000P3o
RP000`3oR000og/00?mj00040?mj00050?mf003oL000of`00?m/003oK@001@3oJ`030?mL00Gooooo
0Ol00001ooooo`006oooool00ol0003oooooooooo`02oooooaT0od`000<0oeT00?mL003oG0001`3o
G0000`3oHP00of/00?m[00020?m[00050?m]003oM@00ogX00?mj003oN`000P3oNP000`3oO@00oh<0
0?n600030?n:00070?n=003oU@00oih00?nj003jbP00ojH00?nN00060?nI00030?nL003oX000oj40
00<0oih001<0oil00?nS003oY`00ojP00?nY003o/@00o<`00?o;003o`P00olD00?o=003liP00b?d0
0?Sl003Ko`00S_l2057b5@23HV/0oP0=00@0o`0000<0_C4k023V802h<bl09P3o00000`2l2UT0o`00
0?l0001@0?l000080<Pj3`2QMCP0f=D00?nk003oZP00oil00?nJ003oT`030?n:00030?n0003oN`00
ogX00080ogX000<0ogT00?m]003oJ`00203oJ`000`3oH`00oe`00?mL0005ooooo`7o00000Oooool0
01_ooooo00?o0000ooooooooool00_oooolI0?m<00030?mK003oG000oe`000H0oe`000<0oeh00?mP
003oHP00103oJ`00103oK000og000?mf003oN@040?mj000=0?ml003oO@00oh800?n8003oRP00oh/0
0?nC003j/@00ojP00?nI003oUP00oi800?n@00020?nA00040?nB003oU000oiL00?nH00<0oiT00P3o
VP006@3oV@00oi`00?nM003oX`00ojP00?n]003o/@00okL00?nh003o`@00old00?oL003oi`00nO/0
0<Go2P1Uo`00EHF?07UfJP1HNW40aaE709UEF@1gM7D0A]TV04co0@1[NfH09@3o00000`3V5QX0P69n
0?l0001B0?l000080<Y=202Md1l0_]lV0?ne003oY`00oiT00?nG003oS0020?n:00030?n2003oN`00
ogX00080ogX000<0ogT00?m/003oJ`002@3oJ`000`3oIP00of40ooooo`04ooooo`7o00000Oooool0
01_ooooo00?o0000ooooooooool00_oooolH0?m<00030?mD003oG000oe`000D0oe`000D0oed00?mL
003oG000oe`00?mO00040?m[0080of`000<0ofd00?ma003oM000103oNP020?mk00060?ml003oP`00
ohP00?n:003oT000ohl00P3oS0050?n:00080?n;003oS000oh/00?n?003oT@00oi800?nE003oU`03
0?nI000G0?nJ003oWP00oj@00?nX003oZ@00ok800?nh003o`P00olh00?oN003Rn`00MoHO03o`BP18
lDH0L?l<05KT6`0fafD0?^<o08Oo002@oPh0Q?8006N8D`3h00d0903o00000`2cBTL0P81O0?l0001B
0?l0000;0?8=2`39;a/0X_8A0?o:003o[`00oj000?nI003oS`00oh/00?n:003oP@001@3oNP00103o
N@00og000?m]003oK@070?m[00030?mZ003oI03ooooo00Cooooo0Ol00001ooooo`006oooool2o`00
00?ooooo5P3oC0000`3oC@00oe@00?mL000:0?mL00040?mN003oHP00of800?mX00D0of/00P3oK@00
0`3oL000ogH00?mj00050?mj00040?ml003oP@00ohL00?n900`0ohX000D0oh/00?n:003oS@00ohl0
0?nD00030?nI000E0?nK003oX@00ojL00?nX003o/`00okX00?o9003of`00moH005cc<P2Eo`T0`?l<
0>7o0025jbd0S?8Q0:c[5`38o`00col007Co3`2GGeT0iQPJ02@0o`0000<0EIUD07b0C03o0000D`3o
00002`3J6QL0S>@Z06GRFP3Wd0H0ojP00?nI003oU@00oh/00?n:003oR@00og`000@0ogX000<0ofd0
0?m[003oJ`001`3oJ`000`3oIP00oed00?mL0004ooooo`;o00000Oooool001_ooooo00?o0000oooo
ooooool00_oooolD0?m<00030?m>003oE000oe/000/0oe`000D0oed00?mL003oG000oe`00?mT0006
0?m[00040?m/003oJ`00ofl00?m/0080ogT01@3oNP00103oN`00og`00?mm003oO@030?n000030?n7
003oQP00ohT000L0ohX000@0oh`00?n;003oS@00oiL00`3oV@004`3oX000ojP00?n[003o^000olX0
0?oS0037o@40c_d00>Gk003ol000oOH009Wo2@3Qo`00n?d00?Gn003Vo`00__l004cd7P2X>EH08`3o
00000`3o00/0;]T;07R08@1D0?l0000<0?l00@3g00d0KIeV0:oW5@3o/`00oj000?nI003oS@00ohX0
0?n9003oOP00og/00`3oNP000`3oL@00of/00?m[00020?m[00030?m/003oJ`00of/00080of/000<0
oeh00?mL003oG0001Oooool1o`00007ooooo000Kooooo`03o`000?oooooooooo00;ooooo403oC000
103oCP00oe400?mA003oE@040?mF00030?mH003oG000oe`000D0oe`000<0oed00?mL003oG0000P3o
G000103oG@00ofH00?mT003oJ@070?m[00050?m/003oK@00ofl00?mf003oN0001P3oNP030?mk0007
0?mj003oO000ogh00?ml003oPP00oh400?n900060?n:000I0?n;003oRP00oi800?nH003oV@00oiX0
0?nS003oZ000okX00?oA002jo080e?`00?oW003og000omX00?oO002kn`40mO@00?o]003om000jol0
08co2@0hVXP0_bU;0>h=5`0R0?l000030:50CP0go`80HIL^05D0o`0000/0ZU@b0;?V9@3`iPd0okh0
0?nY003oV`00oi400?n;003oRP00ogl00?ml00030?mj00030?mh003oL@00ofd000L0of/000<0of00
0?mL003oG0001Oooool1o`00007ooooo000Kooooo`03o`000?oooooooooo00;ooooo2`3oC0020?m=
00@0odh0203oC0000`3oCP00oeX00?mL00080?mL00050?mM003oGP00oe`00?mL003oH@001`3oJ`00
1`3oK000of/00?m]003oJ`00og800?me003oN000203oNP002@3oN`00ogX00?mj003oO000ogX00?mm
003oN`00ohP00?n600040?n:00030?n;003oRP00oi000080oiT001<0oih00?nX003o_@00iO8009go
203Vl0d0om400?o9003ob000ol/00?oF003of@00om/00?oX003Ska80a_l;08Kb8@1Be2D0R3aQ0240
o`0000D0ga@U06^e9P1Wo`00BMDc0?h03@1D0?l0000:0?d03@22bB<0VNlQ09_I?03`c000oj400?nH
003oS000ohX00?n300@0ogX000<0og000?m[003oJ`001`3oJ`000`3oJP00of400?mL0005ooooo`7o
00000Oooool001_ooooo00?o0000ooooooooool00_oooolJ0?m<00030?m?003oG000oe`000H0oe`0
00<0oed00?mL003oG0000P3oG0000`3oI@00ofT00?mY00060?m[00050?m/003oJ`00of/00?m]003o
J`000P3oLP000`3oMP00ogX00?mj00080?mj00<0og/000@0og`00?mn003oQ@00ohL01@3oRP005P3o
S`00oiT00?nI003oYP00okP00>O/003Dm`40om400?o0003o_000ok/00?o0003oa@00olL00?oA003o
f`00ond00?Sm003Co`00K?l:06nI:P3<6C8P0?l0000509QIE01jlP@0R?l008VV9P3A9Bl0E@3o0000
2`3V4aH0US]K03O8KP2miPT0oj`00?nJ003oSP00ohX00?n8003oO000og/00080ogX000<0ogP00?mb
003oKP002@3oJ`000`3oJ03oooooooooo`03ooooo`7o00000Oooool001_ooooo00?o0000oooooooo
ool00_ooool30?m<00030?m=003oC000od`001D0od`000<0oeX00?mL003oG0002@3oG0001@3oGP00
of400?mL003oG000ofT000P0of/000L0of`00?m[003oK@00of/00?mc003oL000og8000`0ogX000D0
og`00?mj003oP@00ohD00?n900030?n:00080?n<003oTP00oiT00?nO003j`P00iND00?SD003o_@03
0?nd000<0?nh003o^@00okh00?o8003of000onX00?Wk002?oQL0=>550>/=BP3o0000jPDK7P3o0000
1P2_=T40GkiM0:;o002Uo`00T/`10;=3@5D0o`0000X0da`K09IJ>@2]oa<0Vo8F0?ni003oV`00oi40
0?n:003oR@00ogd00`3oNP000`3oN000ofd00?m[00070?m[00030?mY003oG`00oe`000Gooooo0Ol0
0001ooooo`006oooool00ol0003oooooooooo`02oooooa/0od`0403oG0000`3oJ000of/00?m[000:
0?m[00060?m]003oJ`00ofh00?mc003oK@00ogP01@3oNP000`3oN`00ogX00?mj00030?mj00040?ml
003oNP00ohD00?n700<0ohX000<0oh/00?nC003oV`000P3o[`000`3oZ`00ojT00?nX00020?nX000=
0?n/003o]@00okT00?o3003oe@00o?000>Cn001ZoRX0?Yn<07mQLP2j;4l0NGe40?843@0L0?l00007
0<lU902KHUD0SNPY0;oo002ko`00S=HU0<4[>`1E0?l000070=0b7P2Lm`d0oO<00?_O003o/P00oj00
0?nE00020?n:00060?n0003oNP00ogX00?mj003oN000of`0203oJ`000`3oG`00oe`00?mL0005oooo
o`7o00000Oooool001_ooooo00?o0000ooooooooool00_oooolJ0?m<00030?mB003oG000oe`000d0
oe`000@0oeh00?mW003oGP00of002P3oJ`000`3oK000of/00?m_00020?m[00030?me003oK`00og40
00X0ogX000<0og/00?ml003oNP00103oRP00203oS@00oiD00?nI003oV`00oid00?nP003oX@00ojH0
0P3oZ000303oZP00okH00?o0003ch`00T_l7097o701jnbP0IN/d02?[FP1bka<0?N4X0;@nEa`0o`00
00P0NX0l0672DP3;o`00dol00<go0028ma@0OFYJ0?l015@0o`0000`0ka0=07N5I@3ll000om000?nh
003oY000oiT00?n;003oRP00ogl00?mj003oN`020?mj00040?mg003oK@00of/00?m/00D0of/000<0
oeh00?mL003oG0001Oooool1o`00007ooooo000Kooooo`;o00000ooooolI0?m<00030?m>003oF`00
oe`000d0oe`000<0oed00?mQ003oG0000P3oG0000`3oI`00of/00?m[00060?m[00040?m/003oJ`00
of/00?m/0080of/000H0og000?m[003oJ`00ogT00?md003oN0090?mj00030?ml003oOP00oh@000<0
ohX000<0oh`00?nC003oV0000`3oV@004@3oVP00oj400?nX003oZ000ojh00?nn003Yk@00Tol90?[d
003lm@00bO4=0;So2036o`00LL4j09UQC`2DC5@0lP/H01P0o`0000X0c20[06V;A`1c[FX0_Ol80>3o
003To`00fol00;Gb2P2NHSD0iAHSE03o00002`3^3A40QllO0<3R403Xj`@0kmP00?ne003oWP00oi40
0?n:003oQ000og/000<0ogX000<0of`00?m[003oJ`001P3oJ`000`3oIP00oe`00?mL0004ooooo`;o
00000Oooool001_ooooo00?o0000ooooooooool00_oooolH0?m<00030?m@003oFP00oe`000P0oe`0
00<0oed00?mL003oG0000`3oG0000`3oGP00oe`00?mL00020?mL00030?mX003oJP00ofP000/0of/0
00L0of`00?m[003oJ`00ofd00?m_003oJ`00ofl000H0ogX000L0og/00?mj003oNP00og/00?mj003o
P000oh8000@0ohX000<0ohd00?nB003oV0000P3oV@004@3oVP00oi`00?nV003oZ@00okL00?OF003h
f`00omP00?oM003nj`00oOL00=Wo2`2oo`00VO8=06?I8P1AXd`0c2De01H0o`0000/0dB0h0=TK<P1d
_C/0H]M40>So003do`00lol00>co002cnPd0M8]G0>HH6`1D0?l0000;0>H;6P2l<c00VeHm07c;;`13
k4d0`o4C0?f`003oUP00ohX00?n8003oN`000`3oNP000`3oL`00ofh00?m[00070?m[00030?mZ003o
I03ooooo00Cooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`02oooooaH0od`000@0odh0
0?mF003oG000oe/00P3oF@000`3oF`00oe`00?mL000>0?mL00050?mQ003oI000oe`00?mL003oH`00
2P3oJ`00103oK000of/00?m[003oK@020?m[00040?m`003oL`00of`00?md00L0ogX000D0og/00?mj
003oO000oh@00?n900030?n:00030?n;003oSP00oiH000<0oiT00100oih00?nX003oZ`00okP00?no
003oaP00old00?oK003oj`00o?/00>3o001cm200=oHb085bC03>6c00o`0;503o0000302FFE00J;lP
01cOHP2_eBL0lOl00?_k003mnP00o?`00?So003FlP@0QHU_09]A@5L0o`0000P0MFI[03O9FP2ckQh0
nlH00?nJ003oR`00ohT00?ml00<0ogX000<0og400?m[003oJ`001P3oJ`000`3oJP00of@00?mO0005
ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool00_oooolD0?m<00050?m>003oE000oe@0
0?mA003oCP000`3oC0000`3oC@00oe800?mL00080?mL00030?mM003oG000oe`00080oe`000<0oed0
0?mO003oG0000P3oG0000`3oH000of/00?m[000>0?m[00060?m^003oJ`00of/00?m`003oN@00ogP0
1`3oNP00103oN`00ogX00?n5003oQ`030?n:0080oh/00100oi<00?nI003oV@00oiX00?nO003oZ000
oj`00?ng003o_P00olH00?oB003mj`00hoh00<oo0028lPd0I8:90`3o00000`3o00D0VTaL0?`0500>
0?l0000@0>HD602IGSL0/cM808M9O01olQX0E;lm0<Wo1@3nmP00oo400?o`003om000oOX00>go002S
fA`0IieA0>HB6U<0o`0000/0iQ8J0>HJ202o=d<0H]M>0;Kb501chcT0i=410?nL003oS000ohX00?ml
00030?mj00030?m`003oJ`00of/000H0of/000<0oel00?mL003oG0001Oooool1o`00007ooooo000K
ooooo`03o`000?oooooooooo00;ooooo4P3oC0000`3oCP00odl00?m?00090?m<00030?mC003oG000
oe`000X0oe`00P3oG@040?mL00050?mR003oJ@00of<00?mS003oJP00203oJ`000`3oK000of/00?m[
00020?m/0080of/000@0og800?m]003oJ`00og@01`3oNP020?mk00030?mn003oRP00ohX00080ohX0
0140oh/00?n<003oU000oiT00?nJ003oV`00ojH00?nY003o/000okT00?o0003od@00e?L408?b5`1k
lPd05^MX0:LfH`040?l0000506^I>`1>/3h0c2100;<k>P3j00d0203o00002`3S3bX0iPTJ0>48:P0o
/fL0JLLi04_b5`16[VX0_O8=0?3j003blP00onP00080onH000D0onP00?oc003LoP@0UWI?0;H_B01D
0?l0000;0?P03@20`bL0Q]<c0<CX:03ojP00i_H00>?G0@3oWP00oh`00?n:003oOP000`3oNP000`3o
MP00ofl00?m[00060?m[00<0oe`01Oooool1o`00007ooooo000Kooooo`03o`000?oooooooooo00;o
oooo3`3oC0000`3oC@00odh00?m>000<0?m<00030?m=003oG000oe`000T0oe`000<0oed00?mL003o
G0000`3oG0000`3oG@00ofD00?mM00020?mL00030?mR003oJ`00of/000`0of/000L0of`00?m]003o
J`00of/00?mc003oN@00ogP000@0ogX000H0og/00?mj003oNP00ogd00?mj003oQ`040?n:000@0?n<
003oUP00oiT00?nJ003oX000ojP00?nZ003o]`00okd00?o;003mh`00oOH00=7o000gkDX09/A_0>DA
9P80o`000280i`dH04RLOP1hj0l0K/d`04>gF`34:340GIe<08Eh:02KDT`0o`000>d46P1VQf80QVQA
09=ELP0TiSh0^b910=T:9P1<d4h0]Ol003k/B`2?mbP0o?H00?oX003ogP00om/00?oH003og000on80
0?oX003mn000^nL?06BRG01^V3h0lP`KDP3o00002`3b3@h0TkDc0?Cj003og`00olh00?_?003l]000
oiT00?n;003oRP00ogl000<0ogX000<0og000?m[003oJ`001P3oJ`000`3oI000oe`00?mL0005oooo
o`7o00000Oooool001_ooooo00?o0000ooooooooool00_ooool<0?m<00030?m=003oC000odd000l0
od`000<0odd00?mL003oG0003`3oG0000`3oH000oe`00?mL00020?mL00030?mQ003oJ`00of/000l0
of/000D0of`00?mb003oJ`00of/00?mh00070?mj00030?mk003oP@00oh@00080ohX00P3oR`006P3o
SP00oiT00?nI003oW000ojP00?nY003o]`00ok/00?o7003of@00on/00?Gm002eo`00@=hh0;@PI`39
5d@0_RiD081TIP1Hna`0aOl00:[o0@14d5h0OK`c08Wb3@1CjQ00Wd9Q0P3o00005`1fVD00D_l707kb
4`23iQL0FML_05VML`1J[V00joh008Wo4@1okCD0onP00?oI003oeP00om<00?oD003oe`00omP00?oR
003ok`00k_l0097o1@1QX4X0c2@[0580o`0000P0iQ0G0:m1E@2gg3H0om800?o0003o/@00oj<00?nI
0080ohX000T0ogl00?mj003oNP00ogX00?mi003oL000ofh00?m[003oK0001@3oJ`000`3oJ000of<0
ooooo`04ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool00_ooool;0?m<00030?m=003o
C000od`00100od`000<0oe800?mL003oG000203oG0000`3oG@00oe`00?mL00030?mL00030?mN003o
G000oe`000<0oe`000D0ofD00?mW003oH000of000?mW00090?m[00050?m/003oJ`00of/00?m[003o
K@000`3oJ`000`3oN000ogX00?mj00040?mj00040?mk003oNP00ogX00?n000@0ohX002P0ohd00?nE
003oV@00oiX00?nW003oZ000okL00?nm003ob@00omT00?g_003So`00`_l006Ko1@1<O8d0=Zmi05;o
0@0Ph7d0VOlE0?3o002clQP0[Ol90>7o002KmRT0@?/O05RFR@2l;d<0ZdAB04:VKP37o`00eol00<Go
001lo`@0=>MQ0:3i6`3ojP00on<00??V003od`00ol/00`3oa`002@3ob`00om<00?oI003ok@00P^lY
06AVR032:D`0o`000?456P1A0?l0000?0<Xc9@2LfAl0b=lV0?o?003o_@00oj`00?nQ003oV000oh/0
0?n:003oP000ogX00?mk003oNP00og0000P0of/000<0ofL00?mQ003oG`001Oooool1o`00007ooooo
000Kooooo`;o00000ooooolM0?m<00030?m=003oFP00oe`000l0oe`000<0oed00?mL003oG0000P3o
G0000`3oGP00of<00?mL00020?mL00030?mN003oJ`00of/000X0of/000P0of`00?m[003oJ`00of/0
0?m_003oL000of/00?ma00H0ogX00P3oO000>03oN`00ohX00?n:003oRP00oh`00?nC003oV@00oi/0
0?nW003oZ`00okP00?o3003odP00on400?3i001lnQ@0KOl;01OXA00VfUh0R?l40<So0028o`00m_`0
0?o`003kl000noD00?gj003Jo0d0a_l007Se3@19`c<0B8N?07KY8P3ToP00n?d007Kf9`1Roa/0bo8B
0?oW003oeP00old00?o9003oa`00ol@00?o3003oa000olH00?o7003ob@00om@00?oU002EmBX0Lha]
05nCD01nKdl0[D4lD@3o00002`2GJTh0a^h=0?[h003og000ol<00?na003oY000oiT00?n>003oRP00
oh4000<0ogX000<0ogP00?m`003oK@001@3oJ`00103oJ@00oe`00?mL003oG004ooooo`;o00000Ooo
ool001_ooooo00?o0000ooooooooool00_oooolM0?m<00030?mG003oG000oe`001@0oe`000<0of00
0?mL003oG0000`3oG00@0?m[00050?m]003oJ`00of/00?m_003oN`00103oNP001@3oN`00ogX00?mj
003oP000ohD000<0ohX00180ohl00?nI003oV`00ojP00?nc003o``00oMT00>[^2@3im`00d?l206Wo
1P1^aB@0/?l305Ob402EmAd0nOX00:ol003gk`020?oK000B0?oO003ok@00no/00>3o001So`h0@<U<
03OP=`2`oPl0on/00?oX002ekQP0M?/]0;?l0P3of000olL00?o2003o_@00okX00P3o^000303o^@00
ok`00?o1003oa`00olX00?oH003ojP00YOhT06cG<`2>iPd0Wc1i0?@03Dl0o`0000d0lPd<076V9@22
TET0Jl9705cT@@3Yh0`0ol000?n[003oW000oi800?n:003oQ000og/00080ogX000<0og400?m[003o
J`001@3oJ`00103oI`00oe`00?mL003oG005ooooo`7o00000Oooool001_ooooo00?o0000oooooooo
ool00_oooolK0?m<00040?m=003oE`00oe`00?mL0080oeT000<0oe/00?mL003oG0003`3oG0000`3o
GP00oe`00?mL00030?mL00050?mQ003oJP00of@00?mP003oI0002`3oJ`00203oK@00of/00?m[003o
J`00og<00?m`003oK`00ogT0103oNP000`3oN`00ogX00?ml00030?n:000S0?n<003oV@00oih00?nZ
003o_000k^/00<Si102Joa`0aoh0093o5@2=o`X0e?X:0?gd003>oP00^?@@0?oM003oe000olh00?o:
003ob`00omH00?oV003Ro@00]?l605So6`1jmb80Z?l00?c[003odP00oll00?_M003Si0H0]o<=0?o8
003o_000203o^0002@3o`000olL00?o>003ogP00oOL00=go002KlPH0C:dk0<@[?01?0?l0000=0>h=
603o0000o`000<`U7`1ClR@0j_`00:_k003ke@00oj/00?nG003oRP00ohD00?mk00020?mj00030?mf
003oK`00ofd000H0of/000<0of400?mL003oG0001Oooool1o`00007ooooo000Kooooo`03o`000?oo
oooooooo00;ooooo6P3oC0001@3oCP00oeX00?mH003oD@00odd000<0od`000<0oe400?mK003oG000
3@3oG0000`3oGP00oe`00?mL00040?mL00030?mV003oGP00oe`00080oe`000<0ofH00?m[003oJ`00
2`3oJ`001@3oK@00of`00?m[003oJ`00ogH000D0ogX000<0og/00?ml003oP@000P3oRP002`3oR`00
oiP00?nO003o/000ol<00?S_002go`00mO800?oR003ogP00gnT30080om@000@0`_D20>g]003ob@00
okl00P3o^`004P3o`@00ol/00?3Y001_maX0[OT=0<Ol103Yk@@0o]h00?o>003o`000okd00?nn003o
``00n/P00?ni003o]@00ojh00?n[0080ojX000<0ojd00?nb003o]P000P3o^0001`3o`P00olX00?oK
003Vm`40Tl@b076/>`3:8T00D03o0000303m00d0o`000?l0003o00`0Pem]06k;@`1VkAh0Z?lF0?3@
003oWP00oh`00?n800<0ogX000<0og400?m[003oJ`001`3oJ`000`3oJ000of<0ooooo`04ooooo`7o
00000Oooool001_ooooo00?o0000ooooooooool00_oooolI0?m<00030?mB003oEP00odh000L0od`0
00<0oe000?mL003oG0004P3oG0000`3oH@00oeh00?mL00030?mL00030?mT003oJ`00of/000/0of/0
00H0of`00?m[003oJ`00of`00?mh003oMP060?mj000T0?n2003oRP00ohX00?n;003oU`00oj@00?[;
003og000^_`009K_9P3oh@00ol/00?o6003o`@00okh00?nm003oc000g]D00?ni003o]000ok<00?ne
003o^000ol<00?gS001[oal0j_h00?oZ003odP00ol@00?nk003o]`00okD00?nc003o]000ojl00P3o
Z@003`3oZ000ojT00?nX003oZ000ojT00?nX003o[000ok@00?nh003o^`00olL00?oQ001[kcl02/Bc
0:U;FP020?l000030=lK6`3o0000o`0004`0o`0000d0_c530?l0003o0000l00@0=8H?00cdXX09>AO
08So1P2kiQ40ojd00?n?003oQ`00ogh00080ogX000<0og@00?m[003oJ`001@3oJ`00103oJP00of80
0?mL003oG005ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool00_oooolG0?m<00030?m>
003oD@00odl000X0od`000<0oe/00?mL003oG000403oG0000`3oG@00oeh00?mL00040?mL00040?mU
003oJ`00of/00?mZ00d0of/000@0ofl00?m/003oJ`00og@0103oNP000`3oN`00ogX00?n400020?n:
000:0?nF003oZ@00kN000=ch002bo`D0nnl00?oA003o`000okT00?nd00<0ok0000<0ojh00?nZ003o
Z0000P3oZ@00303o[P00okT00??R002DoQ00/?860?_/003obP00ok/00?nc003o[@00ojP00?nY00X0
ojP000d0ojT00?n/003o]P00okP00?o3003Wi`00M]`V05mdR@0n[Fl0Tfi<0;/YA`22PQh0k`0V04`0
o`0000h0iQL@07b<803V41X0o`0006QYJ@18lT/0/?l404WRH@3LnP00l>400>je003oS`00ohL00?mk
0080ogX000<0og<00?m]003oJ`001@3oJ`00103oH@00oe`00?mL003oG005ooooo`7o00000Oooool0
01_ooooo00?o0000ooooooooool00_oooolE0?m<00030?m=003oCP00odh000`0od`000<0oeP00?mL
003oG000403oG0000`3oGP00oe`00?mL00030?mL00030?mM003oJP00of800080oe`000<0of<00?m[
003oJ`002@3oJ`001@3oK@00of/00?m[003oJ`00ogH000D0ogX000d0og`00?n1003oRP00ohX00?nC
003oWP00ok800?o>003Do000oN`00?o9003o^000ojd00080ojP001H0ojL00?nU003oX`00oj400?nP
003oX@00ojD00?nX003o[@00okd00?WE003Rn@00U?dI0?o6003o[`00ojT00?nX003oYP00oj@00?nR
003oX@00oj000P3oW`00103oW@00oj800?nT003oY`020?nX000=0?nY003oZP00okH00?nk003oc000
i=hJ0:_e4P1FYVL0Oo8=09;V9`1_b1/0fQXI0?813@1;0?l0000=0:IH<@2QlPd0BlQT08:IE00g]X40
b_h20?Sk002Jnb80Y^TA0?no003oX000ohd00?n600030?mj00030?m`003oJ`00of/000D0of/000@0
oeh00?mL003oG000oe`01Oooool1o`00007ooooo000Kooooo`;o00000ooooolC0?m<0080odd000<0
odh00?m<003oC000303oC0000`3oF`00oe`00?mL000?0?mL00030?mM003oG000oe`000@0oe`000<0
of800?mN003oG0000`3oG0000`3oJP00of/00?m[00070?m[00080?m/003oJ`00of/00?m[003oKP00
og000?m]003oM`040?mj000?0?ml003oR000ohX00?n@003oV`00oj`00?g90038e`<0bOP00?o3003o
[`00ojP00?nT003oV`00oiX000D0oiT000h0oiX00?nK003oY000ojT00?nk003Dm`00m/d00?n`003o
Y`00oj<00?nM003oV@00oiX00?nK00<0oiT000H0oiX00?nI003oVP00oi/00?nL003oX@030?nX000;
0?n/003o]`00ok`00?o;003mi000N<i80:?o1P3Ko`00[Z@b07FA>P3<92/0B`3o00003@2K;6<0a?l?
0?7m002=lPH0[mPO0?;S2P3og`00[o<D09Kb6P3GiP00oil00?n;003oQ0000P3oNP000`3oN@00og00
0?m]00020?m/00@0of/000@0ofL00?mM003oG000oe`01?ooool2o`00007ooooo000Kooooo`03o`00
0?oooooooooo00;ooooo4@3oC0000`3oC@00od`00?m=000?0?m<00030?m@003oG000oe`001H0oe`0
0P3oGP050?mL00030?mY003oJ`00of/000/0of/000@0of`00?m[003oJ`00ogD0103oNP00303oN`00
oh@00?n:003oR`00oi/00?n[003oa000jo400?KU003o^P00ojL00?nO00D0oiT000<0oiP00?nI003o
V@000P3oV@001`3oVP00oil00?nX003eaP00ojX00?nS003oW000303oV@020?nJ000?0?nM003oYP00
ojP00?nY003o[`00okP00?o0003oc@00on400?kd003eo`00cOl008kV3`1I/Rh0/ce204T0o`0000h0
Uf4a09WQ4@3enP00onP00?[P003ocP00olH00?o3003od000d?@20>WK1@3oV`00oh/00?n10080ogX0
00<0ogT00?m]003oJ`001`3oJ`000`3oJP00of<00?mQ0005ooooo`7o00000Oooool001_ooooo00?o
0000ooooooooool00_oooolS0?m<00030?mI003oG000oe`001D0oe`000<0oed00?mN003oG000103o
G0001@3oGP00of/00?mZ003oI@00ofL000P0of/000D0of`00?m[003oJ`00of/00?m_00020?mb00@0
ogX000l0ogd00?n9003oS000oid00?Zi003lg000i?@00>[^003o^P00oj000?nI003oV000oiD00?nB
003oS`000`3oS@00203oS000oi000?nD003oU`00oiT00?nK003oW000oiX00`3oV@030?nH00030?nF
003oV000oiL000L0oiT000l0oiX00?nL003oY`00ojP00?nY003o/`00okT00?o7003oeP00on/00??m
002?RE`0S6U?0=DC@03b0`d0B03o00003`3f00d0k@@J08f0E`37k0d0omH00?o5003o_000okL00?nd
003o_000dN@80?fc003oT000ohX00?mn00020?mj00030?mf003oKP00of/000D0of/000<0ofT00?mO
003oG0000P3oG005ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool00_ooool>0?m<0080
odd04P3oC0000`3oE000oe`00?mL000E0?mL0080oed01P3oG0000`3oI`00of<00?mL00020?mL0003
0?mU003oJ`00of/000P0of/000@0ofd00?m[003oJ`00of/00`3oNP020?mk000;0?n6003oR`00oj00
0>GT003ee@00ml000?nc003oZ`00oiX00?nE003oSP000P3oR`00103oRP00oh/00?n:003oS0020?n:
00050?n;003oRP00ohh00?nB003oU0000P3oTP002P3oT000ohd00?n<003oS`00ohh00?n:003oS`00
ohX00?nC003oS`020?nG00@0oiT000`0oiX00?nK003oZ000ojP00?n^003o^000olD00?oF003Kl`d0
e?8=037DK`2WAD830?l000030?863@3o0000o`0004@0o`0000l0Sf/b09a7D01aDh@0G=YB0?o>003o
^P00ok800?nX003oY`00ojD00?nQ003oU`00ohX00?n5003oO0000P3oNP000`3oM@00of`00?m[0005
0?m[00030?mQ003oG000oe`00080oe`01Oooool1o`00007ooooo000Kooooo`03o`000?oooooooooo
00;ooooo8@3oC0001@3oDP00oe`00?mK003oE000odl00080od`000<0odl00?mF003oG0005P3oG000
0`3oH000of400?mL00030?mL00030?mP003oJ`00of/000/0of/000<0og000?mb003oMP000`3oNP00
2@3oP000ohX00?nR003ke000ojL00?nL003oV000oiD00?n?000D0?n:00050?n<003oRP00ohX00?n;
003oRP000P3oS000103oR`00ohh00?nB003oU`030?nI000;0?nK003oW`00ojP00?nY003o]`00olP0
0>gR3@29lQd0Fo8K05JYFP3<9CT00P3o00000`3l00d0X4I>0?l000140?l0000?0=TN9@1SfBd0Y?8D
06O=D02ml`@0ol<00?nc003oZP00oj@00?nK003oV@00oiD00?n;003oR@00ogd00080ogX000D0ogT0
0?m_003oK@00of/00?m/00040?m[00030?mT003oG000oe`00080oe`01Oooool1o`00007ooooo000K
ooooo`03o`000?oooooooooo00;ooooo803oC0000`3oD`00oeX00?mB00070?m<00030?mF003oG000
oe`000`0oe`000<0oed00?mL003oG000103oG0000`3oG@00oeh00?mL00040?mL00030?mQ003oJ`00
of/000X0of/000@0ofd00?m/003oJ`00og40103oNP001P3oQ@00oi400?nF003oT@00ohh00?n;00H0
ohX000<0ohT00?n:003oR0004@3oRP00203oR`00ohX00?n:003oRP00oh`00?n:003oT@00oi<00`3o
V@003`3oV`00oj<00?nX003o]@00olP007_e7P1DfT<09LIW04Z5T033<SH0WD9Y0=d>:02VCC<0?>8`
0?8=20130?l0000<0=HU7@2DKC<0W:IP0?[h003il@00i=P=0?nj003oZ`00ojL00?nK003oV@00oi@0
0P3oRP000`3oQ@00og/00?mj00020?mj00030?m^003oJ`00of/000H0of/000@0of@00?mM003oG000
oe`01Oooool1o`00007ooooo0008ooooo`;o00001?ooool00ol0003oooooooooo`02ooooo`?o0000
1Oooool00ol0003oooooooooo`02oooooal0od`000<0oe800?mC003oC@00203oC0000`3oC@00oe`0
0?mL000B0?mL00030?mM003oGP00oe`000D0oe`000D0ofL00?mZ003oI000of<00?mY000:0?m[0004
0?m/003oL000ofh00?mi0080ogX000<0og`00?n2003oQ`000P3oR@004P3oR000ohH00?n5003oQ@00
ogh00?n1003oP000og/00?n0003oNP00oh800?mk003oQ@00ogl00?n8003oQ@00ohX00?n900d0ohX0
0`3oR`000`3oS000oiD00?nH00020?nI000?0?nL003oZ@00ok800??C002nl`d0E^HU03nVU`0abDh0
L/`M04ON<01fMh40J<<h09_X3@23T240dBHZ0440o`000140lPP=0;Q;7P2bgQP0eO0C0?oX003oe000
ol<00?nd003oZ000oil00?nI003oV000oh`00?n:003oR@00ogl00?mk00020?mj00040?mb003oKP00
ofd00?m/00D0of/000D0ofH00?mR003oH@00of400?mN0005ooooo`7o00000Oooool000Oooooo00Co
0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000oooooooo
ool00_oooolN0?m<00030?mA003oC`00od`000X0od`000<0oeP00?mL003oG0004@3oG0000`3oG@00
oe`00?mL00040?mL00030?mO003oI@00oed00080oe`000<0oed00?mZ003oJ`00203oJ`001@3oK000
of/00?m/003oMP00ogP000<0ogX000H0og/00?mj003oO@00ogd00?mk003oO0030?mj000A0?mn003o
NP00ogh00?mj003oN`00ogX00?ml003oNP00ogl00?mj003oP000ogX00?n4003oO@00ohP00?n2003o
R0000P3oR@090?n:000E0?n<003oRP00oiD00?nH003oV@00oiX00?nT003o[`00d>D>07On7034n@L0
G^]306^`E`1ahbl0`Ol80;oV503So`00cO8004JfIP3W0B40g`lc0400o`000100Tf8^08WY5P3?o`00
m_`00?oU003od000ol000?na003oZ000oi`00?nI003oT@00oh`00?n:003oQ@00og/00`3oNP000`3o
L`00of/00?m[00050?m[00030?mS003oG000oe`000<0oe`01Oooool1o`00007ooooo0007ooooo`04
o`000?ooooooooooo`0000_ooooo00?o0000ooooooooool00_ooool2o`0000?ooooo703oC0000`3o
CP00oe400?m<000<0?m<00030?mI003oG000oe`00100oe`000<0oed00?mL003oG000103oG0000`3o
G@00of800?mL00040?mL00030?mW003oJ`00of/000D0of/000P0of`00?m[003oJ`00of/00?m]003o
J`00ofl00?mh00/0ogX000L0og/00?mj003oNP00ogX00?mk003oNP00og/000<0ogX000`0og/00?mj
003oO@00ogX00?mn003oNP00ogl00?mm003oN`00ohT00?n3003oR0070?n:000E0?n<003oR`00oi80
0?nI003oVP00oi/00?nW003o/`00oLL00?o;003Qi1L0Z^hU04GX>`3ZoP00o_H00?kg002hlQH0ZDE[
06QBZ`1gV2L0c2lV03h0o`0000d0c2H^0:QI:P2R>UL0GiaB06SOE03@j`d0omd00?o5003o/`00ojP0
0?nK003oV@00oh`00080ohX000P0oh000?mk003oNP00ogX00?mf003oKP00ofd00?m/00D0of/000<0
of400?mL003oG0000`3oG004ooooo`;o00000Oooool000Oooooo00Co0000oooooooooooo00002ooo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo6`3oC0020?m>00d0od`000<0
odd00?mL003oG000603oG0000`3oH000oe`00?mL00040?mL00030?mZ003oJ`00of/000/0of/000@0
ofl00?m[003oL`00ogL05@3oNP001@3oN`00ogX00?ml003oNP00og`00080ogX000D0oh400?mj003o
P@00ohH00?n300060?n:00030?n;003oS000oi<00080oiT00140oid00?nW003o[000okH00?o2002o
h1@0[^<U0>?/003oh@00onD00>G`3@2biQ/0I=9K087n602o;fX0[C`d0?0;6P100?l0000<05:AIP1e
kS40Yol<0>OW003o_000ojT00?nK003oV@00oh`00?n:003oR@00og/00`3oNP000`3oM`00of`00?m[
00060?m[00030?mY003oG@00oe`000<0oe`01Oooool1o`00007ooooo0007ooooo`04o`000?oooooo
ooooo`0000Oooooo1?l00005ooooo`03o`000?oooooooooo00;ooooo6@3oC0000`3oC@00odh00?m<
000>0?m<00030?mC003oG000oe`001L0oe`000<0oeh00?mL003oG000103oG0001P3oH@00ofT00?mR
003oG`00of400?mZ00P0of/000P0of`00?m[003oJ`00ofl00?m[003oN000og800?mi0140ogX000<0
og/00?mj003oNP00103oNP00103oN`00ogX00?mj003oO`020?mj00030?n8003oQ`00ohX000D0ohX0
01D0oh`00?nC003oV@00oiT00?nL003oY`00ojT00?na003o_@00ol<00?o:003oc`00omH00?oR003n
m000l?l00=Oo002TlP@0P/`008J0:`3e2Q/0>@3o00000`3Z2aX0o`000?l000030?l0000=0=TA9P2E
EV40@/Y809g/6P3mc@00oj`00?nN003oV@00oh/00?n:003oQP00og`00?mk00020?mj00030?ma003o
KP00of`000H0of/000@0ofX00?mW003oH`00oeh00P3oG005ooooo`7o00000Oooool000Oooooo00Co
0000oooooooooooo00001oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00;ooooo
6@3oC0000`3oC@00od`00?m<000>0?m<00030?mJ003oG000oe`001H0oe`000<0oed00?mL003oG000
1@3oG0000`3oI`00oed00?mL00020?mL00030?mU003oJ`00of/000P0of/000X0of`00?m[003oJ`00
ofl00?m[003oM@00of`00?mc003oN000og<05`3oNP001P3oO000ogX00?mj003oP@00ogX00?n300D0
ohX000<0oh/00?n<003oU0000P3oV@00403oW000ojD00?nX003o[P00okP00?nl003oa@00old00?oJ
003oj`00n_d00<?o001nk`P0Me]V0=H@@02f9d@h0?l00003071iG03_2a00o`0000@0o`0000`0m00@
027^K`2Ck`/0IoPP0=K/0P3o/000oj800?nI003oS000ohX00?n7003oO@030?mj00030?m/003oJ`00
of/000D0of/000D0of@00?mL003oG000oe`00?mO00020?mM00Gooooo0Ol00001ooooo`002?ooool2
o`0000Sooooo1Ol00004ooooo`03o`000?oooooooooo00;ooooo603oC0000`3oC@00od`00?m<000>
0?m<00050?mD003oG000oe`00?mK003oE@000P3oDP000`3oE@00oe/00?mL000@0?mL00030?mM003o
G000oe`000@0oe`000<0of400?mM003oG0000`3oG0000`3oI000of/00?m[000:0?m[000?0?m/003o
J`00of/00?m]003oJ`00ofl00?m^003oJ`00og@00?mb003oK000ogL00?mi003oM000ogT000X0ogX0
00<0og/00?mj003oNP000P3oNP00103oN`00ogX00?mj003oO0020?mj00030?n2003oP`00ohL000D0
ohX00140ohd00?nF003oV@00oiT00?nM003oY`00ojT00?n^003o^000okd00?o7003of000no000>Co
001_fE40UU9<0>d=6@030?l000030?l02@3o0000o`0003<0o`0000<0`cLa05G39P3b1`d01@3o0000
303m00d0AkA>0=?o003jl`00om400?nf003oYP00oi/00?nB003oRP00ohD00?mk0080ogX000<0ogP0
0?mc003oK@001P3oJ`070?mL00Gooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`02oooo
oaD0od`000<0odd00?m<003oC000403oC000103oD000oe`00?mJ003oD@050?m<00030?m=003oF@00
oe`001D0oe`00P3oGP050?mL00040?mU003oJ`00ofT00?mY00/0of/00P3oK0001@3oJ`00ofd00?m[
003oJ`00og000080of/000D0og<00?m^003oJ`00og000?mj00020?mc00l0ogX000H0og/00?mj003o
N`00og`00?mj003oOP040?n:0080oh/000l0ohd00?nF003oV@00oiT00?nL003oY`00ojP00?na003o
^@00olH00?;O0@2am1H0A=i:07FU@02cB2l01@3o00000`33<S00o`020?l0000a0?l0000409UR=P2U
_`X0KlLl0<`X9@D0o`0000`0_aPk04S6B`1ilQ/0k_D00?oF003oaP00okX00?nQ003oT`00ohX00?n5
003oN`020?mj00050?mc003oJ`00of/00?m[003oK000103oJ`000`3oG`00oe`00?mL00040?mL00Go
oooo0Ol00001ooooo`006oooool00ol0003oooooooooo`02ooooobL0od`000<0odl00?mK003oD`00
203oC0000`3oCP00oe`00?mL000C0?mL0080oed01@3oG0000`3oGP00ofP00?mP00020?mL00030?mT
003oJ`00of/000h0of/000@0ofd00?m[003oJ`00ofl00P3oJ`00203oK`00og800?m[003oJ`00ogL0
0?mh003oL@00ogH02P3oNP00103oN`00ogX00?mj003oN`020?mj00030?mo003oO@00oh<000D0ohX0
00h0ohh00?nH003oV@00oiX00?nQ003oZ000oj`00?nh003o``00om`007?j=@0T/HX0PVMA0?456PD0
o`0000<0c3<708UWA03=5380;`3o00001P3V6P/0MiP[09=c>@3=o`00Uo8B07eXH0@0o`0000d0i0HV
0?l0003Q5c<0>N1E0;Co5`3nl@00a_H20;7k6P3k_@00oiD00?n:003oQ000og/00080ogX000<0ogH0
0?m^003oK0001P3oJ`000`3oJP00of400?mL00040?mL00Gooooo0Ol00001ooooo`006oooool00ol0
003oooooooooo`02ooooobH0od`000<0odh00?mH003oCP002P3oC0000`3oF000oe`00?mL000A0?mL
0080oed01P3oG0000`3oHP00oeh00?mL00020?mL00030?mM003oJ`00of/000h0of/000@0of`00?m[
003oJ`00ofd00P3oJ`00303oKP00of`00?m[003oJ`00ogD00?m/003oJ`00ofd00?mj003oN000og@0
0?mi00<0ogX000<0og/00?mj003oNP001@3oNP020?mk00030?mj003oP@00ohL000@0ohX000h0ohd0
0?n?003oV@00oiT00?nK003oZ@00ojX00?nh003o``00omP00:gm3013gdP0?>4d0;@aC`D0o`0000D0
WTM`06Ko2P2XISl0`2LP0?8=1`0[0?l0000I0>L=4@2_B300fADV07c6;@3Po`00mod00>7o001c]D@0
KI1E0<``;`3_3A@0^Ce;05:NC02b>D`0PVQA02cFK02Eo`L0a_8007Wb1@3ogP00n[T00?nF003oRP00
oh@00?mk00020?mj00030?m]003oJ`00of/00080of/000P0of`00?m[003oJ`00of@00?mQ003oHP00
of400?mN00<0oe`01Oooool1o`00007ooooo000Kooooo`;o00000ooooolU0?m<00030?m?003oD`00
od`000/0od`000<0oeD00?mL003oG0004@3oG0000`3oG@00oe`00?mL00040?mL00030?mO003oGP00
oe`000<0oe`000D0oeh00?m[003oJ`00ofP00?mZ00080?m[00030?m/003oJ`00of/000@0of/000@0
of`00?m[003oJ`00ofd00`3oJ`00203oKP00of/00?m[003oJ`00ogH00?m/003oJ`00og002P3oNP00
1`3oN`00ogX00?mj003oN`00ogd00?mj003oP`00103oRP003P3oS000oiD00?nI003oV@00oj@00?n[
003o^P00olT00?oL003/m`d0d?l007CG<`1ePe40mP0=0`3o0000203b2`d0IGF40:Co2@2/dbL0EmTk
0>h=9@3<<bD0lP/=9`3o00006P3K5b80WeXR0:I?=01mfB@0EHm]05^TH@3`jPl0on`00?OW1`25k3l0
MOdL066<O01F[5/0InX_09Gk6@15h3/0IOhJ05oVAP1>jT@0FolY0>cj003ocP00ojl00?nJ003oS000
oh<00P3oNP000`3oN@00og000?m/00050?m[00030?mU003oG000oe`000<0oe`000<0oed00?mL003o
GP001?ooool2o`00007ooooo000Kooooo`03o`000?oooooooooo00;ooooo903oC0020?m@00d0od`0
00<0oeP00?mL003oG0005`3oG0000`3oG@00oeh00?mL00040?mL00060?mR003oI`00oeh00?mL003o
G@00ofX03@3oJ`001@3oK000of/00?m[003oJ`00of`00080of/00P3oK0020?m[00090?m^003oK@00
of/00?m[003oK`00ogP00?m`003oK`00ogP000T0ogX000D0og/00?mj003oN`00oh@00?n300040?n:
000J0?n?003oV000oiT00?nT003o[`00olX00>GX0@3nl000nOd00<3n3@0/ZVh0^R9E0?l0003C9300
ia0Y0?843@1UUDT0>[:I0=gb2P3No`00K:YW09Y<OP2:WaH0V7l^09UH@P3b0PdS0?l0000L0?8=303o
0000o`000:1H?02;maX0eol00<7b1P36k1X0oml00?oH003og000onP00>on002@h2/0<l=f0:;o2@3/
o000Z?XS0>Kl003Wo`00Jol709;o202?o`d0[OLK0=SN1P3fY000oh/00?n20080ogX000<0ogH00?m[
003oJ`001@3oJ`000`3oI`00oe`00?mL00060?mL00Gooooo0Ol00001ooooo`006oooool00ol0003o
ooooooooo`02ooooo`d0od`000<0odd00?m<003oC0004`3oC0000`3oD000odh00?m<000=0?m<0003
0?mK003oG000oe`001L0oe`000<0oed00?mL003oG000103oG0000`3oI@00oed00?mL00020?mL0003
0?mT003oJ`00of/00180of/000D0of`00?m[003oJ`00of/00?m]00030?m[00050?m`003oK@00of/0
0?m[003oL`001@3oNP000`3oN`00ogX00?mj00030?mj00030?mk003oNP00og/000@0ohX001`0oh`0
0?nF003oV@00oj400?na003=k`@0M?l@06?`7@35o`D0/Ol403Kk:02CBgd0US=h04k3=01<bTH0AZaS
04b`L02jo`80nO`00?cj0032o@d0ZoDJ0;gb3@1W]4D0bQY00?l0003b1Pd0]D0a7P3o0000103f00d0
o`0109EW?P2<Lbh20?l0000I0=`F701D`9P0m_/00?oX003oe`00ol/00?o8003ob@00omT00:;m301e
iBD0IOlD0<3g2`3og`00omd00?oX003Xn`00BOdZ0>Of003]j000lMh00>G/003oZ`00ohX00?n00002
0?mj00030?m`003oKP00of`000H0of/000<0of@00?mL003oG0001@3oG005ooooo`7o00000Oooool0
01_ooooo00?o0000ooooooooool00_oooolR0?m<00030?m?003oC@00od`000d0od`000<0oe800?mL
003oG0005`3oG0000`3oG@00oe`00?mL00040?mL00030?mQ003oG@00oe`000<0oe`000D0of@00?m[
003oJ000of@00?mX000<0?m[00030?m/003oJ`00of/000D0of/000D0ofd00?m[003oJ`00of/00?m^
00030?m[00050?mc003oM000ofd00?m^003oN@002@3oNP020?mm000T0?n8003oRP00oh/00?n:003o
T@00oiX00?nN003o[@00o=800<7l3@1fj2l0D^0o07Kg3@0`YH@09/Mm03BoL@1Dm4T0V_/@0330F`11
_UL0U_dG0?o[003oi`00on/00?gi003Do`80O71b0;`g=P3o0000iQDG06C43@2h<TP0Telj0?813@3b
3AD0lP8=5`3o00008@3<9c80o`0709I>D@1S^cX0W/d@07JcBP3@52`0iQLG0:HnAP1moa00eoH=0?oM
003oa`00okl00?ni003o^`00olH00=3L3@3gf000m]0=0?o9003oa@00ol/00?oI003ll`00W?l10=c]
003o`000ok800?fe003oV000ohT00?mk00020?mj00030?ma003oJ`00of/000@0of/000D0ofL00?mR
003oHP00of<00?mN00050?mL00Gooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`02oooo
ob40od`000<0odd00?m<003oC0003P3oC0001@3oF@00oe`00?mL003oG000oeT00080oeH000<0oeT0
0?mL003oG0005P3oG0000`3oG@00oeh00?mL00040?mL00060?mV003oI000oe`00?mL003oG@00ofX0
4P3oJ`00103oK@00of/00?m[003oJ`020?m/00<0of/000D0og800?m[003oJ`00of/00?mf00080?mj
000H0?mk003oNP00og/00?n5003oR@00ohX00?n;003oS@00oiP00?nK003oZP00ol000?oK003_n000
XN/J02;e>`0PlTL0Q_TI0<3o003No`00dOdB0:Gn4`30n0L0oml00P3oe@004P3og000n_80077U<01F
ma@0VT]00:0/GP1]QU`0X:dc09oo2`1][d<0lPT=0;5I7P2PL``0o`090:I7>P3b2Pd0lP4=0?H03@`0
o`0001T0lP8=0?l0003b21<0[DLa0?l01P2HJRl0N:0^0=TN8`2:Ff@0U^PM0>Co0026jd<0I<8b05V`
A`1MOXl0B]Tk05ok=P3kg000okd00?nf003o/P00ojh00?na003o/P00ok<00080ok@00100okL00?nm
003oeP00^o`<08:o3`3diP00ok800?nQ003oUP00oh/00?n2003oN`00ogX00?md003oJ`00of`01@3o
J`000`3oG@00oe`00?mL00020?mL00030?mN003oG@00oe`00080oe`01Oooool1o`00007ooooo000K
ooooo`03o`000?oooooooooo00;ooooo<@3oC0001@3oD`00oe`00?mK003oE@00odh000@0od`000<0
oe000?mK003oG0005@3oG0000`3oGP00oe`00?mL00030?mL00030?mN003oI000oe`000<0oe`000<0
ofD00?m[003oJ`00403oJ`000`3oK000of/00?m[00050?m[0080of`00`3oJ`00103oM`00og<00?m_
003oN0090?mj000]0?n2003oRP00ohX00?n:003oUP00oid00?n[003o`000m>400<7m1P1HnR40KMdd
05O`8P0aid/0b_l00?Wk003oj000omd00?kE003ob@00olH00?o7003oc@00k=d=07Oe<`0`d6H0@GN/
03^`DP2>lPX0jOl00:gP:P1=_V<0OSZ608O8:P1ec1l0Q4=m06Vo=P2BGT40TgY807^D=`1IX4`0M8`L
0:II>@3Q4C<0o`0?0080o`0001T0n`0=0<8Q@02<Le00NX0U082G9@24S3@0YG=605UoI`1jiPT0[TMD
06C=@`2dlPX0OH8k07]`PP2NfC/0o_@00?ch002ckAX0Dla503fcG@0elT`0jnh00?o3003o/`00ojX0
0080ojP00`3oY`020?nX000@0?nY003o/P00ol000?7_002MlPP0nN800?n`003oV@00oh`00?n9003o
O000ogX00?mi003oL000ofd00?m/00D0of/000<0oeh00?mL003oG0001@3oG0000`3oG@00oe`0oooo
o`04ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool00_ooool`0?m<00040?m>003oF`00
oeP00?m>00L0od`000<0odl00?mL003oG0004`3oG0000`3oGP00oe`00?mL00040?mL00030?mQ003o
G000oe`000<0oe`000H0ofH00?mZ003oH@00oe`00?mN003oJ00=0?m[00050?m/003oJ`00of/00?m[
003oK0000`3oJ`001P3oK@00of/00?m[003oJ`00ofh00?m_0080of/000<0og000?mj003oNP001`3o
NP00:`3oO`00ohD00?n:003oRP00oi@00?nK003o/P00f^d00:gk2P2Al@d0hOL:0:Ka703;oP00N_DF
03g]<P3@o000omX00?o7003o`000okX00?nh003o^P00ol400?o=003]l000FN]205>`G01PaR`0W?HI
0?k`003nl@00UnDP07kE?02ijaT0iol00=3<0@3Bo`00`Ol00:ko0024o`00B]8Q0;A59`3d00d01`3o
00006P2VFBD0D^4M09_o002mo`00a_X=0=go002kcAT0m>l=0??`001Xg2d0R]he0?kW003of`00on00
093a9`2No`40E>`j0:O^3`2lhA/0ok@00?nX003oY`00oj000?nK003oW000oiT00P3oV`002`3oWP00
oj@00?nX003o/`00o/`00<Wh003Gm`80oL@00?nE003oR`00ogl00080ogX000<0ogL00?m]003oJ`00
1P3oJ`000`3oJ000oed00?mL00070?mL00Gooooo0Ol00001ooooo`006oooool00ol0003ooooooooo
o`02ooooobl0od`000<0odd00?mJ003oE0002P3oC0000`3oF@00oe`00?mL000H0?mL00030?mM003o
GP00oe`000@0oe`000<0ofP00?mN003oG0000P3oG0000`3oH000of/00?m[000>0?m[00050?m/003o
J`00of/00?m[003oK000103oJ`00203oK@00of/00?m[003oJ`00og400?mi003oM000ogT01P3oNP00
4`3oN`00oh400?n9003oRP00ohh00?nM003ccP00`oT30;cm003og000ol/00<CN4@3_hP00o^L00;Sn
002PoQT0oMX00?nk003o]`000P3o/P00203o/`00okP00?o0003Bj`/0W^TY0=ca102:naP0kNT=0P3o
f`002P3ohP00on`00?o_003ol`00oOX00?7o003Jo`00[_8>0928H@2k;DL:0?l0000E0;<iA`1JgF80
b?l00>Wo003ko000oo800?oX003oi000g>T70?oH003oc@00olP00?o9003od@00j?<007gl7`3oc@00
okD00?nZ003oX`00oiX000L0oiT000X0oiX00?nP003oZP00okh00>_`003Oi`d0n[/00?n?003oQ`00
og/00P3oNP000`3oK@00of`00?m/00040?m[00050?mW003oH000of000?mR003oH0001`3oG005oooo
o`7o00000Oooool001_ooooo0_l00003oooooa`0od`000<0odh00?m<003oC000403oC0000`3oE`00
oe800?m<000:0?m<00030?mD003oG000oe`00140oe`000<0oed00?mL003oG000103oG0000`3oGP00
oe`00?mL00030?mL00030?mN003oH`00oe`000@0oe`00P3oJ`000`3oJ@00ofH00?mY000C0?m[0003
0?m]003oJ`00of/00080of/000@0ogD00?m/003oJ`00og00203oNP00403oQ000ohX00?n:003oV000
oK`00?_4003]h000o<800?na003o]@00okX00?o<002Fna@0Yn/@0=cG103o]0020?nX000D0?nY003o
Z000oj`00?ne003o`000olH00?o5003ob`00olX00?o7003ob000oll00?oF003og000onL00?od003g
oP00Xo0Z08?96@2@FUP;0?l0000;0?l02P2@GU80J=A/0>Go003nn000onH00?oJ003oe000ol/00?o5
003o_`000P3o^@001P3o_@00k]`00=cG1P3o/P00ojP00?nO00<0oiT000l0oiL00?nF003oT`00oi40
0?nB003oU000oiP00?nJ003oY000okh00=g_0`3o/@00oj400?n:003oO@000P3oNP000`3oL`00ofl0
0?m[00050?m[00030?mP003oG000oe`00080oe`000<0oeh00?mM003oG000103oG004ooooo`;o0000
0Oooool001_ooooo00?o0000ooooooooool00_ooool^0?m<00030?mC003oD@00od`000/0od`000<0
oe@00?mL003oG0007P3oG0000`3oH000oe`00?mL00030?mL00070?mM003oJ`00ofD00?mM003oG000
oed00?mW000B0?m[00060?m/003oJ`00of/00?m[003oK@00of`00P3oJ`000`3oK`00ogX00?mj0005
0?mj0080og/000H0ohP00?n:003oSP00oiL00?nM003oXP020?nQ000L0?nT003oY`00ok000=oM0@3o
bP00ok400?nX003oY@00oj@00?nU003oY`00ojP00?nY003o[@00ok400?nf003o^000okX00?nk003o
`000olH00?o:003oeP00on000?o`003ao`00Q?lU03nOO0d0o`000140iQ0K03NRS`2_o`40mOH00?oP
003oe000olL00?o3003o^P00okL00?nc003o/@00ojl00?n`003o[000oj@00?nK00020?nI00040?nF
003oT@00ohd00?n<00<0ohX000T0oh/00?n=003oT`00oi/00?O4003ka000oiP00?n<003oPP000P3o
NP000`3oN@00og000?m[00060?m[00030?mQ003oG000oe`000@0oe`000<0oed00?mL003oG0000P3o
G005ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool00_ooool]0?m<00030?mB003oC`00
od`000`0od`000<0oeH00?mL003oG0007P3oG0000`3oGP00oe`00?mL00030?mL00030?mQ003oIP00
oe`000<0oe`000<0of000?m[003oJ`004`3oJ`000`3oK000ofd00?m[00020?m[00040?mc003oL000
ofh00?mf00D0ogX00P3oN`001`3oR@00ohX00?n:003oS@00oi800?nF003oV0000P3oV@00303oW@00
oj@00?nR003oX000oi`00?nJ003oV`00oiT00?nK003oWP00oj<00?nW0080ojP000`0ojX00?nb003o
]`00okT00?nm003oaP00old00?oK003nlP00M?8I05JWL039<bD>0?l0000>0;@o;@18/5`0^oH?0?oO
003oc`00ol<00?ni003o]`00ojX00?nY003oZ000ojL00?nS003oW0020?nI00030?nF003oT000oh`0
00T0ohX000D0ohd00?n?003oS@00ohT00?n100030?mj00030?m`003oK000ofd000H0of/000<0ofX0
0?mN003oG0002@3oG005ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool00_oooolH0?m<
00030?m=003oC000od`00140od`000<0odl00?m>003oC0003@3oC0000`3oFP00oe`00?mL000M0?mL
00030?mM003oG000oe`000@0oe`000<0of@00?mM003oG000103oG0020?m[00040?mW003oH`00ofD0
0?mZ01<0of/00P3oK@020?m[00030?mc003oNP00ogX000@0ogX00P3oN`002P3oQ@00ohX00?n:003o
R`00ohX00?n;003oS@00oi800?nE003oV0070?nI0080oiX000<0oi`00?nP003oY`000P3oZ0002P3o
[000okD00?nh003o`000ol/00?oK003nlP00M]dd02cV;`2o:T8>0?l0000;08E=GP1nc3P0i_4=0?oZ
003ocP00okh00?ng003oZ`00ojP00?nW003oX@000`3oV@000`3oU`00oi400?n<00070?n:00090?n9
003oR000ohP00?n6003oQ`00ohH00?n2003oO000og/00080ogX000<0ofl00?m]003oK@001@3oJ`00
1@3oH@00oe`00?mN003oH@00oel000T0oe`01Oooool1o`00007ooooo000Kooooo`03o`000?oooooo
oooo00;ooooo:`3oC0000`3oC`00odh00?m<000=0?m<00030?m@003oG000oe`000<0oe`000<0oeX0
0?mK003oG000403oG0000`3oG@00oe`00?mL00050?mL00030?mM003oG000oe`000<0oe`000<0oed0
0?mP003oG000103oG0000`3oG`00of/00?mR00030?mL00030?mQ003oJ`00of/00140of/000D0ofd0
0?m[003oJ`00of/00?me00020?mb00D0ogX00P3oN`000`3oOP00ohD00?n900030?n:0080oh/000<0
ohX00?n;003oS`000P3oS`000`3oT`00oiL00?nH00040?nI000=0?nL003oXP00ojP00?nX003oZ`00
okP00?nm003oc000o^H00?Wi002Nn240Bl=S0;DNB00>0?l000070?l01@2TBUL0I/Y=09k_703od`00
okd00?nb00020?nX00070?nN003oVP00oiT00?nH003oU@00ohh00?n;00050?n:00040?n3003oQ@00
og/00?mm0080og/000<0ogd00?ml003oNP00103oNP020?m]00L0of/0103oG0000`3oG@00oeh00?mL
00070?mL00Gooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`02ooooobX0od`00P3oC@0?
0?m<00060?mG003oG000oe`00?mI003oD@00odd00P3oC0000`3oCP00oeL00?mL000E0?mL00030?mM
003oG000oe`000@0oe`000<0oeh00?mL003oG000103oG0000`3oHP00of@00?mL00040?mL00030?mZ
003oJ`00of/001<0of/00P3oK@020?m[00030?mg003oNP00ogX000@0ogX000D0og/00?ml003oOP00
oh400?n600070?n:00050?n;003oRP00oh`00?n?003oT@00103oV@00303oV`00oj400?nX003oZ@00
ojl00?nj003od`00U_HA09Go2@1GZfX0WTMI0>h46Ph0o`0000T0WE9>053a:`0[oc@0NolA0?GK003o
_@00ojd00?nX003oX0000P3oV@000`3oV000oi800?n;00050?n:00060?n4003oP000og/00?mk003o
NP00og/01`3oNP001@3oMP00ofh00?m]003oJ`00of`000H0of/000<0of<00?mL003oG0000`3oG002
0?mM00H0oe`01Oooool1o`00007ooooo000Kooooo`03o`000?oooooooooo00;ooooo:@3oC0000`3o
CP00odd00?m<000>0?m<00040?mA003oG000oe/00?mB00L0od`000<0oeH00?mL003oG0006@3oG002
0?mM00H0oe`000<0of@00?mL003oG000103oG0000`3oJ000of/00?mZ00020?mU00030?mZ003oJ`00
of/000X0of/000D0of`00?m[003oJ`00of/00?m]00020?m[00040?m]003oMP00ofl00?mf00H0ogX0
00H0og/00?ml003oNP00oh400?n3003oQP080?n:00040?n<003oR`00oiD00?nH0080oiT000/0oiX0
0?nT003oZ000ojX00?ni003oaP00jN`405go6@0noA/0DMTL081HF@0>0?l0000=09EHDP2=iQX0^_l4
0;gj303dg000okX00?nZ003oY`00oiX00?nI003oV000oi000?n;00040?n:00050?n7003oN`00ogl0
0?mj003oN`001`3oNP020?mi00030?m]003oL000of/000H0of/000D0ofX00?mR003oH@00of@00?mQ
00060?mL00030?mM003oG000oe`000<0oe`01Oooool1o`00007ooooo000Kooooo`03o`000?oooooo
oooo00;ooooo:03oC0000`3oCP00od`00?m<000>0?m<00040?m=003oF`00oeX00?m>00P0od`000<0
odd00?mK003oG000803oG0000`3oGP00oel00?mL00050?mL00030?m[003oI`00oed00080oe`000<0
oeh00?mZ003oJ`003@3oJ`001@3oK000of/00?m[003oJ`00ofh00080of/000<0ofl00?mj003oNP00
1@3oNP020?mk00060?mj003oO000ogX00?n2003oP000ohT01`3oRP003`3oR`00oi800?nH003oV@00
oiX00?nK003oY`00ojX00?ng003o`000nMl007oi7P2Xn`l0OOl206n2D@0=0?l000090?`03@2DI3X0
G<]D0=Oo103oj000ol/00?ni003oZ000oj<00080oiT000<0oi400?n:003oRP000`3oRP00103oO`00
ogh00?mk003oN`070?mj0080ogT000D0og000?m]003oK@00of/00?m/00060?m[00060?mT003oG000
oe`00?mL003oGP00of002`3oG005ooooo`7o00000Oooool001_ooooo0_l00003ooooocT0od`000<0
oeH00?mG003oC@002P3oC0000`3oF000oe`00?mL000@0?mL00030?mM003oG000oe`000D0oe`000<0
oed00?mL003oG000103oG0000`3oGP00oe`00?mL00040?mL00030?mQ003oI`00oe`000@0oe`000<0
ofH00?m[003oJ`00403oJ`001`3oK000of/00?m[003oLP00ofh00?m/003oN@001@3oNP000`3oN`00
ogX00?mk00020?mk0080og`000<0oh<00?n5003oR@001@3oRP003`3oR`00oi400?nH003oV@00oi/0
0?nT003oZ000ok<00?no003oc`00on/00>on001glR80L9540>h=6@0<0?l0000<0>H:8P3f00d0HXUh
05?b903blP00om400?nm003oZ`00oih00?nJ003oU@00oh`00`3oRP000`3oR000ogh00?mm00080?mj
00070?mh003oN@00ofl00?m/003oKP00of/00?m]00080?m[00030?mW003oG000oe`000<0oe`000<0
oeh00?mL003oG000203oG004ooooo`;o00000Oooool001_ooooo00?o0000ooooooooool00_oooolV
0?m<00030?m>003oC000od`000l0od`000<0oe800?mF003oC0002`3oC0000`3oE000oe`00?mL000N
0?mL00030?mM003oGP00oe`000D0oe`000<0of@00?mM003oG000103oG0000`3oI000of/00?m[0002
0?mZ00d0of/000D0of`00?m[003oJ`00of`00?m]00020?m[00030?mf003oM@00ogH000P0ogX000L0
og/00?mj003oO@00ogX00?n3003oQ@00ohT000@0ohX000l0oh/00?nC003oV@00oiT00?nQ003oZ@00
ok@00?no003oc`00o^T00:_b5@0Ri580db<a0?l0003_0AX02P3o0000303V1aX0>LEY03^SO`0]iDP0
E>Pj0>On003>n000jMl00?n/003oWP00oiT00?n?00<0ohX000D0ohH00?n2003oN`00ogX00?mk0007
0?mj00060?m^003oK000ofl00?m[003oK@00of`01`3oJ`00103oI000of800?mW003oH@060?mL0003
0?mM003oG000oe`000H0oe`01Oooool1o`00007ooooo000Kooooo`03o`000?oooooooooo00;ooooo
00<0ocl00?m4003oB@00=03oC0000`3oCP00oe@00?m<000<0?m<00030?mG003oG000oe`001h0oe`0
00<0oed00?mL003oG000103oG0000`3oG@00of000?mL00050?mL00030?mW003oJP00of800080oe`0
00<0of400?m[003oJ`003@3oJ`001`3oK000of/00?m[003oK@00og000?m[003oK@002P3oNP001P3o
N`00ogX00?mm003oNP00ohH00?n800D0ohX000h0oiL00?nI003oWP00ojP00?ng003ob@00omT00?kb
002Co@d0<<Ee05JEO01eG7d0FJMT0=@L?@P0o`0000d0gPXV06::JP1mj1`0N_0d0;So001Ejcd0Po/C
09kl203]iP00ojl00?nL003oU`00oh`00080ohX000@0ohT00?n1003oNP00og/01P3oNP00103oN000
of`00?m_003oK`0;0?m[00060?mW003oG000oe`00?mL003oH000oeh03P3oG005ooooo`7o00000Ooo
ool001_ooooo00?o0000ooooooooool00_ooool30?lm00030?m0003oB000od`001h0od`000<0odd0
0?m<003oC0003`3oC0000`3oC@00oe800?m<000=0?m<00030?mJ003oG000oe`001h0oe`000<0oed0
0?mL003oG000103oG0000`3oG`00oe`00?mL00050?mL00030?mZ003oG`00oe`000<0oe`000<0ofD0
0?m[003oJ`003`3oJ`001`3oK@00of/00?m[003oKP00og<00?m/003oM000203oNP001@3oO000ogX0
0?mk003oO000ogX000<0ohX00180oh/00?n:003oS`00oiT00?nN003o[@00olL00<ce1@3Nn0<0mOd0
08Co2`0glR/0S_T=04Go801ik2H0IWYO0:1GA`3V0bL30?l0000?0?843P2o<380VeTb03kLD015aUX0
W_HZ0?Cn003Yo`00F_@S0<gn003mh`00ok`00?nT003oV@00oi<000<0ohX000<0ogh00?mk003oNP00
1@3oNP000`3oN000og800?mf00020?m[00030?m/003oJ`00of/000T0of/000<0ofP00?mL003oG000
4@3oG005ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool00_ooool50?lm00030?m2003o
B`00od`002h0od`000<0oe400?m<003oC000303oC0000`3oCP00oe`00?mL00020?mL00050?mK003o
EP00oeH00?mG003oF`007P3oG0000`3oG@00oeh00?mL00050?mL0080of401@3oG0000`3oI000of/0
0?m[000B0?m[00070?m_003oJ`00of/00?m_003oN000og@00?mi00070?mj00050?mk003oNP00og`0
0?n0003oP`00103oRP008@3oU@00oi/00?nh003Am0<0/_h109SZ4P20o`/0IO8Q07ob2`3Oo`00i_l0
0;oo001>dcX0EnD_04C@:01@/dP0^B1P0?l0003c00d0J8m:05Go1P2Po`D0LO8^0>_j003ok000n_00
0:Kf6@1olPP0__440?ni003oX000oiP00?n;00020?n:00030?n1003oOP00ogX000H0ogX000D0og00
0?m[003oK@00ofd00?m[00020?m/00L0of/000D0ofX00?mQ003oH@00ofL00?mQ000B0?mL00Gooooo
0Ol00001ooooo`006oooool00ol0003oooooooooo`02ooooo`H0ocd000<0od400?m;003oC0006@3o
C0000`3oC@00od`00?m<000@0?m<00030?m@003oC000od`000d0od`000D0oe@00?mL003oG000oeX0
0?mA00040?m<00030?m=003oEP00oe`001`0oe`000<0oed00?mL003oG0001@3oG0000`3oH@00oe`0
0?mL00040?mL00060?mT003oJ`00ofT00?mS003oHP00ofP04P3oJ`00103oL@00of`00?m[003oL@09
0?mj00040?mk003oNP00oh400?n500<0ohX00100ohh00?nI003oX@00okd00??F003Sg`@0f?440=Gn
001_lQ40mO/00?kb003Jk`/0ROPJ0<co002Ko`00HI/_0`3o00003@3E7cd0?MAL0<;o1P3hnP00on@0
0?oG003od`00e>L80>kX002^nQ40o<D00?nM003oU@000P3oRP000`3oQP00ogl00?mj00050?mj0003
0?mb003oL000og800080of/000<0of`00?m[003oJ`00203oJ`001P3oI000oe`00?mL003oG000of80
0?mN0140oe`01Oooool1o`00007ooooo000Kooooo`03o`000?oooooooooo00;ooooo1`3o?@000`3o
A000od`00?m<000Z0?m<00030?m?003oC000od`000h0od`000<0oe/00?mL003oEP00203oC0000`3o
F000oe`00?mL000B0?mL00030?mM003oG000oe`000@0oe`00P3oG@060?mL00030?mN003oG@00oe`0
00D0oe`000<0ofH00?mX003oG@000P3oG0000`3oG@00ofT00?m[000@0?m[00070?m]003oJ`00of/0
0?mb003oM@00ofl00?mg00070?mj00030?mk003oNP00ogX000<0ohX00140oh/00?nD003oV@00oj@0
0?n/003o^000ol`00<7/002Eo`L0oNX00?oM003oh`00oo<00??n001adE@0BZ200?8040020?l0000@
0=<AB`1=n2`0c_l00?ce003ofP00olT00?o2003o`000okh00=oJ4`3o[P00oiT00?n>003oR`00ohX0
0?n200L0ogX00P3oJ`020?m/00`0of/000<0of@00?mL003oG0000P3oG0000`3oG`00oe`00?mL000>
0?mL00030?mF0?oooooooooo00?ooooo0Ol00001ooooo`006oooool2o`0000?ooooo203o?@000`3o
B@00od`00?m<000X0?m<00030?m>003oC@00od`000h0od`000<0oe<00?mL003oE0002@3oC0000`3o
DP00oe`00?mL000Q0?mL00030?mN003oG000oe`000@0oe`000<0oed00?mW003oG@00103oG0000`3o
I000of/00?m[000:0?m[00050?m/003oJ`00of/00?m[003oK@000`3oJ`00103oL000of/00?m[003o
L0090?mj00030?mm003oO`00ohP00080ohX00240oh`00?nF003oV@00oj400?nZ003o`P00^oX10?oR
003oc@00ol`00?oB003oj000m?d00;oo0013`El0XDm90=@H@02o;cL0;]IO03CEC01Zo1/0`Od20?oC
003o_P00okL00?n_003o[000ojT00?nL003oT`00oh/00?n:003oQ0000P3oO0040?mj0080og<000<0
og000?m[003oJ`000P3oK0080?m[00040?mW003oHP00ofD00?mX00D0oe`000<0oed00?mL003oG000
303oG0000`3oF@00od`0ooooo`03ooooo`;o00000Oooool001_ooooo00?o0000ooooooooool00_oo
ool80?lm00030?m0003oC000od`002L0od`00P3oC@0?0?m<00030?m=003oF`00oe@000/0od`04`3o
G0000`3oG@00oe`00?mL00050?mL00030?mM003oG000oe`000@0oe`000<0oeh00?mM003oG0001@3o
G0000`3oH@00oeh00?mL00040?mL00030?mT003oJ`00of/00140of/000P0ofd00?m/003oJ`00of/0
0?mc003oLP00ofl00?mi00H0ogX00P3oN`002@3oP`00ohP00?n:003oRP00oh`00?nE003oV@00oid0
0?n/00020?nj000I0?ni003o^`00olT00>[/002<o`T0JOhK05_l8`1Tnal0?j1]061kH@1Ioa40b_l0
08?o3`3dh@d0olP00?nh003o[000ojL00?nP003oV@00oiH00?n<003oRP00ohP00?mm00060?mj0080
of/000<0ofd00?m/003oJ`002@3oJ`001P3oJ@00oe`00?mL003oG000of400?mR01<0oe`000<0oe<0
0?m<0?ooool01?ooool1o`00007ooooo000Kooooo`03o`000?oooooooooo00;ooooo2@3o?@000`3o
B@00od`00?m<000V0?m<00030?m>003oC000od`000h0od`000<0oeD00?mC003oC0002`3oC0000`3o
FP00oe`00?mL000W0?mL00030?mQ003oG000oe`000@0oe`000<0ofH00?mZ003oH`000P3oGP000`3o
I`00of/00?m[000<0?m[00050?m]003oJ`00of/00?m/003oK`000P3oJ`000`3oMP00ogX00?mj0007
0?mj000O0?n2003oR@00ohX00?n;003oS000oiD00?nI003oW000oj@00?nX003oZ`00ok<00?nk003n
dP00nnP00:[n1P3Eo`00_ol807kb500VlD/0]?l:0?Wl003`m000g>L=0?nn003o/@00ojP00?nO003o
V@00oiL00?n<00020?n:00030?n1003oN`00ogX000<0ogX000<0ogD00?mc003oL0003@3oJ`000`3o
J000oe`00?mL00020?mL0080oeh01@3oG0000`3oG@00oe`00?mL000:0?mL00030?m@003oC03ooooo
00Cooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`02ooooo`T0ocd000<0odD00?m<003o
C000903oC0020?m=0100od`000<0oe000?mE003oC000303oC0000`3oF`00oe`00?mL000N0?mL0003
0?mM003oG000oe`000D0oe`000<0oeh00?mL003oG0001@3oG0000`3oJ@00oel00?mL00030?mL0003
0?mZ003oJ`00of/000X0of/000D0of`00?m[003oJ`00of/00?m/00030?m[00030?mf003oL000og40
00H0ogX000<0og/00?ml003oP0000`3oRP005P3oS000oi800?nI003oV@00oil00?nW003oZ@00ok80
0?nm003ob@00lN@00?o]003Yo000Q_@D04cD?@2@o`T0o_400?oI003ob000okT00?n[003oYP020?nI
00050?nA003oR`00ohX00?n6003oOP001@3oNP00103oK000of/00?m]003oK0090?m[00050?mW003o
HP00of@00?mZ003oGP00103oG0020?mM0140oe`000<0oe<00?m<0?ooool01?ooool1o`00007ooooo
000Kooooo`03o`000?oooooooooo00;ooooo2@3o?@000`3o@@00od`00?m<000S0?m<00030?m=003o
C000od`000l0od`000<0odd00?mE003oC000303oC0000`3oC@00oe`00?mL000V0?mL00030?mM003o
GP00oe`000D0oe`000<0of400?mP003oG000103oG0000`3oI`00of/00?m[000A0?m[00040?m_003o
K000of/00?m[00P0ogX000<0ogd00?n0003oRP000P3oRP006`3oS000oi@00?nI003oV@00oih00?nX
003oZP00okH00?nl003ob@00omT00?_^002bo`40EolA0;3o2`3nk@00om800?o2003o]`00ojT00?nS
003oV@00oiH00?n;003oRP00ohT00?n000040?mj00030?mh003oM000og4000<0of/000<0of`00?m[
003oJ`001P3oJ`001@3oG@00oe`00?mL003oGP00of@001L0oe`000<0oeP00?m<0?ooool01?ooool1
o`00007ooooo000Kooooo`03o`000?oooooooooo00;ooooo2@3o?@000`3o@@00od`00?m<000S0?m<
00030?m=003oC000od`000l0od`000<0oe<00?m<003oC000303oC0001`3oD@00oe`00?mL003oG000
oe/00?mB003oCP000P3oC0000`3oC`00oeL00?mL000E0?mL00030?mM003oG000oe`000D0oe`000<0
oed00?mL003oG0001@3oG0000`3oH@00oe`00?mL00040?mL00050?mX003oJ`00ofD00?mR003oI000
2`3oJ`001@3oK000of/00?m[003oJ`00of`00080of/000@0ofd00?mf003oL@00ogP01P3oNP000`3o
OP00oh400?n:00020?n:000F0?n<003oUP00oiT00?nI003oX@00ojP00?n/003o^@00ol@00?oA003o
i000mo/006co303Ro`00on/00?oF003oaP00okP00?nY003oX@00oiT00?nB0080ohX000<0ohH00?mk
003oNP000`3oNP00103oL`00of/00?m/003oK@0;0?m[00@0oe`000<0oed00?mO003oG0001@3oG000
0`3oG@00oe`00?mL000>0?mL00030?mA0?oooooooooo00?ooooo0Ol00001ooooo`004oooool3o`00
00Gooooo00?o0000ooooooooool00_ooool90?lm00030?lo003oC000od`003@0od`000<0oe000?m=
003oC0003@3oC0001@3oEP00oe`00?mL003oE@00odd000H0od`000<0oeH00?mL003oG0008P3oG000
0`3oGP00oed00?mL00040?mL00030?mN003oJP00of4000<0oe`000<0of<00?m[003oJ`002`3oJ`00
1@3oK000of/00?m[003oJ`00ofl00080of/000<0og000?mj003oNP001@3oNP000`3oO000ohP00?n:
00020?n:000E0?n<003oV@00oiT00?nL003oY`00ojT00?nh003o`@00om400?oU003LoP00Tol:09co
003@o0<0m>l00?oA003o`000ok000?nU003oVP00oi800080ohX000<0ogd00?mk003oNP000P3oNP00
0`3oM@00og<00?m/000:0?m[0080ofH000<0of/00?mP003oG0000`3oG0000`3oG@00oeh00?mL000E
0?mL00030?mK0?oooooooooo00?ooooo0Ol00001ooooo`005?ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00;ooooo2@3o?@000`3o@@00od`00?m<000c0?m<0080odh03P3oC000103o
C@00oe/00?mL003oDP080?m<00030?m=003oF`00oe`001X0oe`000<0oed00?mL003oG0001@3oG000
0`3oGP00oe`00?mL00040?mL00030?mR003oH000oe`000<0oe`000<0oeh00?m[003oJ`003P3oJ`00
1`3oK000of/00?m[003oJ`00og<00?me003oMP001`3oNP030?n:000G0?n;003oT`00oiT00?nK003o
Y`00ojP00?ng003o``00m>@00??h002:o`P0i_X00?Gf002AlPD0VOl50?7_303aj@00olD00?n_003o
W000oi@00?n;003oR0000P3oN`020?mj00040?mi003oJ`00of/00?m]00T0of/000D0of@00?mL003o
G000oeh00?mV00050?mL00030?mM003oG000oe`000h0oe`000L0oeD00?m@003oC`00oe000?mD003o
F@00oe`000Gooooo0Ol00001ooooo`005?ooool00ol0003oooooooooo`04ooooo`;o00000oooool9
0?lm00030?m1003oC000od`00200od`000<0odd00?m<003oC0003`3oC0000`3oC@00odh00?m<000>
0?m<00030?mC003oG000oe4000X0od`000<0oeH00?mL003oG000603oG0000`3oG@00oe`00?mL0005
0?mL00030?mN003oG000oe`000D0oe`000<0of800?mL003oG0000`3oG0001P3oGP00of/00?m[003o
I`00ofD00?mZ00h0of/00P3oK@000`3oJ`00of`00?mj00050?mj0080ogh00`3oRP005`3oSP00oiT0
0?nJ003oYP00oj/00?ni003oaP00mNl007Cb3038o@00omd00?oC003ogP00hOL00;oo002<f1<0fOT0
0?o4003oX@00oi<00?n:003oQ000og`00080ogX000<0ogP00?ma003oL0002`3oJ`001P3oH000oe`0
0?mL003oG000oed00?mP01@0oe`000<0oe400?m<003oC000103oC0000`3oD03oooooooooo`02oooo
o`;o00000Oooool001Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`T0
ocd000<0odD00?m<003oC000<P3oC0000`3oCP00od`00?m<000=0?m<00030?m=003oF`00oe8000/0
od`000<0oe<00?mL003oG0009`3oG0000`3oG`00oe`00?mL00040?mL00030?mQ003oJ@00oeh00080
oe`000<0oeh00?mZ003oJ`00303oJ`00103oK000of/00?m[003oK`020?mh00D0ogX000l0og`00?n7
003oRP00ohX00?n=003oV000oiX00?nW003o/`00okl00?o>003Wm0P0/od<0>kW003o``000P3o_P00
2P3chP00om`00?;V003WlP00m>800?79003oU`00ohX00?n0003oN`020?mj00030?md003oJ`00of/0
00P0of/000@0ofX00?mY003oJ`00of@0103oG0000`3oG@00oeh00?mL00040?mL00030?mM003oG000
oe`000X0oe`000<0oeL00?m<003oC0001P3oC005ooooo`7o00000Oooool001Cooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`02ooooo`T0ocd000<0odP00?m<003oC000<@3oC0000`3o
CP00od`00?m<000>0?m<00030?mE003oE000od`000/0od`000<0oe000?mL003oG0007`3oG0000`3o
G@00oe`00?mL00040?mL00030?mM003oGP00oe`000D0oe`000<0ofD00?mN003oG0000`3oG0000`3o
I@00of/00?m[000=0?m[00040?m/003oL000of/00?m/00@0ogX000<0og/00?mj003oO`000P3oRP00
3@3oR`00oiL00?nI003oZ`00ol/00?oD003oi`00e?/80>Oe003ob000ok<00?n[003o[0000P3o[P00
1P3o/`00olP00=;^203n^P00oi@00?n800<0ogX000<0og<00?m_003oK@00203oJ`001P3oJP00oed0
0?mL003oGP00ofH00?mN00@0oe`00P3oG@0A0?mL00030?mD003oC000od`000H0od`01Oooool1o`00
007ooooo000Cooooo`;o00001_ooool00ol0003oooooooooo`02ooooo`P0ocd000<0och00?m<003o
C000<@3oC0000`3oCP00od`00?m<000>0?m<00030?m>003oEP00od`000`0od`000<0oe@00?mL003o
G0000`3oG0000`3oF`00oeT00?mK000P0?mL00030?mM003oG000oe`000@0oe`000<0oeh00?mQ003o
G000103oG0001@3oI000of/00?m[003oJ000ofX000L0of/000D0of`00?m[003oJ`00of/00?m/0002
0?m[00030?m]003oNP00ogX000<0ogX00P3oO0005`3oQ@00ohX00?n;003oU@00oi/00?n]003]k@00
__d10<>o3@3Kn000lNP00?nm003oY`00oj400?nL003oV`00oid00?nO003o[@00lmh00?nT003oR`00
oh000080ogX000<0ogT00?mc003oJ`002@3oJ`000`3oI000oe`00?mL00020?mL00030?mQ003oG000
oe`001D0oe`000<0oe@00?m<003oC0001P3oC005ooooo`7o00000Oooool001Cooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`02ooooo`P0ocd000<0od<00?m<003oC000@P3oC0000`3o
E@00odd00?m<000<0?m<00060?mE003oG000oe`00?mL003oF@00oe000`3oC0000`3oD000oeT00?mL
000M0?mL00030?mM003oG000oe`000@0oe`000<0of000?mL003oG000103oG0001P3oI`00ofP00?mN
003oG000oed00?mY00T0of/000L0of`00?m[003oJ`00of/00?ma003oK000ofl000@0ogX001L0og/0
0?n6003oRP00oh/00?nE003oV`00oj`00?o?002AkB80Z70E0?CY003o^`00ojP00?nL003oV@00oiP0
0?nF003oU000oiH00?nL003o^P00oi<00?n600030?mj00030?m_003oJ`00of/000T0of/000<0ofL0
0?mL003oG0000`3oG0000`3oGP00oe`00?mL000D0?mL00030?mF003oC000od`000H0od`01Oooool1
o`00007ooooo000Kooooo`03o`000?oooooooooo00;ooooo203o?@000`3oB000od`00?m<00110?m<
00030?m?003oD000od`000d0od`000D0oeT00?mL003oG000oe@00?m=00050?m<00030?m=003oFP00
oe`00280oe`00P3oG@050?mL00030?mN003oJ000oed000<0oe`000<0of800?m[003oJ`002P3oJ`00
103oK000of/00?m[003oKP050?mj000>0?n0003oRP00ohX00?nC003oW000ok800??S003Eo000eo<0
0?K[003o[@00oid00?nH003oTP020?n;0080ohX000@0oh/00?n<003oQP00og`00P3oNP000`3oL`00
ofl00?m[00070?m[00050?mW003oH000of800?mY003oGP00103oG0000`3oG@00oe`00?mL000D0?mL
00030?mK003oC000od`000H0od`01Oooool1o`00007ooooo000Kooooo`03o`000?oooooooooo00;o
oooo1`3o?@000`3o@P00od`00?m<00120?m<00030?mA003oC000od`000`0od`000@0odh00?mL003o
F`00oe40203oC0000`3oC`00oe`00?mL000J0?mL00030?mM003oG000oe`000@0oe`000<0oeh00?mL
003oG000103oG0000`3oHP00oeh00?mL00030?mL00030?mP003oJ`00of/000`0of/000@0of`00?m`
003oKP00ogH00`3oNP003@3oN`00ohT00?n:003oU@00oih00?n`003fg`00knd00?o3003o/`00oj40
0?nG003oS@000`3oRP00103oQP00oh<00?n0003oOP030?mj00030?mc003oKP00of/000P0of/000D0
oeh00?mL003oG000oed00?mR00050?mL00030?mM003oG000oe`001@0oe`000<0oe<00?m<003oC000
1@3oC005ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool00_ooool70?lm00030?m9003o
C000od`00440od`000<0oe400?m<003oC0003@3oC0000`3oE000oe`00?mC000:0?m<00030?mI003o
G000oe`00200oe`000<0oed00?mL003oG0000`3oG0000`3oG@00oel00?mL00040?mL00050?mR003o
J`00of@00?mP003oI0002P3oJ`00103oK@00of/00?m[003oMP030?mj000<0?ml003oR000ohX00?nD
003oW`00ok400>[N003NhPH0ok<00?nR003oV000oh`00P3oRP001@3oP`00og`00?mk003oNP00og/0
0080ogX000<0ogT00?mb003oK0002P3oJ`001P3oGP00oe`00?mL003oG000oed00?mO00/0oe`000<0
oed00?mL003oG0001P3oG0002@3oE`00oe000?m?003oC`00oe<00?mJ003oG000oe/00?m>00060?m<
00Gooooo0Ol00001ooooo`006oooool2o`0000?ooooo1P3o?@000`3oA000od`00?m<00110?m<0080
odh03`3oC0000`3oF`00oeL00?m<000:0?m<00030?mE003oG000oe`002H0oe`000<0oeh00?mL003o
G000103oG0000`3oI`00of400?mL00020?mL00030?mW003oJ`00of/000T0of/00P3oK@004P3oLP00
ogX00?mj003oN`00ohH00?n;003oU`00ojL00?nm003Xk000lnH00?na003oW000ohh00?n:003oQP00
ogh00?mk00D0ogX000@0ogD00?m`003oJ`00of`01`3oJ`00103oHP00of000?mU003oI0040?mL0080
oed04P3oG0000`3oE000od`00?m<00040?m<00030?mB003oF`00oeP000H0od`01?ooool2o`00007o
oooo000Kooooo`03o`000?oooooooooo00;ooooo1@3o?@000`3o?`00od/00?m<00120?m<00030?m>
003oC000od`000d0od`000<0oe800?mI003oC@002`3oC0000`3oE000oe`00?mL000V0?mL00030?mM
003oG000oe`000<0oe`000<0oeh00?mQ003oG0000`3oG0000`3oI000of/00?m[000;0?m[000@0?mc
003oN@00ogX00?mj003oPP00ohd00?nN003mb`00j^D00?O9003lcP00n/`00?nG003oRP00oh@00?ml
00@0ogX000H0ogP00?mg003oJ`00ofh00?m[003oK@070?m[00060?mW003oG000oe`00?mL003oH@00
oeh05P3oG0000`3oF`00od`00?m<00060?m<00030?m=003oE`00oeH000D0od`01Oooool1o`00007o
oooo000Kooooo`03o`000?oooooooooo00;ooooo1@3o?@000`3oB@00od`00?m<00110?m<00030?m>
003oC000od`000h0od`000<0oeT00?m>003oC0002`3oC0000`3oE000oe`00?mL00030?mL00040?mJ
003oEP00oeH00?mJ01h0oe`000<0oed00?mL003oG000103oG0000`3oH000oe`00?mL00030?mL0005
0?mW003oJP00of@00?mS003oJ@00203oJ`000`3oK000of/00?m`00020?mj000;0?mo003nU`00ol80
0?_C003oY`00oi/00?nO003e/@00oh`00?n2003oN`000`3oNP000`3oN@00og000?ma00020?m/0003
0?m[003oK000of/000D0of/000<0ofT00?mZ003oJ000103oG0000`3oG`00oe`00?mL00040?mL0003
0?mM003oG000oe`000d0oe`000<0oeP00?m<003oC000203oC0000`3oE000oe<00?m<00030?m<00Go
oooo0Ol00001ooooo`006oooool00ol0003oooooooooo`02ooooo`@0ocd000<0odH00?m<003oC000
@@3oC0020?m=00l0od`00P3oDP0=0?m<00060?mG003oG000oe`00?mL003oE`00odl0103oC0000`3o
DP00oe/00?mL000Q0?mL00030?mN003oG@00oe`000<0oe`000<0oed00?mX003oG@000P3oG0000`3o
H000of/00?m[00050?m[00050?m/003oJ`00of/00?m^003oL0000P3oNP002@3oQ@00oi<00?nK003o
S`00oh/00?n9003oQ`00oh000?mk00020?mj00050?mh003oL000ofl00?m[003oK@002@3oJ`001@3o
IP00oe`00?mM003oI000oel000@0oe`000<0oeh00?mL003oG0004`3oG0000`3oF000od`00?m<0009
0?m<0080oe400`3oC005ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool00_ooool30?lm
00030?m3003oC000od`00480od`000<0odh00?m<003oC0003P3oC0000`3oEP00od`00?m<000<0?m<
00040?mJ003oG000oe`00?mD00L0od`000<0oe000?mL003oG000803oG0000`3oG@00oe`00?mL0003
0?mL00030?mQ003oG@00oe`000<0oe`02`3oJ`002@3oKP00og800?mj003oNP00ogd00?mo003oP000
og`00?mk00030?mj00060?mg003oM000of/00?m]003oJ`00of`02P3oJ`001@3oI000oe`00?mL003o
G000of4001X0oe`000<0oeX00?m<003oC0002P3oC000103oCP00oe000?m<003oC005ooooo`7o0000
0Oooool001_ooooo00?o0000ooooooooool00_ooool20?lm00030?m1003oC000od`000P0od`000D0
od/00?m8003oA@00od<00?m200020?m000040?m2003oA000odL00?m;02l0od`000<0odd00?m<003o
C0003P3oC0000`3oDP00odd00?m<000<0?m<00040?m?003oG000oe`00?mB00T0od`000<0oeL00?mL
003oG0005`3oG0000`3oG@00oe`00?mL00040?mL00030?mM003oG000oe`000<0oe`000<0oed00?mN
003oG0000`3oG0001@3oH000ofX00?mR003oG`00ofL000P0of/000@0ofd00?m`003oM@00ogT0103o
NP001@3oN@00ogD00?m`003oK`00of`000/0of/000@0of<00?mM003oHP00ofD0103oG0000`3oGP00
oe`00?mL000H0?mL00030?m?003oC000od`000X0od`00P3oCP000`3oC03oooooooooo`03ooooo`7o
00000Oooool001_ooooo00?o0000ooooooooool00_ooool00`3o?@00od000?m;00070?m<00030?m;
003oAP00od4000/0ocd000<0od800?m9003oC000?03oC0000`3oCP00oe000?m<000=0?m<00030?mC
003oG000oe<000X0od`000<0oe800?mL003oG000903oG0000`3oGP00oe`00?mL00030?mL00050?mT
003oGP00oe`00?mL003oG@002@3oJ`020?m/0080ofd000H0og000?ma003oL000ofd00?m[003oK00:
0?m[0080ofX000H0of/00?mL003oG000oe`00?mQ003oG@030?mL00030?mM003oG000oe`00100oe`0
00H0oe/00?mE003oD000odl00?mC003oF@020?mL00030?mF003oC000od`000/0od`000<0odd00?m>
0?ooool01?ooool1o`00007ooooo000Kooooo`03o`000?oooooooooo00;ooooo00<0ocl00?m;003o
C0001@3oC0000`3oB000od800?lm000?0?lm00030?m2003oB`00od`001D0od`000<0odd00?m<003o
C0004@3oC0000`3oC@00od`00?m<000>0?m<00030?m@003oC000od`000d0od`000<0oeX00?mF003o
C0002P3oC0000`3oD000oe`00?mL000T0?mL00030?mM003oG000oe`00080oe`000<0oed00?mP003o
G0000`3oG000103oJ`00ofL00?mV003oJP090?m[00030?m/003oK@00of/000`0of/000D0ofT00?mM
003oG@00ofL00?mN00030?mL00030?mN003oG000oe`001<0oe`000<0oe/00?m?003oC000103oC000
103oDP00oe/00?mL003oCP0=0?m<00030?m=0?oooooooooo00?ooooo0Ol00001ooooo`006oooool2
o`0000?ooooo00<0od/00?m<003oC0000`3oC0000`3oAP00ocl00?lm000B0?lm00030?lo003oB`00
od`002L0od`000<0odd00?m<003oC0003P3oC0020?m>00h0od`000<0oe000?mJ003oC@002`3oC000
0`3oD000oe`00?mL00040?mL00030?mK003oF@00oe/001`0oe`000<0oed00?mL003oG0000`3oG000
0`3oG`00oe`00?mL00020?mL00050?mQ003oI000oe`00?mL003oH`005@3oJ`00103oJ@00of800?mY
003oI0020?mL00030?mM003oH@00oe`00080oe`000<0oed00?mL003oG0004`3oG0000`3oEP00od`0
0?m<00050?m<00030?m=003oE`00oeL000h0od`01?ooool2o`00007ooooo000Kooooo`03o`000?oo
oooooooo00;ooooo103oC0000`3oAP00ocl00?lm000E0?lm00030?m0003oB`00od`003L0od`000<0
odh00?m<003oC0003@3oC0000`3oE`00odl00?m<000;0?m<00030?m@003oG000oe`00080oe`000<0
oeH00?m?003oC0000P3oC0000`3oDP00oe/00?mL000I0?mL00030?mM003oG000oe`000<0oe`000<0
oed00?mL003oG0000P3oG000203oH@00oe`00?mL003oG000of000?mY003oH`00of@03`3oJ`001`3o
I`00ofP00?m[003oG`00oe`00?mM003oI0000`3oG0000`3oGP00oe`00?mL000G0?mL00030?m@003o
C000od`000L0od`000<0oeL00?mC003oC000303oC005ooooo`7o00000Oooool001_ooooo00?o0000
ooooooooool00_ooool20?m<00030?m9003o@000ocd001P0ocd000<0odD00?m<003oC000=@3oC000
0`3oCP00od`00?m<000=0?m<00030?m>003oEP00od`000`0od`000D0oe000?mL003oG000oe`00?mB
00060?m<00030?m?003oG000oe`001L0oe`000<0oed00?mL003oG0000`3oG0000`3oG@00oe`00?mL
00020?mL00030?mM003oGP00oe`00080oe`000@0of<00?mO003oG000oe`00P3oJ@000`3oIP00of/0
0?m[00070?m[00030?mW003oJP00ofT00080oe`000D0ofL00?mM003oG000oe`00?mP00040?mL0003
0?mN003oG000oe`00080oe`000<0oed00?mL003oG0004@3oG0000`3oD000od`00?m<00080?m<0003
0?mF003oC@00od`000/0od`01Oooool1o`00007ooooo000Kooooo`03o`000?oooooooooo00;ooooo
00<0od/00?m4003o?P006P3o?@000`3o?P00od/00?m<000S0?m<00030?m=003oC000od`000l0od`0
00<0odd00?m<003oC0003@3oC0000`3oD`00odh00?m<000<0?m<00040?mD003oG000oe`00?mA00P0
od`000<0oeD00?mL003oG0008@3oG0000`3oGP00oe`00?mL00020?mL000C0?mP003oG000oe`00?mL
003oIP00oeh00?mL003oI@00ofT00?mP003oI000of/00?mS003oH@00ofX00?mS003oG000oel00?mU
00020?mL00030?mN003oH000oe`00080oe`000<0oeh00?mL003oG0006P3oG0000`3oD000od`00?m<
00080?m<00030?m=003oE@00od`000/0od`01Oooool1o`00007ooooo000Kooooo`03o`000?oooooo
oooo00;ooooo00<0ocl00?lm003o?@006`3o?@000`3o@`00od`00?m<00130?m<00030?m=003oD`00
od`000d0od`000<0oeP00?mL003oD`002@3oC0000`3oC`00oe`00?mL000Q0?mL00040?mM003oG000
oe`00?mL0080oed00`3oG0000`3oH@00oe`00?mL00020?mP0080oe`000D0ofL00?mL003oG000of80
0?mN00020?mL00050?mQ003oG000oe`00?mL003oGP000`3oG0000`3oG@00oe`00?mL000D0?mL0080
oeT000D0oe/00?mL003oG000oe`00?mE000;0?m<00030?m=003oDP00od`000X0od`01Oooool1o`00
007ooooo000Kooooo`03o`000?oooooooooo00;ooooo7P3o?@000`3o?`00od`00?m<000<0?m<0003
0?m=003oC000od`003@0od`000<0oe400?m<003oC000303oC0000`3oC@00oe`00?mF000;0?m<0003
0?mK003oG000oe`002@0oe`000H0oed00?mL003oG000oe`00?mM003oGP020?mL00050?mO003oG000
oe`00?mL003oH0000P3oG0001@3oGP00oe`00?mL003oG000oeh000<0oe`000@0oeh00?mL003oG000
oe`00P3oG@080?mL00030?mM003oG000oe`000P0oe`000T0oe/00?m?003oC000od`00?m=003oDP00
oe/00?mL003oFP00303oC0000`3oCP00odl00?m<00090?m<00Gooooo0Ol00001ooooo`006oooool0
0ol0003oooooooooo`02oooooal0ocd000<0odX00?m<003oC000@@3oC0020?m>00h0od`000<0oe<0
0?mJ003oC@002`3oC0000`3oF000oe`00?mL00030?mL00030?mI003oEP00oeP001<0oe`000<0oed0
0?mL003oG000303oG0001@3oGP00oe`00?mL003oG000oed000<0oe`000D0of000?mL003oG000oe`0
0?mP00020?mL00030?mN003oG000oe`00080oe`000D0oed00?mL003oG000oe`00?mM000C0?mL0003
0?m?003oC000od`000<0od`000@0odd00?mG003oG000oe00303oC0020?m>00T0od`01Oooool1o`00
007ooooo000Kooooo`03o`000?oooooooooo00;ooooo7`3o?@000`3oA`00od`00?m<00110?m<0003
0?m@003oC000od`000d0od`000<0oeP00?m?003oC0002`3oC0001P3oF000oe`00?mL003oG000oeL0
0?m>00<0od`000<0odh00?mG003oG0006P3oG0020?mM00L0oe`000<0oed00?mL003oG0002@3oG000
0`3oG@00oe`00?mL000H0?mL00030?mI003oC000od`000H0od`000<0oeL00?mH003oC000303oC000
0`3oCP00odd00?m<00070?m<00Gooooo0Ol00001ooooo`006oooool2o`0000?ooooo7`3o?@000`3o
AP00od`00?m<00100?m<0080odd03P3oC0000`3oC`00oeD00?m<000<0?m<00<0oe`000<0oe<00?m<
003oC000103oC0000`3oC@00oeT00?mL000I0?mL00030?mM003oG000oe`000h0oe`000<0oed00?mL
003oG000703oG0000`3oE`00od`00?m<00070?m<00030?mG003oD@00od`000`0od`000<0odh00?m=
003oC0001P3oC004ooooo`;o00000Oooool001_ooooo00?o0000ooooooooool0ooooool1ooooo`7o
00000Oooool001_ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Tooooo`03o`00
0?oooooooooo02Cooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0Tooooo`03o`00
0?oooooooooo02Cooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0Aooooo`7o0000
0Oooool001_ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool00_ooool1o`00007ooooo000Koooooooo00001Ol00001
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00\
\>"],
  ImageRangeCache->{{{98.5625, 327.938}, {328.25, 142.062}} -> {-4.49454, \
0.706921, 0.0128321, 0.0128321}}],

Cell["\<\
(per chi non lo riconoscesse, stiamo parlando di un famoso insieme \
frattale, noto come insieme di Mandelbrot, dal nome del matematico polacco di \
adozione francese Beno\[IHat]t B. Mandelbrot, che ne ha studiato le propriet\
\[AGrave] negli anni '70).\
\>", "Text"],

Cell[TextData[{
  "Per semplificarvi la vita, descriveremo tutte le operazioni di cui abbiamo \
parlato nel paragrafo precedente, in modo che possiate portare a termine \
l'esercitazione anche se, per esempio, avete dovuto rilanciare il kernel o \
eseguire nuovamente ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ". Ovviamente, alcune di queste operazioni - come per esempio la copia dei \
file dalla directory CompilerAdditions o l'esecuzione di ranlib - potranno \
essere saltate senza pregiudicare i risultati ottenuti."
}], "Text"],

Cell["\<\
Se leggete questo file, lo avete probabilmente scaricato dal sito \
del corso. Questa operazione ha avuto come effetto quello di creare nel \
vostro desktop una cartella il cui nome \[EGrave] math-bin. Se cos\[IGrave] \
non fosse, create una nuova cartella sul desktop (posizionandovi sul desktop \
e selezionanando la voce di menu File/New Folder dal Finder) e rinominatela \
in modo che si chiami math-bin, copiandovi infine i file mandelbrot.c e \
mandelbrot.tm che avete scaricato dal sito del corso. A questo punto possiamo \
utilizzare questa directory come directory corrente:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(SetDirectory["\<~/Desktop/math-bin\>"]\)], "Input"],

Cell[BoxData[
    \("/Users/silsis2/Desktop/math-bin"\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Prima di iniziare la seconda parte dell'esercitazione, ricordiamo che cosa \
sono i numeri complessi: l'idea \[EGrave] quella di introdurre un numero \
particolare, indicato tramite ",
  Cell[BoxData[
      \(TraditionalForm\`i\)]],
  " nella notazione matematica tradizionale ed equivalente alla radice \
quadrata di -1. Tale numero, chiamato unit\[AGrave] immaginaria, viene \
indicato in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " tramite la costante I:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(I\)], "Input"],

Cell[BoxData[
    \(\[ImaginaryI]\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(I^2\)], "Input"],

Cell[BoxData[
    \(\(-1\)\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Ovviamente \[EGrave] possibile scrivere espressioni contenenti sia l'unit\
\[AGrave] immaginaria sia altri valori numerici, nonch\[EAcute] eseguire su \
di essi le usuali operazioni algebriche, avendo cura di ricordare che il \
quadrato di ",
  Cell[BoxData[
      \(TraditionalForm\`i\)]],
  " \[EGrave] pari a -1:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Expand[\((1 - I)\) \((2 + I)\)]\)], "Input"],

Cell[BoxData[
    \(3 - \[ImaginaryI]\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "In generale il risultato di queste operazioni \[EGrave] un'espressione del \
tipo ",
  Cell[BoxData[
      \(TraditionalForm\`a + i\ b\)]],
  ", dove ",
  Cell[BoxData[
      \(TraditionalForm\`a\)]],
  " e ",
  Cell[BoxData[
      \(TraditionalForm\`b\)]],
  " sono numeri reali. Tale espressione viene chiamata numero complesso, di \
cui ",
  Cell[BoxData[
      \(TraditionalForm\`a\)]],
  " e ",
  Cell[BoxData[
      \(TraditionalForm\`b\)]],
  " sono detti, rispettivamente, la parte reale e la parte immaginaria."
}], "Text"],

Cell["\<\
La cella seguente definisce una funzione f, avente due argomenti; \
il valore restituito dalla funzione si otterr\[AGrave] sostituendo il secondo \
argomento al quadrato del primo:\
\>", "Text"],

Cell[BoxData[
    \(\(f[z_, mu_] := z^2 + mu;\)\)], "Input"],

Cell["\<\
Naturalmente \[EGrave] possibile specificare come argomenti per \
questa funzione sia numeri reali sia numeri complessi:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(f[3, 1]\)], "Input"],

Cell[BoxData[
    \(10\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(f[I, 3 - I]\)], "Input"],

Cell[BoxData[
    \(2 - \[ImaginaryI]\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Soffermiamoci ora su questo problema: dato un numero complesso ",
  Cell[BoxData[
      \(TraditionalForm\`\[Mu]\)]],
  ", calcoliamo il valore ",
  Cell[BoxData[
      \(TraditionalForm\`v\_1 = f(0, \[Mu])\)]],
  ", sulla base di questo calcoliamo ",
  Cell[BoxData[
      \(TraditionalForm\`v\_2 = f(v\_1, \[Mu])\)]],
  " e iteriamo il procedimento in modo da ottenere una successione ",
  Cell[BoxData[
      \(TraditionalForm\`\((v\_1, v\_2,  ... )\)\)]],
  ". Per esempio, se ",
  Cell[BoxData[
      \(TraditionalForm\`\[Mu] = 1 + 9  i\)]],
  ", avremo"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(mu = 1 + 9  I;\)\), "\[IndentingNewLine]", 
    \(v1 = f[0, mu]\)}], "Input"],

Cell[BoxData[
    \(1 + 9\ \[ImaginaryI]\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(v2 = f[v1, mu]\)], "Input"],

Cell[BoxData[
    \(\(-79\) + 27\ \[ImaginaryI]\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(v3 = f[v2, mu]\)], "Input"],

Cell[BoxData[
    \(5513 - 4257\ \[ImaginaryI]\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Volendo saltare le computazioni intermedie possiamo fare riferimento alla \
funzione Nest, che ci permette di calcolare f per dieci volte a partire da 0 \
(notate l'uso di una funzione pura per descrivere la funzione che accetta \
come argomento ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " e restituisce ",
  Cell[BoxData[
      \(TraditionalForm\`f(x, \[Mu])\)]],
  ":"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Nest[f[#, mu] &, 0, 10]\)], "Input"],

Cell[BoxData[
    \(\(-623208064858021916799074439021771668143862819552197414627066696475245\
102231631172175214929782592412694944543746888279937131599636748713103593811392\
046561411218586794775745366777490963036282069534385494024389939734218220691003\
247252764303085766760369976602473503611689298799898526542405700704550665224053\
948313529708312327960137833294002121493239314026832186177107893467241210933534\
367278761828488231975608105777316763072261265875129172328192233507964407077503\
749471009019468784348724487050479\) - 
      481232336374742676608010315540259251208273675001547341327227177246182553\
435011646799990957080927802736689605472609669227593285483109806010789462329057\
115131347666548742623728457045460687356733401835969225451765705899117751302064\
229646091466148555635246409353981225314935192620477248843992149399488778001517\
684305266669400529810729755660577525760007900941808874138156043511064512040610\
666897175157914805363380359872356127664335388205165099152712795138846695047935\
332904210894779203372209904873\ \[ImaginaryI]\)], "Output"]
}, Open  ]],

Cell["\<\
Se ci ponessimo il problema di decidere se la successione che \
stiamo generando sia o meno convergente, dovremmo stabilire un criterio \
approssimato per valutare se la convergenza avviene o meno senza dover \
generare tutti gli elementi della succession (che sono infiniti!). Adottiamo \
questo criterio: se il valore assoluto della parte immaginaria del primo \
elemento della sequenza \[EGrave] superiore a 100, stabiliamo che questa \
diverge, altrimenti calcoliamo il secondo elemento su cui riapplichiamo lo \
stesso criterio. Se arriviamo a generare dieci elementi della sequenza, \
decidiamo automaticamente che questa diverge. La seguente funzione mandelbrot \
accetta come argomento una lista contenente la parte reale e immaginaria di \
\[Mu] e restituisce il numero di elementi della corrispodnente sequenza che \
\[EGrave] necessario generare prima di decidere, tramite il precedente \
criterio, se questa diverge o meno:\
\>", "Text"],

Cell[BoxData[
    \(mandelbrot[{x_, y_}] := 
      Block[{nZ = 0. , nMu = N[x] + I\ N[y]}, \[IndentingNewLine]For[
          count = 0, \((Abs[nZ] < 100)\) && \((count < 
                10)\), \(count++\), \[IndentingNewLine]\(nZ = 
              f[nZ, nMu];\)\[IndentingNewLine]]; \[IndentingNewLine]count\
\[IndentingNewLine]]\)], "Input"],

Cell[TextData[{
  "Per esempio, se consideriamo nuovamente ",
  Cell[BoxData[
      \(TraditionalForm\`1 + 9  i\)]],
  " come valore per \[Mu] otteniamo il seguente risultato, che quindi \
equivale a decidere che la sequenza diverge:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(mandelbrot[{1, 9}]\)], "Input"],

Cell[BoxData[
    \(3\)], "Output"]
}, Open  ]],

Cell["\<\
Attrezziamoci per poter determinare il tempo necessario per \
calcolare questa funzione. Tenuto conto del formato della lista restituita da \
Timing, nella cella seguente memorizziamo in risultato e tempo, \
rispettivamente, il risultato di 1+1 e il tempo necessario per calcolare \
questa somma:\
\>", "Text"],

Cell[BoxData[
    \(\({tempo, risultato} = Timing[1 + 1];\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(tempo\)], "Input"],

Cell[BoxData[
    \(0.00002700000004551839`\ Second\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(risultato\)], "Input"],

Cell[BoxData[
    \(2\)], "Output"]
}, Open  ]],

Cell["\<\
Usando la stessa tecnica possiamo calcolare una lista \
bidimensionale in cui ogni posizione identifica il valore restituito da \
mandelbrot al variare della parte reale e immaginaria del valore di innesco \
di \[Mu] in due opportuni intervalli:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \({tempo, matrix} = 
      Timing[Table[
          mandelbrot[{x, y}], {y, \(-1.3\), 1.3,  .1}, {x, \(-1.7\), 
            0.5,  .1}]]\)], "Input"],

Cell[BoxData[
    \({0.21885100000008606`\ Second, {{4, 4, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 
          5, 6, 6, 6, 5, 5, 5, 5, 5, 5}, {4, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 6, 
          6, 6, 6, 6, 6, 6, 6, 5, 5, 5, 5}, {5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 6, 
          6, 6, 6, 7, 10, 8, 7, 6, 6, 6, 5, 5}, {5, 5, 5, 5, 5, 5, 5, 5, 6, 
          6, 6, 6, 6, 7, 8, 10, 10, 10, 7, 6, 6, 6, 5}, {5, 5, 5, 5, 5, 5, 6, 
          6, 6, 6, 6, 7, 7, 8, 9, 10, 10, 10, 8, 7, 6, 6, 6}, {5, 5, 5, 5, 6, 
          6, 6, 6, 6, 7, 7, 7, 8, 9, 10, 10, 10, 10, 9, 8, 7, 7, 6}, {5, 5, 
          6, 6, 6, 6, 6, 6, 7, 7, 8, 10, 10, 10, 10, 10, 10, 10, 10, 9, 9, 8, 
          6}, {5, 6, 6, 6, 6, 7, 7, 7, 7, 8, 9, 10, 10, 10, 10, 10, 10, 10, 
          10, 10, 10, 10, 7}, {6, 6, 6, 7, 7, 7, 8, 8, 8, 9, 10, 10, 10, 10, 
          10, 10, 10, 10, 10, 10, 10, 10, 7}, {6, 6, 7, 7, 10, 10, 9, 10, 9, 
          10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 8}, {6, 7, 7, 
          8, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 
          10, 10, 8}, {7, 7, 8, 9, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 
          10, 10, 10, 10, 10, 10, 10, 10, 8}, {8, 9, 9, 10, 10, 10, 10, 10, 
          10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 8}, {10, 
          10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 
          10, 10, 10, 9, 7}, {8, 9, 9, 10, 10, 10, 10, 10, 10, 10, 10, 10, 
          10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 8}, {7, 7, 8, 9, 10, 10, 
          10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 
          8}, {6, 7, 7, 8, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 
          10, 10, 10, 10, 10, 10, 8}, {6, 6, 7, 7, 10, 10, 9, 10, 9, 10, 10, 
          10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 8}, {6, 6, 6, 7, 7, 7, 
          8, 8, 8, 9, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 7}, {5, 
          6, 6, 6, 6, 7, 7, 7, 7, 8, 9, 10, 10, 10, 10, 10, 10, 10, 10, 10, 
          10, 10, 7}, {5, 5, 6, 6, 6, 6, 6, 6, 7, 7, 8, 10, 10, 10, 10, 10, 
          10, 10, 10, 9, 9, 8, 6}, {5, 5, 5, 5, 6, 6, 6, 6, 6, 7, 7, 7, 8, 9, 
          10, 10, 10, 10, 9, 8, 7, 7, 6}, {5, 5, 5, 5, 5, 5, 6, 6, 6, 6, 6, 
          7, 7, 8, 9, 10, 10, 10, 8, 7, 6, 6, 6}, {5, 5, 5, 5, 5, 5, 5, 5, 6, 
          6, 6, 6, 6, 7, 8, 10, 10, 10, 7, 6, 6, 6, 5}, {5, 5, 5, 5, 5, 5, 5, 
          5, 5, 5, 6, 6, 6, 6, 7, 10, 8, 7, 6, 6, 6, 5, 5}, {4, 5, 5, 5, 5, 
          5, 5, 5, 5, 5, 5, 6, 6, 6, 6, 6, 6, 6, 6, 5, 5, 5, 5}, {4, 4, 5, 5, 
          5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 6, 6, 6, 5, 5, 5, 5, 5, 
          5}}}\)], "Output"]
}, Open  ]],

Cell["\<\
Abbiamo ottenuto, impiegando un tempo di elaborazione quasi \
trascurabile, una matrice che possiamo visualizzare tramite la funzione \
ListDensityPlot (cercate nella documentazione elettronica sia la descrizione \
della funzione, sia quella della funzione Hue):\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(ListDensityPlot[matrix, Mesh \[Rule] False, 
        ColorFunction \[Rule] Hue];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.041806 0.0192308 0.0356125 [
[.01923 -0.0125 -3 -9 ]
[.01923 -0.0125 3 0 ]
[.22826 -0.0125 -3 -9 ]
[.22826 -0.0125 3 0 ]
[.43729 -0.0125 -6 -9 ]
[.43729 -0.0125 6 0 ]
[.64632 -0.0125 -6 -9 ]
[.64632 -0.0125 6 0 ]
[.85535 -0.0125 -6 -9 ]
[.85535 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01923 -6 -4.5 ]
[-0.0125 .01923 0 4.5 ]
[-0.0125 .19729 -6 -4.5 ]
[-0.0125 .19729 0 4.5 ]
[-0.0125 .37536 -12 -4.5 ]
[-0.0125 .37536 0 4.5 ]
[-0.0125 .55342 -12 -4.5 ]
[-0.0125 .55342 0 4.5 ]
[-0.0125 .73148 -12 -4.5 ]
[-0.0125 .73148 0 4.5 ]
[-0.0125 .90954 -12 -4.5 ]
[-0.0125 .90954 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.01923 0 m
.01923 .00625 L
s
[(0)] .01923 -0.0125 0 1 Mshowa
.22826 0 m
.22826 .00625 L
s
[(5)] .22826 -0.0125 0 1 Mshowa
.43729 0 m
.43729 .00625 L
s
[(10)] .43729 -0.0125 0 1 Mshowa
.64632 0 m
.64632 .00625 L
s
[(15)] .64632 -0.0125 0 1 Mshowa
.85535 0 m
.85535 .00625 L
s
[(20)] .85535 -0.0125 0 1 Mshowa
.125 Mabswid
.06104 0 m
.06104 .00375 L
s
.10284 0 m
.10284 .00375 L
s
.14465 0 m
.14465 .00375 L
s
.18645 0 m
.18645 .00375 L
s
.27007 0 m
.27007 .00375 L
s
.31187 0 m
.31187 .00375 L
s
.35368 0 m
.35368 .00375 L
s
.39548 0 m
.39548 .00375 L
s
.4791 0 m
.4791 .00375 L
s
.5209 0 m
.5209 .00375 L
s
.56271 0 m
.56271 .00375 L
s
.60452 0 m
.60452 .00375 L
s
.68813 0 m
.68813 .00375 L
s
.72993 0 m
.72993 .00375 L
s
.77174 0 m
.77174 .00375 L
s
.81355 0 m
.81355 .00375 L
s
.89716 0 m
.89716 .00375 L
s
.93896 0 m
.93896 .00375 L
s
.98077 0 m
.98077 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01923 m
.00625 .01923 L
s
[(0)] -0.0125 .01923 1 0 Mshowa
0 .19729 m
.00625 .19729 L
s
[(5)] -0.0125 .19729 1 0 Mshowa
0 .37536 m
.00625 .37536 L
s
[(10)] -0.0125 .37536 1 0 Mshowa
0 .55342 m
.00625 .55342 L
s
[(15)] -0.0125 .55342 1 0 Mshowa
0 .73148 m
.00625 .73148 L
s
[(20)] -0.0125 .73148 1 0 Mshowa
0 .90954 m
.00625 .90954 L
s
[(25)] -0.0125 .90954 1 0 Mshowa
.125 Mabswid
0 .05484 m
.00375 .05484 L
s
0 .09046 m
.00375 .09046 L
s
0 .12607 m
.00375 .12607 L
s
0 .16168 m
.00375 .16168 L
s
0 .23291 m
.00375 .23291 L
s
0 .26852 m
.00375 .26852 L
s
0 .30413 m
.00375 .30413 L
s
0 .33974 m
.00375 .33974 L
s
0 .41097 m
.00375 .41097 L
s
0 .44658 m
.00375 .44658 L
s
0 .48219 m
.00375 .48219 L
s
0 .51781 m
.00375 .51781 L
s
0 .58903 m
.00375 .58903 L
s
0 .62464 m
.00375 .62464 L
s
0 .66026 m
.00375 .66026 L
s
0 .69587 m
.00375 .69587 L
s
0 .76709 m
.00375 .76709 L
s
0 .80271 m
.00375 .80271 L
s
0 .83832 m
.00375 .83832 L
s
0 .87393 m
.00375 .87393 L
s
0 .94516 m
.00375 .94516 L
s
0 .98077 m
.00375 .98077 L
s
.25 Mabswid
0 0 m
0 1 L
s
.01923 .99375 m
.01923 1 L
s
.22826 .99375 m
.22826 1 L
s
.43729 .99375 m
.43729 1 L
s
.64632 .99375 m
.64632 1 L
s
.85535 .99375 m
.85535 1 L
s
.125 Mabswid
.06104 .99625 m
.06104 1 L
s
.10284 .99625 m
.10284 1 L
s
.14465 .99625 m
.14465 1 L
s
.18645 .99625 m
.18645 1 L
s
.27007 .99625 m
.27007 1 L
s
.31187 .99625 m
.31187 1 L
s
.35368 .99625 m
.35368 1 L
s
.39548 .99625 m
.39548 1 L
s
.4791 .99625 m
.4791 1 L
s
.5209 .99625 m
.5209 1 L
s
.56271 .99625 m
.56271 1 L
s
.60452 .99625 m
.60452 1 L
s
.68813 .99625 m
.68813 1 L
s
.72993 .99625 m
.72993 1 L
s
.77174 .99625 m
.77174 1 L
s
.81355 .99625 m
.81355 1 L
s
.89716 .99625 m
.89716 1 L
s
.93896 .99625 m
.93896 1 L
s
.98077 .99625 m
.98077 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .01923 m
1 .01923 L
s
.99375 .19729 m
1 .19729 L
s
.99375 .37536 m
1 .37536 L
s
.99375 .55342 m
1 .55342 L
s
.99375 .73148 m
1 .73148 L
s
.99375 .90954 m
1 .90954 L
s
.125 Mabswid
.99625 .05484 m
1 .05484 L
s
.99625 .09046 m
1 .09046 L
s
.99625 .12607 m
1 .12607 L
s
.99625 .16168 m
1 .16168 L
s
.99625 .23291 m
1 .23291 L
s
.99625 .26852 m
1 .26852 L
s
.99625 .30413 m
1 .30413 L
s
.99625 .33974 m
1 .33974 L
s
.99625 .41097 m
1 .41097 L
s
.99625 .44658 m
1 .44658 L
s
.99625 .48219 m
1 .48219 L
s
.99625 .51781 m
1 .51781 L
s
.99625 .58903 m
1 .58903 L
s
.99625 .62464 m
1 .62464 L
s
.99625 .66026 m
1 .66026 L
s
.99625 .69587 m
1 .69587 L
s
.99625 .76709 m
1 .76709 L
s
.99625 .80271 m
1 .80271 L
s
.99625 .83832 m
1 .83832 L
s
.99625 .87393 m
1 .87393 L
s
.99625 .94516 m
1 .94516 L
s
.99625 .98077 m
1 .98077 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.01923 .01923 translate
.96154 .96154 scale
69 string
23 27 8 [23 0 0 27 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage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P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`004oooool2o`0003Kooooo0ol0000cooooo`?o0000
1?ooool2o`0002oooooo0ol00003ooooo`?o0000;oooool5o`0000?ooooo0_l0000Uooooo`004_oo
ool01?l0003oooooooooool0000dooooo`05o`000?ooooooooooooooool00000<oooool00ol0003o
ooooooooo`02ooooo`04o`000?ooooooooooo`0002oooooo00Go0000ooooooooooooooooo`000003
ooooo`03o`000?oooooooooo02gooooo00Co0000oooooooooooo00000_ooool01?l0003ooooooooo
ool0000Tooooo`004_ooool01?l0003oooooooooool0000hooooo`03o`000?oooooooooo037ooooo
00?o0000ooooooooool00_ooool01?l0003oooooooooool0000_ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`00
02Cooooo000Booooo`04o`000?ooooooooooo`0003Sooooo00?o0000ooooooooool0<Oooool00ol0
003oooooooooo`02ooooo`04o`000?ooooooooooo`0002oooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`0_ooooo`05o`000?ooooooooooooooool000000_ooool00ol0003ooooooooo
o`0Rooooo`004_ooool01?l0003oooooooooool0000dooooo`Co0000=?ooool00ol0003ooooooooo
o`02ooooo`04o`000?ooooooooooo`0002oooooo00Co0000oooooooooooooooo1?l0000_ooooo`05
o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool0000Tooooo`004_ooool01?l0
003oooooooooool0000dooooo`03o`000?oooooooooo03Cooooo0_l00004ooooo`04o`000?oooooo
ooooo`0002kooooo0_l00003ooooo`03o`000?oooooooooo033ooooo00Go0000oooooooooooooooo
o`000002ooooo`04o`000?ooooooooooo`0002Cooooo000Cooooo`;o0000=Oooool5o`0003?ooooo
00?o0000ooooooooool00oooool2o`00033ooooo00Co0000oooooooooooooooo1Ol0000_ooooo`?o
00001?ooool2o`0002Gooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo003ooooo
ob7ooooo000?oooooooo00004Ol00001ooooo`003oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`02ooooo`7o0000
0Oooool000oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0fooooo`03o`000?oo
oooooooo03Kooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0fooooo`03o`000?oo
oooooooo02Cooooo0Ol00001ooooo`002?ooool2o`0000Gooooo00?o0000ooooooooool0ooooool=
ooooo`7o00000Oooool000Oooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`3o
ooooo`gooooo0Ol00001ooooo`001oooool01?l0003oooooooooool00004ooooo`03o`000?oooooo
oooo0?oooooo3Oooool1o`00007ooooo0007ooooo`04o`000?ooooooooooo`0000Cooooo0ol0003o
ooooo`cooooo0_l00001ooooo`001oooool01?l0003oooooooooool00004ooooo`03o`000?oooooo
oooo00;ooooo5ooo0029oooo02;o0?l0A?ooo`04ooooo`7o00000Oooool000Oooooo00Co0000oooo
oooooooo00001?ooool00ol0003oooooooooo`02oooooaOoo`00ROooo`0Ro`3o04Coool01?ooool1
o`00007ooooo0008ooooo`;o00001Oooool00ol0003oooooooooo`02oooooaOoo`00ROooo`0Ro`3o
04Coool01?ooool1o`00007ooooo000?ooooo`03o`000?oooooooooo00;ooooo5ooo0029oooo02;o
0?l0A?ooo`04ooooo`7o00000Oooool000oooooo00?o0000ooooooooool00_oooolGool008Woool0
8_l0o`14oooo00Cooooo0Ol00001ooooo`003oooool00ol0003oooooooooo`02oooooaOoo`00ROoo
o`0Ro`3o04Coool01?ooool1o`00007ooooo000?ooooo`03o`000?oooooooooo00;ooooo5ooo0029
oooo02;o0?l0A?ooo`04ooooo`7o00000Oooool000oooooo00?o0000ooooooooool00_oooolGool0
08Woool08_l0o`14oooo00Cooooo0Ol00001ooooo`003oooool2o`0000?ooooo5ooo0029oooo02;o
0?l0A?ooo`03ooooo`;o00000Oooool000oooooo00?o0000ooooooooool00_ooool;ool007;oool0
G?l0o`0]oooo00Cooooo0Ol00001ooooo`003oooool00ol0003oooooooooo`02ooooo`_oo`00L_oo
o`1Lo`3o02goool01?ooool1o`00007ooooo000?ooooo`03o`000?oooooooooo00;ooooo2ooo001b
oooo05co0?l0;Oooo`04ooooo`7o00000Oooool000oooooo00?o0000ooooooooool00_ooool;ool0
07;oool0G?l0o`0]oooo00Cooooo0Ol00001ooooo`003oooool00ol0003oooooooooo`02ooooo`_o
o`00L_ooo`1Lo`3o02goool01?ooool1o`00007ooooo000?ooooo`03o`000?oooooooooo00;ooooo
2ooo001boooo05co0?l0;Oooo`04ooooo`7o00000Oooool000oooooo00?o0000ooooooooool00_oo
ool;ool007;oool0G?l0o`0]oooo00Cooooo0Ol00001ooooo`003oooool00ol0003oooooooooo`02
ooooo`_oo`00L_ooo`1Lo`3o02goool01?ooool1o`00007ooooo000?ooooo`03o`000?oooooooooo
00;ooooo2ooo001boooo05co0?l0;Oooo`04ooooo`7o00000Oooool000oooooo0_l00003ooooo`_o
o`00L_ooo`1Lo`3o02goool00oooool2o`00007ooooo000?ooooo`03o`000?oooooooooo00;ooooo
L_ooo`0^o`3o00_o0?oo2ooo000<o`00o`_o0?oo8_l0o`0Goooo00Cooooo0Ol00001ooooo`003ooo
ool00ol0003oooooooooo`02ooooog;oool0;_l0o`0;o`3oo`_oo`003?l00?l;o`3oob;o0?l05ooo
o`04ooooo`7o00000Oooool000oooooo00?o0000ooooooooool00_oooomboooo02ko0?l02ol0ool;
ool000co003o2ol0oolRo`3o01Ooool01?ooool1o`00007ooooo000?ooooo`03o`000?oooooooooo
00;oooooL_ooo`0^o`3o00_o0?oo2ooo000<o`00o`_o0?oo8_l0o`0Goooo00Cooooo0Ol00001oooo
o`003oooool00ol0003oooooooooo`02ooooog;oool0;_l0o`0;o`3oo`_oo`003?l00?l;o`3oob;o
0?l05oooo`04ooooo`7o00000Oooool000oooooo00?o0000ooooooooool00_oooomboooo02ko0?l0
2ol0ool;ool000co003o2ol0oolRo`3o01Ooool01?ooool1o`00007ooooo000?ooooo`03o`000?oo
oooooooo00;oooooL_ooo`0^o`3o00_o0?oo2ooo000<o`00o`_o0?oo8_l0o`0Goooo00Cooooo0Ol0
0001ooooo`003oooool00ol0003oooooooooo`02ooooog;oool0;_l0o`0;o`3oo`_oo`003?l00?l;
o`3oob;o0?l05oooo`04ooooo`7o00000Oooool000oooooo00?o0000ooooooooool00_oooomboooo
02ko0?l02ol0ool;ool000co003o2ol0oolRo`3o01Ooool01?ooool1o`00007ooooo000?ooooo`;o
00000ooooomboooo02ko0?l02ol0ool;ool000co003o2ol0oolRo`3o01Ooool00oooool2o`00007o
oooo000?ooooo`03o`000?oooooooooo00;oooooFoooo`0io`3o00co0?oo2ol00?lRool000co0?oo
8_l0o`0;oooo00Cooooo0Ol00001ooooo`003oooool00ol0003oooooooooo`02oooooe_oool0>Ol0
o`0<o`3oo`_o003o8_oo000<o`3oob;o0?l02oooo`04ooooo`7o00000Oooool000oooooo00?o0000
ooooooooool00_oooomKoooo03Wo0?l03?l0ool;o`00ob;oo`003?l0oolRo`3o00_oool01?ooool1
o`00007ooooo000?ooooo`03o`000?oooooooooo00;oooooFoooo`0io`3o00co0?oo2ol00?lRool0
00co0?oo8_l0o`0;oooo00Cooooo0Ol00001ooooo`003oooool00ol0003oooooooooo`02oooooe_o
ool0>Ol0o`0<o`3oo`_o003o8_oo000<o`3oob;o0?l02oooo`04ooooo`7o00000Oooool000oooooo
00?o0000ooooooooool00_oooomKoooo03Wo0?l03?l0ool;o`00ob;oo`003?l0oolRo`3o00_oool0
1?ooool1o`00007ooooo000?ooooo`03o`000?oooooooooo00;oooooFoooo`0io`3o00co0?oo2ol0
0?lRool000co0?oo8_l0o`0;oooo00Cooooo0Ol00001ooooo`003oooool00ol0003oooooooooo`02
oooooe_oool0>Ol0o`0<o`3oo`_o003o8_oo000<o`3oob;o0?l02oooo`04ooooo`7o00000Oooool0
00oooooo0_l00003oooooe_oool0>Ol0o`0<o`3oo`_o003o8_oo000<o`3oob;o0?l02oooo`03oooo
o`;o00000Oooool000oooooo00?o0000ooooooooool00_oooom4oooo03Wo0?l05ol0ool<o`00o`_o
o`3o8_oo000<o`00o`_o0?oo8_l0o`04ooooo`7o00000Oooool000oooooo00?o0000ooooooooool0
0_oooom4oooo03Wo0?l05ol0ool<o`00o`_oo`3o8_oo000<o`00o`_o0?oo8_l0o`04ooooo`7o0000
0Oooool000oooooo00?o0000ooooooooool00_oooom4oooo03Wo0?l05ol0ool<o`00o`_oo`3o8_oo
000<o`00o`_o0?oo8_l0o`04ooooo`7o00000Oooool000oooooo00?o0000ooooooooool00_oooom4
oooo03Wo0?l05ol0ool<o`00o`_oo`3o8_oo000<o`00o`_o0?oo8_l0o`04ooooo`7o00000Oooool0
00oooooo00?o0000ooooooooool00_oooom4oooo03Wo0?l05ol0ool<o`00o`_oo`3o8_oo000<o`00
o`_o0?oo8_l0o`04ooooo`7o00000Oooool000oooooo00?o0000ooooooooool00_oooom4oooo03Wo
0?l05ol0ool<o`00o`_oo`3o8_oo000<o`00o`_o0?oo8_l0o`04ooooo`7o00000Oooool000oooooo
00?o0000ooooooooool00_oooom4oooo03Wo0?l05ol0ool<o`00o`_oo`3o8_oo000<o`00o`_o0?oo
8_l0o`04ooooo`7o00000Oooool000Oooooo0ol00005ooooo`03o`000?oooooooooo00;oooooA?oo
o`0io`3o01Oo0?oo3?l00?l;ool0ob;oo`003?l00?l;o`3oob;o0?l01?ooool1o`00007ooooo0006
ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`02ooooodCoool0>Ol0
o`0Go`3oo`co003o2ooo0?lRool000co003o2ol0oolRo`3o00Cooooo0Ol00001ooooo`002_ooool0
0ol0003oooooooooo`02ooooo`?o00000_oooom4oooo03Wo0?l05ol0ool<o`00o`_oo`3o8_oo000<
o`00o`_o0?oo8_l0o`03ooooo`;o00000Oooool000[ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`02ooooobkoool0>Ol0o`0Ro`3oo`_o003o3?oo0?l]ool000coo`3o2ol00?lGo`3o
o`_o0?l01?ooool1o`00007ooooo0006ooooo`Co00001Oooool00ol0003oooooooooo`02ooooobko
ool0>Ol0o`0Ro`3oo`_o003o3?oo0?l]ool000coo`3o2ol00?lGo`3oo`_o0?l01?ooool1o`00007o
oooo0006ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00_ooool^oooo03Wo0?l0
8_l0ool;o`00o`coo`3o;Ooo000<ool0o`_o003o5ol0ool;o`3o00Cooooo0Ol00001ooooo`001_oo
ool5o`0000Cooooo00?o0000ooooooooool00_ooool^oooo03Wo0?l08_l0ool;o`00o`coo`3o;Ooo
000<ool0o`_o003o5ol0ool;o`3o00Cooooo0Ol00001ooooo`003oooool00ol0003oooooooooo`02
ooooobkoool0>Ol0o`0Ro`3oo`_o003o3?oo0?l]ool000coo`3o2ol00?lGo`3oo`_o0?l01?ooool1
o`00007ooooo000?ooooo`03o`000?oooooooooo00;ooooo;_ooo`0io`3o02;o0?oo2ol00?l<ool0
obgoo`003?oo0?l;o`00oaOo0?oo2ol0o`04ooooo`7o00000Oooool000oooooo00?o0000oooooooo
ool00_ooool^oooo03Wo0?l08_l0ool;o`00o`coo`3o;Ooo000<ool0o`_o003o5ol0ool;o`3o00Co
oooo0Ol00001ooooo`003oooool00ol0003oooooooooo`02ooooobkoool0>Ol0o`0Ro`3oo`_o003o
3?oo0?l]ool000coo`3o2ol00?lGo`3oo`_o0?l01?ooool1o`00007ooooo000?ooooo`03o`000?oo
oooooooo00;ooooo;_ooo`0io`3o02;o0?oo2ol00?l<ool0obgoo`003?oo0?l;o`00oaOo0?oo2ol0
o`04ooooo`7o00000Oooool000oooooo0_l00003oooooaOoool0A?l0o`0Go`3oo`_o003oG?oo000F
ool0o`co003o2ol0o`03ooooo`;o00000Oooool000oooooo00?o0000ooooooooool00_oooolGoooo
04Co0?l05ol0ool;o`00oecoo`005_oo0?l<o`00o`_o0?l01?ooool1o`00007ooooo000?ooooo`03
o`000?oooooooooo00;ooooo5oooo`14o`3o01Oo0?oo2ol00?mLool001Koo`3o3?l00?l;o`3o00Co
oooo0Ol00001ooooo`003oooool00ol0003oooooooooo`02oooooaOoool0A?l0o`0Go`3oo`_o003o
G?oo000Fool0o`co003o2ol0o`04ooooo`7o00000Oooool000oooooo00?o0000ooooooooool00_oo
oolGoooo04Co0?l05ol0ool;o`00oecoo`005_oo0?l<o`00o`_o0?l01?ooool1o`00007ooooo000?
ooooo`03o`000?oooooooooo00;ooooo5oooo`14o`3o01Oo0?oo2ol00?mLool001Koo`3o3?l00?l;
o`3o00Cooooo0Ol00001ooooo`003oooool00ol0003oooooooooo`02oooooaOoool0A?l0o`0Go`3o
o`_o003oG?oo000Fool0o`co003o2ol0o`04ooooo`7o00000Oooool000oooooo00?o0000oooooooo
ool00_oooolGoooo04Co0?l05ol0ool;o`00oecoo`005_oo0?l<o`00o`_o0?l01?ooool1o`00007o
oooo000?ooooo`03o`000?oooooooooo00;ooooo5oooo`14o`3o01Oo0?oo2ol00?mLool001Koo`3o
3?l00?l;o`3o00Cooooo0Ol00001ooooo`003oooool2o`0000?ooooo5oooo`14o`3o01Oo0?oo2ol0
0?mLool001Koo`3o3?l00?l;o`3o00?ooooo0_l00001ooooo`003oooool00ol0003oooooooooo`02
ooooo`_oool0;_l0o`0^o`3oo`_o003o2ooo0?mnool000_o0?oo1?ooool1o`00007ooooo000?oooo
o`03o`000?oooooooooo00;ooooo2oooo`0^o`3o02ko0?oo2ol00?l;ool0ogkoo`002ol0ool4oooo
o`7o00000Oooool000oooooo00?o0000ooooooooool00_ooool;oooo02ko0?l0;_l0ool;o`00o`_o
o`3oO_oo000;o`3oo`Cooooo0Ol00001ooooo`003oooool00ol0003oooooooooo`02ooooo`_oool0
;_l0o`0^o`3oo`_o003o2ooo0?mnool000_o0?oo1?ooool1o`00007ooooo000?ooooo`03o`000?oo
oooooooo00;ooooo2oooo`0^o`3o02ko0?oo2ol00?l;ool0ogkoo`002ol0ool4ooooo`7o00000Ooo
ool000oooooo00?o0000ooooooooool00_ooool;oooo02ko0?l0;_l0ool;o`00o`_oo`3oO_oo000;
o`3oo`Cooooo0Ol00001ooooo`003oooool00ol0003oooooooooo`02ooooo`_oool0;_l0o`0^o`3o
o`_o003o2ooo0?mnool000_o0?oo1?ooool1o`00007ooooo000?ooooo`03o`000?oooooooooo00;o
oooo2oooo`0^o`3o02ko0?oo2ol00?l;ool0ogkoo`002ol0ool4ooooo`7o00000Oooool000oooooo
00?o0000ooooooooool00_ooool;oooo02ko0?l0;_l0ool;o`00o`_oo`3oO_oo000;o`3oo`Cooooo
0Ol00001ooooo`003oooool2o`0000?ooooo2oooo`0^o`3o02ko0?oo2ol00?l;ool0ogkoo`002ol0
ool3ooooo`;o00000Oooool000oooooo00?o0000ooooooooool00_oooolRo`3o02;o0?oo8ol00?l;
ool0ohWoo`002ol0ool4ooooo`7o00000Oooool000oooooo00?o0000ooooooooool00_oooolRo`3o
02;o0?oo8ol00?l;ool0ohWoo`002ol0ool4ooooo`7o00000Oooool000oooooo00?o0000oooooooo
ool00_oooolRo`3o02;o0?oo8ol00?l;ool0ohWoo`002ol0ool4ooooo`7o00000Oooool000oooooo
00?o0000ooooooooool00_oooolRo`3o02;o0?oo8ol00?l;ool0ohWoo`002ol0ool4ooooo`7o0000
0Oooool000oooooo00?o0000ooooooooool00_oooolRo`3o02;o0?oo8ol00?l;ool0ohWoo`002ol0
ool4ooooo`7o00000Oooool000oooooo00?o0000ooooooooool00_oooolRo`3o02;o0?oo8ol00?l;
ool0ohWoo`002ol0ool4ooooo`7o00000Oooool000oooooo00?o0000ooooooooool00_oooolRo`3o
02;o0?oo8ol00?l;ool0ohWoo`002ol0ool4ooooo`7o00000Oooool000oooooo00?o0000oooooooo
ool00_oooolRo`3o02;o0?oo8ol00?l;ool0ohWoo`002ol0ool4ooooo`7o00000Oooool000oooooo
00?o0000ooooooooool00_oooolRo`3o02;o0?oo8ol00?l;ool0ohWoo`002ol0ool4ooooo`7o0000
0Oooool000oooooo0_l00003oooooaOo0?l05ol0oolFool000coo`3o2ooo000<ool0oiCoo`002ol0
0?l3ooooo`;o00000Oooool000oooooo00?o0000ooooooooool00_oooolGo`3o01Oo0?oo5_oo000<
ool0o`_oo`003?oo0?nDool000_o003o1?ooool1o`00007ooooo000?ooooo`03o`000?oooooooooo
00;ooooo5ol0o`0Go`3ooaKoo`003?oo0?l;ool000coo`3oU?oo000;o`00o`Cooooo0Ol00001oooo
o`003oooool00ol0003oooooooooo`02oooooaOo0?l05ol0oolFool000coo`3o2ooo000<ool0oiCo
o`002ol00?l4ooooo`7o00000Oooool000oooooo00?o0000ooooooooool00_oooolGo`3o01Oo0?oo
5_oo000<ool0o`_oo`003?oo0?nDool000_o003o1?ooool1o`00007ooooo000?ooooo`03o`000?oo
oooooooo00;ooooo5ol0o`0Go`3ooaKoo`003?oo0?l;ool000coo`3oU?oo000;o`00o`Cooooo0Ol0
0001ooooo`003oooool00ol0003oooooooooo`02oooooaOo0?l05ol0oolFool000coo`3o2ooo000<
ool0oiCoo`002ol00?l4ooooo`7o00000Oooool00004ooooool0003o0000o`0000Cooooo0_l00005
ooooo`03o`000?oooooooooo00;ooooo5ol0o`0Go`3ooaKoo`003?oo0?l;ool000coo`3oU?oo000;
o`00o`Cooooo0Ol00001ooooo`000_ooool00ol0003oooooooooo`02ooooo`04o`000?oooooooooo
o`0000Cooooo00?o0000ooooooooool00_oooolGo`3o01Oo0?oo5_oo000<ool0o`_oo`003?oo0?nD
ool000_o003o1?ooool1o`00007ooooo0002ooooo`03o`000?oooooooooo00;ooooo00Co0000oooo
oooooooo00001?ooool3o`0000;ooooo5ol0o`0Go`3ooaKoo`003?oo0?l;ool000coo`3oU?oo000;
o`00o`?ooooo0_l00001ooooo`000_ooool00ol0003oooooooooo`02ooooo`04o`000?oooooooooo
o`0000Cooooo00?o0000ooooooooool00_ooool;o`3o01Oo0?oo3?l00?o=ool000_o003o1?ooool1
o`00007ooooo0002ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00001?ooool0
0ol0003oooooooooo`02ooooo`_o0?l05ol0ool<o`00olgoo`002ol00?l4ooooo`7o00000Oooool0
0003ooooool0003o000000Cooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`02
ooooo`_o0?l05ol0ool<o`00olgoo`002ol00?l4ooooo`7o00000Oooool000;ooooo00?o0000oooo
ooooool00oooool2o`0000Gooooo00?o0000ooooooooool00_ooool;o`3o01Oo0?oo3?l00?o=ool0
00_o003o1?ooool1o`00007ooooo000?ooooo`03o`000?oooooooooo00;ooooo2ol0o`0Go`3oo`co
003ocOoo000;o`00o`Cooooo0Ol00001ooooo`003oooool00ol0003oooooooooo`02ooooo`_o0?l0
5ol0ool<o`00olgoo`002ol00?l4ooooo`7o00000Oooool000oooooo00?o0000ooooooooool00_oo
ool;o`3o01Oo0?oo3?l00?o=ool000_o003o1?ooool1o`00007ooooo000?ooooo`03o`000?oooooo
oooo00;ooooo2ol0o`0Go`3oo`co003ocOoo000;o`00o`Cooooo0Ol00001ooooo`003oooool00ol0
003oooooooooo`02ooooo`_o0?l05ol0ool<o`00olgoo`002ol00?l4ooooo`7o00000Oooool000oo
oooo0_l00003ooooo`_o0?l05ol0ool<o`00olgoo`002ol00?l3ooooo`;o00000Oooool000oooooo
00?o0000ooooooooool00_oooolGo`3oo`_o003o3?oo0?o=ool000_o003o1?ooool1o`00007ooooo
000?ooooo`03o`000?oooooooooo00;ooooo5ol0ool;o`00o`coo`3ocOoo000;o`00o`Cooooo0Ol0
0001ooooo`003oooool00ol0003oooooooooo`02oooooaOo0?oo2ol00?l<ool0olgoo`002ol00?l4
ooooo`7o00000Oooool000oooooo00?o0000ooooooooool00_oooolGo`3oo`_o003o3?oo0?o=ool0
00_o003o1?ooool1o`00007ooooo000?ooooo`03o`000?oooooooooo00;ooooo5ol0ool;o`00o`co
o`3ocOoo000;o`00o`Cooooo0Ol00001ooooo`003oooool00ol0003oooooooooo`02oooooaOo0?oo
2ol00?l<ool0olgoo`002ol00?l4ooooo`7o00000Oooool000oooooo00?o0000ooooooooool00_oo
oolGo`3oo`_o003o3?oo0?o=ool000_o003o1?ooool1o`00007ooooo000?ooooo`03o`000?oooooo
oooo00;ooooo5ol0ool;o`00o`coo`3ocOoo000;o`00o`Cooooo0Ol00001ooooo`003oooool00ol0
003oooooooooo`02oooooaOo0?oo2ol00?l<ool0olgoo`002ol00?l4ooooo`7o00000Oooool000oo
oooo0_l00003ooooo`_o003o5ooo0?oIool000_o003o0oooool2o`00007ooooo000?ooooo`03o`00
0?oooooooooo00;ooooo2ol00?lGool0omWoo`002ol00?l4ooooo`7o00000Oooool000oooooo00?o
0000ooooooooool00_ooool;o`00oaOoo`3ofOoo000;o`00o`Cooooo0Ol00001ooooo`003oooool0
0ol0003oooooooooo`02ooooo`_o003o5ooo0?oIool000_o003o1?ooool1o`00007ooooo000?oooo
o`03o`000?oooooooooo00;ooooo2ol00?lGool0omWoo`002ol00?l4ooooo`7o00000Oooool000oo
oooo00?o0000ooooooooool00_ooool;o`00oaOoo`3ofOoo000;o`00o`Cooooo0Ol00001ooooo`00
3oooool00ol0003oooooooooo`02ooooo`_o003o5ooo0?oIool000_o003o1?ooool1o`00007ooooo
000?ooooo`03o`000?oooooooooo00;ooooo2ol00?lGool0omWoo`002ol00?l4ooooo`7o00000Ooo
ool000oooooo00?o0000ooooooooool00_ooool;o`00oaOoo`3ofOoo000;o`00o`Cooooo0Ol00001
ooooo`003oooool2o`0000?ooooo2ol00?lGool0omWoo`002ol00?l3ooooo`;o00000Oooool000oo
oooo00?o0000ooooooooool00_ooooo_ool000coo`3o2ol0ool4ooooo`7o00000Oooool000oooooo
00?o0000ooooooooool00_ooooo_ool000coo`3o2ol0ool4ooooo`7o00000Oooool000oooooo00?o
0000ooooooooool00_ooooo_ool000coo`3o2ol0ool4ooooo`7o00000Oooool000oooooo00?o0000
ooooooooool00_ooooo_ool000coo`3o2ol0ool4ooooo`7o00000Oooool000oooooo00?o0000oooo
ooooool00_ooooo_ool000coo`3o2ol0ool4ooooo`7o00000Oooool000oooooo00?o0000oooooooo
ool00_ooooo_ool000coo`3o2ol0ool4ooooo`7o00000Oooool000oooooo00?o0000ooooooooool0
0_ooooo_ool000coo`3o2ol0ool4ooooo`7o00000Oooool000oooooo00?o0000ooooooooool00_oo
ooo_ool000coo`3o2ol0ool4ooooo`7o00000Oooool000oooooo00?o0000ooooooooool00_ooooo_
ool000coo`3o2ol0ool4ooooo`7o00000Oooool000oooooo0_l00003ooooonooo`003?oo0?l;o`3o
o`?ooooo0_l00001ooooo`003oooool00ol0003oooooooooo`02ooooo`_o003o5ooo0?oIool000_o
003o1?ooool1o`00007ooooo000?ooooo`03o`000?oooooooooo00;ooooo2ol00?lGool0omWoo`00
2ol00?l4ooooo`7o00000Oooool000oooooo00?o0000ooooooooool00_ooool;o`00oaOoo`3ofOoo
000;o`00o`Cooooo0Ol00001ooooo`003oooool00ol0003oooooooooo`02ooooo`_o003o5ooo0?oI
ool000_o003o1?ooool1o`00007ooooo000?ooooo`03o`000?oooooooooo00;ooooo2ol00?lGool0
omWoo`002ol00?l4ooooo`7o00000Oooool000oooooo00?o0000ooooooooool00_ooool;o`00oaOo
o`3ofOoo000;o`00o`Cooooo0Ol00001ooooo`0000Coooooo`000?l0003o00000oooool3o`0000Go
oooo00?o0000ooooooooool00_ooool;o`00oaOoo`3ofOoo000;o`00o`Cooooo0Ol00001ooooo`00
0_ooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`02ooooo`_o003o5ooo0?oIool000_o003o1?ooool1o`00007ooooo0002ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`_o003o
5ooo0?oIool000_o003o1?ooool1o`00007ooooo0002ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool00_ooool3o`0000;ooooo5ol0ool;o`00o`coo`3ocOoo000;o`00o`?ooooo0_l0
0001ooooo`000_ooool01?l0003oooooooooooooool4o`0000Gooooo00?o0000ooooooooool00_oo
oolGo`3oo`_o003o3?oo0?o=ool000_o003o1?ooool1o`00007ooooo00000ooooooo0000o`000003
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00_oooolGo`3oo`_o003o3?oo0?o=
ool000_o003o1?ooool1o`00007ooooo0002ooooo`04o`000?ooooooooooooooo`Go00001?ooool0
0ol0003oooooooooo`02oooooaOo0?oo2ol00?l<ool0olgoo`002ol00?l4ooooo`7o00000Oooool0
00oooooo00?o0000ooooooooool00_oooolGo`3oo`_o003o3?oo0?o=ool000_o003o1?ooool1o`00
007ooooo000?ooooo`03o`000?oooooooooo00;ooooo5ol0ool;o`00o`coo`3ocOoo000;o`00o`Co
oooo0Ol00001ooooo`003oooool00ol0003oooooooooo`02oooooaOo0?oo2ol00?l<ool0olgoo`00
2ol00?l4ooooo`7o00000Oooool000oooooo00?o0000ooooooooool00_oooolGo`3oo`_o003o3?oo
0?o=ool000_o003o1?ooool1o`00007ooooo000?ooooo`03o`000?oooooooooo00;ooooo5ol0ool;
o`00o`coo`3ocOoo000;o`00o`Cooooo0Ol00001ooooo`003oooool2o`0000?ooooo5ol0ool;o`00
o`coo`3ocOoo000;o`00o`?ooooo0_l00001ooooo`003oooool00ol0003oooooooooo`02ooooo`_o
0?l05ol0ool<o`00olgoo`002ol00?l4ooooo`7o00000Oooool000oooooo00?o0000ooooooooool0
0_ooool;o`3o01Oo0?oo3?l00?o=ool000_o003o1?ooool1o`00007ooooo000?ooooo`03o`000?oo
oooooooo00;ooooo2ol0o`0Go`3oo`co003ocOoo000;o`00o`Cooooo0Ol00001ooooo`003oooool0
0ol0003oooooooooo`02ooooo`_o0?l05ol0ool<o`00olgoo`002ol00?l4ooooo`7o00000Oooool0
00oooooo00?o0000ooooooooool00_ooool;o`3o01Oo0?oo3?l00?o=ool000_o003o1?ooool1o`00
007ooooo000?ooooo`03o`000?oooooooooo00;ooooo2ol0o`0Go`3oo`co003ocOoo000;o`00o`Co
oooo0Ol00001ooooo`003oooool00ol0003oooooooooo`02ooooo`_o0?l05ol0ool<o`00olgoo`00
2ol00?l4ooooo`7o00000Oooool000oooooo00?o0000ooooooooool00_ooool;o`3o01Oo0?oo3?l0
0?o=ool000_o003o1?ooool1o`00007ooooo000?ooooo`03o`000?oooooooooo00;ooooo2ol0o`0G
o`3oo`co003ocOoo000;o`00o`Cooooo0Ol00001ooooo`003oooool2o`0000?ooooo5ol0o`0Go`3o
oaKoo`003?oo0?l;ool000coo`3oU?oo000;o`00o`?ooooo0_l00001ooooo`003oooool00ol0003o
ooooooooo`02oooooaOo0?l05ol0oolFool000coo`3o2ooo000<ool0oiCoo`002ol00?l4ooooo`7o
00000Oooool000oooooo00?o0000ooooooooool00_oooolGo`3o01Oo0?oo5_oo000<ool0o`_oo`00
3?oo0?nDool000_o003o1?ooool1o`00007ooooo000?ooooo`03o`000?oooooooooo00;ooooo5ol0
o`0Go`3ooaKoo`003?oo0?l;ool000coo`3oU?oo000;o`00o`Cooooo0Ol00001ooooo`003oooool0
0ol0003oooooooooo`02oooooaOo0?l05ol0oolFool000coo`3o2ooo000<ool0oiCoo`002ol00?l4
ooooo`7o00000Oooool000oooooo00?o0000ooooooooool00_oooolGo`3o01Oo0?oo5_oo000<ool0
o`_oo`003?oo0?nDool000_o003o1?ooool1o`00007ooooo000?ooooo`03o`000?oooooooooo00;o
oooo5ol0o`0Go`3ooaKoo`003?oo0?l;ool000coo`3oU?oo000;o`00o`Cooooo0Ol00001ooooo`00
3oooool00ol0003oooooooooo`02oooooaOo0?l05ol0oolFool000coo`3o2ooo000<ool0oiCoo`00
2ol00?l4ooooo`7o00000Oooool000oooooo00?o0000ooooooooool00_oooolGo`3o01Oo0?oo5_oo
000<ool0o`_oo`003?oo0?nDool000_o003o1?ooool1o`00007ooooo000?ooooo`03o`000?oooooo
oooo00;ooooo5ol0o`0Go`3ooaKoo`003?oo0?l;ool000coo`3oU?oo000;o`00o`Cooooo0Ol00001
ooooo`003oooool2o`0000?ooooo8_l0o`0Ro`3oob?o003o2ooo0?n9ool000_o0?oo0oooool2o`00
007ooooo000?ooooo`03o`000?oooooooooo00;ooooo8_l0o`0Ro`3oob?o003o2ooo0?n9ool000_o
0?oo1?ooool1o`00007ooooo000?ooooo`03o`000?oooooooooo00;ooooo8_l0o`0Ro`3oob?o003o
2ooo0?n9ool000_o0?oo1?ooool1o`00007ooooo000?ooooo`03o`000?oooooooooo00;ooooo8_l0
o`0Ro`3oob?o003o2ooo0?n9ool000_o0?oo1?ooool1o`00007ooooo000?ooooo`03o`000?oooooo
oooo00;ooooo8_l0o`0Ro`3oob?o003o2ooo0?n9ool000_o0?oo1?ooool1o`00007ooooo000?oooo
o`03o`000?oooooooooo00;ooooo8_l0o`0Ro`3oob?o003o2ooo0?n9ool000_o0?oo1?ooool1o`00
007ooooo000?ooooo`03o`000?oooooooooo00;ooooo8_l0o`0Ro`3oob?o003o2ooo0?n9ool000_o
0?oo1?ooool1o`00007ooooo000?ooooo`03o`000?oooooooooo00;ooooo8_l0o`0Ro`3oob?o003o
2ooo0?n9ool000_o0?oo1?ooool1o`00007ooooo000?ooooo`03o`000?oooooooooo00;ooooo8_l0
o`0Ro`3oob?o003o2ooo0?n9ool000_o0?oo1?ooool1o`00007ooooo000?ooooo`;o00000ooooolR
o`3o02;o0?oo8ol00?l;ool0ohWoo`002ol0ool3ooooo`;o00000Oooool000oooooo00?o0000oooo
ooooool00_ooool;oooo02ko0?l0;_l0ool;o`00o`_oo`3oO_oo000;o`3oo`Cooooo0Ol00001oooo
o`003oooool00ol0003oooooooooo`02ooooo`_oool0;_l0o`0^o`3oo`_o003o2ooo0?mnool000_o
0?oo1?ooool1o`00007ooooo000?ooooo`03o`000?oooooooooo00;ooooo2oooo`0^o`3o02ko0?oo
2ol00?l;ool0ogkoo`002ol0ool4ooooo`7o00000Oooool000oooooo00?o0000ooooooooool00_oo
ool;oooo02ko0?l0;_l0ool;o`00o`_oo`3oO_oo000;o`3oo`Cooooo0Ol00001ooooo`003oooool0
0ol0003oooooooooo`02ooooo`_oool0;_l0o`0^o`3oo`_o003o2ooo0?mnool000_o0?oo1?ooool1
o`00007ooooo000?ooooo`03o`000?oooooooooo00;ooooo2oooo`0^o`3o02ko0?oo2ol00?l;ool0
ogkoo`002ol0ool4ooooo`7o00000Oooool000oooooo00?o0000ooooooooool00_ooool;oooo02ko
0?l0;_l0ool;o`00o`_oo`3oO_oo000;o`3oo`Cooooo0Ol00001ooooo`001Ol00003ooooo`;o0000
1Oooool00ol0003oooooooooo`02ooooo`_oool0;_l0o`0^o`3oo`_o003o2ooo0?mnool000_o0?oo
1?ooool1o`00007ooooo00001Ooooooo0000oooooooooooo000000;ooooo00Co0000oooooooooooo
00001?ooool00ol0003oooooooooo`02ooooo`_oool0;_l0o`0^o`3oo`_o003o2ooo0?mnool000_o
0?oo1?ooool1o`00007ooooo0002ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo
00001?ooool3o`0000;ooooo5oooo`14o`3o01Oo0?oo2ol00?mLool001Koo`3o3?l00?l;o`3o00?o
oooo0_l00001ooooo`000oooool01Ol0003ooooooooooooooooo000000;ooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`02oooooaOoool0A?l0o`0Go`3oo`_o003oG?oo000Fool0o`co
003o2ol0o`04ooooo`7o00000Oooool00005o`000?ooooooooooooooool000000_ooool01?l0003o
ooooooooool00004ooooo`03o`000?oooooooooo00;ooooo5oooo`14o`3o01Oo0?oo2ol00?mLool0
01Koo`3o3?l00?l;o`3o00Cooooo0Ol00001ooooo`0000Go0000ooooooooooooooooo`000002oooo
o`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool00_oooolGoooo04Co0?l05ol0ool;
o`00oecoo`005_oo0?l<o`00o`_o0?l01?ooool1o`00007ooooo00001?oooooo0000o`000?l00004
ooooo`;o00001Oooool00ol0003oooooooooo`02oooooaOoool0A?l0o`0Go`3oo`_o003oG?oo000F
ool0o`co003o2ol0o`04ooooo`7o00000Oooool000oooooo00?o0000ooooooooool00_oooolGoooo
04Co0?l05ol0ool;o`00oecoo`005_oo0?l<o`00o`_o0?l01?ooool1o`00007ooooo000?ooooo`03
o`000?oooooooooo00;ooooo5oooo`14o`3o01Oo0?oo2ol00?mLool001Koo`3o3?l00?l;o`3o00Co
oooo0Ol00001ooooo`003oooool00ol0003oooooooooo`02oooooaOoool0A?l0o`0Go`3oo`_o003o
G?oo000Fool0o`co003o2ol0o`04ooooo`7o00000Oooool000oooooo00?o0000ooooooooool00_oo
oolGoooo04Co0?l05ol0ool;o`00oecoo`005_oo0?l<o`00o`_o0?l01?ooool1o`00007ooooo000?
ooooo`03o`000?oooooooooo00;ooooo5oooo`14o`3o01Oo0?oo2ol00?mLool001Koo`3o3?l00?l;
o`3o00Cooooo0Ol00001ooooo`003oooool2o`0000?ooooo;_ooo`0io`3o02;o0?oo2ol00?l<ool0
obgoo`003?oo0?l;o`00oaOo0?oo2ol0o`03ooooo`;o00000Oooool000oooooo00?o0000oooooooo
ool00_ooool^oooo03Wo0?l08_l0ool;o`00o`coo`3o;Ooo000<ool0o`_o003o5ol0ool;o`3o00Co
oooo0Ol00001ooooo`003oooool00ol0003oooooooooo`02ooooobkoool0>Ol0o`0Ro`3oo`_o003o
3?oo0?l]ool000coo`3o2ol00?lGo`3oo`_o0?l01?ooool1o`00007ooooo000?ooooo`03o`000?oo
oooooooo00;ooooo;_ooo`0io`3o02;o0?oo2ol00?l<ool0obgoo`003?oo0?l;o`00oaOo0?oo2ol0
o`04ooooo`7o00000Oooool000oooooo00?o0000ooooooooool00_ooool^oooo03Wo0?l08_l0ool;
o`00o`coo`3o;Ooo000<ool0o`_o003o5ol0ool;o`3o00Cooooo0Ol00001ooooo`003oooool00ol0
003oooooooooo`02ooooobkoool0>Ol0o`0Ro`3oo`_o003o3?oo0?l]ool000coo`3o2ol00?lGo`3o
o`_o0?l01?ooool1o`00007ooooo000?ooooo`03o`000?oooooooooo00;ooooo;_ooo`0io`3o02;o
0?oo2ol00?l<ool0obgoo`003?oo0?l;o`00oaOo0?oo2ol0o`04ooooo`7o00000Oooool000oooooo
00?o0000ooooooooool00_ooool^oooo03Wo0?l08_l0ool;o`00o`coo`3o;Ooo000<ool0o`_o003o
5ol0ool;o`3o00Cooooo0Ol00001ooooo`003oooool00ol0003oooooooooo`02ooooobkoool0>Ol0
o`0Ro`3oo`_o003o3?oo0?l]ool000coo`3o2ol00?lGo`3oo`_o0?l01?ooool1o`00007ooooo000?
ooooo`;o00000oooool^oooo03Wo0?l08_l0ool;o`00o`coo`3o;Ooo000<ool0o`_o003o5ol0ool;
o`3o00?ooooo0_l00001ooooo`003oooool00ol0003oooooooooo`02ooooodCoool0>Ol0o`0Go`3o
o`co003o2ooo0?lRool000co003o2ol0oolRo`3o00Cooooo0Ol00001ooooo`003oooool00ol0003o
ooooooooo`02ooooodCoool0>Ol0o`0Go`3oo`co003o2ooo0?lRool000co003o2ol0oolRo`3o00Co
oooo0Ol00001ooooo`003oooool00ol0003oooooooooo`02ooooodCoool0>Ol0o`0Go`3oo`co003o
2ooo0?lRool000co003o2ol0oolRo`3o00Cooooo0Ol00001ooooo`003oooool00ol0003ooooooooo
o`02ooooodCoool0>Ol0o`0Go`3oo`co003o2ooo0?lRool000co003o2ol0oolRo`3o00Cooooo0Ol0
0001ooooo`003oooool00ol0003oooooooooo`02ooooodCoool0>Ol0o`0Go`3oo`co003o2ooo0?lR
ool000co003o2ol0oolRo`3o00Cooooo0Ol00001ooooo`003oooool00ol0003oooooooooo`02oooo
odCoool0>Ol0o`0Go`3oo`co003o2ooo0?lRool000co003o2ol0oolRo`3o00Cooooo0Ol00001oooo
o`003oooool00ol0003oooooooooo`02ooooodCoool0>Ol0o`0Go`3oo`co003o2ooo0?lRool000co
003o2ol0oolRo`3o00Cooooo0Ol00001ooooo`003oooool00ol0003oooooooooo`02ooooodCoool0
>Ol0o`0Go`3oo`co003o2ooo0?lRool000co003o2ol0oolRo`3o00Cooooo0Ol00001ooooo`003ooo
ool00ol0003oooooooooo`02ooooodCoool0>Ol0o`0Go`3oo`co003o2ooo0?lRool000co003o2ol0
oolRo`3o00Cooooo0Ol00001ooooo`003oooool2o`0000?oooooFoooo`0io`3o00co0?oo2ol00?lR
ool000co0?oo8_l0o`0;oooo00?ooooo0_l00001ooooo`003oooool00ol0003oooooooooo`02oooo
oe_oool0>Ol0o`0<o`3oo`_o003o8_oo000<o`3oob;o0?l02oooo`04ooooo`7o00000Oooool000oo
oooo00?o0000ooooooooool00_oooomKoooo03Wo0?l03?l0ool;o`00ob;oo`003?l0oolRo`3o00_o
ool01?ooool1o`00007ooooo000?ooooo`03o`000?oooooooooo00;oooooFoooo`0io`3o00co0?oo
2ol00?lRool000co0?oo8_l0o`0;oooo00Cooooo0Ol00001ooooo`003oooool00ol0003ooooooooo
o`02oooooe_oool0>Ol0o`0<o`3oo`_o003o8_oo000<o`3oob;o0?l02oooo`04ooooo`7o00000Ooo
ool000oooooo00?o0000ooooooooool00_oooomKoooo03Wo0?l03?l0ool;o`00ob;oo`003?l0oolR
o`3o00_oool01?ooool1o`00007ooooo000?ooooo`03o`000?oooooooooo00;oooooFoooo`0io`3o
00co0?oo2ol00?lRool000co0?oo8_l0o`0;oooo00Cooooo0Ol00001ooooo`003oooool00ol0003o
ooooooooo`02oooooe_oool0>Ol0o`0<o`3oo`_o003o8_oo000<o`3oob;o0?l02oooo`04ooooo`7o
00000Oooool000oooooo00?o0000ooooooooool00_oooomKoooo03Wo0?l03?l0ool;o`00ob;oo`00
3?l0oolRo`3o00_oool01?ooool1o`00007ooooo000?ooooo`03o`000?oooooooooo00;oooooFooo
o`0io`3o00co0?oo2ol00?lRool000co0?oo8_l0o`0;oooo00Cooooo0Ol00001ooooo`003oooool2
o`0000?oooooL_ooo`0^o`3o00_o0?oo2ooo000<o`00o`_o0?oo8_l0o`0Goooo00?ooooo0_l00001
ooooo`003oooool00ol0003oooooooooo`02ooooog;oool0;_l0o`0;o`3oo`_oo`003?l00?l;o`3o
ob;o0?l05oooo`04ooooo`7o00000Oooool000oooooo00?o0000ooooooooool00_oooomboooo02ko
0?l02ol0ool;ool000co003o2ol0oolRo`3o01Ooool01?ooool1o`00007ooooo000?ooooo`03o`00
0?oooooooooo00;oooooL_ooo`0^o`3o00_o0?oo2ooo000<o`00o`_o0?oo8_l0o`0Goooo00Cooooo
0Ol00001ooooo`003oooool00ol0003oooooooooo`02ooooog;oool0;_l0o`0;o`3oo`_oo`003?l0
0?l;o`3oob;o0?l05oooo`04ooooo`7o00000Oooool000oooooo00?o0000ooooooooool00_oooomb
oooo02ko0?l02ol0ool;ool000co003o2ol0oolRo`3o01Ooool01?ooool1o`00007ooooo000?oooo
o`03o`000?oooooooooo00;oooooL_ooo`0^o`3o00_o0?oo2ooo000<o`00o`_o0?oo8_l0o`0Goooo
00Cooooo0Ol00001ooooo`001Ol00002ooooo`?o00001Oooool00ol0003oooooooooo`02ooooog;o
ool0;_l0o`0;o`3oo`_oo`003?l00?l;o`3oob;o0?l05oooo`04ooooo`7o00000Oooool00007oooo
ool0003oooooooooool0003oooooo`000003ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool00_oooomboooo02ko0?l02ol0ool;ool000co003o2ol0oolRo`3o01Ooool01?ooool1o`00
007ooooo0002ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool3o`0000;o
oooo2ooo001boooo05co0?l0;Oooo`03ooooo`;o00000Oooool000?ooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo2ooo001boooo05co0?l0
;Oooo`04ooooo`7o00000Oooool00006o`000?ooooooooooooooool0003ooooo1?l00005ooooo`03
o`000?oooooooooo00;ooooo2ooo001boooo05co0?l0;Oooo`04ooooo`7o00000Oooool00007o`00
0?ooooooooooooooool0003oooooo`000008ooooo`03o`000?oooooooooo00;ooooo2ooo001boooo
05co0?l0;Oooo`04ooooo`7o00000Oooool00004ooooool0003o0000o`0000;ooooo1Ol00004oooo
o`03o`000?oooooooooo00;ooooo2ooo001boooo05co0?l0;Oooo`04ooooo`7o00000Oooool000oo
oooo00?o0000ooooooooool00_ooool;ool007;oool0G?l0o`0]oooo00Cooooo0Ol00001ooooo`00
3oooool00ol0003oooooooooo`02ooooo`_oo`00L_ooo`1Lo`3o02goool01?ooool1o`00007ooooo
000?ooooo`03o`000?oooooooooo00;ooooo2ooo001boooo05co0?l0;Oooo`04ooooo`7o00000Ooo
ool000oooooo00?o0000ooooooooool00_ooool;ool007;oool0G?l0o`0]oooo00Cooooo0Ol00001
ooooo`003oooool00ol0003oooooooooo`02ooooo`_oo`00L_ooo`1Lo`3o02goool01?ooool1o`00
007ooooo000?ooooo`;o00000ooooolGool008Woool08_l0o`14oooo00?ooooo0_l00001ooooo`00
3oooool00ol0003oooooooooo`02oooooaOoo`00ROooo`0Ro`3o04Coool01?ooool1o`00007ooooo
000?ooooo`03o`000?oooooooooo00;ooooo5ooo0029oooo02;o0?l0A?ooo`04ooooo`7o00000Ooo
ool000oooooo00?o0000ooooooooool00_oooolGool008Woool08_l0o`14oooo00Cooooo0Ol00001
ooooo`003oooool00ol0003oooooooooo`02oooooaOoo`00ROooo`0Ro`3o04Coool01?ooool1o`00
007ooooo000?ooooo`03o`000?oooooooooo00;ooooo5ooo0029oooo02;o0?l0A?ooo`04ooooo`7o
00000Oooool000oooooo00?o0000ooooooooool00_oooolGool008Woool08_l0o`14oooo00Cooooo
0Ol00001ooooo`003oooool00ol0003oooooooooo`02oooooaOoo`00ROooo`0Ro`3o04Coool01?oo
ool1o`00007ooooo000?ooooo`03o`000?oooooooooo00;ooooo5ooo0029oooo02;o0?l0A?ooo`04
ooooo`7o00000Oooool000oooooo00?o0000ooooooooool00_oooolGool008Woool08_l0o`14oooo
00Cooooo0Ol00001ooooo`003oooool2o`000?oooooo3Oooool2o`00007ooooo000?ooooo`03o`00
0?oooooooooo0?oooooo3Oooool1o`00007ooooo000?ooooo`03o`000?oooooooooo0?oooooo3Ooo
ool1o`00007ooooo000?ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0=_ooool0
0ol0003oooooooooo`0fooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0=_ooool0
0ol0003oooooooooo`0Tooooo`7o00000Oooool000oooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool00_ooool1o`00
007ooooo000?oooooooo00004Ol00001ooooo`00oooooolQooooo`00\
\>"],
  ImageRangeCache->{{{132.938, 362.312}, {441.438, 212.062}} -> {-16.4739, \
25.4613, 0.0882003, 0.10354}}]
}, Open  ]],

Cell["\<\
Per tentare di visualizzare meglio i bordi dell'insieme rosso al \
centro del grafico possiamo discretizzare il rettangolo considerato \
utilizzando un maggior numero di punti:\
\>", "Text"],

Cell[BoxData[
    \(\({tempo, matrix} = 
        Timing[Table[
            mandelbrot[{x, y}], {y, \(-1.3\), 1.3,  .05}, {x, \(-1.7\), 
              0.5,  .05}]];\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(tempo\)], "Input"],

Cell[BoxData[
    \(0.8336629999998877`\ Second\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(ListDensityPlot[matrix, Mesh \[Rule] False, 
        ColorFunction \[Rule] Hue];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0213675 0.0192308 0.0181422 [
[.01923 -0.0125 -3 -9 ]
[.01923 -0.0125 3 0 ]
[.23291 -0.0125 -6 -9 ]
[.23291 -0.0125 6 0 ]
[.44658 -0.0125 -6 -9 ]
[.44658 -0.0125 6 0 ]
[.66026 -0.0125 -6 -9 ]
[.66026 -0.0125 6 0 ]
[.87393 -0.0125 -6 -9 ]
[.87393 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01923 -6 -4.5 ]
[-0.0125 .01923 0 4.5 ]
[-0.0125 .20065 -12 -4.5 ]
[-0.0125 .20065 0 4.5 ]
[-0.0125 .38208 -12 -4.5 ]
[-0.0125 .38208 0 4.5 ]
[-0.0125 .5635 -12 -4.5 ]
[-0.0125 .5635 0 4.5 ]
[-0.0125 .74492 -12 -4.5 ]
[-0.0125 .74492 0 4.5 ]
[-0.0125 .92634 -12 -4.5 ]
[-0.0125 .92634 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.01923 0 m
.01923 .00625 L
s
[(0)] .01923 -0.0125 0 1 Mshowa
.23291 0 m
.23291 .00625 L
s
[(10)] .23291 -0.0125 0 1 Mshowa
.44658 0 m
.44658 .00625 L
s
[(20)] .44658 -0.0125 0 1 Mshowa
.66026 0 m
.66026 .00625 L
s
[(30)] .66026 -0.0125 0 1 Mshowa
.87393 0 m
.87393 .00625 L
s
[(40)] .87393 -0.0125 0 1 Mshowa
.125 Mabswid
.06197 0 m
.06197 .00375 L
s
.1047 0 m
.1047 .00375 L
s
.14744 0 m
.14744 .00375 L
s
.19017 0 m
.19017 .00375 L
s
.27564 0 m
.27564 .00375 L
s
.31838 0 m
.31838 .00375 L
s
.36111 0 m
.36111 .00375 L
s
.40385 0 m
.40385 .00375 L
s
.48932 0 m
.48932 .00375 L
s
.53205 0 m
.53205 .00375 L
s
.57479 0 m
.57479 .00375 L
s
.61752 0 m
.61752 .00375 L
s
.70299 0 m
.70299 .00375 L
s
.74573 0 m
.74573 .00375 L
s
.78846 0 m
.78846 .00375 L
s
.8312 0 m
.8312 .00375 L
s
.91667 0 m
.91667 .00375 L
s
.9594 0 m
.9594 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01923 m
.00625 .01923 L
s
[(0)] -0.0125 .01923 1 0 Mshowa
0 .20065 m
.00625 .20065 L
s
[(10)] -0.0125 .20065 1 0 Mshowa
0 .38208 m
.00625 .38208 L
s
[(20)] -0.0125 .38208 1 0 Mshowa
0 .5635 m
.00625 .5635 L
s
[(30)] -0.0125 .5635 1 0 Mshowa
0 .74492 m
.00625 .74492 L
s
[(40)] -0.0125 .74492 1 0 Mshowa
0 .92634 m
.00625 .92634 L
s
[(50)] -0.0125 .92634 1 0 Mshowa
.125 Mabswid
0 .05552 m
.00375 .05552 L
s
0 .0918 m
.00375 .0918 L
s
0 .12808 m
.00375 .12808 L
s
0 .16437 m
.00375 .16437 L
s
0 .23694 m
.00375 .23694 L
s
0 .27322 m
.00375 .27322 L
s
0 .30951 m
.00375 .30951 L
s
0 .34579 m
.00375 .34579 L
s
0 .41836 m
.00375 .41836 L
s
0 .45464 m
.00375 .45464 L
s
0 .49093 m
.00375 .49093 L
s
0 .52721 m
.00375 .52721 L
s
0 .59978 m
.00375 .59978 L
s
0 .63607 m
.00375 .63607 L
s
0 .67235 m
.00375 .67235 L
s
0 .70864 m
.00375 .70864 L
s
0 .7812 m
.00375 .7812 L
s
0 .81749 m
.00375 .81749 L
s
0 .85377 m
.00375 .85377 L
s
0 .89006 m
.00375 .89006 L
s
0 .96263 m
.00375 .96263 L
s
0 .99891 m
.00375 .99891 L
s
.25 Mabswid
0 0 m
0 1 L
s
.01923 .99375 m
.01923 1 L
s
.23291 .99375 m
.23291 1 L
s
.44658 .99375 m
.44658 1 L
s
.66026 .99375 m
.66026 1 L
s
.87393 .99375 m
.87393 1 L
s
.125 Mabswid
.06197 .99625 m
.06197 1 L
s
.1047 .99625 m
.1047 1 L
s
.14744 .99625 m
.14744 1 L
s
.19017 .99625 m
.19017 1 L
s
.27564 .99625 m
.27564 1 L
s
.31838 .99625 m
.31838 1 L
s
.36111 .99625 m
.36111 1 L
s
.40385 .99625 m
.40385 1 L
s
.48932 .99625 m
.48932 1 L
s
.53205 .99625 m
.53205 1 L
s
.57479 .99625 m
.57479 1 L
s
.61752 .99625 m
.61752 1 L
s
.70299 .99625 m
.70299 1 L
s
.74573 .99625 m
.74573 1 L
s
.78846 .99625 m
.78846 1 L
s
.8312 .99625 m
.8312 1 L
s
.91667 .99625 m
.91667 1 L
s
.9594 .99625 m
.9594 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .01923 m
1 .01923 L
s
.99375 .20065 m
1 .20065 L
s
.99375 .38208 m
1 .38208 L
s
.99375 .5635 m
1 .5635 L
s
.99375 .74492 m
1 .74492 L
s
.99375 .92634 m
1 .92634 L
s
.125 Mabswid
.99625 .05552 m
1 .05552 L
s
.99625 .0918 m
1 .0918 L
s
.99625 .12808 m
1 .12808 L
s
.99625 .16437 m
1 .16437 L
s
.99625 .23694 m
1 .23694 L
s
.99625 .27322 m
1 .27322 L
s
.99625 .30951 m
1 .30951 L
s
.99625 .34579 m
1 .34579 L
s
.99625 .41836 m
1 .41836 L
s
.99625 .45464 m
1 .45464 L
s
.99625 .49093 m
1 .49093 L
s
.99625 .52721 m
1 .52721 L
s
.99625 .59978 m
1 .59978 L
s
.99625 .63607 m
1 .63607 L
s
.99625 .67235 m
1 .67235 L
s
.99625 .70864 m
1 .70864 L
s
.99625 .7812 m
1 .7812 L
s
.99625 .81749 m
1 .81749 L
s
.99625 .85377 m
1 .85377 L
s
.99625 .89006 m
1 .89006 L
s
.99625 .96263 m
1 .96263 L
s
.99625 .99891 m
1 .99891 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.01923 .01923 translate
.96154 .96154 scale
135 string
45 53 8 [45 0 0 53 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FF0000FF0000FF0000FF0000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FF0000FF0000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FF0000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FF0000FF00
00FF0000FF0000FF0000FF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FFFF00FFFF0000FFFF0000FF00000000FF00FFFF00FFFF00FFFF
00FF0000FF0000FF0000FF0000FF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FFFF00FFFF00FFFF0000FFFF0000FF0000FF00FFFF00FF0000FF00FFFF
00FFFF00FF0000FF0000FF0000FF0000FF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FFFF00FFFF00FFFF0000FFFF00FFFF0000FF0000FF0000FF0000FF00000000FF
00FFFF00FFFF00FF0000FF0000FF0000FF0000FF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF
00FFFF00FFFF00FFFF0000FF0000FFFF00FFFF0000FF0000FF0000FF0000FF00000000FF
00FFFF00FFFF00FFFF00FF0000FF0000FF0000FF0000FF0000FF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF00FFFF00FFFF
00FFFF00FFFF0000FF0000FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF00FF
0000FF00FFFF00FFFF00FFFF00FF0000FF0000FF0000FF0000FF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF00FFFF00FFFF00FFFF
00FFFF0000FF0000FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FF00FFFF00FFFF00FFFF00FF0000FF0000FF0000FF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FFFF00FFFF00FFFF00FFFF00FFFF0000FF
0000FF0000FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00FF0000FF0000FF00FFFF00FFFF00FFFF00FFFF00FF0000FF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FFFF00FFFF00FFFF00FFFF0000FF0000FFFF00FF
FF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00FF0000FF0000FF0000FF0000FF00FFFF00FFFF00FF00
FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FFFF00FFFF00FFFF00FFFF00FFFF0000FFFF00FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00FFFF00FFFF00FFFF00000000FF00FFFF00FF00
FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF00FFFF
FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FFFF00FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF00FFFF
FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FFFF00FFFF00FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF00FFFF
00FF0000FF0000FF0000FF0000FF0000FF0000FFFF00FFFF00FFFF00FFFF00FFFF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF00FFFF00FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF00FFFF
00FF0000FF0000FF0000FF0000FF0000FFFF00FFFF00FFFFFF00FFFF00FF0000FF0000FF
0000FF0000FF0000FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF
00FF0000FF0000FF0000FF0000FFFF00FFFF00FFFF0000FFFF0000FF0000FF0000FF00FF
FF00FFFF0000FF0000FF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
00FF0000FF0000FF0000FFFF00FFFF00FFFF0000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
00FF0000FF0000FFFF00FFFF00FFFF00FFFF0000FFFF00FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FFFF00FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
00FFFF00FFFF00FFFF0000FF0000FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
00FFFF0000FF0000FF0000FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF
0000FF0000FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF
FF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF00FFFF
FF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF
0000FF0000FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF
00FFFF0000FF0000FF0000FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF
00FFFF00FFFF00FFFF0000FF0000FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FFFF00FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
00FF0000FF0000FFFF00FFFF00FFFF00FFFF0000FFFF00FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
00FF0000FF0000FF0000FFFF00FFFF00FFFF0000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
00FF0000FF0000FF0000FF0000FFFF00FFFF00FFFF0000FFFF0000FF0000FF0000FF00FF
FF00FFFF0000FF0000FF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
00FF0000FF0000FF0000FF0000FF0000FFFF00FFFF00FFFFFF00FFFF00FF0000FF0000FF
0000FF0000FF0000FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF
00FF0000FF0000FF0000FF0000FF0000FF0000FFFF00FFFF00FFFF00FFFF00FFFF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF00FFFF00FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF00FFFF
FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FFFF00FFFF00FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF00FFFF
FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FFFF00FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF00FFFF
FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF00FFFF
FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FFFF00FFFF00FFFF00FFFF00FFFF0000FFFF00FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00FFFF00FFFF00FFFF00000000FF00FFFF00FF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FFFF00FFFF00FFFF00FFFF0000FF0000FFFF00FF
FF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00FF0000FF0000FF0000FF0000FF00FFFF00FFFF00FF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FFFF00FFFF00FFFF00FFFF00FFFF0000FF
0000FF0000FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00FF0000FF0000FF00FFFF00FFFF00FFFF00FFFF00FF0000FF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF00FFFF00FFFF00FFFF
00FFFF0000FF0000FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FF00FFFF00FFFF00FFFF00FF0000FF0000FF0000FF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF00FFFF00FFFF
00FFFF00FFFF0000FF0000FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF00FF
0000FF00FFFF00FFFF00FFFF00FF0000FF0000FF0000FF0000FF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF
00FFFF00FFFF00FFFF0000FF0000FFFF00FFFF0000FF0000FF0000FF0000FF00000000FF
00FFFF00FFFF00FFFF00FF0000FF0000FF0000FF0000FF0000FF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FFFF00FFFF00FFFF0000FFFF00FFFF0000FF0000FF0000FF0000FF00000000FF
00FFFF00FFFF00FF0000FF0000FF0000FF0000FF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FFFF00FFFF00FFFF0000FFFF0000FF0000FF00FFFF00FF0000FF00FFFF
00FFFF00FF0000FF0000FF0000FF0000FF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FFFF00FFFF0000FFFF0000FF00000000FF00FFFF00FFFF00FFFF
00FF0000FF0000FF0000FF0000FF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FF0000FF00
00FF0000FF0000FF0000FF00FFFF00FFFF00FFFF00FFFF00FFFF00
FF0000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FF0000FF0000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FF0000FF0000FF0000FF0000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`004oooool2o`0003Cooooo0ol00004ooooo`;o0000
<?ooool5o`0000?ooooo0_l0000aooooo`?o00001?ooool2o`0003;ooooo0ol00003ooooo`;o0000
8?ooool001;ooooo00Co0000oooooooooooo0000=?ooool00ol0003oooooooooo`02ooooo`04o`00
0?ooooooooooo`00033ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0000_
ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool0000booooo`05o`00
0?ooooooooooooooool000000_ooool00ol0003oooooooooo`0Mooooo`004_ooool01?l0003ooooo
ooooool0000dooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo0000<Oooool00ol0
003oooooooooo`02ooooo`04o`000?ooooooooooo`0003?ooooo00Co0000oooooooooooo00000_oo
ool00ol0003oooooooooo`0]ooooo`Go00000_ooool01?l0003oooooooooool0000Oooooo`004_oo
ool01?l0003oooooooooool0000dooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo
0000<_ooool01Ol0003ooooooooooooooooo000000;ooooo00?o0000ooooooooool0;oooool2o`00
00?ooooo00Co0000oooooooooooo0000;oooool01?l0003oooooooooool00003ooooo`04o`000?oo
ooooooooo`0001oooooo000Booooo`04o`000?ooooooooooo`0003Cooooo00?o0000ooooooooool0
0_ooool01?l0003oooooooooool0000_ooooo`05o`000?ooooooooooooooool000000_ooool01?l0
003oooooooooool0000cooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool0;_oo
ool00ol0003oooooo`000003ooooo`04o`000?ooooooooooo`0001oooooo000Booooo`04o`000?oo
ooooooooo`0003?ooooo0_l00004ooooo`04o`000?ooooooooooo`0002oooooo00Go0000oooooooo
ooooooooo`000002ooooo`04o`000?ooooooooooo`0002oooooo00Go0000ooooooooooooooooo`00
0002ooooo`04o`000?ooooooooooo`00037ooooo0_l00003ooooo`04o`000?ooooooooooo`0001oo
oooo000Cooooo`;o0000=Oooool00ol0003oooooooooo`03ooooo`;o0000<Oooool3o`0000Cooooo
0_l0000aooooo`?o00001?ooool2o`0003?ooooo00?o0000ooooooooool00_ooool2o`00023ooooo
003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo000?oooooooo0000
4Ol00001ooooo`003oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool02?ooool1o`00007ooooo000?ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool0=oooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo03Oooooo00?o0000
ooooooooool0=oooool00ol0003oooooooooo`0Oooooo`7o00000Oooool000Sooooo0_l00005oooo
o`03o`000?oooooooooo0?oooooo3Oooool1o`00007ooooo0007ooooo`04o`000?ooooooooooo`00
00Cooooo00?o0000ooooooooool0ooooool=ooooo`7o00000Oooool000Oooooo00Co0000oooooooo
oooo00001?ooool00ol0003oooooooooo`3oooooo`gooooo0Ol00001ooooo`001oooool01?l0003o
ooooooooool00004ooooo`?o0000ooooool<ooooo`;o00000Oooool000Oooooo00Co0000oooooooo
oooo00001?ooool00ol0003oooooooooo`02oooooaOoo`00Q_ooo`0Yo`3o043oool01?ooool1o`00
007ooooo0007ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool00_oooolGool0
08Koool0:Ol0o`10oooo00Cooooo0Ol00001ooooo`002?ooool2o`0000Gooooo00?o0000oooooooo
ool00_oooolGool008Koool0:Ol0o`10oooo00Cooooo0Ol00001ooooo`003oooool00ol0003ooooo
ooooo`02oooooaOoo`00Q_ooo`0Yo`3o043oool01?ooool1o`00007ooooo000?ooooo`03o`000?oo
oooooooo00;ooooo5ooo0026oooo02Wo0?l0@?ooo`04ooooo`7o00000Oooool000oooooo00?o0000
ooooooooool00_ooool<ool008Koool0A_l0o`0^oooo00Cooooo0Ol00001ooooo`003oooool00ol0
003oooooooooo`02ooooo`coo`00Q_ooo`16o`3o02koool01?ooool1o`00007ooooo000?ooooo`03
o`000?oooooooooo00;ooooo3?oo0026oooo04Ko0?l0;_ooo`04ooooo`7o00000Oooool000oooooo
00?o0000ooooooooool00_ooool<ool008Koool0A_l0o`0^oooo00Cooooo0Ol00001ooooo`003ooo
ool2o`0000?ooooo3?oo0026oooo04Ko0?l0;_ooo`03ooooo`;o00000Oooool000oooooo00?o0000
ooooooooool00_ooool6ool007[oool0GOl0o`0Yoooo00Cooooo0Ol00001ooooo`003oooool00ol0
003oooooooooo`02ooooo`Koo`00N_ooo`1Mo`3o02Woool01?ooool1o`00007ooooo000?ooooo`03
o`000?oooooooooo00;ooooo1_oo001joooo05go0?l0:Oooo`04ooooo`7o00000Oooool000oooooo
00?o0000ooooooooool00_ooool6ool007[oool0GOl0o`0Yoooo00Cooooo0Ol00001ooooo`003ooo
ool00ol0003oooooooooo`02ooooogGoool0;_l0o`0So`3oob?o0?l07Oooo`04ooooo`7o00000Ooo
ool000oooooo00?o0000ooooooooool00_oooomeoooo02ko0?l08ol0oolSo`3o01goool01?ooool1
o`00007ooooo000?ooooo`03o`000?oooooooooo00;oooooMOooo`0^o`3o02?o0?oo8ol0o`0Moooo
00Cooooo0Ol00001ooooo`003oooool00ol0003oooooooooo`02ooooogGoool0;_l0o`0So`3oob?o
0?l07Oooo`04ooooo`7o00000Oooool000oooooo0_l00003ooooogGoool0;_l0o`0So`3oob?o0?l0
7Oooo`03ooooo`;o00000Oooool000oooooo00?o0000ooooooooool00_oooom_oooo02ko0?l03?l0
ool6o`00o`_oo`001_l00?lBo`3ooago0?l05oooo`04ooooo`7o00000Oooool000oooooo00?o0000
ooooooooool00_oooom_oooo02ko0?l03?l0ool6o`00o`_oo`001_l00?lBo`3ooago0?l05oooo`04
ooooo`7o00000Oooool000oooooo00?o0000ooooooooool00_oooom_oooo02ko0?l03?l0ool6o`00
o`_oo`001_l00?lBo`3ooago0?l05oooo`04ooooo`7o00000Oooool000oooooo00?o0000oooooooo
ool00_oooom_oooo02ko0?l03?l0ool6o`00o`_oo`001_l00?lBo`3ooago0?l05oooo`04ooooo`7o
00000Oooool000oooooo00?o0000ooooooooool00_oooom_oooo02ko0?l03?l0ool6o`00o`_oo`00
1_l00?lBo`3ooago0?l05oooo`04ooooo`7o00000Oooool000oooooo00?o0000ooooooooool00_oo
oomSoooo03Co0?l04_l0ool6o`00o`_oo`003?oo0?l6o`00o`co0?oo7Ol0o`0Aoooo00Cooooo0Ol0
0001ooooo`003oooool00ol0003oooooooooo`02ooooof?oool0=?l0o`0Bo`3oo`Ko003o2ooo000<
ool0o`Ko003o3?l0oolMo`3o017oool01?ooool1o`00007ooooo000?ooooo`03o`000?oooooooooo
00;oooooHoooo`0do`3o01;o0?oo1_l00?l;ool000coo`3o1_l00?l<o`3ooago0?l04Oooo`04oooo
o`7o00000Oooool000oooooo00?o0000ooooooooool00_oooomSoooo03Co0?l04_l0ool6o`00o`_o
o`003?oo0?l6o`00o`co0?oo7Ol0o`0Aoooo00Cooooo0Ol00001ooooo`003oooool2o`0000?ooooo
Hoooo`0do`3o01;o0?oo1_l00?l;ool000coo`3o1_l00?l<o`3ooago0?l04Oooo`03ooooo`;o0000
0Oooool000oooooo00?o0000ooooooooool00_oooomGoooo03_o0?l04Ol0ool6o`00o`Koo`3o7Ooo
0006o`00o`_o0?oo7Ol0o`0<oooo00Cooooo0Ol00001ooooo`003oooool00ol0003oooooooooo`02
oooooeOoool0>ol0o`0Ao`3oo`Ko003o1_oo0?lMool000Ko003o2ol0oolMo`3o00coool01?ooool1
o`00007ooooo000?ooooo`03o`000?oooooooooo00;oooooEoooo`0ko`3o017o0?oo1_l00?l6ool0
oagoo`001_l00?l;o`3ooago0?l03?ooo`04ooooo`7o00000Oooool000oooooo00?o0000oooooooo
ool00_oooomGoooo03_o0?l04Ol0ool6o`00o`Koo`3o7Ooo0006o`00o`_o0?oo7Ol0o`0<oooo00Co
oooo0Ol00001ooooo`003oooool00ol0003oooooooooo`02oooooeOoool0>ol0o`0Ao`3oo`Ko003o
1_oo0?lMool000Ko003o2ol0oolMo`3o00coool01?ooool1o`00007ooooo000?ooooo`03o`000?oo
oooooooo00;oooooC?ooo`0jo`3o01Oo0?oo3?l00?l6ool0oagoo`001_l00?lAo`3oob?o0?l01?oo
ool1o`00007ooooo000?ooooo`03o`000?oooooooooo00;oooooC?ooo`0jo`3o01Oo0?oo3?l00?l6
ool0oagoo`001_l00?lAo`3oob?o0?l01?ooool1o`00007ooooo000?ooooo`03o`000?oooooooooo
00;oooooC?ooo`0jo`3o01Oo0?oo3?l00?l6ool0oagoo`001_l00?lAo`3oob?o0?l01?ooool1o`00
007ooooo000?ooooo`03o`000?oooooooooo00;oooooC?ooo`0jo`3o01Oo0?oo3?l00?l6ool0oago
o`001_l00?lAo`3oob?o0?l01?ooool1o`00007ooooo000?ooooo`;o00000ooooom<oooo03[o0?l0
5ol0ool<o`00o`Koo`3o7Ooo0006o`00oa7o0?oo8ol0o`03ooooo`;o00000Oooool000oooooo00?o
0000ooooooooool00_oooom0oooo03[o0?l07Ol0ool<o`00o`Koo`3o8ooo0006ool0o`Ko003o4Ol0
oolMo`3o00Cooooo0Ol00001ooooo`003oooool00ol0003oooooooooo`02oooood3oool0>_l0o`0M
o`3oo`co003o1_oo0?lSool000Koo`3o1_l00?lAo`3ooago0?l01?ooool1o`00007ooooo000?oooo
o`03o`000?oooooooooo00;ooooo@?ooo`0jo`3o01go0?oo3?l00?l6ool0ob?oo`001_oo0?l6o`00
oa7o0?oo7Ol0o`04ooooo`7o00000Oooool000oooooo00?o0000ooooooooool00_oooom0oooo03[o
0?l07Ol0ool<o`00o`Koo`3o8ooo0006ool0o`Ko003o4Ol0oolMo`3o00Cooooo0Ol00001ooooo`00
3oooool00ol0003oooooooooo`02oooood3oool0>_l0o`0Mo`3oo`co003o1_oo0?lSool000Koo`3o
1_l00?lAo`3ooago0?l01?ooool1o`00007ooooo000?ooooo`03o`000?oooooooooo00;ooooo=?oo
o`11o`3o01go0?oo2ol00?l6ool0obooo`002ol00?lBo`3ooaOo0?l01?ooool1o`00007ooooo0000
1?oooooo0000o`000?l00004ooooo`;o00001Oooool00ol0003oooooooooo`02ooooocCoool0@Ol0
o`0Mo`3oo`_o003o1_oo0?l_ool000_o003o4_l0oolGo`3o00Cooooo0Ol00001ooooo`000_ooool0
0ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool00_oo
ooldoooo047o0?l07Ol0ool;o`00o`Koo`3o;ooo000;o`00oa;o0?oo5ol0o`04ooooo`7o00000Ooo
ool000;ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00004ooooo`03o`000?oo
oooooooo00;ooooo=?ooo`11o`3o01go0?oo2ol00?l6ool0obooo`002ol00?lBo`3ooaOo0?l01?oo
ool1o`00007ooooo0002ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00001?oo
ool3o`0000;ooooo=?ooo`11o`3o01go0?oo2ol00?l6ool0obooo`002ol00?lBo`3ooaOo0?l00ooo
ool2o`00007ooooo0002ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00001?oo
ool00ol0003oooooooooo`02ooooobooool0>_l0o`0Mo`3ooa7o003o3?oo0?l_ool000Koo`3o2ol0
0?lGo`3oo`co0?l01?ooool1o`00007ooooo00000ooooooo0000o`000004ooooo`04o`000?oooooo
ooooo`0000Cooooo00?o0000ooooooooool00_ooool_oooo03[o0?l07Ol0oolAo`00o`coo`3o;ooo
0006ool0o`_o003o5ol0ool<o`3o00Cooooo0Ol00001ooooo`000_ooool00ol0003oooooooooo`03
ooooo`;o00001Oooool00ol0003oooooooooo`02ooooobooool0>_l0o`0Mo`3ooa7o003o3?oo0?l_
ool000Koo`3o2ol00?lGo`3oo`co0?l01?ooool1o`00007ooooo000?ooooo`03o`000?oooooooooo
00;ooooo;oooo`0jo`3o01go0?oo4Ol00?l<ool0obooo`001_oo0?l;o`00oaOo0?oo3?l0o`04oooo
o`7o00000Oooool000oooooo00?o0000ooooooooool00_ooool_oooo03[o0?l07Ol0oolAo`00o`co
o`3o;ooo0006ool0o`_o003o5ol0ool<o`3o00Cooooo0Ol00001ooooo`003oooool00ol0003ooooo
ooooo`02ooooob?oool0@?l0o`0Go`3oo`co003o5ooo0?lkool000Goo`3o6?l00?l;o`3oo`Ko0?l0
1?ooool1o`00007ooooo000?ooooo`03o`000?oooooooooo00;ooooo8oooo`10o`3o01Oo0?oo3?l0
0?lGool0oc_oo`001Ooo0?lHo`00o`_o0?oo1_l0o`04ooooo`7o00000Oooool000oooooo00?o0000
ooooooooool00_oooolSoooo043o0?l05ol0ool<o`00oaOoo`3o>ooo0005ool0oaSo003o2ol0ool6
o`3o00Cooooo0Ol00001ooooo`003oooool00ol0003oooooooooo`02ooooob?oool0@?l0o`0Go`3o
o`co003o5ooo0?lkool000Goo`3o6?l00?l;o`3oo`Ko0?l01?ooool1o`00007ooooo000?ooooo`;o
00000ooooolSoooo043o0?l05ol0ool<o`00oaOoo`3o>ooo0005ool0oaSo003o2ol0ool6o`3o00?o
oooo0_l00001ooooo`003oooool00ol0003oooooooooo`02oooooaOoool0@?l0o`0No`3oo`Go003o
1_oo0?mMool001;oo`3o1_oo0005o`00o`Ko0?oo1_l0o`04ooooo`7o00000Oooool000oooooo00?o
0000ooooooooool00_oooolGoooo043o0?l07_l0ool5o`00o`Koo`3oGOoo000Bool0o`Koo`001Ol0
0?l6o`3oo`Ko0?l01?ooool1o`00007ooooo000?ooooo`03o`000?oooooooooo00;ooooo5oooo`10
o`3o01ko0?oo1Ol00?l6ool0oegoo`004_oo0?l6ool000Go003o1_l0ool6o`3o00Cooooo0Ol00001
ooooo`003oooool00ol0003oooooooooo`02oooooaOoool0@?l0o`0No`3oo`Go003o1_oo0?mMool0
01;oo`3o1_oo0005o`00o`Ko0?oo1_l0o`04ooooo`7o00000Oooool000oooooo00?o0000oooooooo
ool00_oooolBoooo03[o0?l08ol0ool;o`00oh3oo`001_l00?l6o`3oo`Cooooo0Ol00001ooooo`00
3oooool00ol0003oooooooooo`02oooooa;oool0>_l0o`0So`3oo`_o003oP?oo0006o`00o`Ko0?oo
1?ooool1o`00007ooooo000?ooooo`03o`000?oooooooooo00;ooooo4_ooo`0jo`3o02?o0?oo2ol0
0?n0ool000Ko003o1_l0ool4ooooo`7o00000Oooool000oooooo00?o0000ooooooooool00_oooolB
oooo03[o0?l08ol0ool;o`00oh3oo`001_l00?l6o`3oo`Cooooo0Ol00001ooooo`003oooool00ol0
003oooooooooo`02oooooa;oool0>_l0o`0So`3oo`_o003oP?oo0006o`00o`Ko0?oo1?ooool1o`00
007ooooo000?ooooo`;o00000oooool<oooo02ko0?l0;ol0ool<o`00o`Goo`3oP?oo0006o`00o`Ko
0?oo0oooool2o`00007ooooo000?ooooo`03o`000?oooooooooo00;ooooo3?ooo`0^o`3o02oo0?oo
3?l00?l5ool0oh3oo`001_l00?l6o`3oo`Cooooo0Ol00001ooooo`003oooool00ol0003ooooooooo
o`02ooooo`coool0;_l0o`0_o`3oo`co003o1Ooo0?n0ool000Ko003o1_l0ool4ooooo`7o00000Ooo
ool000oooooo00?o0000ooooooooool00_ooool<oooo02ko0?l0;ol0ool<o`00o`Goo`3oP?oo0006
o`00o`Ko0?oo1?ooool1o`00007ooooo000?ooooo`03o`000?oooooooooo00;ooooo3?ooo`0^o`3o
02oo0?oo3?l00?l5ool0oh3oo`001_l00?l6o`3oo`Cooooo0Ol00001ooooo`003oooool00ol0003o
ooooooooo`02ooooo`Koool0:Ol0o`0^o`3ooa;o003o2ooo0?n0ool000Ko003o1_l0ool4ooooo`7o
00000Oooool000oooooo00?o0000ooooooooool00_ooool6oooo02Wo0?l0;_l0oolBo`00o`_oo`3o
P?oo0006o`00o`Ko0?oo1?ooool1o`00007ooooo000?ooooo`03o`000?oooooooooo00;ooooo1_oo
o`0Yo`3o02ko0?oo4_l00?l;ool0oh3oo`001_l00?l6o`3oo`Cooooo0Ol00001ooooo`003oooool0
0ol0003oooooooooo`02ooooo`Koool0:Ol0o`0^o`3ooa;o003o2ooo0?n0ool000Ko003o1_l0ool4
ooooo`7o00000Oooool000oooooo0_l00003ooooo`Koool0:Ol0o`0^o`3ooa;o003o2ooo0?n0ool0
00Ko003o1_l0ool3ooooo`;o00000Oooool000oooooo00?o0000ooooooooool00_oooolSo`3o01go
0?oo:Ol00?l<ool0ohGoo`001_l00?l6o`3oo`Cooooo0Ol00001ooooo`003oooool00ol0003ooooo
ooooo`02ooooob?o0?l07Ol0oolYo`00o`coo`3oQOoo0006o`00o`Ko0?oo1?ooool1o`00007ooooo
000?ooooo`03o`000?oooooooooo00;ooooo8ol0o`0Mo`3oobWo003o3?oo0?n5ool000Ko003o1_l0
ool4ooooo`7o00000Oooool000oooooo00?o0000ooooooooool00_oooolSo`3o01go0?oo:Ol00?l<
ool0ohGoo`001_l00?l6o`3oo`Cooooo0Ol00001ooooo`003oooool00ol0003oooooooooo`02oooo
ob?o0?l07Ol0oolYo`00o`coo`3oQOoo0006o`00o`Ko0?oo1?ooool1o`00007ooooo000?ooooo`03
o`000?oooooooooo00;ooooo7Ol0o`0Bo`3oo`_oo`3o7Ol00?lHool0oh_oo`001_oo0?l6o`00o`Co
oooo0Ol00001ooooo`003oooool00ol0003oooooooooo`02oooooago0?l04_l0ool;ool0oago003o
6?oo0?n;ool000Koo`3o1_l00?l4ooooo`7o00000Oooool000oooooo00?o0000ooooooooool00_oo
oolMo`3o01;o0?oo2ooo0?lMo`00oaSoo`3oRooo0006ool0o`Ko003o1?ooool1o`00007ooooo000?
ooooo`03o`000?oooooooooo00;ooooo7Ol0o`0Bo`3oo`_oo`3o7Ol00?lHool0oh_oo`001_oo0?l6
o`00o`Cooooo0Ol00001ooooo`003oooool2o`0000?ooooo7Ol0o`0Bo`3oo`_oo`3o7Ol00?lHool0
oh_oo`001_oo0?l6o`00o`?ooooo0_l00001ooooo`003oooool00ol0003oooooooooo`02oooooaOo
0?l04_l0ool6o`00oa7oo`003?oo0?l;ool000coo`3oWOoo0006o`00o`Cooooo0Ol00001ooooo`00
3oooool00ol0003oooooooooo`02oooooaOo0?l04_l0ool6o`00oa7oo`003?oo0?l;ool000coo`3o
WOoo0006o`00o`Cooooo0Ol00001ooooo`003oooool00ol0003oooooooooo`02oooooaOo0?l04_l0
ool6o`00oa7oo`003?oo0?l;ool000coo`3oWOoo0006o`00o`Cooooo0Ol00001ooooo`003oooool0
0ol0003oooooooooo`02oooooaOo0?l04_l0ool6o`00oa7oo`003?oo0?l;ool000coo`3oWOoo0006
o`00o`Cooooo0Ol00001ooooo`003oooool00ol0003oooooooooo`02oooooaOo0?l04_l0ool6o`00
oa7oo`003?oo0?l;ool000coo`3oWOoo0006o`00o`Cooooo0Ol00001ooooo`003oooool00ol0003o
ooooooooo`02oooooa;o0?l04Ol0ool<o`00om7oo`001_l00?l4ooooo`7o00000Oooool000oooooo
00?o0000ooooooooool00_oooolBo`3o017o0?oo3?l00?oAool000Ko003o1?ooool1o`00007ooooo
0005o`0000?ooooo0_l00005ooooo`03o`000?oooooooooo00;ooooo4_l0o`0Ao`3oo`co003odOoo
0006o`00o`Cooooo0Ol00001ooooo`0000Goooooo`000?ooooooooooo`000002ooooo`04o`000?oo
ooooooooo`0000Cooooo00?o0000ooooooooool00_oooolBo`3o017o0?oo3?l00?oAool000Ko003o
1?ooool1o`00007ooooo0002ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo0000
1?ooool3o`0000;ooooo4_l0o`0Ao`3oo`co003odOoo0006o`00o`?ooooo0_l00001ooooo`000ooo
ool01Ol0003ooooooooooooooooo000000;ooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`02ooooo`co0?l05ol0ool6o`00o`Koo`3odOoo0006o`00o`Cooooo0Ol00001ooooo`0000Go
0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000oooooooo
ool00_ooool<o`3o01Oo0?oo1_l00?l6ool0om7oo`001_l00?l4ooooo`7o00000Oooool00005o`00
0?ooooooooooooooool000000_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo
00;ooooo3?l0o`0Go`3oo`Ko003o1_oo0?oAool000Ko003o1?ooool1o`00007ooooo00001?oooooo
0000o`000?l00004ooooo`;o00001Oooool00ol0003oooooooooo`02ooooo`co0?l05ol0ool6o`00
o`Koo`3odOoo0006o`00o`Cooooo0Ol00001ooooo`003oooool00ol0003oooooooooo`02ooooo`co
0?l05ol0ool6o`00o`Koo`3odOoo0006o`00o`Cooooo0Ol00001ooooo`003oooool00ol0003ooooo
ooooo`02oooooaOo0?oo4_l00?l6ool0om7oo`001_l00?l4ooooo`7o00000Oooool000oooooo00?o
0000ooooooooool00_oooolGo`3ooa;o003o1_oo0?oAool000Ko003o1?ooool1o`00007ooooo000?
ooooo`03o`000?oooooooooo00;ooooo5ol0oolBo`00o`Koo`3odOoo0006o`00o`Cooooo0Ol00001
ooooo`003oooool00ol0003oooooooooo`02oooooaOo0?oo4_l00?l6ool0om7oo`001_l00?l4oooo
o`7o00000Oooool000oooooo0_l00003oooooaOo0?oo4_l00?l6ool0om7oo`001_l00?l3ooooo`;o
00000Oooool000oooooo00?o0000ooooooooool00_oooolBo`3oo`_o003o3?oo0?oGool000Ko003o
1?ooool1o`00007ooooo000?ooooo`03o`000?oooooooooo00;ooooo4_l0ool;o`00o`coo`3oeooo
0006o`00o`Cooooo0Ol00001ooooo`003oooool00ol0003oooooooooo`02oooooa;o0?oo2ol00?l<
ool0omOoo`001_l00?l4ooooo`7o00000Oooool000oooooo00?o0000ooooooooool00_oooolBo`3o
o`_o003o3?oo0?oGool000Ko003o1?ooool1o`00007ooooo000?ooooo`03o`000?oooooooooo00;o
oooo4_l0ool;o`00o`coo`3oeooo0006o`00o`Cooooo0Ol00001ooooo`003oooool00ol0003ooooo
ooooo`02ooooo`Ko0?oo4Ol00?l6ool0omgoo`001_oo0?l6o`00o`Cooooo0Ol00001ooooo`003ooo
ool00ol0003oooooooooo`02ooooo`Ko0?oo4Ol00?l6ool0omgoo`001_oo0?l6o`00o`Cooooo0Ol0
0001ooooo`003oooool00ol0003oooooooooo`02ooooo`Ko0?oo4Ol00?l6ool0omgoo`001_oo0?l6
o`00o`Cooooo0Ol00001ooooo`003oooool00ol0003oooooooooo`02ooooo`Ko0?oo4Ol00?l6ool0
omgoo`001_oo0?l6o`00o`Cooooo0Ol00001ooooo`003oooool2o`0000?ooooo3?l00?lAool0omgo
o`001_oo0?l6o`00o`?ooooo0_l00001ooooo`003oooool00ol0003oooooooooo`02ooooo`co003o
4Ooo0?oMool000Koo`3o1_l00?l4ooooo`7o00000Oooool000oooooo00?o0000ooooooooool00_oo
ool<o`00oa7oo`3ogOoo0006ool0o`Ko003o1?ooool1o`00007ooooo000?ooooo`03o`000?oooooo
oooo00;ooooo3?l00?lAool0omgoo`001_oo0?l6o`00o`Cooooo0Ol00001ooooo`003oooool00ol0
003oooooooooo`02ooooo`co003o4Ooo0?oMool000Koo`3o1_l00?l4ooooo`7o00000Oooool000oo
oooo00?o0000ooooooooool00_ooool6ool0onooo`001Ooo0?l<o`00o`Cooooo0Ol00001ooooo`00
3oooool00ol0003oooooooooo`02ooooo`Koo`3okooo0005ool0o`co003o1?ooool1o`00007ooooo
000?ooooo`03o`000?oooooooooo00;ooooo1_oo0?o_ool000Goo`3o3?l00?l4ooooo`7o00000Ooo
ool000oooooo00?o0000ooooooooool00_ooool6ool0onooo`001Ooo0?l<o`00o`Cooooo0Ol00001
ooooo`003oooool00ol0003oooooooooo`02ooooo`Koo`3okooo0005ool0o`co003o1?ooool1o`00
007ooooo000?ooooo`;o00000ooooooeool000Goo`3o1_l00?l6o`3oo`?ooooo0_l00001ooooo`00
3oooool00ol0003oooooooooo`02ooooooGoo`001Ooo0?l6o`00o`Ko0?oo1?ooool1o`00007ooooo
000?ooooo`03o`000?oooooooooo00;ooooomOoo0005ool0o`Ko003o1_l0ool4ooooo`7o00000Ooo
ool000oooooo00?o0000ooooooooool00_oooooeool000Goo`3o1_l00?l6o`3oo`Cooooo0Ol00001
ooooo`003oooool00ol0003oooooooooo`02ooooooGoo`001Ooo0?l6o`00o`Ko0?oo1?ooool1o`00
007ooooo000?ooooo`03o`000?oooooooooo00;ooooo1_oo0?o_ool000Goo`3o3?l00?l4ooooo`7o
00000Oooool000oooooo00?o0000ooooooooool00_ooool6ool0onooo`001Ooo0?l<o`00o`Cooooo
0Ol00001ooooo`003oooool00ol0003oooooooooo`02ooooo`Koo`3okooo0005ool0o`co003o1?oo
ool1o`00007ooooo000?ooooo`03o`000?oooooooooo00;ooooo1_oo0?o_ool000Goo`3o3?l00?l4
ooooo`7o00000Oooool000oooooo00?o0000ooooooooool00_ooool6ool0onooo`001Ooo0?l<o`00
o`Cooooo0Ol00001ooooo`003oooool2o`0000?ooooo3?l00?lAool0omgoo`001_oo0?l6o`00o`?o
oooo0_l00001ooooo`003oooool00ol0003oooooooooo`02ooooo`co003o4Ooo0?oMool000Koo`3o
1_l00?l4ooooo`7o00000Oooool000oooooo00?o0000ooooooooool00_ooool<o`00oa7oo`3ogOoo
0006ool0o`Ko003o1?ooool1o`00007ooooo000?ooooo`03o`000?oooooooooo00;ooooo3?l00?lA
ool0omgoo`001_oo0?l6o`00o`Cooooo0Ol00001ooooo`003oooool00ol0003oooooooooo`02oooo
o`co003o4Ooo0?oMool000Koo`3o1_l00?l4ooooo`7o00000Oooool000oooooo00?o0000oooooooo
ool00_ooool6o`3ooa7o003o1_oo0?oMool000Koo`3o1_l00?l4ooooo`7o00000Oooool000oooooo
00?o0000ooooooooool00_ooool6o`3ooa7o003o1_oo0?oMool000Koo`3o1_l00?l4ooooo`7o0000
0Oooool00004ooooool0003o0000o`0000Cooooo0_l00005ooooo`03o`000?oooooooooo00;ooooo
1_l0oolAo`00o`Koo`3ogOoo0006ool0o`Ko003o1?ooool1o`00007ooooo00001Ol0003ooooooooo
oooooooo000000;ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`02ooooo`Ko
0?oo4Ol00?l6ool0omgoo`001_oo0?l6o`00o`Cooooo0Ol00001ooooo`001?ooool01?l0003ooooo
ooooool00002ooooo`03o`000?oooooooooo00;ooooo0ol00002ooooo`Ko0?oo4Ol00?l6ool0omgo
o`001_oo0?l6o`00o`?ooooo0_l00001ooooo`000_ooool2o`0000?ooooo00Co0000oooooooooooo
00001?ooool00ol0003oooooooooo`02oooooa;o0?oo2ol00?l<ool0omOoo`001_l00?l4ooooo`7o
00000Oooool000Cooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00;ooooo4_l0ool;o`00o`coo`3oeooo0006o`00o`Cooooo0Ol00001ooooo`00
00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000oooo
ooooool00_oooolBo`3oo`_o003o3?oo0?oGool000Ko003o1?ooool1o`00007ooooo00001?oooooo
0000o`000?l00004ooooo`;o00001Oooool00ol0003oooooooooo`02oooooa;o0?oo2ol00?l<ool0
omOoo`001_l00?l4ooooo`7o00000Oooool000oooooo00?o0000ooooooooool00_oooolBo`3oo`_o
003o3?oo0?oGool000Ko003o1?ooool1o`00007ooooo000?ooooo`03o`000?oooooooooo00;ooooo
5ol0oolBo`00o`Koo`3odOoo0006o`00o`Cooooo0Ol00001ooooo`003oooool00ol0003ooooooooo
o`02oooooaOo0?oo4_l00?l6ool0om7oo`001_l00?l4ooooo`7o00000Oooool000oooooo00?o0000
ooooooooool00_oooolGo`3ooa;o003o1_oo0?oAool000Ko003o1?ooool1o`00007ooooo000?oooo
o`03o`000?oooooooooo00;ooooo5ol0oolBo`00o`Koo`3odOoo0006o`00o`Cooooo0Ol00001oooo
o`003oooool2o`0000?ooooo5ol0oolBo`00o`Koo`3odOoo0006o`00o`?ooooo0_l00001ooooo`00
3oooool00ol0003oooooooooo`02ooooo`co0?l05ol0ool6o`00o`Koo`3odOoo0006o`00o`Cooooo
0Ol00001ooooo`003oooool00ol0003oooooooooo`02ooooo`co0?l05ol0ool6o`00o`Koo`3odOoo
0006o`00o`Cooooo0Ol00001ooooo`003oooool00ol0003oooooooooo`02ooooo`co0?l05ol0ool6
o`00o`Koo`3odOoo0006o`00o`Cooooo0Ol00001ooooo`003oooool00ol0003oooooooooo`02oooo
o`co0?l05ol0ool6o`00o`Koo`3odOoo0006o`00o`Cooooo0Ol00001ooooo`003oooool00ol0003o
ooooooooo`02ooooo`co0?l05ol0ool6o`00o`Koo`3odOoo0006o`00o`Cooooo0Ol00001ooooo`00
3oooool00ol0003oooooooooo`02oooooa;o0?l04Ol0ool<o`00om7oo`001_l00?l4ooooo`7o0000
0Oooool000oooooo00?o0000ooooooooool00_oooolBo`3o017o0?oo3?l00?oAool000Ko003o1?oo
ool1o`00007ooooo000?ooooo`03o`000?oooooooooo00;ooooo4_l0o`0Ao`3oo`co003odOoo0006
o`00o`Cooooo0Ol00001ooooo`003oooool00ol0003oooooooooo`02oooooa;o0?l04Ol0ool<o`00
om7oo`001_l00?l4ooooo`7o00000Oooool000oooooo0_l00003oooooa;o0?l04Ol0ool<o`00om7o
o`001_l00?l3ooooo`;o00000Oooool000oooooo00?o0000ooooooooool00_oooolGo`3o01;o0?oo
1_l00?lAool000coo`3o2ooo000<ool0oigoo`001_l00?l4ooooo`7o00000Oooool000oooooo00?o
0000ooooooooool00_oooolGo`3o01;o0?oo1_l00?lAool000coo`3o2ooo000<ool0oigoo`001_l0
0?l4ooooo`7o00000Oooool000oooooo00?o0000ooooooooool00_oooolGo`3o01;o0?oo1_l00?lA
ool000coo`3o2ooo000<ool0oigoo`001_l00?l4ooooo`7o00000Oooool000oooooo00?o0000oooo
ooooool00_oooolGo`3o01;o0?oo1_l00?lAool000coo`3o2ooo000<ool0oigoo`001_l00?l4oooo
o`7o00000Oooool000oooooo00?o0000ooooooooool00_oooolMo`3o01;o0?oo2ooo0?lMo`00oaSo
o`3oRooo0006ool0o`Ko003o1?ooool1o`00007ooooo000?ooooo`03o`000?oooooooooo00;ooooo
7Ol0o`0Bo`3oo`_oo`3o7Ol00?lHool0oh_oo`001_oo0?l6o`00o`Cooooo0Ol00001ooooo`003ooo
ool00ol0003oooooooooo`02oooooago0?l04_l0ool;ool0oago003o6?oo0?n;ool000Koo`3o1_l0
0?l4ooooo`7o00000Oooool000oooooo00?o0000ooooooooool00_oooolMo`3o01;o0?oo2ooo0?lM
o`00oaSoo`3oRooo0006ool0o`Ko003o1?ooool1o`00007ooooo000?ooooo`03o`000?oooooooooo
00;ooooo7Ol0o`0Bo`3oo`_oo`3o7Ol00?lHool0oh_oo`001_oo0?l6o`00o`Cooooo0Ol00001oooo
o`003oooool2o`0000?ooooo8ol0o`0Mo`3oobWo003o3?oo0?n5ool000Ko003o1_l0ool3ooooo`;o
00000Oooool000oooooo00?o0000ooooooooool00_oooolSo`3o01go0?oo:Ol00?l<ool0ohGoo`00
1_l00?l6o`3oo`Cooooo0Ol00001ooooo`003oooool00ol0003oooooooooo`02ooooob?o0?l07Ol0
oolYo`00o`coo`3oQOoo0006o`00o`Ko0?oo1?ooool1o`00007ooooo000?ooooo`03o`000?oooooo
oooo00;ooooo8ol0o`0Mo`3oobWo003o3?oo0?n5ool000Ko003o1_l0ool4ooooo`7o00000Oooool0
00oooooo00?o0000ooooooooool00_oooolSo`3o01go0?oo:Ol00?l<ool0ohGoo`001_l00?l6o`3o
o`Cooooo0Ol00001ooooo`003oooool00ol0003oooooooooo`02ooooo`Koool0:Ol0o`0^o`3ooa;o
003o2ooo0?n0ool000Ko003o1_l0ool4ooooo`7o00000Oooool000oooooo00?o0000ooooooooool0
0_ooool6oooo02Wo0?l0;_l0oolBo`00o`_oo`3oP?oo0006o`00o`Ko0?oo1?ooool1o`00007ooooo
000?ooooo`03o`000?oooooooooo00;ooooo1_ooo`0Yo`3o02ko0?oo4_l00?l;ool0oh3oo`001_l0
0?l6o`3oo`Cooooo0Ol00001ooooo`003oooool00ol0003oooooooooo`02ooooo`Koool0:Ol0o`0^
o`3ooa;o003o2ooo0?n0ool000Ko003o1_l0ool4ooooo`7o00000Oooool000oooooo00?o0000oooo
ooooool00_ooool6oooo02Wo0?l0;_l0oolBo`00o`_oo`3oP?oo0006o`00o`Ko0?oo1?ooool1o`00
007ooooo000?ooooo`;o00000oooool<oooo02ko0?l0;ol0ool<o`00o`Goo`3oP?oo0006o`00o`Ko
0?oo0oooool2o`00007ooooo000?ooooo`03o`000?oooooooooo00;ooooo3?ooo`0^o`3o02oo0?oo
3?l00?l5ool0oh3oo`001_l00?l6o`3oo`Cooooo0Ol00001ooooo`003oooool00ol0003ooooooooo
o`02ooooo`coool0;_l0o`0_o`3oo`co003o1Ooo0?n0ool000Ko003o1_l0ool4ooooo`7o00000Ooo
ool000oooooo00?o0000ooooooooool00_ooool<oooo02ko0?l0;ol0ool<o`00o`Goo`3oP?oo0006
o`00o`Ko0?oo1?ooool1o`00007ooooo000?ooooo`03o`000?oooooooooo00;ooooo3?ooo`0^o`3o
02oo0?oo3?l00?l5ool0oh3oo`001_l00?l6o`3oo`Cooooo0Ol00001ooooo`003oooool00ol0003o
ooooooooo`02oooooa;oool0>_l0o`0So`3oo`_o003oP?oo0006o`00o`Ko0?oo1?ooool1o`00007o
oooo000?ooooo`03o`000?oooooooooo00;ooooo4_ooo`0jo`3o02?o0?oo2ol00?n0ool000Ko003o
1_l0ool4ooooo`7o00000Oooool000;ooooo0ol00003ooooo`;o00001Oooool00ol0003ooooooooo
o`02oooooa;oool0>_l0o`0So`3oo`_o003oP?oo0006o`00o`Ko0?oo1?ooool1o`00007ooooo0003
ooooo`05o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00;ooooo4_ooo`0jo`3o02?o0?oo2ol00?n0ool000Ko003o1_l0ool4ooooo`7o00000Ooo
ool000Go00000_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo00;ooooo4_oo
o`0jo`3o02?o0?oo2ol00?n0ool000Ko003o1_l0ool4ooooo`7o00000Oooool00004o`000?oooooo
ooooo`0000?ooooo00Co0000oooooooooooo00001?ooool3o`0000;ooooo5oooo`10o`3o01ko0?oo
1Ol00?l6ool0oegoo`004_oo0?l6ool000Go003o1_l0ool6o`3o00?ooooo0_l00001ooooo`0000Co
ooooo`000?oooooo00000oooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo00;o
oooo5oooo`10o`3o01ko0?oo1Ol00?l6ool0oegoo`004_oo0?l6ool000Go003o1_l0ool6o`3o00Co
oooo0Ol00001ooooo`000_ooool2o`0000?ooooo00Co0000oooooooooooo00001?ooool00ol0003o
ooooooooo`02oooooaOoool0@?l0o`0No`3oo`Go003o1_oo0?mMool001;oo`3o1_oo0005o`00o`Ko
0?oo1_l0o`04ooooo`7o00000Oooool000?ooooo00?o0000ooooooooool00_ooool2o`0000Gooooo
00?o0000ooooooooool00_oooolGoooo043o0?l07_l0ool5o`00o`Koo`3oGOoo000Bool0o`Koo`00
1Ol00?l6o`3oo`Ko0?l01?ooool1o`00007ooooo000?ooooo`03o`000?oooooooooo00;ooooo5ooo
o`10o`3o01ko0?oo1Ol00?l6ool0oegoo`004_oo0?l6ool000Go003o1_l0ool6o`3o00Cooooo0Ol0
0001ooooo`003oooool00ol0003oooooooooo`02ooooob?oool0@?l0o`0Go`3oo`co003o5ooo0?lk
ool000Goo`3o6?l00?l;o`3oo`Ko0?l01?ooool1o`00007ooooo000?ooooo`03o`000?oooooooooo
00;ooooo8oooo`10o`3o01Oo0?oo3?l00?lGool0oc_oo`001Ooo0?lHo`00o`_o0?oo1_l0o`04oooo
o`7o00000Oooool000oooooo00?o0000ooooooooool00_oooolSoooo043o0?l05ol0ool<o`00oaOo
o`3o>ooo0005ool0oaSo003o2ol0ool6o`3o00Cooooo0Ol00001ooooo`003oooool00ol0003ooooo
ooooo`02ooooob?oool0@?l0o`0Go`3oo`co003o5ooo0?lkool000Goo`3o6?l00?l;o`3oo`Ko0?l0
1?ooool1o`00007ooooo000?ooooo`03o`000?oooooooooo00;ooooo8oooo`10o`3o01Oo0?oo3?l0
0?lGool0oc_oo`001Ooo0?lHo`00o`_o0?oo1_l0o`04ooooo`7o00000Oooool000oooooo0_l00003
ooooobooool0>_l0o`0Mo`3ooa7o003o3?oo0?l_ool000Koo`3o2ol00?lGo`3oo`co0?l00oooool2
o`00007ooooo000?ooooo`03o`000?oooooooooo00;ooooo;oooo`0jo`3o01go0?oo4Ol00?l<ool0
obooo`001_oo0?l;o`00oaOo0?oo3?l0o`04ooooo`7o00000Oooool000oooooo00?o0000oooooooo
ool00_ooool_oooo03[o0?l07Ol0oolAo`00o`coo`3o;ooo0006ool0o`_o003o5ol0ool<o`3o00Co
oooo0Ol00001ooooo`003oooool00ol0003oooooooooo`02ooooobooool0>_l0o`0Mo`3ooa7o003o
3?oo0?l_ool000Koo`3o2ol00?lGo`3oo`co0?l01?ooool1o`00007ooooo000?ooooo`03o`000?oo
oooooooo00;ooooo;oooo`0jo`3o01go0?oo4Ol00?l<ool0obooo`001_oo0?l;o`00oaOo0?oo3?l0
o`04ooooo`7o00000Oooool000oooooo00?o0000ooooooooool00_ooooldoooo047o0?l07Ol0ool;
o`00o`Koo`3o;ooo000;o`00oa;o0?oo5ol0o`04ooooo`7o00000Oooool000oooooo00?o0000oooo
ooooool00_ooooldoooo047o0?l07Ol0ool;o`00o`Koo`3o;ooo000;o`00oa;o0?oo5ol0o`04oooo
o`7o00000Oooool000oooooo00?o0000ooooooooool00_ooooldoooo047o0?l07Ol0ool;o`00o`Ko
o`3o;ooo000;o`00oa;o0?oo5ol0o`04ooooo`7o00000Oooool000oooooo00?o0000ooooooooool0
0_ooooldoooo047o0?l07Ol0ool;o`00o`Koo`3o;ooo000;o`00oa;o0?oo5ol0o`04ooooo`7o0000
0Oooool000oooooo0_l00003ooooocCoool0@Ol0o`0Mo`3oo`_o003o1_oo0?l_ool000_o003o4_l0
oolGo`3o00?ooooo0_l00001ooooo`003oooool00ol0003oooooooooo`02oooood3oool0>_l0o`0M
o`3oo`co003o1_oo0?lSool000Koo`3o1_l00?lAo`3ooago0?l01?ooool1o`00007ooooo000?oooo
o`03o`000?oooooooooo00;ooooo@?ooo`0jo`3o01go0?oo3?l00?l6ool0ob?oo`001_oo0?l6o`00
oa7o0?oo7Ol0o`04ooooo`7o00000Oooool000oooooo00?o0000ooooooooool00_oooom0oooo03[o
0?l07Ol0ool<o`00o`Koo`3o8ooo0006ool0o`Ko003o4Ol0oolMo`3o00Cooooo0Ol00001ooooo`00
3oooool00ol0003oooooooooo`02oooood3oool0>_l0o`0Mo`3oo`co003o1_oo0?lSool000Koo`3o
1_l00?lAo`3ooago0?l01?ooool1o`00007ooooo000?ooooo`03o`000?oooooooooo00;oooooC?oo
o`0jo`3o01Oo0?oo3?l00?l6ool0oagoo`001_l00?lAo`3oob?o0?l01?ooool1o`00007ooooo000?
ooooo`03o`000?oooooooooo00;oooooC?ooo`0jo`3o01Oo0?oo3?l00?l6ool0oagoo`001_l00?lA
o`3oob?o0?l01?ooool1o`00007ooooo000?ooooo`03o`000?oooooooooo00;oooooC?ooo`0jo`3o
01Oo0?oo3?l00?l6ool0oagoo`001_l00?lAo`3oob?o0?l01?ooool1o`00007ooooo000?ooooo`03
o`000?oooooooooo00;oooooC?ooo`0jo`3o01Oo0?oo3?l00?l6ool0oagoo`001_l00?lAo`3oob?o
0?l01?ooool1o`00007ooooo000?ooooo`03o`000?oooooooooo00;oooooC?ooo`0jo`3o01Oo0?oo
3?l00?l6ool0oagoo`001_l00?lAo`3oob?o0?l01?ooool1o`00007ooooo000?ooooo`;o00000ooo
oomGoooo03_o0?l04Ol0ool6o`00o`Koo`3o7Ooo0006o`00o`_o0?oo7Ol0o`0<oooo00?ooooo0_l0
0001ooooo`003oooool00ol0003oooooooooo`02oooooeOoool0>ol0o`0Ao`3oo`Ko003o1_oo0?lM
ool000Ko003o2ol0oolMo`3o00coool01?ooool1o`00007ooooo000?ooooo`03o`000?oooooooooo
00;oooooEoooo`0ko`3o017o0?oo1_l00?l6ool0oagoo`001_l00?l;o`3ooago0?l03?ooo`04oooo
o`7o00000Oooool000oooooo00?o0000ooooooooool00_oooomGoooo03_o0?l04Ol0ool6o`00o`Ko
o`3o7Ooo0006o`00o`_o0?oo7Ol0o`0<oooo00Cooooo0Ol00001ooooo`003oooool00ol0003ooooo
ooooo`02oooooeOoool0>ol0o`0Ao`3oo`Ko003o1_oo0?lMool000Ko003o2ol0oolMo`3o00coool0
1?ooool1o`00007ooooo000?ooooo`03o`000?oooooooooo00;oooooHoooo`0do`3o01;o0?oo1_l0
0?l;ool000coo`3o1_l00?l<o`3ooago0?l04Oooo`04ooooo`7o00000Oooool000oooooo00?o0000
ooooooooool00_oooomSoooo03Co0?l04_l0ool6o`00o`_oo`003?oo0?l6o`00o`co0?oo7Ol0o`0A
oooo00Cooooo0Ol00001ooooo`003oooool00ol0003oooooooooo`02ooooof?oool0=?l0o`0Bo`3o
o`Ko003o2ooo000<ool0o`Ko003o3?l0oolMo`3o017oool01?ooool1o`00007ooooo000?ooooo`03
o`000?oooooooooo00;oooooHoooo`0do`3o01;o0?oo1_l00?l;ool000coo`3o1_l00?l<o`3ooago
0?l04Oooo`04ooooo`7o00000Oooool000oooooo00?o0000ooooooooool00_oooomSoooo03Co0?l0
4_l0ool6o`00o`_oo`003?oo0?l6o`00o`co0?oo7Ol0o`0Aoooo00Cooooo0Ol00001ooooo`003ooo
ool2o`0000?oooooKoooo`0^o`3o00co0?oo1_l00?l;ool000Ko003o4_l0oolMo`3o01Ooool00ooo
ool2o`00007ooooo000?ooooo`03o`000?oooooooooo00;oooooKoooo`0^o`3o00co0?oo1_l00?l;
ool000Ko003o4_l0oolMo`3o01Ooool01?ooool1o`00007ooooo000?ooooo`03o`000?oooooooooo
00;oooooKoooo`0^o`3o00co0?oo1_l00?l;ool000Ko003o4_l0oolMo`3o01Ooool01?ooool1o`00
007ooooo000?ooooo`03o`000?oooooooooo00;oooooKoooo`0^o`3o00co0?oo1_l00?l;ool000Ko
003o4_l0oolMo`3o01Ooool01?ooool1o`00007ooooo000?ooooo`03o`000?oooooooooo00;ooooo
Koooo`0^o`3o00co0?oo1_l00?l;ool000Ko003o4_l0oolMo`3o01Ooool01?ooool1o`00007ooooo
000?ooooo`03o`000?oooooooooo00;oooooMOooo`0^o`3o02?o0?oo8ol0o`0Moooo00Cooooo0Ol0
0001ooooo`003oooool00ol0003oooooooooo`02ooooogGoool0;_l0o`0So`3oob?o0?l07Oooo`04
ooooo`7o00000Oooool00004ooooool0003o0000o`0000Cooooo0_l00005ooooo`03o`000?oooooo
oooo00;oooooMOooo`0^o`3o02?o0?oo8ol0o`0Moooo00Cooooo0Ol00001ooooo`0000Go0000oooo
ooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool00_oo
oomeoooo02ko0?l08ol0oolSo`3o01goool01?ooool1o`00007ooooo0004ooooo`04o`000?oooooo
ooooo`0000;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooogGoool0;_l0
o`0So`3oob?o0?l07Oooo`04ooooo`7o00000Oooool000Cooooo00Co0000oooooooooooo00000_oo
ool00ol0003oooooooooo`02ooooo`?o00000_ooool6ool007[oool0GOl0o`0Yoooo00?ooooo0_l0
0001ooooo`001?l00003ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool00_oo
ool6ool007[oool0GOl0o`0Yoooo00Cooooo0Ol00001ooooo`0000?o0000ooooooooool01?ooool0
1?l0003oooooooooool00004ooooo`03o`000?oooooooooo00;ooooo1_oo001joooo05go0?l0:Ooo
o`04ooooo`7o00000Oooool000Go00000oooool2o`0000Gooooo00?o0000ooooooooool00_ooool6
ool007[oool0GOl0o`0Yoooo00Cooooo0Ol00001ooooo`003oooool00ol0003oooooooooo`02oooo
o`Koo`00N_ooo`1Mo`3o02Woool01?ooool1o`00007ooooo000?ooooo`03o`000?oooooooooo00;o
oooo3?oo0026oooo04Ko0?l0;_ooo`04ooooo`7o00000Oooool000oooooo00?o0000ooooooooool0
0_ooool<ool008Koool0A_l0o`0^oooo00Cooooo0Ol00001ooooo`003oooool00ol0003ooooooooo
o`02ooooo`coo`00Q_ooo`16o`3o02koool01?ooool1o`00007ooooo000?ooooo`03o`000?oooooo
oooo00;ooooo3?oo0026oooo04Ko0?l0;_ooo`04ooooo`7o00000Oooool000oooooo00?o0000oooo
ooooool00_ooool<ool008Koool0A_l0o`0^oooo00Cooooo0Ol00001ooooo`003oooool2o`0000?o
oooo5ooo0026oooo02Wo0?l0@?ooo`03ooooo`;o00000Oooool000oooooo00?o0000ooooooooool0
0_oooolGool008Koool0:Ol0o`10oooo00Cooooo0Ol00001ooooo`003oooool00ol0003ooooooooo
o`02oooooaOoo`00Q_ooo`0Yo`3o043oool01?ooool1o`00007ooooo000?ooooo`03o`000?oooooo
oooo00;ooooo5ooo0026oooo02Wo0?l0@?ooo`04ooooo`7o00000Oooool000oooooo00?o0000oooo
ooooool00_oooolGool008Koool0:Ol0o`10oooo00Cooooo0Ol00001ooooo`003oooool00ol0003o
ooooooooo`3oooooo`gooooo0Ol00001ooooo`003oooool00ol0003oooooooooo`3oooooo`gooooo
0Ol00001ooooo`003oooool00ol0003oooooooooo`3oooooo`gooooo0Ol00001ooooo`003oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0=oooool0
0ol0003oooooooooo`0gooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool07oooool1
o`00007ooooo000?ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`08ooooo`7o00000Oooool000ooooooool0000Ao`00007ooooo003oooooob7ooooo
0000\
\>"],
  ImageRangeCache->{{{132.938, 362.312}, {403.438, 174.062}} -> {-32.2316, \
40.3255, 0.172566, 0.203244}}]
}, Open  ]],

Cell[BoxData[
    \(\({tempo, matrix} = 
        Timing[Table[
            mandelbrot[{x, y}], {y, \(-1.3\), 1.3,  .01}, {x, \(-1.7\), 
              0.5,  .01}]];\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(tempo\)], "Input"],

Cell[BoxData[
    \(20.45493499999975`\ Second\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(ListDensityPlot[matrix, Mesh \[Rule] False, 
        ColorFunction \[Rule] Hue];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00435085 0.0192308 0.00368406 [
[.01923 -0.0125 -3 -9 ]
[.01923 -0.0125 3 0 ]
[.23677 -0.0125 -6 -9 ]
[.23677 -0.0125 6 0 ]
[.45432 -0.0125 -9 -9 ]
[.45432 -0.0125 9 0 ]
[.67186 -0.0125 -9 -9 ]
[.67186 -0.0125 9 0 ]
[.8894 -0.0125 -9 -9 ]
[.8894 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01923 -6 -4.5 ]
[-0.0125 .01923 0 4.5 ]
[-0.0125 .20343 -12 -4.5 ]
[-0.0125 .20343 0 4.5 ]
[-0.0125 .38764 -18 -4.5 ]
[-0.0125 .38764 0 4.5 ]
[-0.0125 .57184 -18 -4.5 ]
[-0.0125 .57184 0 4.5 ]
[-0.0125 .75604 -18 -4.5 ]
[-0.0125 .75604 0 4.5 ]
[-0.0125 .94024 -18 -4.5 ]
[-0.0125 .94024 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.01923 0 m
.01923 .00625 L
s
[(0)] .01923 -0.0125 0 1 Mshowa
.23677 0 m
.23677 .00625 L
s
[(50)] .23677 -0.0125 0 1 Mshowa
.45432 0 m
.45432 .00625 L
s
[(100)] .45432 -0.0125 0 1 Mshowa
.67186 0 m
.67186 .00625 L
s
[(150)] .67186 -0.0125 0 1 Mshowa
.8894 0 m
.8894 .00625 L
s
[(200)] .8894 -0.0125 0 1 Mshowa
.125 Mabswid
.06274 0 m
.06274 .00375 L
s
.10625 0 m
.10625 .00375 L
s
.14976 0 m
.14976 .00375 L
s
.19326 0 m
.19326 .00375 L
s
.28028 0 m
.28028 .00375 L
s
.32379 0 m
.32379 .00375 L
s
.3673 0 m
.3673 .00375 L
s
.41081 0 m
.41081 .00375 L
s
.49782 0 m
.49782 .00375 L
s
.54133 0 m
.54133 .00375 L
s
.58484 0 m
.58484 .00375 L
s
.62835 0 m
.62835 .00375 L
s
.71537 0 m
.71537 .00375 L
s
.75888 0 m
.75888 .00375 L
s
.80238 0 m
.80238 .00375 L
s
.84589 0 m
.84589 .00375 L
s
.93291 0 m
.93291 .00375 L
s
.97642 0 m
.97642 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01923 m
.00625 .01923 L
s
[(0)] -0.0125 .01923 1 0 Mshowa
0 .20343 m
.00625 .20343 L
s
[(50)] -0.0125 .20343 1 0 Mshowa
0 .38764 m
.00625 .38764 L
s
[(100)] -0.0125 .38764 1 0 Mshowa
0 .57184 m
.00625 .57184 L
s
[(150)] -0.0125 .57184 1 0 Mshowa
0 .75604 m
.00625 .75604 L
s
[(200)] -0.0125 .75604 1 0 Mshowa
0 .94024 m
.00625 .94024 L
s
[(250)] -0.0125 .94024 1 0 Mshowa
.125 Mabswid
0 .05607 m
.00375 .05607 L
s
0 .09291 m
.00375 .09291 L
s
0 .12975 m
.00375 .12975 L
s
0 .16659 m
.00375 .16659 L
s
0 .24027 m
.00375 .24027 L
s
0 .27711 m
.00375 .27711 L
s
0 .31396 m
.00375 .31396 L
s
0 .3508 m
.00375 .3508 L
s
0 .42448 m
.00375 .42448 L
s
0 .46132 m
.00375 .46132 L
s
0 .49816 m
.00375 .49816 L
s
0 .535 m
.00375 .535 L
s
0 .60868 m
.00375 .60868 L
s
0 .64552 m
.00375 .64552 L
s
0 .68236 m
.00375 .68236 L
s
0 .7192 m
.00375 .7192 L
s
0 .79288 m
.00375 .79288 L
s
0 .82972 m
.00375 .82972 L
s
0 .86656 m
.00375 .86656 L
s
0 .9034 m
.00375 .9034 L
s
0 .97709 m
.00375 .97709 L
s
.25 Mabswid
0 0 m
0 1 L
s
.01923 .99375 m
.01923 1 L
s
.23677 .99375 m
.23677 1 L
s
.45432 .99375 m
.45432 1 L
s
.67186 .99375 m
.67186 1 L
s
.8894 .99375 m
.8894 1 L
s
.125 Mabswid
.06274 .99625 m
.06274 1 L
s
.10625 .99625 m
.10625 1 L
s
.14976 .99625 m
.14976 1 L
s
.19326 .99625 m
.19326 1 L
s
.28028 .99625 m
.28028 1 L
s
.32379 .99625 m
.32379 1 L
s
.3673 .99625 m
.3673 1 L
s
.41081 .99625 m
.41081 1 L
s
.49782 .99625 m
.49782 1 L
s
.54133 .99625 m
.54133 1 L
s
.58484 .99625 m
.58484 1 L
s
.62835 .99625 m
.62835 1 L
s
.71537 .99625 m
.71537 1 L
s
.75888 .99625 m
.75888 1 L
s
.80238 .99625 m
.80238 1 L
s
.84589 .99625 m
.84589 1 L
s
.93291 .99625 m
.93291 1 L
s
.97642 .99625 m
.97642 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .01923 m
1 .01923 L
s
.99375 .20343 m
1 .20343 L
s
.99375 .38764 m
1 .38764 L
s
.99375 .57184 m
1 .57184 L
s
.99375 .75604 m
1 .75604 L
s
.99375 .94024 m
1 .94024 L
s
.125 Mabswid
.99625 .05607 m
1 .05607 L
s
.99625 .09291 m
1 .09291 L
s
.99625 .12975 m
1 .12975 L
s
.99625 .16659 m
1 .16659 L
s
.99625 .24027 m
1 .24027 L
s
.99625 .27711 m
1 .27711 L
s
.99625 .31396 m
1 .31396 L
s
.99625 .3508 m
1 .3508 L
s
.99625 .42448 m
1 .42448 L
s
.99625 .46132 m
1 .46132 L
s
.99625 .49816 m
1 .49816 L
s
.99625 .535 m
1 .535 L
s
.99625 .60868 m
1 .60868 L
s
.99625 .64552 m
1 .64552 L
s
.99625 .68236 m
1 .68236 L
s
.99625 .7192 m
1 .7192 L
s
.99625 .79288 m
1 .79288 L
s
.99625 .82972 m
1 .82972 L
s
.99625 .86656 m
1 .86656 L
s
.99625 .9034 m
1 .9034 L
s
.99625 .97709 m
1 .97709 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.01923 .01923 translate
.96154 .96154 scale
663 string
221 261 8 [221 0 0 261 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00
FF0000FF0000FF0000FF0000FF0000FF0000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00
FF0000FF0000FF0000FF0000FF0000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00
FF0000FF0000FF0000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00
FF0000FF0000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00
FF0000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF0000FF0000FF0000FFFF00FFFF00FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF0000FF0000FFFF00FFFF0000FF0000FF0000FF00FFFF00FFFF00FFFF00FFFF00FF
0000FF0000FF0000FF0000FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
0000FF0000FF0000FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00FF0000FF0000FF0000FF0000FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
0000FF0000FF0000FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00FFFF00FF0000FF0000FF0000FF0000FF0000FF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF
0000FF0000FF0000FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00FFFF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF
0000FF0000FF0000FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00FFFF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF
0000FF0000FF0000FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00FFFF00FFFF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF
0000FF0000FF0000FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00FFFF00FFFF00FFFF00FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF
0000FF0000FF0000FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FF
FF00FF0000FF0000FF0000FF0000FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF
0000FF0000FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FF
FF0000FF00FFFF00FF0000FF0000FF0000FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF
0000FF0000FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FFFF0000FF0000FF0000
FF0000FF0000FF00FF0000FF0000FF0000FF0000FF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF
0000FF0000FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00FF0000FF0000FF0000FF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00FFFF00FF0000FF0000FF0000FF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00FFFF00FF0000FF0000FF0000FF0000FF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00FFFF00FF0000FF0000FF0000FF0000FF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00FFFF00FF0000FF0000FF0000FF0000FF0000FF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF00FF
FF00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00FFFF00FF0000FF0000FF0000FF0000FF0000FF0000FF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF00FFFF00FF
FF00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00FFFF00FFFF00FF0000FF0000FF0000FF0000FF0000FF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF00FFFF00FF
FF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00FFFF00FFFF00FF0000FF0000FF0000FF0000FF0000FF0000FF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF00FFFF00FFFF00FF
FF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00FFFF00FFFF00FFFF00FF0000FF0000FF0000FF0000FF0000FF
0000FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF00FFFF00FFFF00FFFF00FF
FF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00FFFF00FFFF00FFFF00FF0000FF0000FF0000FF0000FF0000FF
0000FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF00FFFF00FFFF00FFFF00FFFF00FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00FFFF00FFFF00FFFF00FF0000FF0000FF0000FF0000FF
0000FF0000FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00FFFF00FFFF00FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00FFFF00FFFF00FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FFFF00FFFF00FF0000FF0000FF
0000FF0000FF0000FF0000FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FFFF00FFFF00FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FFFF00FFFF00FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FFFF00FFFF00FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FFFF00FFFF00FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FFFF00FFFF00FF
FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF00FF
FF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FFFF00FFFF00FF
FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF00FFFF00FF
FF00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FFFF00FF
FF00FFFF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF00FFFF00FFFF00FF
FF00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FFFF00FF
FF00FFFF00FFFF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF00FFFF00FFFF00FFFF00FFFF00FF
FF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FFFF00FF
FF00FFFF00FFFF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FF
FF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF
FF00FFFF00FFFF00FFFF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FF0000FF00
00FF0000FF0000FF0000FF0000FF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FF
FF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF
FF00FFFF00FFFF00FFFF00FFFF00FFFF00FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FF00
00FF0000FF0000FF0000FF0000FF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF00FF
FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FF
FF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FF0000FF0000FF0000FF0000FF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF00FFFF00FFFF00FFFF00FFFF00FF
FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FF0000FF0000FF0000FF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FF
FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FF0000FF0000FF0000FF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FF
FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FF0000FF0000FF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF00FF
FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00FFFF00FFFF00FFFF00FFFF00FFFF00FF
FF00FFFF00FFFF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF00FF
FF00FFFF00FF0000FF0000FF0000FF0000FF0000FF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FF0000FF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF00FFFF00FF
FF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FFFF00FFFF00FFFF00FFFF00FF
FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FF
FF00FFFF0000FF00FFFF00FF0000FF0000FF0000FF0000FF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF00FFFF00FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FFFF00FFFF00FF
FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000
FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF00FFFF00FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF
FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF00FFFF00FFFF00FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF00FFFF00FFFF00FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF00FFFF00FFFF00FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00FFFF00FF0000FF0000FF0000FF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF00FFFF00FFFF00FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF
00FFFF00FFFF00FFFF00FFFF00FFFF
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FFFF00FF0000FF0000FF0000FF
00FFFF00FFFF00FFFF00FFFF00FFFF
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FFFF00FF0000FF0000FF
0000FF00FFFF00FFFF00FFFF00FFFF
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF
0000FF00FFFF00FFFF00FFFF00FFFF
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF
0000FF00FFFF00FFFF00FFFF00FFFF
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF
0000FF00FFFF00FFFF00FFFF00FFFF
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF
0000FF0000FF00FFFF00FFFF00FFFF
FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF
0000FF0000FF00FFFF00FFFF00FFFF
FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF
0000FF0000FF00FFFF00FFFF00FFFF
FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF00FF
FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF
0000FF0000FF00FFFF00FFFF00FFFF
FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF00FFFF00FF
FF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FFFF00FF0000FF0000FF
0000FF0000FF00FFFF00FFFF00FFFF
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF00FFFF00FFFF00FF
FF00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FFFF00FF0000FF0000FF
0000FF0000FF0000FF00FFFF00FFFF
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF00FFFF00FFFF00FFFF00FF
FF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FFFF00FF0000FF0000FF
0000FF0000FF0000FF00FFFF00FFFF
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF00FFFF00FFFF00FFFF00FFFF00FF
FF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FFFF00FFFF00FF0000FF0000FF
0000FF0000FF0000FF00FFFF00FFFF
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FF
FF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FFFF00FFFF00FF0000FF0000FF
0000FF0000FF0000FF00FFFF00FFFF
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FF
FF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FFFF00FFFF00FF0000FF0000FF
0000FF0000FF0000FF00FFFF00FFFF
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FFFF00FFFF00FFFF00FF0000FF
0000FF0000FF0000FF0000FF00FFFF
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FFFF00FFFF00FFFF00FF0000FF
0000FF0000FF0000FF0000FF00FFFF
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF00FF
FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FFFF00FFFF00FF0000FF
0000FF0000FF0000FF0000FF00FFFF
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF00FFFF00FFFF00FFFF00FF
FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FFFF00FFFF00FFFF00FF
0000FF0000FF0000FF0000FF0000FF
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
0000FF0000FF0000FF0000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FF
FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FFFF00FFFF00FF
0000FF0000FF0000FF0000FF0000FF
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
0000FF0000FF0000FFFF00FFFF0000FF0000FF0000FF0000FF00FFFF00FFFF00FFFF00FF
FF00FFFF00FFFF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FF
FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FF
FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FFFF00FF
FF00FF0000FF0000FF0000FF0000FF
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF
0000FF0000FF0000FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF
FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FF
FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FF
FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FF
FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF
FF00FFFF00FF0000FF0000FF0000FF
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF
0000FF0000FF0000FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FF
FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FF
FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FF
FF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00FF0000FF0000FF0000FF
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF
0000FF0000FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FF
FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF00FFFF00FF
FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FF
FF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00FFFF00FF0000FF0000FF
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF
0000FF0000FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FF
FF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00FF0000FF0000FF
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF
0000FF0000FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FFFF00FFFF00FFFF00FFFF00FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00FFFF00FF0000FF
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF
0000FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00FFFF00FF0000FF
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF
0000FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00FFFF00FF0000FF
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00FF0000FF
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00FF0000FF
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00FFFF00FF0000FF
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00FFFF00FF0000FF
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00FFFF00FF0000FF
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF00FF
FF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00FFFF00FF0000FF0000FF
00FF0000FF0000FF0000FF0000FF0000FF0000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF00FF
FF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00FFFF00FF0000FF0000FF
00FF0000FF0000FF0000FF0000FF0000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF00FFFF00FF
FF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00FFFF00FF0000FF0000FF
00FF0000FF0000FF0000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF00FFFF00FF
FF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00FFFF00FFFF00FF0000FF0000FF
00FF0000FF0000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF00FFFF00FFFF00FF
FF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00FFFF00FFFF00FF0000FF0000FF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF00FFFF00FFFF00FFFF00FF
FF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00FFFF00FF0000FF0000FF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF00FFFF00FFFF00FFFF00FFFF00FF
FF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00FFFF00FF0000FF0000FF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FF
FF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00FFFF00FF0000FF0000FF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00FFFF00FF0000FF0000FF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00FFFF00FF0000FF0000FF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00FFFF00FF0000FF0000FF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00FFFF00FF0000FF0000FF0000FF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00FFFF00FF0000FF0000FF0000FF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF00FF
FF00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF
FF00FFFF00FF0000FF0000FF0000FF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF00FFFF00FF
FF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF
FF00FFFF00FF0000FF0000FF0000FF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF00FFFF00FFFF00FF
FF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF
FF00FF0000FF0000FF0000FF0000FF
00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF00FFFF00FFFF00FFFF00FFFF00FF
FF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FFFF00FF
FF00FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FFFF00FF
FF00FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FFFF00FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FFFF00FFFF00FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FFFF00FFFF00FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF00FFFF00FFFF00FF
FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FFFF00FFFF00FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FF
FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FFFF00FFFF00FF0000FF
0000FF0000FF0000FF0000FF0000FF
FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FF
FF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FFFF00FFFF00FF0000FF
0000FF0000FF0000FF0000FF0000FF
FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FF
FF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FFFF00FFFF00FFFF00FF0000FF
0000FF0000FF0000FF0000FF0000FF
FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FFFF00FFFF00FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
FF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00FFFF00FFFF00FFFF00FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00FFFF00FFFF00FFFF00FF0000FF0000FF
0000FF0000FF0000FF0000FF00FFFF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00FFFF00FFFF00FFFF00FF0000FF0000FF
0000FF0000FF0000FF0000FF00FFFF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00FFFF00FFFF00FFFF00FF0000FF0000FF
0000FF0000FF0000FF0000FF00FFFF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00FFFF00FFFF00FFFF00FFFF00FF0000FF0000FF
0000FF0000FF0000FF0000FF00FFFF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00FFFF00FFFF00FFFF00FFFF00FF0000FF0000FF
0000FF0000FF0000FF0000FF00FFFF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00FFFF00FFFF00FFFF00FFFF00FF0000FF0000FF
0000FF0000FF0000FF0000FF00FFFF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00FFFF00FFFF00FFFF00FF0000FF0000FF
0000FF0000FF0000FF0000FF00FFFF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00FFFF00FFFF00FFFF00FF0000FF0000FF
0000FF0000FF0000FF0000FF00FFFF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00FFFF00FFFF00FFFF00FF0000FF0000FF
0000FF0000FF0000FF0000FF00FFFF
FF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00FFFF00FFFF00FFFF00FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FFFF00FFFF00FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF
FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FF
FF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FFFF00FFFF00FFFF00FF0000FF
0000FF0000FF0000FF0000FF0000FF
FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FF
FF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FFFF00FFFF00FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FF
FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FFFF00FFFF00FF0000FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF00FFFF00FFFF00FF
FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FFFF00FFFF00FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FFFF00FFFF00FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FFFF00FFFF00FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FFFF00FF
0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FFFF00FF
FF00FF0000FF0000FF0000FF0000FF
00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF00FFFF00FFFF00FFFF00FFFF00FF
FF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FFFF00FF
FF00FF0000FF0000FF0000FF0000FF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF00FFFF00FFFF00FF
FF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF
FF00FF0000FF0000FF0000FF0000FF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF00FFFF00FF
FF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF
FF00FFFF00FF0000FF0000FF0000FF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF00FF
FF00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF
FF00FFFF00FF0000FF0000FF0000FF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00FFFF00FF0000FF0000FF0000FF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00FFFF00FF0000FF0000FF0000FF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00FFFF00FF0000FF0000FF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00FFFF00FF0000FF0000FF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00FFFF00FF0000FF0000FF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FF
FF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00FFFF00FF0000FF0000FF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF00FFFF00FFFF00FFFF00FFFF00FF
FF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00FFFF00FF0000FF0000FF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF00FFFF00FFFF00FFFF00FF
FF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00FFFF00FF0000FF0000FF
00FF0000FF0000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF00FFFF00FFFF00FF
FF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00FFFF00FFFF00FF0000FF0000FF
00FF0000FF0000FF0000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF00FFFF00FF
FF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00FFFF00FFFF00FF0000FF0000FF
00FF0000FF0000FF0000FF0000FF0000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF00FFFF00FF
FF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00FFFF00FF0000FF0000FF
00FF0000FF0000FF0000FF0000FF0000FF0000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF00FF
FF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00FFFF00FF0000FF0000FF
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF00FF
FF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00FFFF00FF0000FF0000FF
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00FFFF00FF0000FF
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00FFFF00FF0000FF
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00FFFF00FF0000FF
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00FF0000FF
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00FF0000FF
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF
0000FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00FFFF00FF0000FF
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF
0000FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00FFFF00FF0000FF
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF
0000FF0000FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FFFF00FFFF00FFFF00FFFF00FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00FFFF00FF0000FF
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF
0000FF0000FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FF
FF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00FF0000FF0000FF
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF
0000FF0000FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FF
FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF00FFFF00FF
FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FF
FF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00FFFF00FF0000FF0000FF
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF
0000FF0000FF0000FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FF
FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FF
FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FF
FF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00FF0000FF0000FF0000FF
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF
0000FF0000FF0000FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF
FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FF
FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FF
FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FF
FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF
FF00FFFF00FF0000FF0000FF0000FF
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
0000FF0000FF0000FFFF00FFFF0000FF0000FF0000FF0000FF00FFFF00FFFF00FFFF00FF
FF00FFFF00FFFF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FF
FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FF
FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FFFF00FF
FF00FF0000FF0000FF0000FF0000FF
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
0000FF0000FF0000FF0000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FF
FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FFFF00FFFF00FF
0000FF0000FF0000FF0000FF0000FF
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF00FFFF00FFFF00FFFF00FF
FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FFFF00FFFF00FFFF00FF
0000FF0000FF0000FF0000FF0000FF
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF00FF
FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FFFF00FFFF00FF0000FF
0000FF0000FF0000FF0000FF00FFFF
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FFFF00FFFF00FFFF00FF0000FF
0000FF0000FF0000FF0000FF00FFFF
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FFFF00FFFF00FFFF00FF0000FF
0000FF0000FF0000FF0000FF00FFFF
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FF
FF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FFFF00FFFF00FF0000FF0000FF
0000FF0000FF0000FF00FFFF00FFFF
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FF
FF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FFFF00FFFF00FF0000FF0000FF
0000FF0000FF0000FF00FFFF00FFFF
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF00FFFF00FFFF00FFFF00FFFF00FF
FF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FFFF00FFFF00FF0000FF0000FF
0000FF0000FF0000FF00FFFF00FFFF
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF00FFFF00FFFF00FFFF00FF
FF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FFFF00FF0000FF0000FF
0000FF0000FF0000FF00FFFF00FFFF
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF00FFFF00FFFF00FF
FF00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FFFF00FF0000FF0000FF
0000FF0000FF0000FF00FFFF00FFFF
FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF00FFFF00FF
FF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FFFF00FF0000FF0000FF
0000FF0000FF00FFFF00FFFF00FFFF
FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF00FF
FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF
0000FF0000FF00FFFF00FFFF00FFFF
FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF
0000FF0000FF00FFFF00FFFF00FFFF
FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF
0000FF0000FF00FFFF00FFFF00FFFF
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF
0000FF0000FF00FFFF00FFFF00FFFF
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF
0000FF00FFFF00FFFF00FFFF00FFFF
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF
0000FF00FFFF00FFFF00FFFF00FFFF
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF
0000FF00FFFF00FFFF00FFFF00FFFF
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FFFF00FF0000FF0000FF
0000FF00FFFF00FFFF00FFFF00FFFF
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FFFF00FF0000FF0000FF0000FF
00FFFF00FFFF00FFFF00FFFF00FFFF
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF00FFFF00FFFF00FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF
00FFFF00FFFF00FFFF00FFFF00FFFF
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF00FFFF00FFFF00FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00FFFF00FF0000FF0000FF0000FF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF00FFFF00FFFF00FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF00FFFF00FFFF00FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF00FFFF00FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF
FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF00FFFF00FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FFFF00FFFF00FF
FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000
FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF00FFFF00FF
FF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FFFF00FFFF00FFFF00FFFF00FF
FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FF
FF00FFFF0000FF00FFFF00FF0000FF0000FF0000FF0000FF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF00FF
FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00FFFF00FFFF00FFFF00FFFF00FFFF00FF
FF00FFFF00FFFF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF00FF
FF00FFFF00FF0000FF0000FF0000FF0000FF0000FF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FF0000FF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FF
FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FF0000FF0000FF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FF
FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FF0000FF0000FF0000FF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF00FFFF00FFFF00FFFF00FFFF00FF
FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FF0000FF0000FF0000FF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF00FF
FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FF
FF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FF0000FF0000FF0000FF0000FF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FF
FF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF
FF00FFFF00FFFF00FFFF00FFFF00FFFF00FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FF00
00FF0000FF0000FF0000FF0000FF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FF
FF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF
FF00FFFF00FFFF00FFFF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FF0000FF00
00FF0000FF0000FF0000FF0000FF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF00FFFF00FFFF00FFFF00FFFF00FF
FF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FFFF00FF
FF00FFFF00FFFF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF00FFFF00FFFF00FF
FF00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FFFF00FF
FF00FFFF00FFFF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF00FFFF00FF
FF00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FFFF00FF
FF00FFFF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF00FF
FF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FFFF00FFFF00FF
FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FFFF00FFFF00FF
FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FFFF00FFFF00FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FFFF00FFFF00FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FFFF00FFFF00FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FFFF00FFFF00FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FFFF00FFFF00FF0000FF0000FF
0000FF0000FF0000FF0000FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00FFFF00FFFF00FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00FFFF00FFFF00FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF00FFFF00FFFF00FFFF00FFFF00FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00FFFF00FFFF00FFFF00FF0000FF0000FF0000FF0000FF
0000FF0000FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF00FFFF00FFFF00FFFF00FF
FF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00FFFF00FFFF00FFFF00FF0000FF0000FF0000FF0000FF0000FF
0000FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF00FFFF00FFFF00FF
FF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00FFFF00FFFF00FFFF00FF0000FF0000FF0000FF0000FF0000FF
0000FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF00FFFF00FF
FF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00FFFF00FFFF00FF0000FF0000FF0000FF0000FF0000FF0000FF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF00FFFF00FF
FF00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00FFFF00FFFF00FF0000FF0000FF0000FF0000FF0000FF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF00FF
FF00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00FFFF00FF0000FF0000FF0000FF0000FF0000FF0000FF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00FFFF00FF0000FF0000FF0000FF0000FF0000FF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00FFFF00FF0000FF0000FF0000FF0000FF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00FFFF00FF0000FF0000FF0000FF0000FF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00FFFF00FF0000FF0000FF0000FF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF
0000FF0000FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00FF0000FF0000FF0000FF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF
0000FF0000FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FFFF0000FF0000FF0000
FF0000FF0000FF00FF0000FF0000FF0000FF0000FF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF
0000FF0000FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FF
FF0000FF00FFFF00FF0000FF0000FF0000FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF
0000FF0000FF0000FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FF
FF00FF0000FF0000FF0000FF0000FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF
0000FF0000FF0000FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00FFFF00FFFF00FFFF00FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF
0000FF0000FF0000FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00FFFF00FFFF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF
0000FF0000FF0000FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00FFFF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF
0000FF0000FF0000FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00FFFF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
0000FF0000FF0000FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00FFFF00FF0000FF0000FF0000FF0000FF0000FF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
0000FF0000FF0000FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00FF0000FF0000FF0000FF0000FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF0000FF0000FFFF00FFFF0000FF0000FF0000FF00FFFF00FFFF00FFFF00FFFF00FF
0000FF0000FF0000FF0000FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF0000FF0000FF0000FFFF00FFFF00FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00
FF0000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00
FF0000FF0000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00
FF0000FF0000FF0000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00
FF0000FF0000FF0000FF0000FF0000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00
FF0000FF0000FF0000FF0000FF0000FF0000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQ
ooooo`006Oooool2o`0003Cooooo0ol00004ooooo`;o0000;Oooool3o`0000Cooooo0_l00004oooo
o`;o0000:oooool3o`0000?ooooo0ol00004ooooo`;o0000:_ooool5o`0000?ooooo0_l00004oooo
o`;o00006?ooool001Sooooo00Co0000oooooooooooo0000<_ooool01Ol0003ooooooooooooooooo
000000;ooooo00Co0000oooooooooooo0000;Oooool00ol0003oooooooooo`02ooooo`04o`000?oo
ooooooooo`0000;ooooo00Co0000oooooooooooo0000:oooool01Ol0003ooooooooooooooooo0000
00?ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`0Xooooo`04o`000?oooooo
ooooo`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0000Gooooo`00
6?ooool01?l0003oooooooooool0000fooooo`04o`000?ooooooooooo`0000;ooooo00?o0000oooo
ooooool0:oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000
oooooooooooo0000:oooool00ol0003oooooooooo`05ooooo`04o`000?ooooooooooo`0000;ooooo
00?o0000ooooooooool0:Oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;o
oooo00Co0000oooooooooooo00005oooool001Sooooo00Co0000oooooooooooo0000=_ooool01?l0
003oooooooooool00002ooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool00_ooool0
1?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0002_ooooo00?o0000ooooooooool0
1Oooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo02[ooooo00Go0000oooooooo
ooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool05Oooool0
01Sooooo00Co0000oooooooooooo0000<_ooool4o`0000?ooooo00Co0000oooooooooooo0000;Ooo
ool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo
0000:oooool01?l0003oooooooooooooool4o`0000?ooooo00Co0000oooooooooooo0000:Oooool0
1Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000_ooool01?l0003ooooo
ooooool0000Gooooo`006?ooool01?l0003oooooooooool0000booooo`03o`000?oooooooooo00Co
oooo00Co0000oooooooooooo0000;?ooool2o`0000Cooooo00Co0000oooooooooooo00000_ooool0
1?l0003oooooooooool0000Zooooo`;o00000oooool00ol0003oooooooooo`04ooooo`04o`000?oo
ooooooooo`0002Wooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`00
00;ooooo00Co0000oooooooooooo00005oooool001Wooooo0_l0000cooooo`Go00000oooool2o`00
02kooooo00?o0000ooooooooool00oooool2o`0000Cooooo0_l0000/ooooo`04o`000?oooooooooo
ooooo`Go00000oooool2o`0002_ooooo0ol00004ooooo`;o00001?ooool2o`0001Sooooo003ooooo
ob7ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo000Eoooooooo00002ol00001
ooooo`005Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool00oooool1o`00007ooooo000Eooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool0=oooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo03Oooooo00?o0000oooooooo
ool0=oooool00ol0003oooooooooo`0Jooooo`7o00000Oooool000kooooo0_l00005ooooo`03o`00
0?oooooooooo0?oooooo1oooool1o`00007ooooo000=ooooo`04o`000?ooooooooooo`0000Cooooo
00?o0000ooooooooool0ooooool7ooooo`7o00000Oooool000gooooo00Co0000oooooooooooo0000
1?ooool2o`000?oooooo1oooool2o`00007ooooo000=ooooo`04o`000?ooooooooooo`0000Cooooo
00?o0000ooooooooool00_oooolB0?l008T0ool0:@00o`0k0?oo00Gooooo0Ol00001ooooo`003Ooo
ool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo00;ooooo4@3o00260?oo03400?l0
=`3oo`05ooooo`7o00000Oooool000gooooo00Co0000oooooooooooo00001?ooool00ol0003ooooo
ooooo`02ooooo`l0o`00Q@3oo`0f003o03D0ool01Oooool1o`00007ooooo000>ooooo`;o00001Ooo
ool00ol0003oooooooooo`02ooooo`h0o`00PP3oo`0l003o03<0ool01Oooool1o`00007ooooo000E
ooooo`03o`000?oooooooooo00;ooooo303o00220?oo04800?l0;`3oo`05ooooo`7o00000Oooool0
01Gooooo00?o0000ooooooooool00_ooool:0?l00880ool0AP00o`0]0?oo00Gooooo0Ol00001oooo
o`005Oooool00ol0003oooooooooo`02ooooo`P0o`00P@3oo`1;003o02/0ool01Oooool1o`00007o
oooo000Eooooo`03o`000?oooooooooo00;ooooo1`3o001o0?oo04l00?l0:P3oo`05ooooo`7o0000
0Oooool001Gooooo00?o0000ooooooooool00_ooool60?l007h0ool0E000o`0W0?oo00Gooooo0Ol0
0001ooooo`005Oooool2o`0000?ooooo0`3o001n0?oo05T00?l09@3oo`04ooooo`;o00000Oooool0
01Gooooo00?o0000ooooooooool00_ooool20?l007d0ool0G000o`0T0?oo00Gooooo0Ol00001oooo
o`005Oooool00ol0003oooooooooo`02ooooo`030?l0003oo`00ool007X0ool0;@00o`0;003oobT0
0?l08@3oo`05ooooo`7o00000Oooool001Gooooo00?o0000ooooooooool00_oooomj0?oo02`00?l0
5000oolU003o0200ool01Oooool1o`00007ooooo000Eooooo`03o`000?oooooooooo00;oooooN03o
o`0/003o01P00?oo9@00o`0N0?oo00Gooooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`02
ooooogH0ool0;@00o`0M003oob800?l07@3oo`05ooooo`7o00000Oooool001Gooooo00?o0000oooo
ooooool00_oooomc0?oo02d00?l08P00oolQ003o01`0ool01Oooool1o`00007ooooo000Eooooo`03
o`000?oooooooooo00;oooooL@3oo`0^003o00/00?oo2P000?l@003oob800?l06@3oo`05ooooo`7o
00000Oooool001Gooooo00?o0000ooooooooool00_oooom_0?oo02l00?l02P00ool40000o`80o`3o
20000?l@003oob400?l0603oo`05ooooo`7o00000Oooool001Gooooo00?o0000ooooooooool00_oo
oom/0?oo03400?l02P00ool30000o`040?l0o`3o0000o`000?l000H0o`3o1@000?l@003ooal00?l0
5`3oo`05ooooo`7o00000Oooool001Gooooo0_l00003ooooofX0ool0<P00o`0:003oo`@0003o00<0
o`3o0?l0003o00001`3o00000`3o0?l0003o0000o`030000oa000?oo7`00o`0F0?oo00Cooooo0_l0
0001ooooo`005Oooool00ol0003oooooooooo`02ooooofT0ool0<000o`0=003oo`@0003o00<0o`3o
0?l0003o00001`3o00020?l0o`H0003o4000oolO003o01@0ool01Oooool1o`00007ooooo000Eoooo
o`03o`000?oooooooooo00;oooooI`3oo`0a003o00d00?oo1@000?l20?l0o`P0o`000P3o0?l80000
o`l00?oo8000o`0B0?oo00Gooooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`02ooooof@0
ool0<`00o`0>003oo`D0003o0P3o0?l90?l00080o`3o2`000?l=003ooal00?l04@3oo`05ooooo`7o
00000Oooool001Gooooo00?o0000ooooooooool00_oooomR0?oo03@00?l03P00ool60000o`80o`3o
2P3o00040?l0o`X0003o3000oolO003o0100ool01Oooool1o`00007ooooo000Eooooo`03o`000?oo
oooooooo00;oooooH03oo`0e003o00l00?oo1P000?l20?l0o`X0o`001@3o0?l;0000o`/00?oo8000
o`0>0?oo00Gooooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`02oooooe/0ool00P20o`0d
003o00800?n04000ool50000o`80P03o0P3o0?l;0?l000<0o`20203o0?l00`3o0800P03o0800o`03
0000o`030020o`00ool00?oo00L00?oo00<00?n0003o0000o`007@00o`000`20o`00ool00?oo000:
0?oo00Gooooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`02oooooeT0ool0=`00o`0B003o
o`H0003o103o0?lA0?l000030?l0o`3o0000o`0000@0o`0000<0o`3o0000o`000?l00`000?l:003o
ob400?l02P3oo`05ooooo`7o00000Oooool001Gooooo00?o0000ooooooooool00_oooomH0?oo03L0
0?l04`00ool60000o`@0o`3o6@3o00000`3o0?l0003o0000o`020000o`/00?oo8@00o`090?oo00Go
oooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`02oooooeD0ool0>000o`0C003oo`P0003o
103o0?lI0?l000030?l0o`000?l0003o00<0003o3000oolP003o00P0ool01Oooool1o`00007ooooo
000Eooooo`;o00000ooooomC0?oo03T00?l04`00ool80000o`D0o`3o6@3o00030?l0o`<0003o3@00
oolP003o00L0ool01?ooool2o`00007ooooo000Eooooo`03o`000?oooooooooo00;oooooD@3oo`0h
003o01D00?oo2@000?l50?l0oaT0o`000`3o0?l40000o`d00?oo8000o`060?oo00Gooooo0Ol00001
ooooo`005Oooool00ol0003oooooooooo`02ooooodh0ool0>P00o`0E003oo`T0003o1P3o0?lI0?l0
00<0o`3o10000?l>003oob000?l01@3oo`05ooooo`7o00000Oooool001Gooooo00?o0000oooooooo
ool00_oooom<0?oo03X00?l05`00ool90000o`H0o`3o6@3o00030?l0o`D0003o3P00oolQ003o00<0
ool01Oooool1o`00007ooooo000Eooooo`03o`000?oooooooooo00;oooooB`3oo`0j003o01L00?oo
2@000?l60?l0oaX0o`000`3o0?l70000o`d00?oo8P00o`000`3oo`3oooooooooo`03ooooo`7o0000
0Oooool001Gooooo00?o0000ooooooooool00_oooom90?oo03T00?l06@00ool90000o`L0o`3o6P3o
00040?l0o`H0003o3`00oolQ003o00Gooooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`02
ooooodH0ool0>`00o`0H003oo`/0003o1P3o0?lK0?l000@0o`3o1`000?l?003oob000?l01Oooool1
o`00007ooooo000Eooooo`03o`000?oooooooooo00;oooooA03oo`0k003o01T00?oo2`000?l50?l0
oad0o`001@3o0?l70000o`l00?oo7`00o`05ooooo`7o00000Oooool001Gooooo00?o0000oooooooo
ool00_oooom20?oo03/00?l06P00ool;0000o`D0o`3o7P3o00050?l0o`L0003o4000oolN003o00Go
oooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`02ooooocl0ool0?000o`0K003oo`X0003o
1P3o0?lP0?l000D0o`3o1`000?lA003ooa`00?l01Oooool1o`00007ooooo000Eooooo`;o00000ooo
ooln0?oo03/00?l07000ool:0000o`H0o`3o8`3o00030?l0o`P0003o4@00oolK003o00Cooooo0_l0
0001ooooo`005Oooool00ol0003oooooooooo`02oooooc`0ool0>`00o`0L003oo`/0003o1@3o0?lV
0?l000<0o`3o20000?lB003ooaT00?l01Oooool1o`00007ooooo000Eooooo`03o`000?oooooooooo
00;ooooo>P3oo`0l003o01/00?oo30000?l50?l0obP0o`000`3o0?l70000oa<00?oo6000o`05oooo
o`7o00000Oooool001Gooooo00?o0000ooooooooool00_oooolg0?oo03`00?l07@00ool<0000o`@0
o`3o:P3o00030?l0o`P0003o5000oolF003o00Gooooo0Ol00001ooooo`005Oooool00ol0003ooooo
ooooo`02ooooocD0ool0?000o`0M003oo`h0003o103o0?l[0?l000@0o`3o20000?lC003ooaD00?l0
1Oooool1o`00007ooooo000Eooooo`03o`000?oooooooooo00;ooooo<`3oo`0m003o01d00?oo3P00
0?l40?l0ob`0o`00103o0?l90000oaD00?oo4P00o`05ooooo`7o00000Oooool001Gooooo00?o0000
ooooooooool00_oooolb0?oo03`00?l07000ool?0000o`H0o`3o;@3o00040?l0o`T0003o5@00oolA
003o00Gooooo0Ol00001ooooo`001oooool3o`0000Cooooo0_l00005ooooo`03o`000?oooooooooo
00;ooooo;`3oo`0m003o01`00?oo40000?l60?l0obh0o`001@3o0?l90000oaD00?oo4000o`05oooo
o`7o00000Oooool000Kooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?oooooooooo
o`0000Cooooo00?o0000ooooooooool00_ooool]0?oo03d00?l07000oolA0000o`L0o`3o;P3o0005
0?l0o`/0003o5@00ool>003o00Gooooo0Ol00001ooooo`002_ooool01?l0003oooooooooool00002
ooooo`03o`000?oooooooooo00;ooooo0_l00003ooooob/0ool0?P00o`0K003ooa80003o1`3o0?l`
0?l000D0o`3o30000?lD003oo`d00?l01?ooool2o`00007ooooo000:ooooo`04o`000?oooooooooo
o`0000;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooobX0ool0?@00o`0J
003ooa@0003o203o0?l`0?l000H0o`3o30000?lD003oo``00?l01Oooool1o`00007ooooo0006oooo
o`Co00000oooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo00;ooooo9`3oo`0o
003o01T00?oo50000?l90?l0oc40o`001P3o0?l>0000oaD00?oo2@00o`05ooooo`7o00000Oooool0
00Kooooo00?o0000ooooooooool01?ooool01?l0003oooooooooool00004ooooo`03o`000?oooooo
oooo00;ooooo9@3oo`0n003o01X00?oo4`000?l<0?l0oc<0o`001@3o0?l?0000oa@00?oo2000o`05
ooooo`7o00000Oooool000Kooooo1Ol00003ooooo`;o00001Oooool00ol0003oooooooooo`02oooo
ob@0ool0?@00o`0I003ooa@0003o3@3o0?ld0?l000P0o`3o40000?lA003oo`L00?l01Oooool1o`00
007ooooo000Eooooo`03o`000?oooooooooo00;ooooo8@3oo`0o003o01P00?oo4@000?l@0?l0ocL0
o`00203o0?lB0000o`l00?oo1P00o`05ooooo`7o00000Oooool001Gooooo00?o0000ooooooooool0
0_oooolP0?oo03d00?l06P00ool>0000oa80o`3o>P3o00090?l0oa@0003o3000ool5003o00Gooooo
0Ol00001ooooo`005Oooool00ol0003oooooooooo`02oooooah0ool0?P00o`0J003oo`/0003o503o
0?lm0?l000T0o`3o5@000?l:003oo`D00?l01Oooool1o`00007ooooo000Eooooo`03o`000?oooooo
oooo00;ooooo7@3oo`0m003o01T00?oo2`000?lC0?l0od<0o`002P3o0?lD0000o`X00?oo0`00o`05
ooooo`7o00000Oooool001Gooooo00?o0000ooooooooool00_oooolK0?oo03d00?l06P00ool90000
o`X0o`3oDP3o000:0?l0o`T0003o103o0?l50000o`X00?oo0P00o`05ooooo`7o00000Oooool001Go
oooo0_l00003oooooaT0ool0?000o`0L003oo`T0003o1@3o0?mI0?l001D0o`3o00<0o`000?l0o`3o
0?l01@000?l9003oo`03003o0?oooooooooo00;ooooo0_l00001ooooo`005Oooool00ol0003ooooo
ooooo`02oooooaL0ool0?000o`0M003oo`T0003o0P3o0?mO0?l00100o`3o1P3o00000`3o0?l0003o
0000o`030000o`P00?oo00<00?l0ooooooooool00oooool1o`00007ooooo000Eooooo`03o`000?oo
oooooooo00;ooooo5P3oo`0k003o01h00?oo2@000?l20?l0of80o`003@3o0?l80?l000030?l0o`00
0?l0003o0080003o2@00ool5ooooo`7o00000Oooool001Gooooo00?o0000ooooooooool00_oooolE
0?oo03T00?l08000ool90000o`<0o`3oIP3o00070?l0o`/0o`0000<0o`3o0000o`000?l00P000?l8
003oo`Gooooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`02oooooa80ool0>P00o`0P003o
o`/0003o0`3o0?mh0?l000030?l0o`000?l0003o00<0003o1`00ool5ooooo`7o00000Oooool001Go
oooo00?o0000ooooooooool00_oooolA0?oo03P00?l08P00ool;0000o`<0o`3oN@3o00030?l0o`<0
003o1`00ool5ooooo`7o00000Oooool001Gooooo00?o0000ooooooooool00_ooool@0?oo03H00?l0
9000ool<0000o`<0o`3oNP3o00020?l0o`@0003o1P00ool5ooooo`7o00000Oooool001Gooooo00?o
0000ooooooooool00_ooool>0?oo03D00?l09P00ool<0000o`@0o`3oNP3o00030?l0o`<0003o1P00
ool5ooooo`7o00000Oooool001Gooooo00?o0000ooooooooool00_ooool=0?oo03@00?l09`00ool=
0000o`@0o`3oO03o00020?l0o`<0003o1@00ool5ooooo`7o00000Oooool001Gooooo00?o0000oooo
ooooool00_ooool<0?oo03400?l0:P00ool<0000o`H0o`3oO@3o0000103o0?l0003o0000o`000?l5
003oo`Gooooo0Ol00001ooooo`005Oooool2o`0000?ooooo2P3oo`0`003o02X00?oo3P000?l60?l0
ogh0o`0000@0o`3o0000o`000?l0003o1@00ool4ooooo`;o00000Oooool001Gooooo00?o0000oooo
ooooool00_ooool90?oo02d00?l0;@00ool?0000o`H0o`3oOP3o0000103o0?l0003o0000o`000?l5
003oo`Gooooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`02ooooo`L0ool0;000o`0^003o
oa00003o1`3o0?mn0?l000030?l0o`000?l0003o00<0003o0`00ool5ooooo`7o00000Oooool001Go
oooo00?o0000ooooooooool00_ooool60?oo02X00?l0<000ool@0000o`L0o`3oO`3o00000`3o0?l0
003o0000o`030000o`<00?oo1Oooool1o`00007ooooo000Eooooo`03o`000?oooooooooo00;ooooo
1@3oo`0Y003o02l00?oo4P000?l80?l0ogl0o`0000<0o`3o0000o`000?l00`000?l3003oo`Gooooo
0Ol00001ooooo`005Oooool00ol0003oooooooooo`02ooooo`<0ool0:@00o`0_003ooa<0003o203o
0?n00?l000030?l0o`000?l0003o00<0003o0`00ool5ooooo`7o00000Oooool001Gooooo00?o0000
ooooooooool00_ooool20?oo02P00?l0;P00oolD0000o`T0o`3oP03o00020?l0o`D0003o0`00ool5
ooooo`7o00000Oooool001Gooooo00?o0000ooooooooool00_oooolW003o02h00?oo5P000?l80?l0
oh80o`000P3o0?l60000o`800?oo1Oooool1o`00007ooooo000Eooooo`03o`000?oooooooooo00;o
oooo9@00o`000`00oh000?oo003oo`0T003oo`D0083o60000?l00`200?l0o`3o0?l0o`050?l0o`03
0?l0P03o0000o`0007l0o`000P3o08020?l0o`H0003o0P00ool5ooooo`7o00000Oooool001Gooooo
00?o0000ooooooooool00_oooolS003o02<00?oo8P000?l80?l0oh<0o`00103o0?l60000o`800?oo
1Oooool1o`00007ooooo000Eooooo`;o00000ooooolQ003o01d00?oo:@000?l90?l0oh<0o`00103o
0?l60000o`800?oo1?ooool2o`00007ooooo000Eooooo`03o`000?oooooooooo00;ooooo8000o`0B
003ooc80003o2`3o0?n40?l000D0o`3o1P000?l00`00ooooooooooooo`03ooooo`7o00000Oooool0
01Gooooo00?o0000ooooooooool00_oooolO003o00l00?oo=0000?l<0?l0ohD0o`001@3o0?l60000
o`03003ooooooooooooo00?ooooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`02oooooah0
0?l03P00oold0000o``0o`3oR@3o00030?l0o`H0003o00<00?ooooooooooool00oooool1o`00007o
oooo000Eooooo`03o`000?oooooooooo00;ooooo7@00o`0>003ooc40003o3`3o0?n:0?l000@0o`3o
1P000?l5ooooo`7o00000Oooool001Gooooo00?o0000ooooooooool00_oooolL003o00h00?oo1000
0?l90?l0oah0003o5@3o0?n<0?l000<0o`3o1P000?l5ooooo`7o00000Oooool001Gooooo00?o0000
ooooooooool00_oooolK003o00l00?oo0`000?l00`3o0?l0o`000?l000030?l000P0o`3o3`000?lO
0?l0ohh0o`000`3o0?l50000o`Gooooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`02oooo
oaT00?l03`00ool50000o`030?l0o`3o0000o`0000H0o`00<P3o0?n@0?l000@0o`3o0`000?l5oooo
o`7o00000Oooool001Gooooo00?o0000ooooooooool00_oooolH003o00l00?oo1P000?l00`3o0?l0
o`000?l000090?l002h0o`3oT`3o00020?l0o`<0003o1Oooool1o`00007ooooo000Eooooo`03o`00
0?oooooooooo00;ooooo5`00o`0@003oo`D0003o0P3o0?l<0?l00180o`3o1@3o000C0?l0oiH0o`00
0`3o0?l20000o`Gooooo0Ol00001ooooo`005Oooool2o`0000?ooooo5@00o`0A003oo`H0003o0P3o
0?l=0?l000h0o`3o303o000<0?l0oi/0o`0000<0o`3o0000o`000?l01?ooool2o`00007ooooo000E
ooooo`03o`000?oooooooooo00;ooooo5000o`0A003oo`L0003o0P3o0?lA0?l000H0o`3o]`3o0002
0?l0o`030000oooooooooooo00?ooooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`02oooo
oa800?l04`00ool60000o`<0o`3ocP3o00020?l0o`030000oooooooooooo00?ooooo0Ol00001oooo
o`005Oooool00ol0003oooooooooo`02oooooa400?l04`00ool70000o`<0o`3ocP3o00020?l0o`03
0000oooooooooooo00?ooooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`02oooooa000?l0
4`00ool80000o`<0o`3oc`3o00000`3o0?l0003oooooo`04ooooo`7o00000Oooool001Gooooo00?o
0000ooooooooool00_ooool?003o01@00?oo20000?l20?l0om00o`0000<0o`3o0000ooooool01?oo
ool1o`00007ooooo000Eooooo`03o`000?oooooooooo00;ooooo3@00o`0D003oo`T0003o0`3o0?o?
0?l00080o`3o00<0003oooooooooool00oooool1o`00007ooooo00001?oooooo0000o`000?l00004
ooooo`;o00001?ooool2o`0000Gooooo00?o0000ooooooooool00_ooool<003o01@00?oo2P000?l3
0?l0oll0o`000P3o0?l00`000?ooooooooooo`03ooooo`7o00000Oooool000;ooooo00?o0000oooo
ooooool00_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Cooooo00?o
0000ooooooooool00_ooool:003o01D00?oo2`000?l30?l0oll0o`000P3o0?l00`000?oooooooooo
o`03ooooo`7o00000Oooool000;ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0
0002ooooo`04o`000?ooooooooooo`0000Cooooo0_l00003ooooo`T00?l05P00ool90000o`D0o`3o
c@3o00030?l0o`80003o1?ooool2o`00007ooooo0002ooooo`03o`000?oooooooooo00;ooooo00Co
0000oooooooooooo00000_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo00;o
oooo1`00o`0G003oo`X0003o1@3o0?o=0?l000<0o`3o0P000?l5ooooo`7o00000Oooool000;ooooo
00?o0000ooooooooool00_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`00
00Cooooo00?o0000ooooooooool00_ooool6003o01L00?oo2P000?l60?l0old0o`000`3o0?l20000
o`Gooooo0Ol00001ooooo`0000?oooooo`000?l000001?ooool01?l0003oooooooooool00002oooo
o`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool00_ooool3003o01T00?oo2`000?l6
0?l0ol`0o`00103o0?l20000o`Gooooo0Ol00001ooooo`000_ooool00ol0003oooooooooo`03oooo
o`;o00001?ooool2o`0000Gooooo00?o0000ooooooooool00_ooool2003o01T00?oo2`000?l70?l0
ol`0o`00103o0?l20000o`Gooooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`02oooooaP0
0?oo3@000?l70?l0olh0o`000`3o0?l20000o`Gooooo0Ol00001ooooo`005Oooool00ol0003ooooo
ooooo`02oooooaL00?oo3@000?l80?l0olh0o`000`3o0?l20000o`Gooooo0Ol00001ooooo`005Ooo
ool00ol0003oooooooooo`02oooooaH00?oo3@000?l80?l0oll0o`000`3o0?l20000o`Gooooo0Ol0
0001ooooo`005Oooool00ol0003oooooooooo`02oooooaD00?oo30000?l90?l0om00o`000`3o0?l2
0000o`Gooooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`02oooooa800?oo3P000?l80?l0
om80o`000`3o0?l20000o`Gooooo0Ol00001ooooo`005Oooool2o`0000?ooooo4@00ool=0000o`T0
o`3od`3o00030?l0o`80003o1?ooool2o`00007ooooo000Eooooo`03o`000?oooooooooo00;ooooo
4000ool=0000o`T0o`3od`3o00030?l0o`<0003o1Oooool1o`00007ooooo000Eooooo`03o`000?oo
oooooooo00;ooooo3P00ool>0000o`L0o`3oeP3o00030?l0o`<0003o1Oooool1o`00007ooooo000E
ooooo`03o`000?oooooooooo00;ooooo3000ool?0000o`D0o`3of03o00040?l0o`<0003o1Oooool1
o`00007ooooo000Eooooo`03o`000?oooooooooo00;ooooo2@00ool@0000o`D0o`3ofP3o00040?l0
o`<0003o1Oooool1o`00007ooooo000Eooooo`03o`000?oooooooooo00;ooooo1`00oolA0000o`D0
o`3of`3o00020?l0o`D0003o1Oooool1o`00007ooooo000Eooooo`03o`000?oooooooooo00;ooooo
0`00oolC0000o`L0o`3ofP3o00030?l0o`D0003o1Oooool1o`00007ooooo000Eooooo`03o`000?oo
oooooooo00;ooooo5@000?l70?l0om/0o`000`3o0?l50000o`Gooooo0Ol00001ooooo`005Oooool0
0ol0003oooooooooo`02oooooa@0003o203o0?oK0?l00080o`3o1P000?l5ooooo`7o00000Oooool0
01Gooooo00?o0000ooooooooool00_oooolA0000o`X0o`3of`3o00030?l0o`H0003o1Oooool1o`00
007ooooo000Eooooo`;o00000oooool?0000o`X0o`3og@3o00030?l0o`H0003o1?ooool2o`00007o
oooo000Eooooo`03o`000?oooooooooo00;ooooo2P000?l>0?l0omh0o`000`3o0?l60000o`Gooooo
0Ol00001ooooo`005Oooool00ol0003oooooooooo`02ooooo`H0003o403o0?oO0?l000<0o`3o1`00
0?l5ooooo`7o00000Oooool001Gooooo00?o0000ooooooooool00_oooolD0?l0on40o`000`3o0?l7
0000o`Gooooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`02oooooa40o`3ohP3o00050?l0
o`L0003o1Oooool1o`00007ooooo000Eooooo`03o`000?oooooooooo00;ooooo2@3o0?oZ0?l000@0
o`3o20000?l5ooooo`7o00000Oooool001Gooooo00?o0000ooooooooool00_ooool20?l0oo00o`00
1@3o0?l80000o`Gooooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`02oooooo80o`001@3o
0?l70000o`03003ooooooooooooo00?ooooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`02
oooooo80o`001@3o0?l70000o`03003ooooooooooooo00?ooooo0Ol00001ooooo`005Oooool00ol0
003oooooooooo`02oooooo80o`001@3o0?l70000o`03003ooooooooooooo00?ooooo0Ol00001oooo
o`005Oooool2o`0000?oooool@3o00060?l0o`L0003o00<00?ooooooooooool00_ooool2o`00007o
oooo000Eooooo`03o`000?oooooooooo00;oooool@3o00060?l0o`L0003o00<00?ooooooooooool0
0oooool1o`00007ooooo000Eooooo`03o`000?oooooooooo00;ooooolP3o00050?l0o`L0003o00<0
0?ooooooooooool00oooool1o`00007ooooo000Eooooo`03o`000?oooooooooo00;ooooolP3o0005
0?l0o`L0003o00<00?ooooooooooool00oooool1o`00007ooooo000Eooooo`03o`000?oooooooooo
00;ooooolP3o00050?l0o`L0003o00<00?ooooooooooool00oooool1o`00007ooooo000Eooooo`03
o`000?oooooooooo00;ooooo0P3o0?o`0?l000D0o`3o20000?l5ooooo`7o00000Oooool001Gooooo
00?o0000ooooooooool00_ooool90?l0onX0o`00103o0?l80000o`Gooooo0Ol00001ooooo`005Ooo
ool00ol0003oooooooooo`02oooooa40o`3ohP3o00050?l0o`L0003o1Oooool1o`00007ooooo000E
ooooo`03o`000?oooooooooo00;ooooo503o0?oQ0?l000<0o`3o1`000?l5ooooo`7o00000Oooool0
01Gooooo0_l00003ooooo`H0003o403o0?oO0?l000<0o`3o1`000?l4ooooo`;o00000Oooool001Go
oooo00?o0000ooooooooool00_ooool:0000o`h0o`3ogP3o00030?l0o`H0003o1Oooool1o`00007o
oooo000Eooooo`03o`000?oooooooooo00;ooooo3`000?l:0?l0omd0o`000`3o0?l60000o`Gooooo
0Ol00001ooooo`005Oooool00ol0003oooooooooo`02oooooa40003o2P3o0?oK0?l000<0o`3o1P00
0?l5ooooo`7o00000Oooool001Gooooo00?o0000ooooooooool00_oooolD0000o`P0o`3of`3o0002
0?l0o`H0003o1Oooool1o`00007ooooo000Eooooo`03o`000?oooooooooo00;ooooo5@000?l70?l0
om/0o`000`3o0?l50000o`Gooooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`02ooooo`<0
0?oo4`000?l70?l0omX0o`000`3o0?l50000o`Gooooo0Ol00001ooooo`005Oooool00ol0003ooooo
ooooo`02ooooo`L00?oo4@000?l50?l0om/0o`000P3o0?l50000o`Gooooo0Ol00001ooooo`0000Co
ooooo`000?l0003o00000oooool3o`0000Cooooo0_l00005ooooo`03o`000?oooooooooo00;ooooo
2@00ool@0000o`D0o`3ofP3o00040?l0o`<0003o1Oooool1o`00007ooooo0002ooooo`05o`000?oo
ooooooooooooool000000oooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool00_ooool<003oo`l0003o1@3o0?oH0?l000@0o`3o0`000?l5ooooo`7o
00000Oooool000;ooooo00?o0000ooooooooool01Oooool01?l0003oooooooooool00002ooooo`03
o`000?oooooooooo00;ooooo0_l00003ooooo`h00?oo3P000?l70?l0omH0o`000`3o0?l30000o`Co
oooo0_l00001ooooo`000_ooool00ol0003oooooooooo`05ooooo`04o`000?ooooooooooo`0000;o
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02oooooa000?oo3@000?l90?l0om<0
o`000`3o0?l30000o`Gooooo0Ol00001ooooo`000_ooool01?l0003oooooooooooooool4o`0000?o
oooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`02oooooa400?oo3@000?l90?l0
om<0o`000`3o0?l20000o`Gooooo0Ol00001ooooo`0000?oooooo`000?l000000oooool00ol0003o
ooooooooo`04ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool00_oooolB003o
o`h0003o203o0?oB0?l000<0o`3o0P000?l5ooooo`7o00000Oooool000;ooooo00Co0000oooooooo
oooooooo1Ol00003ooooo`;o00001Oooool00ol0003oooooooooo`02oooooaD00?oo30000?l90?l0
om00o`000`3o0?l20000o`Gooooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`02oooooaH0
0?oo3@000?l80?l0oll0o`000`3o0?l20000o`Gooooo0Ol00001ooooo`005Oooool00ol0003ooooo
ooooo`02oooooaL00?oo3@000?l80?l0olh0o`000`3o0?l20000o`Gooooo0Ol00001ooooo`005Ooo
ool00ol0003oooooooooo`02oooooaP00?oo3@000?l70?l0olh0o`000`3o0?l20000o`Gooooo0Ol0
0001ooooo`005Oooool00ol0003oooooooooo`02ooooo`800?l06@00ool;0000o`L0o`3oc03o0004
0?l0o`80003o1Oooool1o`00007ooooo000Eooooo`03o`000?oooooooooo00;ooooo0`00o`0I003o
o`/0003o1P3o0?o<0?l000@0o`3o0P000?l5ooooo`7o00000Oooool001Gooooo0_l00003ooooo`H0
0?l05`00ool:0000o`H0o`3oc@3o00030?l0o`80003o1?ooool2o`00007ooooo000Eooooo`03o`00
0?oooooooooo00;ooooo1`00o`0G003oo`X0003o1@3o0?o=0?l000<0o`3o0P000?l5ooooo`7o0000
0Oooool001Gooooo00?o0000ooooooooool00_ooool9003o01H00?oo2@000?l50?l0old0o`000`3o
0?l20000o`Gooooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`02ooooo`X00?l05@00ool;
0000o`<0o`3oc`3o00020?l0o`030000oooooooooooo00?ooooo0Ol00001ooooo`005Oooool00ol0
003oooooooooo`02ooooo``00?l05000ool:0000o`<0o`3oc`3o00020?l0o`030000oooooooooooo
00?ooooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`02ooooo`d00?l05000ool90000o`<0
o`3oc`3o00020?l0o`030000oooooooooooo00?ooooo0Ol00001ooooo`005Oooool00ol0003ooooo
ooooo`02ooooo`l00?l05000ool80000o`80o`3od03o00000`3o0?l0003oooooo`04ooooo`7o0000
0Oooool001Gooooo00?o0000ooooooooool00_ooool@003o01<00?oo20000?l30?l0oll0o`0000<0
o`3o0000ooooool01?ooool1o`00007ooooo000Eooooo`03o`000?oooooooooo00;ooooo4@00o`0C
003oo`L0003o0`3o0?o>0?l00080o`3o00<0003oooooooooool00oooool1o`00007ooooo000Eoooo
o`03o`000?oooooooooo00;ooooo4P00o`0C003oo`H0003o0`3o0?o>0?l00080o`3o00<0003ooooo
ooooool00oooool1o`00007ooooo000Eooooo`;o00000ooooolD003o01400?oo1`000?l20?l0oa40
o`001P3o0?ng0?l00080o`3o00<0003oooooooooool00_ooool2o`00007ooooo000Eooooo`03o`00
0?oooooooooo00;ooooo5@00o`0A003oo`H0003o0P3o0?l=0?l000h0o`3o303o000<0?l0oi/0o`00
00<0o`3o0000o`000?l01Oooool1o`00007ooooo000Eooooo`03o`000?oooooooooo00;ooooo5`00
o`0@003oo`D0003o0P3o0?l<0?l00180o`3o1@3o000C0?l0oiH0o`000`3o0?l20000o`Gooooo0Ol0
0001ooooo`005Oooool00ol0003oooooooooo`02oooooaP00?l03`00ool60000o`030?l0o`3o0000
o`0000T0o`00;P3o0?nC0?l00080o`3o0`000?l5ooooo`7o00000Oooool001Gooooo00?o0000oooo
ooooool00_oooolI003o00l00?oo1@000?l00`3o0?l0o`000?l000060?l00380o`3oT03o00040?l0
o`<0003o1Oooool1o`00007ooooo000Eooooo`03o`000?oooooooooo00;ooooo6`00o`0?003oo`<0
003o00<0o`3o0?l0003o00000`3o00080?l0o`l0003o7`3o0?n>0?l000<0o`3o1@000?l5ooooo`7o
00000Oooool001Gooooo00?o0000ooooooooool00_oooolL003o00h00?oo10000?l90?l0oah0003o
5@3o0?n<0?l000<0o`3o1P000?l5ooooo`7o00000Oooool001Gooooo00?o0000ooooooooool00_oo
oolM003o00h00?oo<@000?l?0?l0ohX0o`00103o0?l60000o`Gooooo0Ol00001ooooo`005Oooool0
0ol0003oooooooooo`02oooooah00?l03P00oold0000o``0o`3oR@3o00030?l0o`H0003o00<00?oo
ooooooooool00oooool1o`00007ooooo000Eooooo`03o`000?oooooooooo00;ooooo7`00o`0?003o
oc@0003o303o0?n50?l000D0o`3o1P000?l00`00ooooooooooooo`03ooooo`7o00000Oooool001Go
oooo0_l00003ooooob000?l04P00oolb0000o`/0o`3oQ03o00050?l0o`H0003o00<00?oooooooooo
ool00_ooool2o`00007ooooo000Eooooo`03o`000?oooooooooo00;ooooo8@00o`0M003oobT0003o
2@3o0?n30?l000@0o`3o1P000?l2003oo`Gooooo0Ol00001ooooo`005Oooool00ol0003ooooooooo
o`02ooooob<00?l08`00oolR0000o`P0o`3oP`3o00040?l0o`H0003o0P00ool5ooooo`7o00000Ooo
ool001Gooooo00?o0000ooooooooool00_oooolU003o0003003oP000ool00?oo02@00?oo1@00P?lH
0000o`030800o`3o0?l0o`3o00D0o`3o00<0o`200?l0003o0000O`3o00020?l0P080o`3o1P000?l2
003oo`Gooooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`02ooooobL00?l0;P00oolF0000
o`P0o`3oPP3o00020?l0o`H0003o0P00ool5ooooo`7o00000Oooool001Gooooo00?o0000oooooooo
ool00_ooool20?oo02P00?l0;P00oolD0000o`T0o`3oP03o00020?l0o`D0003o0`00ool5ooooo`7o
00000Oooool001Gooooo00?o0000ooooooooool00_ooool30?oo02T00?l0;`00oolC0000o`P0o`3o
P03o00000`3o0?l0003o0000o`030000o`<00?oo1Oooool1o`00007ooooo000Eooooo`03o`000?oo
oooooooo00;ooooo1@3oo`0Y003o02l00?oo4P000?l80?l0ogl0o`0000<0o`3o0000o`000?l00`00
0?l3003oo`Gooooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`02ooooo`H0ool0:P00o`0`
003ooa00003o1`3o0?mo0?l000030?l0o`000?l0003o00<0003o0`00ool5ooooo`7o00000Oooool0
01Gooooo0_l00003ooooo`L0ool0;000o`0^003ooa00003o1`3o0?mn0?l000030?l0o`000?l0003o
00<0003o0`00ool4ooooo`;o00000Oooool001Gooooo00?o0000ooooooooool00_ooool90?oo02d0
0?l0;@00ool?0000o`H0o`3oOP3o0000103o0?l0003o0000o`000?l5003oo`Gooooo0Ol00001oooo
o`005Oooool00ol0003oooooooooo`02ooooo`X0ool0<000o`0Z003oo`h0003o1P3o0?mn0?l00004
0?l0o`000?l0003o0000o`D00?oo1Oooool1o`00007ooooo000Eooooo`03o`000?oooooooooo00;o
oooo303oo`0a003o02X00?oo30000?l60?l0ogd0o`0000@0o`3o0000o`000?l0003o1@00ool5oooo
o`7o00000Oooool001Gooooo00?o0000ooooooooool00_ooool=0?oo03@00?l09`00ool=0000o`@0
o`3oO03o00020?l0o`<0003o1@00ool5ooooo`7o00000Oooool001Gooooo00?o0000ooooooooool0
0_ooool>0?oo03D00?l09P00ool<0000o`@0o`3oNP3o00030?l0o`<0003o1P00ool5ooooo`7o0000
0Oooool001Gooooo00?o0000ooooooooool00_ooool@0?oo03H00?l09000ool<0000o`<0o`3oNP3o
00020?l0o`@0003o1P00ool5ooooo`7o00000Oooool001Gooooo00?o0000ooooooooool00_oooolA
0?oo03P00?l08P00ool;0000o`<0o`3oN@3o00030?l0o`<0003o1`00ool5ooooo`7o00000Oooool0
00Go00000oooool2o`0000Cooooo0_l00005ooooo`03o`000?oooooooooo00;ooooo4P3oo`0j003o
02000?oo2`000?l30?l0ogP0o`0000<0o`3o0000o`000?l00`000?l7003oo`Gooooo0Ol00001oooo
o`0000Goooooo`000?ooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000
oooooooooooo00001?ooool00ol0003oooooooooo`02oooooaD0ool0>@00o`0P003oo`T0003o0`3o
0?mV0?l000L0o`3o2`3o00000`3o0?l0003o0000o`020000o`P00?oo1Oooool1o`00007ooooo0002
ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool01?l0003ooooooooo
ool00004ooooo`;o00000ooooolF0?oo03/00?l07P00ool90000o`80o`3oHP3o000=0?l0o`P0o`00
00<0o`3o0000o`000?l00P000?l9003oo`Cooooo0_l00001ooooo`000oooool01Ol0003ooooooooo
oooooooo000000;ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00;ooooo5`3oo`0l003o01d00?oo2@000?l20?l0oel0o`00403o0?l60?l00003
0?l0o`000?l0003o00<0003o2000ool00`00o`3oooooooooo`03ooooo`7o00000Oooool00005o`00
0?ooooooooooooooool000000_ooool01?l0003oooooooooool00002ooooo`04o`000?oooooooooo
o`0000Cooooo00?o0000ooooooooool00_oooolI0?oo03`00?l07000ool90000o`D0o`3oF@3o000E
0?l0o`030?l0003o0?l0o`3o00D0003o2@00ool00`00o`3oooooooooo`03ooooo`7o00000Oooool0
0005o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00002ooooo`04o`000?oo
ooooooooo`0000Cooooo00?o0000ooooooooool00_oooolK0?oo03d00?l06P00ool90000o`X0o`3o
DP3o000:0?l0o`T0003o103o0?l50000o`X00?oo0P00o`05ooooo`7o00000Oooool00004ooooool0
003o0000o`0000Cooooo0_l00004ooooo`;o00001Oooool00ol0003oooooooooo`02oooooad0ool0
?@00o`0I003oo`/0003o4`3o0?m30?l000X0o`3o50000?l:003oo`<00?l01Oooool1o`00007ooooo
000Eooooo`03o`000?oooooooooo00;ooooo7P3oo`0n003o01X00?oo2`000?lD0?l0ocd0o`002@3o
0?lE0000o`X00?oo1@00o`05ooooo`7o00000Oooool001Gooooo00?o0000ooooooooool00_oooolP
0?oo03d00?l06P00ool>0000oa80o`3o>P3o00090?l0oa@0003o3000ool5003o00Gooooo0Ol00001
ooooo`005Oooool00ol0003oooooooooo`02ooooob40ool0?`00o`0H003ooa40003o403o0?lg0?l0
00P0o`3o4P000?l?003oo`H00?l01Oooool1o`00007ooooo000Eooooo`03o`000?oooooooooo00;o
oooo903oo`0m003o01T00?oo50000?l=0?l0oc@0o`00203o0?l@0000oa400?oo1`00o`05ooooo`7o
00000Oooool001Gooooo00?o0000ooooooooool00_oooolU0?oo03h00?l06P00oolC0000o``0o`3o
<`3o00050?l0o`l0003o5000ool8003o00Gooooo0Ol00001ooooo`005Oooool2o`0000?ooooo9`3o
o`0o003o01T00?oo50000?l90?l0oc40o`001P3o0?l>0000oaD00?oo2@00o`04ooooo`;o00000Ooo
ool001Gooooo00?o0000ooooooooool00_oooolZ0?oo03d00?l06P00oolD0000o`P0o`3o<03o0006
0?l0o``0003o5000ool<003o00Gooooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`02oooo
ob/0ool0?P00o`0K003ooa80003o1`3o0?l`0?l000D0o`3o30000?lD003oo`d00?l01Oooool1o`00
007ooooo000Eooooo`03o`000?oooooooooo00;ooooo;@3oo`0m003o01`00?oo4@000?l70?l0obh0
o`001@3o0?l;0000oaD00?oo3P00o`05ooooo`7o00000Oooool001Gooooo00?o0000ooooooooool0
0_ooool_0?oo03d00?l07000ool@0000o`H0o`3o;P3o00050?l0o`T0003o5@00ool@003o00Gooooo
0Ol00001ooooo`005Oooool00ol0003oooooooooo`02oooooc80ool0?000o`0L003oo`l0003o1P3o
0?l]0?l000@0o`3o2@000?lE003ooa400?l01Oooool1o`00007ooooo000Eooooo`03o`000?oooooo
oooo00;ooooo<`3oo`0m003o01d00?oo3P000?l40?l0ob`0o`00103o0?l90000oaD00?oo4P00o`05
ooooo`7o00000Oooool001Gooooo00?o0000ooooooooool00_oooole0?oo03`00?l07@00ool>0000
o`@0o`3o:`3o00040?l0o`P0003o4`00oolE003o00Gooooo0Ol00001ooooo`005Oooool00ol0003o
ooooooooo`02ooooocL0ool0?000o`0M003oo``0003o103o0?lZ0?l000<0o`3o20000?lD003ooaH0
0?l01Oooool1o`00007ooooo000Eooooo`03o`000?oooooooooo00;ooooo>P3oo`0l003o01/00?oo
30000?l50?l0obP0o`000`3o0?l70000oa<00?oo6000o`05ooooo`7o00000Oooool001Gooooo0_l0
0003oooooc`0ool0>`00o`0L003oo`/0003o1@3o0?lV0?l000<0o`3o20000?lB003ooaT00?l01?oo
ool2o`00007ooooo000Eooooo`03o`000?oooooooooo00;ooooo?P3oo`0k003o01`00?oo2P000?l6
0?l0ob<0o`000`3o0?l80000oa400?oo6`00o`05ooooo`7o00000Oooool001Gooooo00?o0000oooo
ooooool00_oooolo0?oo03`00?l06`00ool:0000o`H0o`3o803o00050?l0o`L0003o4@00oolL003o
00Gooooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`02oooood80ool0>`00o`0J003oo`/0
003o1@3o0?lN0?l000D0o`3o1`000?l@003ooah00?l01Oooool1o`00007ooooo000Eooooo`03o`00
0?oooooooooo00;oooooA03oo`0k003o01T00?oo2`000?l50?l0oad0o`001@3o0?l70000o`l00?oo
7`00o`05ooooo`7o00000Oooool001Gooooo00?o0000ooooooooool00_oooom60?oo03/00?l06000
ool;0000o`H0o`3o6`3o00040?l0o`L0003o3`00oolP003o00Gooooo0Ol00001ooooo`005Oooool0
0ol0003oooooooooo`02ooooodT0ool0>@00o`0I003oo`T0003o1`3o0?lJ0?l000@0o`3o1P000?l?
003oob400?l01Oooool1o`00007ooooo000Eooooo`03o`000?oooooooooo00;oooooB`3oo`0j003o
01L00?oo2@000?l60?l0oaX0o`000`3o0?l70000o`d00?oo8P00o`000`3oo`3oooooooooo`03oooo
o`7o00000Oooool001Gooooo00?o0000ooooooooool00_oooom<0?oo03X00?l05`00ool90000o`H0
o`3o6@3o00030?l0o`D0003o3P00oolQ003o00<0ool01Oooool1o`00007ooooo000Eooooo`;o0000
0ooooom>0?oo03X00?l05@00ool90000o`H0o`3o6@3o00030?l0o`@0003o3P00oolP003o00D0ool0
1?ooool2o`00007ooooo000Eooooo`03o`000?oooooooooo00;oooooD@3oo`0h003o01D00?oo2@00
0?l50?l0oaT0o`000`3o0?l40000o`d00?oo8000o`060?oo00Gooooo0Ol00001ooooo`005Oooool0
0ol0003oooooooooo`02oooooe<0ool0>@00o`0C003oo`P0003o1@3o0?lI0?l000<0o`3o0`000?l=
003oob000?l01`3oo`05ooooo`7o00000Oooool001Gooooo00?o0000ooooooooool00_oooomE0?oo
03P00?l04`00ool80000o`@0o`3o6@3o00000`3o0?l0003o0000o`030000o``00?oo8000o`080?oo
00Gooooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`02oooooeP0ool0=`00o`0C003oo`H0
003o103o0?lI0?l000030?l0o`000?l0003o0080003o2`00oolQ003o00T0ool01Oooool1o`00007o
oooo000Eooooo`03o`000?oooooooooo00;oooooF@3oo`0g003o01800?oo1P000?l40?l0oa40o`00
00<0o`3o0?l0003o0000103o00000`3o0?l0003o0000o`030000o`X00?oo8@00o`0:0?oo00Gooooo
0Ol00001ooooo`005Oooool00ol0003oooooooooo`02oooooe/0ool00P20o`0d003o00800?n04000
ool50000o`80P03o0P3o0?l;0?l000<0o`20203o0?l00`3o0800P03o0800o`030000o`030020o`00
ool00?oo00L00?oo00<00?n0003o0000o`007@00o`000`20o`00ool00?oo000:0?oo00Gooooo0Ol0
0001ooooo`005Oooool00ol0003oooooooooo`02ooooof00ool0=@00o`0?003oo`H0003o0P3o0?l:
0?l000D0o`3o2`000?l;003oob000?l03P3oo`05ooooo`7o00000Oooool001Gooooo00?o0000oooo
ooooool00_oooomR0?oo03@00?l03P00ool60000o`80o`3o2P3o00040?l0o`X0003o3000oolO003o
0100ool01Oooool1o`00007ooooo000Eooooo`03o`000?oooooooooo00;oooooI03oo`0c003o00h0
0?oo1@000?l20?l0o`T0o`000P3o0?l;0000o`d00?oo7`00o`0A0?oo00Gooooo0Ol00001ooooo`00
5Oooool2o`0000?oooooI`3oo`0a003o00d00?oo1@000?l20?l0o`P0o`000P3o0?l80000o`l00?oo
8000o`0B0?oo00Cooooo0_l00001ooooo`005Oooool00ol0003oooooooooo`02ooooofT0ool0<000
o`0=003oo`@0003o00<0o`3o0?l0003o00001`3o00020?l0o`H0003o4000oolO003o01@0ool01Ooo
ool1o`00007ooooo000Eooooo`03o`000?oooooooooo00;oooooJP3oo`0b003o00X00?oo10000?l0
0`3o0?l0o`000?l000070?l000030?l0o`000?l0003o00<0003o4000oolO003o01H0ool01Oooool1
o`00007ooooo000Eooooo`03o`000?oooooooooo00;oooooK03oo`0a003o00X00?oo0`000?l0103o
0?l0o`000?l0003o00060?l0o`D0003o4000oolO003o01L0ool01Oooool1o`00007ooooo000Eoooo
o`03o`000?oooooooooo00;oooooK`3oo`0_003o00X00?oo10000?l20?l0o`P0003o4000oolQ003o
01P0ool01Oooool1o`00007ooooo000Eooooo`03o`000?oooooooooo00;oooooL@3oo`0^003o00/0
0?oo2P000?l@003oob800?l06@3oo`05ooooo`7o00000Oooool001Gooooo00?o0000ooooooooool0
0_oooomc0?oo02d00?l08P00oolQ003o01`0ool01Oooool1o`00007ooooo000Eooooo`03o`000?oo
oooooooo00;oooooMP3oo`0]003o01d00?oo8P00o`0M0?oo00Gooooo0Ol00001ooooo`001Ol00002
ooooo`?o00001?ooool2o`0000Gooooo00?o0000ooooooooool00_oooomh0?oo02`00?l06000oolU
003o01h0ool01Oooool1o`00007ooooo00001ooooooo0000oooooooooooo0000ooooool000000ooo
ool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
0_oooomj0?oo02`00?l05000oolU003o0200ool01Oooool1o`00007ooooo0002ooooo`03o`000?oo
oooooooo00Gooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`02ooooo`;o0000
0oooool00`3o0000ool00?oo001j0?oo02d00?l02`00oolY003o0240ool01?ooool2o`00007ooooo
0003ooooo`03o`000?oooooooooo00Cooooo00Co0000oooooooooooo00000_ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00;ooooo0P3o001m0?oo05`00?l0903oo`05ooooo`7o0000
0Oooool00006o`000?ooooooooooooooool0003ooooo1?l00003ooooo`04o`000?ooooooooooo`00
00Cooooo00?o0000ooooooooool00_ooool30?l007h0ool0F@00o`0U0?oo00Gooooo0Ol00001oooo
o`0000Oo0000ooooooooooooooooo`000?oooooo000000Kooooo00Co0000oooooooooooo00001?oo
ool00ol0003oooooooooo`02ooooo`H0o`00OP3oo`1D003o02L0ool01Oooool1o`00007ooooo0000
1?oooooo0000o`000?l00002ooooo`Go00000oooool2o`0000Gooooo00?o0000ooooooooool00_oo
ool70?l007l0ool0C`00o`0Z0?oo00Gooooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`02
ooooo`P0o`00P@3oo`1;003o02/0ool01Oooool1o`00007ooooo000Eooooo`03o`000?oooooooooo
00;ooooo2P3o00220?oo04H00?l0;@3oo`05ooooo`7o00000Oooool001Gooooo00?o0000oooooooo
ool00_ooool<0?l00880ool0@P00o`0_0?oo00Gooooo0Ol00001ooooo`005Oooool00ol0003ooooo
ooooo`02ooooo`h0o`00PP3oo`0l003o03<0ool01Oooool1o`00007ooooo000Eooooo`03o`000?oo
oooooooo00;ooooo3`3o00250?oo03H00?l0=@3oo`05ooooo`7o00000Oooool001Gooooo0_l00003
oooooa40o`00QP3oo`0a003o03L0ool01?ooool2o`00007ooooo000Eooooo`03o`000?oooooooooo
00;ooooo4P3o00290?oo02T00?l0>`3oo`05ooooo`7o00000Oooool001Gooooo00?o0000oooooooo
ool0ooooool7ooooo`7o00000Oooool001Gooooo00?o0000ooooooooool0ooooool7ooooo`7o0000
0Oooool001Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0gooooo`03o`000?oo
oooooooo03Kooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`0gooooo`03o`000?oo
oooooooo01[ooooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool00oooool1o`00007ooooo000Eoooooooo00002ol00001oooo
o`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00\
\>"],
  ImageRangeCache->{{{132.938, 362.312}, {403.438, 174.062}} -> {-166.865, \
200.142, 0.866422, 1.02324}}]
}, Open  ]],

Cell["\<\
L'ultimo risultato che abbiamo ottenuto ha richiesto un tempo di \
elaborazione non trascurabile. Se tentassimo di aumentare il numero di punti \
nel grafico cominceremmo a dover attendere un tempo non indifferente.\
\>", \
"Text"],

Cell[TextData[{
  "L'operazione successiva consiste nello scrivere una funzione mandelbrotC \
richiamabile dall'interno di ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " ma il cui codice sia eseguito in linguaggio macchina. Il procedimento sar\
\[AGrave] analogo a quello visto nel paragrafo precedente. Nella directory \
math-bin trovate un file il cui nome \[EGrave] mandelbrot.c e il cui \
contenuto \[EGrave] il seguente:"
}], "Text"],

Cell["\<\
#include <math.h>
#include <stdlib.h>

#include \"mathlink.h\"
#define MAXCOUNT 100
#define MAXVALUE 100000

typedef struct {
  double re;
  double im;
} complex;

complex f(complex z,complex mu) {       
  complex ret;
  ret.re=mu.re-z.im*z.im+z.re*z.re;
  ret.im=mu.im+2*z.im*z.re;
  return ret;  
}

void mandelbrotC(double x0, double x1, double y0, double y1, int steps) {
  long dimensions[2]={(long)steps,(long)steps};
  char *heads[2]={\"List\",\"List\"};
  double x,y;
  int i,j,count;
  complex z,mu;
  int *res = (int*) malloc(steps*steps*sizeof(int));
  double stepx=(x1-x0)/steps;
  double stepy=(y1-y0)/steps;
  for(x=x0,i=0;i<steps;i++,x+=stepx)
    for(y=y0,j=0;j<steps;j++,y+=stepy) {
      mu.re=x;
      mu.im=y;
      z.re=0.0;
      z.im=0.0;
      for(count=0;count<MAXCOUNT;count++) {
        z=f(z,mu);
        if(fabs(z.im)>MAXVALUE) break;
      }
      res[i+j*steps]=count;
    }
  MLPutIntegerArray(stdlink,res,dimensions,heads,2);
  free(res);
}

int main(int argc, char *argv[]) {
  return MLMain(argc, argv);
}\
\>", "Program",
  CellChangeTimes -> {{3.38933701752048*^9, 3.3893370326171923`*^9}}],

Cell["\<\
Notate come in realt\[AGrave] questo programma restituisca \
direttamente la matrice dei valori su cui si basa il grafico. Inoltre il \
codice evidenzia alcune differenze rispetto alla strategia utilizzata per \
costruire la funzione mandelbrot, che permettono di ottenere un risultato \
migliore. Per poter compilare questo sorgente \[EGrave] necessario utilizzare \
un secondo file, che trovate sempre nella directory math-bin e il cui nome \
\[EGrave] mandelbrot.tm. Il suo contenuto \[EGrave] il seguente:\
\>", "Text"],

Cell["\<\
:Begin:
:Function:\t\tmandelbrotC
:Pattern:
\tmandelbrotC[{{x0_Real,x1_Real},{y0_Real,y1_Real}},steps_Integer]
:Arguments:\t\t{x0,x1,y0,y1,steps}
:ArgumentTypes:\t{Real,Real,Real,Real,Integer}
:ReturnType:\tManual
:End:\
\>", "Program"],

Cell["\<\
Per poter compilare il programma \[EGrave] necessario eseguire un \
terminale. Trovate l'icona corrispondente nella directory \
Applications/Utilities (la directory Applications si trova nella root \
directory del disco fisso, ma trovate un link a essa anche nella parte \
sinistra delle finestre del finder). Se eseguite un doppio click su questa \
icona comparir\[AGrave] una nuova finestra, simile a quella di un terminale \
in U*ix.\
\>", "Text"],

Cell["\<\
Il terminale \[EGrave] inizialmente posizionato nella vostra home \
directory: se provate a eseguire il comando pwd dovreste ottenere come output \
/Users/silsis2. Se cos\[IGrave] non fosse, eseguite il comando cd \
/Users/silsis2 (oppure cd ~), in modo da posizionarvi nella vostra home. A \
questo punto \[EGrave] necessario spostarsi nella directory math-bin, \
eseguendo il comando cd math-bin. Entro questa directory dovreste trovare i \
due file mandelbrot.tm e mandelbrot.c precedentemente descritti. Per \
sincerarvene potete eseguire il comando ls, che stampa l'elenco dei file \
contenuti nella directory corrente.\
\>", "Text"],

Cell[TextData[{
  "Utilizzando il terminale \[EGrave] ora possibile compilare il sorgente \
contenuto nel file mandelbrot.c. Il processo di compilazione sar\[AGrave] \
leggermente diverso rispetto a quello che utilizzate normalmente, in quanto \
\[EGrave] necessario far riferimento ad alcune librerie fornite assieme a ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ". Il modo pi\[UGrave] semplice per eseguire questa operazione consiste nel \
copiare i contenuti della directory /Applications/Mathematica\\ \
5.1.app/AddOns/MathLink/DeveloperKit/Darwin/CompilerAdditions/\nall'interno \
della directory corrente. Non \[EGrave] sicuramente il modo pi\[UGrave] \
elegante, ma ci permette di lavorare in una cartella su cui abbiamo i diritti \
di scrittura. Se l'operazione \[EGrave] andata a buon fine, nella directory \
corrente dovreste trovare, oltre ai file precedentemente copiati, anche \
libML.a (contenente le librerie sopra menzionate), mathlink,h (il file \
incluso all'interno di mandelbrot.c), mcc (che utilizzeremo al posto di cc) e \
mprep (che in realt\[AGrave] non utilizzeremo). A questo punto siamo in grado \
di generare l'eseguibile corrispondente a mandelbrot.c, eseguendo il comando"
}], "Text"],

Cell["./mcc./mandelbrot.tm./mandelbrot.c-o./mandelbrot", "Program"],

Cell["\<\
Probabilmente otterrete un errore che segnala che \[EGrave] \
necessario eseguire il comando ranlib per poter utilizzare le librerie \
contenute in libML.a (se cos\[IGrave] non fosse, saltate questo passo e \
saltate direttamente al prossimo capoverso). Sar\[AGrave] sufficiente \
eseguire il comando ranlib ./limML.a (ed \[EGrave] in questa fase che \
necessitiamo dei diritti di scrittura sulla directory), che non dovrebbe \
produrre alcun output. Dopodich\[EAcute] dovreste poter eseguire senza \
problemi il processo di compilazione precedentemente descritto.\
\>", "Text"],

Cell[TextData[{
  "Se tutto \[EGrave] andato a buon fine, nella directory corrente dovreste \
trovare un nuovo file, il cui nome \[EGrave] mandelbrot. Se provate a \
lanciarlo eseguento il comando ./mandelbrot, otterrete la stampa del \
messaggio \"Create link:\". Premete CTRL-C per due volte in modo da terminare \
l'esecuzione . In realt\[AGrave] questo programma non \[EGrave] pensato per \
essere eseguito in questo modo, ma per venire lanciato direttamente da ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ", valutando la cella seguente:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(link = Install["\<mandelbrot\>"]\)], "Input",
  CellChangeTimes -> {{3.3893360578387623`*^9, 3.389336058234626*^9}, \
{3.389337045863743*^9, 3.389337047059045*^9}}],

Cell[BoxData[
    \(LinkObject["./mandelbrot", 9, 5]\)], "Output"]
}, Open  ]],

Cell["\<\
\[CapitalEGrave] importante che il nome del file indicato tra doppi \
apici come argomento di Install sia lo stesso che \[EGrave] stato creato \
quando abbiamo compilato mandelbrot.c. Inoltre, la cella di output potrebbe \
contenere, nella parte finale, dei numeri diversi. \[CapitalEGrave] inoltre \
possibile verificare come contestualmente sia stato eseguito in background il \
programma mandelbrot (per esempio eseguento il comando top, che potete \
lasciare in esecuzione mentre procedete con il resto di questa \
esercitazione).\
\>", "Text"],

Cell["\<\
Se il procedimento finora descritto \[EGrave] stato seguito \
correttamente, dovrebbe essere possibile valutare la cella seguente, \
ottenendo una cella di output che contiene una lista\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(matrix = mandelbrotC[{{\(-1.7\), 0.5}, {\(-1.3\), 1.3}}, 7]\)], "Input",\

  CellChangeTimes -> {3.389155046774818*^9, 3.389336281475046*^9, \
{3.389336551257587*^9, 3.389336589970912*^9}, {3.3893370526248693`*^9, \
3.3893370589509287`*^9}}],

Cell[BoxData[
    \({{5, 5, 5, 5, 6, 6, 6}, {5, 6, 6, 6, 8, 17, 7}, {6, 7, 8, 9, 100, 100, 
        100}, {7, 10, 100, 20, 100, 100, 100}, {7, 10, 100, 20, 100, 100, 
        100}, {6, 7, 8, 9, 100, 100, 100}, {5, 6, 6, 6, 8, 17, 
        7}}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Il processo di valutazione, che apparentemente \[EGrave] stato uguale a \
quelli finora utilizzati, ha in realt\[AGrave] previsto di passare, \
sfruttando il protocollo ",
  StyleBox["MathLink",
    FontSlant->"Italic"],
  ", gli argomenti specificati al processo che sta eseguendo il programma il \
cui sorgente \[EGrave] contenuto in mandelbrot.c, per poi invocare la \
funzione mandelbrotC ivi definita, interpretando i risultati da essa \
restituiti come una lista di valori che viene inviata al kernel, che a sua \
volta la interpreta come contenuto della cella di output."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(ListDensityPlot[matrix, Mesh \[Rule] False, 
        ColorFunction \[Rule] Hue];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.137363 0.0192308 0.137363 [
[.01923 -0.0125 -3 -9 ]
[.01923 -0.0125 3 0 ]
[.15659 -0.0125 -3 -9 ]
[.15659 -0.0125 3 0 ]
[.29396 -0.0125 -3 -9 ]
[.29396 -0.0125 3 0 ]
[.43132 -0.0125 -3 -9 ]
[.43132 -0.0125 3 0 ]
[.56868 -0.0125 -3 -9 ]
[.56868 -0.0125 3 0 ]
[.70604 -0.0125 -3 -9 ]
[.70604 -0.0125 3 0 ]
[.84341 -0.0125 -3 -9 ]
[.84341 -0.0125 3 0 ]
[.98077 -0.0125 -3 -9 ]
[.98077 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01923 -6 -4.5 ]
[-0.0125 .01923 0 4.5 ]
[-0.0125 .15659 -6 -4.5 ]
[-0.0125 .15659 0 4.5 ]
[-0.0125 .29396 -6 -4.5 ]
[-0.0125 .29396 0 4.5 ]
[-0.0125 .43132 -6 -4.5 ]
[-0.0125 .43132 0 4.5 ]
[-0.0125 .56868 -6 -4.5 ]
[-0.0125 .56868 0 4.5 ]
[-0.0125 .70604 -6 -4.5 ]
[-0.0125 .70604 0 4.5 ]
[-0.0125 .84341 -6 -4.5 ]
[-0.0125 .84341 0 4.5 ]
[-0.0125 .98077 -6 -4.5 ]
[-0.0125 .98077 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.01923 0 m
.01923 .00625 L
s
[(0)] .01923 -0.0125 0 1 Mshowa
.15659 0 m
.15659 .00625 L
s
[(1)] .15659 -0.0125 0 1 Mshowa
.29396 0 m
.29396 .00625 L
s
[(2)] .29396 -0.0125 0 1 Mshowa
.43132 0 m
.43132 .00625 L
s
[(3)] .43132 -0.0125 0 1 Mshowa
.56868 0 m
.56868 .00625 L
s
[(4)] .56868 -0.0125 0 1 Mshowa
.70604 0 m
.70604 .00625 L
s
[(5)] .70604 -0.0125 0 1 Mshowa
.84341 0 m
.84341 .00625 L
s
[(6)] .84341 -0.0125 0 1 Mshowa
.98077 0 m
.98077 .00625 L
s
[(7)] .98077 -0.0125 0 1 Mshowa
.125 Mabswid
.0467 0 m
.0467 .00375 L
s
.07418 0 m
.07418 .00375 L
s
.10165 0 m
.10165 .00375 L
s
.12912 0 m
.12912 .00375 L
s
.18407 0 m
.18407 .00375 L
s
.21154 0 m
.21154 .00375 L
s
.23901 0 m
.23901 .00375 L
s
.26648 0 m
.26648 .00375 L
s
.32143 0 m
.32143 .00375 L
s
.3489 0 m
.3489 .00375 L
s
.37637 0 m
.37637 .00375 L
s
.40385 0 m
.40385 .00375 L
s
.45879 0 m
.45879 .00375 L
s
.48626 0 m
.48626 .00375 L
s
.51374 0 m
.51374 .00375 L
s
.54121 0 m
.54121 .00375 L
s
.59615 0 m
.59615 .00375 L
s
.62363 0 m
.62363 .00375 L
s
.6511 0 m
.6511 .00375 L
s
.67857 0 m
.67857 .00375 L
s
.73352 0 m
.73352 .00375 L
s
.76099 0 m
.76099 .00375 L
s
.78846 0 m
.78846 .00375 L
s
.81593 0 m
.81593 .00375 L
s
.87088 0 m
.87088 .00375 L
s
.89835 0 m
.89835 .00375 L
s
.92582 0 m
.92582 .00375 L
s
.9533 0 m
.9533 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01923 m
.00625 .01923 L
s
[(0)] -0.0125 .01923 1 0 Mshowa
0 .15659 m
.00625 .15659 L
s
[(1)] -0.0125 .15659 1 0 Mshowa
0 .29396 m
.00625 .29396 L
s
[(2)] -0.0125 .29396 1 0 Mshowa
0 .43132 m
.00625 .43132 L
s
[(3)] -0.0125 .43132 1 0 Mshowa
0 .56868 m
.00625 .56868 L
s
[(4)] -0.0125 .56868 1 0 Mshowa
0 .70604 m
.00625 .70604 L
s
[(5)] -0.0125 .70604 1 0 Mshowa
0 .84341 m
.00625 .84341 L
s
[(6)] -0.0125 .84341 1 0 Mshowa
0 .98077 m
.00625 .98077 L
s
[(7)] -0.0125 .98077 1 0 Mshowa
.125 Mabswid
0 .0467 m
.00375 .0467 L
s
0 .07418 m
.00375 .07418 L
s
0 .10165 m
.00375 .10165 L
s
0 .12912 m
.00375 .12912 L
s
0 .18407 m
.00375 .18407 L
s
0 .21154 m
.00375 .21154 L
s
0 .23901 m
.00375 .23901 L
s
0 .26648 m
.00375 .26648 L
s
0 .32143 m
.00375 .32143 L
s
0 .3489 m
.00375 .3489 L
s
0 .37637 m
.00375 .37637 L
s
0 .40385 m
.00375 .40385 L
s
0 .45879 m
.00375 .45879 L
s
0 .48626 m
.00375 .48626 L
s
0 .51374 m
.00375 .51374 L
s
0 .54121 m
.00375 .54121 L
s
0 .59615 m
.00375 .59615 L
s
0 .62363 m
.00375 .62363 L
s
0 .6511 m
.00375 .6511 L
s
0 .67857 m
.00375 .67857 L
s
0 .73352 m
.00375 .73352 L
s
0 .76099 m
.00375 .76099 L
s
0 .78846 m
.00375 .78846 L
s
0 .81593 m
.00375 .81593 L
s
0 .87088 m
.00375 .87088 L
s
0 .89835 m
.00375 .89835 L
s
0 .92582 m
.00375 .92582 L
s
0 .9533 m
.00375 .9533 L
s
.25 Mabswid
0 0 m
0 1 L
s
.01923 .99375 m
.01923 1 L
s
.15659 .99375 m
.15659 1 L
s
.29396 .99375 m
.29396 1 L
s
.43132 .99375 m
.43132 1 L
s
.56868 .99375 m
.56868 1 L
s
.70604 .99375 m
.70604 1 L
s
.84341 .99375 m
.84341 1 L
s
.98077 .99375 m
.98077 1 L
s
.125 Mabswid
.0467 .99625 m
.0467 1 L
s
.07418 .99625 m
.07418 1 L
s
.10165 .99625 m
.10165 1 L
s
.12912 .99625 m
.12912 1 L
s
.18407 .99625 m
.18407 1 L
s
.21154 .99625 m
.21154 1 L
s
.23901 .99625 m
.23901 1 L
s
.26648 .99625 m
.26648 1 L
s
.32143 .99625 m
.32143 1 L
s
.3489 .99625 m
.3489 1 L
s
.37637 .99625 m
.37637 1 L
s
.40385 .99625 m
.40385 1 L
s
.45879 .99625 m
.45879 1 L
s
.48626 .99625 m
.48626 1 L
s
.51374 .99625 m
.51374 1 L
s
.54121 .99625 m
.54121 1 L
s
.59615 .99625 m
.59615 1 L
s
.62363 .99625 m
.62363 1 L
s
.6511 .99625 m
.6511 1 L
s
.67857 .99625 m
.67857 1 L
s
.73352 .99625 m
.73352 1 L
s
.76099 .99625 m
.76099 1 L
s
.78846 .99625 m
.78846 1 L
s
.81593 .99625 m
.81593 1 L
s
.87088 .99625 m
.87088 1 L
s
.89835 .99625 m
.89835 1 L
s
.92582 .99625 m
.92582 1 L
s
.9533 .99625 m
.9533 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .01923 m
1 .01923 L
s
.99375 .15659 m
1 .15659 L
s
.99375 .29396 m
1 .29396 L
s
.99375 .43132 m
1 .43132 L
s
.99375 .56868 m
1 .56868 L
s
.99375 .70604 m
1 .70604 L
s
.99375 .84341 m
1 .84341 L
s
.99375 .98077 m
1 .98077 L
s
.125 Mabswid
.99625 .0467 m
1 .0467 L
s
.99625 .07418 m
1 .07418 L
s
.99625 .10165 m
1 .10165 L
s
.99625 .12912 m
1 .12912 L
s
.99625 .18407 m
1 .18407 L
s
.99625 .21154 m
1 .21154 L
s
.99625 .23901 m
1 .23901 L
s
.99625 .26648 m
1 .26648 L
s
.99625 .32143 m
1 .32143 L
s
.99625 .3489 m
1 .3489 L
s
.99625 .37637 m
1 .37637 L
s
.99625 .40385 m
1 .40385 L
s
.99625 .45879 m
1 .45879 L
s
.99625 .48626 m
1 .48626 L
s
.99625 .51374 m
1 .51374 L
s
.99625 .54121 m
1 .54121 L
s
.99625 .59615 m
1 .59615 L
s
.99625 .62363 m
1 .62363 L
s
.99625 .6511 m
1 .6511 L
s
.99625 .67857 m
1 .67857 L
s
.99625 .73352 m
1 .73352 L
s
.99625 .76099 m
1 .76099 L
s
.99625 .78846 m
1 .78846 L
s
.99625 .81593 m
1 .81593 L
s
.99625 .87088 m
1 .87088 L
s
.99625 .89835 m
1 .89835 L
s
.99625 .92582 m
1 .92582 L
s
.99625 .9533 m
1 .9533 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.01923 .01923 translate
.96154 .96154 scale
21 string
7 7 8 [7 0 0 7 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00
FF4C00FF5C00FF5C00FF5C00FF7A00FAFF00FF6B00
FF5C00FF6B00FF7A00FF8A00FF0000FF0000FF0000
FF6B00FF9900FF0000CCFF00FF0000FF0000FF0000
FF6B00FF9900FF0000CCFF00FF0000FF0000FF0000
FF5C00FF6B00FF7A00FF8A00FF0000FF0000FF0000
FF4C00FF5C00FF5C00FF5C00FF7A00FAFF00FF6B00
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003ooooooolQ
ooooo`003oooool2o`0002;ooooo0ol0000Rooooo`Go00008_ooool3o`0002Cooooo0ol0000Qoooo
o`?o00008oooool3o`0002Cooooo00?o0000ooooooooool01_ooool000kooooo00Co0000oooooooo
oooo00008_ooool00ol0003oooooooooo`0Rooooo`04o`000?ooooooooooo`00027ooooo00Go0000
ooooooooooooooooo`00000Tooooo`03o`000?oooooooooo01oooooo00Go0000oooooooooooooooo
o`00000Qooooo`05o`000?ooooooooooooooool000008oooool00ol0003oooooooooo`06ooooo`00
3_ooool01?l0003oooooooooool0000Rooooo`03o`000?oooooooooo02?ooooo00?o0000oooooooo
ool09Oooool00ol0003oooooooooo`0Oooooo`Go00009?ooool00ol0003oooooooooo`0Oooooo`05
o`000?ooooooooooooooool000009?ooool00ol0003oooooooooo`05ooooo`003_ooool01?l0003o
ooooooooool0000Rooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool08_ooool2o`00
02;ooooo00Co0000oooooooooooo00009Oooool00ol0003oooooooooo`0Oooooo`Co00009Oooool0
0ol0003oooooooooo`05ooooo`003_ooool01?l0003oooooooooool0000Rooooo`03o`000?oooooo
oooo027ooooo00Go0000ooooooooooooooooo`00000Uooooo`03o`000?oooooooooo023ooooo00?o
0000ooooool000008Oooool4o`0002;ooooo00?o0000ooooooooool09oooool00ol0003ooooooooo
o`04ooooo`003_ooool01?l0003oooooooooool0000Qooooo`;o00008oooool01Ol0003ooooooooo
oooooooo0000027ooooo00Go0000ooooooooooooooooo`00000Sooooo`;o00008Oooool00ol0003o
ooooooooo`0Tooooo`03o`000?oooooooooo02;ooooo00Go0000ooooooooooooooooo`000006oooo
o`003oooool2o`0002?ooooo00?o0000ooooooooool08_ooool3o`0002?ooooo0ol0000Uooooo`03
o`000?oooooooooo01oooooo1Ol0000Sooooo`;o00008_ooool5o`0000Kooooo003oooooob7ooooo
003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo000:oooooooo0000
5Ol00002ooooo`002_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`7o00000Oooool1ooooo`002_ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool08oooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool08_ooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool00_ooool1
o`00007ooooo0Oooool000?ooooo0_l00005ooooo`03o`000?oooooooooo0?oooooo4Oooool1o`00
007ooooo0Oooool000;ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`3ooooo
oa7ooooo0Ol00001ooooo`7ooooo0002ooooo`04o`000?ooooooooooo`0000Cooooo0ol0003ooooo
o`oooooo0ol00002ooooo`000_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo
00?oooooUoooC01boomL00Cooooo0Ol00001ooooo`7ooooo0002ooooo`04o`000?ooooooooooo`00
00Cooooo00?o0000ooooooooool00ooooonGoom<07;ooe`01?ooool1o`00007ooooo0Oooool000;o
oooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`03oooooiOood`0L_ooG004oooo
o`7o00000Oooool1ooooo`000oooool2o`0000Gooooo00?o0000ooooooooool00ooooonGoom<07;o
oe`01?ooool1o`00007ooooo0Oooool000[ooooo00?o0000ooooooooool00ooooonGoom<07;ooe`0
1?ooool1o`00007ooooo0Oooool000[ooooo00?o0000ooooooooool00ooooonGoom<07;ooe`01?oo
ool1o`00007ooooo0Oooool000[ooooo00?o0000ooooooooool00ooooonGoom<07;ooe`01?ooool1
o`00007ooooo0Oooool000[ooooo0_l00004oooooiOood`0L_ooG003ooooo`;o00000_ooool000[o
oooo00?o0000ooooooooool00ooooonGoom<07;ooe`01?ooool1o`00007ooooo0Oooool000[ooooo
00?o0000ooooooooool00ooooonGoom<07;ooe`01?ooool1o`00007ooooo0Oooool000[ooooo00?o
0000ooooooooool00ooooonGoom<07;ooe`01?ooool1o`00007ooooo0Oooool000[ooooo00?o0000
ooooooooool00ooooonGoom<07;ooe`01?ooool1o`00007ooooo0Oooool000[ooooo00?o0000oooo
ooooool00ooooonGoom<07;ooe`01?ooool1o`00007ooooo0Oooool000[ooooo00?o0000oooooooo
ool00ooooonGoom<07;ooe`01?ooool1o`00007ooooo0Oooool000[ooooo0_l00004oooooiOood`0
L_ooG003ooooo`;o00000_ooool000[ooooo00?o0000ooooooooool00ooooonGoom<07;ooe`01?oo
ool1o`00007ooooo0Oooool000[ooooo00?o0000ooooooooool00ooooonGoom<07;ooe`01?ooool1
o`00007ooooo0Oooool000[ooooo00?o0000ooooooooool00ooooonGoom<07;ooe`01?ooool1o`00
007ooooo0Oooool000[ooooo00?o0000ooooooooool00ooooonGoom<07;ooe`01?ooool1o`00007o
oooo0Oooool000[ooooo00?o0000ooooooooool00ooooonGoom<07;ooe`01?ooool1o`00007ooooo
0Oooool000[ooooo00?o0000ooooooooool00ooooonGoom<07;ooe`01?ooool1o`00007ooooo0Ooo
ool000[ooooo00?o0000ooooooooool00ooooonGoom<07;ooe`01?ooool1o`00007ooooo0Oooool0
00[ooooo0_l00004oooooiOood`0L_ooG003ooooo`;o00000_ooool000[ooooo00?o0000oooooooo
ool00ooooonGoom<07;ooe`01?ooool1o`00007ooooo0Oooool000[ooooo00?o0000ooooooooool0
0ooooonGoom<07;ooe`01?ooool1o`00007ooooo0Oooool000[ooooo00?o0000ooooooooool00ooo
oonGoom<07;ooe`01?ooool1o`00007ooooo0Oooool000[ooooo00?o0000ooooooooool00ooooonG
oom<07;ooe`01?ooool1o`00007ooooo0Oooool000[ooooo00?o0000ooooooooool00ooooonGoom<
07;ooe`01?ooool1o`00007ooooo0Oooool000[ooooo00?o0000ooooooooool00ooooonGoom<07;o
oe`01?ooool1o`00007ooooo0Oooool000[ooooo0_l00004oooooiOood`0L_ooG003ooooo`;o0000
0_ooool000[ooooo00?o0000ooooooooool00ooooonGoom<07;ooe`01?ooool1o`00007ooooo0Ooo
ool000[ooooo00?o0000ooooooooool00ooooonGoom<07;ooe`01?ooool1o`00007ooooo0Oooool0
00[ooooo00?o0000ooooooooool00ooooonGoom<07;ooe`01?ooool1o`00007ooooo0Oooool000[o
oooo00?o0000ooooooooool00ooooonGoom<07;ooe`01?ooool1o`00007ooooo0Oooool000;ooooo
0ol00005ooooo`03o`000?oooooooooo00?oooooUoooC01boomL00Cooooo0Ol00001ooooo`7ooooo
0003ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00ooooonGoom<07;ooe`01?oo
ool1o`00007ooooo0Oooool000?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03
oooooiOood`0L_ooG004ooooo`7o00000Oooool1ooooo`000oooool00ol0003oooooooooo`04oooo
o`?o00000ooooonGoom<07;ooe`00_ooool3o`0000;ooooo0003ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool00ooooolUoom<07;ooe`09_ooNP0Voo[o02Koof/01?ooool1o`00007o
oooo0Oooool000;ooooo0_l00006ooooo`03o`000?oooooooooo00?ooooo9OooC01boomL02KoogX0
9_ojo`0Voom[00Cooooo0Ol00001ooooo`7ooooo0003ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool00ooooolUoom<07;ooe`09_ooNP0Voo[o02Koof/01?ooool1o`00007ooooo0Ooo
ool000[ooooo00?o0000ooooooooool00ooooolUoom<07;ooe`09_ooNP0Voo[o02Koof/01?ooool1
o`00007ooooo0Oooool000[ooooo00?o0000ooooooooool00ooooolUoom<07;ooe`09_ooNP0Voo[o
02Koof/01?ooool1o`00007ooooo0Oooool000[ooooo00?o0000ooooooooool00ooooolUoom<07;o
oe`09_ooNP0Voo[o02Koof/01?ooool1o`00007ooooo0Oooool000[ooooo0_l00004ooooobGood`0
L_ooG00Voomj02Kon_l09_ooJ`03ooooo`;o00000_ooool000[ooooo00?o0000ooooooooool00ooo
oolUoom<07;ooe`09_ooNP0Voo[o02Koof/01?ooool1o`00007ooooo0Oooool000[ooooo00?o0000
ooooooooool00ooooolUoom<07;ooe`09_ooNP0Voo[o02Koof/01?ooool1o`00007ooooo0Oooool0
00[ooooo00?o0000ooooooooool00ooooolUoom<07;ooe`09_ooNP0Voo[o02Koof/01?ooool1o`00
007ooooo0Oooool000[ooooo00?o0000ooooooooool00ooooolUoom<07;ooe`09_ooNP0Voo[o02Ko
of/01?ooool1o`00007ooooo0Oooool000[ooooo00?o0000ooooooooool00ooooolUoom<07;ooe`0
9_ooNP0Voo[o02Koof/01?ooool1o`00007ooooo0Oooool000[ooooo00?o0000ooooooooool00ooo
oolUoom<07;ooe`09_ooNP0Voo[o02Koof/01?ooool1o`00007ooooo0Oooool000[ooooo00?o0000
ooooooooool00ooooolUoom<07;ooe`09_ooNP0Voo[o02Koof/01?ooool1o`00007ooooo0Oooool0
00[ooooo0_l00004ooooobGood`0L_ooG00Voomj02Kon_l09_ooJ`03ooooo`;o00000_ooool000[o
oooo00?o0000ooooooooool00ooooolUoom<07;ooe`09_ooNP0Voo[o02Koof/01?ooool1o`00007o
oooo0Oooool000[ooooo00?o0000ooooooooool00ooooolUoom<07;ooe`09_ooNP0Voo[o02Koof/0
1?ooool1o`00007ooooo0Oooool000[ooooo00?o0000ooooooooool00ooooolUoom<07;ooe`09_oo
NP0Voo[o02Koof/01?ooool1o`00007ooooo0Oooool000[ooooo00?o0000ooooooooool00ooooolU
oom<07;ooe`09_ooNP0Voo[o02Koof/01?ooool1o`00007ooooo0Oooool000[ooooo00?o0000oooo
ooooool00ooooolUoom<07;ooe`09_ooNP0Voo[o02Koof/01?ooool1o`00007ooooo0Oooool000[o
oooo00?o0000ooooooooool00ooooolUoom<07;ooe`09_ooNP0Voo[o02Koof/01?ooool1o`00007o
oooo0Oooool000[ooooo00?o0000ooooooooool00ooooolUoom<07;ooe`09_ooNP0Voo[o02Koof/0
1?ooool1o`00007ooooo0Oooool000[ooooo0_l00004ooooobGood`0L_ooG00Voomj02Kon_l09_oo
J`03ooooo`;o00000_ooool000[ooooo00?o0000ooooooooool00ooooolUoom<07;ooe`09_ooNP0V
oo[o02Koof/01?ooool1o`00007ooooo0Oooool000[ooooo00?o0000ooooooooool00ooooolUoom<
07;ooe`09_ooNP0Voo[o02Koof/01?ooool1o`00007ooooo0Oooool000[ooooo00?o0000oooooooo
ool00ooooolUoom<07;ooe`09_ooNP0Voo[o02Koof/01?ooool1o`00007ooooo0Oooool000[ooooo
00?o0000ooooooooool00ooooolUoom<07;ooe`09_ooNP0Voo[o02Koof/01?ooool1o`00007ooooo
0Oooool000[ooooo00?o0000ooooooooool00ooooolUoom<07;ooe`09_ooNP0Voo[o02Koof/01?oo
ool1o`00007ooooo0Oooool000[ooooo00?o0000ooooooooool00ooooolUoom<07;ooe`09_ooNP0V
oo[o02Koof/01?ooool1o`00007ooooo0Oooool000[ooooo0_l00004ooooobGood`0L_ooG00Voomj
02Kon_l09_ooJ`03ooooo`;o00000_ooool000[ooooo00?o0000ooooooooool00ooooolUoom<07;o
oe`09_ooNP0Voo[o02Koof/01?ooool1o`00007ooooo0Oooool000[ooooo00?o0000ooooooooool0
0ooooolUoom<07;ooe`09_ooNP0Voo[o02Koof/01?ooool1o`00007ooooo0Oooool000[ooooo00?o
0000ooooooooool00ooooolUoom<07;ooe`09_ooNP0Voo[o02Koof/01?ooool1o`00007ooooo0Ooo
ool000[ooooo00?o0000ooooooooool00ooooolUoom<07;ooe`09_ooNP0Voo[o02Koof/01?ooool1
o`00007ooooo0Oooool00003ooooool0003o000000?o00001?ooool00ol0003oooooooooo`03oooo
obGood`0L_ooG00Voomj02Kon_l09_ooJ`04ooooo`7o00000Oooool1ooooo`000_ooool01?l0003o
ooooooooool00004ooooo`03o`000?oooooooooo00?ooooo9OooC01boomL02KoogX09_ojo`0Voom[
00Cooooo0Ol00001ooooo`7ooooo0003ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool00ooooolUoom<07;ooe`09_ooNP0Voo[o02Koof/01?ooool1o`00007ooooo0Oooool000Cooooo
00?o0000ooooooooool00oooool3o`0000?ooooo9OooG00Voom[02KoogX09_ooRP1bool000;ooooo
0ol00002ooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00?ooooo9OooG00Voom[02KoogX09_ooRP1bool000Cooooo0Ol00001ooooo`7ooooo0000
0ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00ooooolU
oomL02Koof/09_ooNP0Voon:07;oo`001?ooool1o`00007ooooo0Oooool000;ooooo0ol00005oooo
o`03o`000?oooooooooo00?ooooo9OooG00Voom[02KoogX09_ooRP1bool000Cooooo0Ol00001oooo
o`7ooooo000:ooooo`03o`000?oooooooooo00?ooooo9OooG00Voom[02KoogX09_ooRP1bool000Co
oooo0Ol00001ooooo`7ooooo000:ooooo`03o`000?oooooooooo00?ooooo9OooG00Voom[02KoogX0
9_ooRP1bool000Cooooo0Ol00001ooooo`7ooooo000:ooooo`03o`000?oooooooooo00?ooooo9Ooo
G00Voom[02KoogX09_ooRP1bool000Cooooo0Ol00001ooooo`7ooooo000:ooooo`;o00001?oooolU
oomL02Koof/09_ooNP0Voon:07;oo`000oooool2o`0000;ooooo000:ooooo`03o`000?oooooooooo
00?ooooo9OooG00Voom[02KoogX09_ooRP1bool000Cooooo0Ol00001ooooo`7ooooo000:ooooo`03
o`000?oooooooooo00?ooooo9OooG00Voom[02KoogX09_ooRP1bool000Cooooo0Ol00001ooooo`7o
oooo000:ooooo`03o`000?oooooooooo00?ooooo9OooG00Voom[02KoogX09_ooRP1bool000Cooooo
0Ol00001ooooo`7ooooo000:ooooo`03o`000?oooooooooo00?ooooo9OooG00Voom[02KoogX09_oo
RP1bool000Cooooo0Ol00001ooooo`7ooooo000:ooooo`03o`000?oooooooooo00?ooooo9OooG00V
oom[02KoogX09_ooRP1bool000Cooooo0Ol00001ooooo`7ooooo000:ooooo`03o`000?oooooooooo
00?ooooo9OooG00Voom[02KoogX09_ooRP1bool000Cooooo0Ol00001ooooo`7ooooo000:ooooo`03
o`000?oooooooooo00?ooooo9OooG00Voom[02KoogX09_ooRP1bool000Cooooo0Ol00001ooooo`7o
oooo000:ooooo`;o00001?oooolUoomL02Koof/09_ooNP0Voon:07;oo`000oooool2o`0000;ooooo
000:ooooo`03o`000?oooooooooo00?ooooo9OooG00Voom[02KoogX09_ooRP1bool000Cooooo0Ol0
0001ooooo`7ooooo000:ooooo`03o`000?oooooooooo00?ooooo9OooG00Voom[02KoogX09_ooRP1b
ool000Cooooo0Ol00001ooooo`7ooooo000:ooooo`03o`000?oooooooooo00?ooooo9OooG00Voom[
02KoogX09_ooRP1bool000Cooooo0Ol00001ooooo`7ooooo000:ooooo`03o`000?oooooooooo00?o
oooo9OooG00Voom[02KoogX09_ooRP1bool000Cooooo0Ol00001ooooo`7ooooo000:ooooo`03o`00
0?oooooooooo00?ooooo9OooG00Voom[02KoogX09_ooRP1bool000Cooooo0Ol00001ooooo`7ooooo
000:ooooo`03o`000?oooooooooo00?ooooo9OooG00Voom[02KoogX09_ooRP1bool000Cooooo0Ol0
0001ooooo`7ooooo000:ooooo`;o00001?oooolUoomL02Koof/09_ooNP0Voon:07;oo`000oooool2
o`0000;ooooo000:ooooo`03o`000?oooooooooo00?ooooo9OooG00Voom[02KoogX09_ooRP1bool0
00Cooooo0Ol00001ooooo`7ooooo000:ooooo`03o`000?oooooooooo00?ooooo9OooG00Voom[02Ko
ogX09_ooRP1bool000Cooooo0Ol00001ooooo`7ooooo000:ooooo`03o`000?oooooooooo00?ooooo
9OooG00Voom[02KoogX09_ooRP1bool000Cooooo0Ol00001ooooo`7ooooo000:ooooo`03o`000?oo
oooooooo00?ooooo9OooG00Voom[02KoogX09_ooRP1bool000Cooooo0Ol00001ooooo`7ooooo000:
ooooo`03o`000?oooooooooo00?ooooo9OooG00Voom[02KoogX09_ooRP1bool000Cooooo0Ol00001
ooooo`7ooooo000:ooooo`03o`000?oooooooooo00?ooooo9OooG00Voom[02KoogX09_ooRP1bool0
00Cooooo0Ol00001ooooo`7ooooo000:ooooo`03o`000?oooooooooo00?ooooo9OooG00Voom[02Ko
ogX09_ooRP1bool000Cooooo0Ol00001ooooo`7ooooo000:ooooo`;o00001?oooolUoomL02Koof/0
9_ooNP0Voon:07;oo`000oooool2o`0000;ooooo000:ooooo`03o`000?oooooooooo00?ooooo9Ooo
G00Voom[02KoogX09_ooRP1bool000Cooooo0Ol00001ooooo`7ooooo000:ooooo`03o`000?oooooo
oooo00?ooooo9OooG00Voom[02KoogX09_ooRP1bool000Cooooo0Ol00001ooooo`7ooooo000:oooo
o`03o`000?oooooooooo00?ooooo9OooG00Voom[02KoogX09_ooRP1bool000Cooooo0Ol00001oooo
o`7ooooo000:ooooo`03o`000?oooooooooo00?ooooo9OooG00Voom[02KoogX09_ooRP1bool000Co
oooo0Ol00001ooooo`7ooooo0002ooooo`?o00001Oooool00ol0003oooooooooo`03ooooobGooe`0
9_ooJ`0Voomj02KoohX0L_oo0004ooooo`7o00000Oooool1ooooo`0000?oooooo`000?ooool00_oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo9OooG00Voom[02KoogX09_oo
RP1bool000Cooooo0Ol00001ooooo`7ooooo0005ooooo`03o`000?oooooooooo00;ooooo0ol00003
ooooobGooe`09_ooJ`0Voomj02KoohX0L_oo0002ooooo`?o00000_ooool000?ooooo0_l00005oooo
o`03o`000?oooooooooo00?ooooo9OooJ`0VoonI02Koo`009_o<o`1bool000Cooooo0Ol00001oooo
o`7ooooo0005ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00ooooolUoom[02Ko
oiT09_oo000Volco07;oo`001?ooool1o`00007ooooo0Oooool00003ooooool0003ooooo00;ooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooobGoof/09_ooV@0Vool002Koc?l0
L_oo0004ooooo`7o00000Oooool1ooooo`000_ooool3o`0000Gooooo00?o0000ooooooooool00ooo
oolUoom[02KooiT09_oo000Volco07;oo`001?ooool1o`00007ooooo0Oooool000[ooooo00?o0000
ooooooooool00ooooolUoom[02KooiT09_oo000Volco07;oo`001?ooool1o`00007ooooo0Oooool0
00[ooooo00?o0000ooooooooool00ooooolUoom[02KooiT09_oo000Volco07;oo`001?ooool1o`00
007ooooo0Oooool000[ooooo00?o0000ooooooooool00ooooolUoom[02KooiT09_oo000Volco07;o
o`001?ooool1o`00007ooooo0Oooool000[ooooo0_l00004ooooobGoof/09_ooV@0Vool002Koc?l0
L_oo0003ooooo`;o00000_ooool000[ooooo00?o0000ooooooooool00ooooolUoom[02KooiT09_oo
000Volco07;oo`001?ooool1o`00007ooooo0Oooool000[ooooo00?o0000ooooooooool00ooooolU
oom[02KooiT09_oo000Volco07;oo`001?ooool1o`00007ooooo0Oooool000[ooooo00?o0000oooo
ooooool00ooooolUoom[02KooiT09_oo000Volco07;oo`001?ooool1o`00007ooooo0Oooool000[o
oooo00?o0000ooooooooool00ooooolUoom[02KooiT09_oo000Volco07;oo`001?ooool1o`00007o
oooo0Oooool000[ooooo00?o0000ooooooooool00ooooolUoom[02KooiT09_oo000Volco07;oo`00
1?ooool1o`00007ooooo0Oooool000[ooooo00?o0000ooooooooool00ooooolUoom[02KooiT09_oo
000Volco07;oo`001?ooool1o`00007ooooo0Oooool000[ooooo0_l00004ooooobGoof/09_ooV@0V
ool002Koc?l0L_oo0003ooooo`;o00000_ooool000[ooooo00?o0000ooooooooool00ooooolUoom[
02KooiT09_oo000Volco07;oo`001?ooool1o`00007ooooo0Oooool000[ooooo00?o0000oooooooo
ool00ooooolUoom[02KooiT09_oo000Volco07;oo`001?ooool1o`00007ooooo0Oooool000[ooooo
00?o0000ooooooooool00ooooolUoom[02KooiT09_oo000Volco07;oo`001?ooool1o`00007ooooo
0Oooool000[ooooo00?o0000ooooooooool00ooooolUoom[02KooiT09_oo000Volco07;oo`001?oo
ool1o`00007ooooo0Oooool000[ooooo00?o0000ooooooooool00ooooolUoom[02KooiT09_oo000V
olco07;oo`001?ooool1o`00007ooooo0Oooool000[ooooo00?o0000ooooooooool00ooooolUoom[
02KooiT09_oo000Volco07;oo`001?ooool1o`00007ooooo0Oooool000[ooooo00?o0000oooooooo
ool00ooooolUoom[02KooiT09_oo000Volco07;oo`001?ooool1o`00007ooooo0Oooool000[ooooo
0_l00004ooooobGoof/09_ooV@0Vool002Koc?l0L_oo0003ooooo`;o00000_ooool000[ooooo00?o
0000ooooooooool00ooooolUoom[02KooiT09_oo000Volco07;oo`001?ooool1o`00007ooooo0Ooo
ool000[ooooo00?o0000ooooooooool00ooooolUoom[02KooiT09_oo000Volco07;oo`001?ooool1
o`00007ooooo0Oooool000[ooooo00?o0000ooooooooool00ooooolUoom[02KooiT09_oo000Volco
07;oo`001?ooool1o`00007ooooo0Oooool000[ooooo00?o0000ooooooooool00ooooolUoom[02Ko
oiT09_oo000Volco07;oo`001?ooool1o`00007ooooo0Oooool000[ooooo00?o0000ooooooooool0
0ooooolUoom[02KooiT09_oo000Volco07;oo`001?ooool1o`00007ooooo0Oooool000[ooooo00?o
0000ooooooooool00ooooolUoom[02KooiT09_oo000Volco07;oo`001?ooool1o`00007ooooo0Ooo
ool000[ooooo00?o0000ooooooooool00ooooolUoom[02KooiT09_oo000Volco07;oo`001?ooool1
o`00007ooooo0Oooool000[ooooo0_l00004ooooobGoof/09_ooV@0Vool002Koc?l0L_oo0003oooo
o`;o00000_ooool000[ooooo00?o0000ooooooooool00ooooolUoom[02KooiT09_oo000Volco07;o
o`001?ooool1o`00007ooooo0Oooool000[ooooo00?o0000ooooooooool00ooooolUoom[02KooiT0
9_oo000Volco07;oo`001?ooool1o`00007ooooo0Oooool000[ooooo00?o0000ooooooooool00ooo
oolUoom[02KooiT09_oo000Volco07;oo`001?ooool1o`00007ooooo0Oooool000[ooooo00?o0000
ooooooooool00ooooolUoom[02KooiT09_oo000Volco07;oo`001?ooool1o`00007ooooo0Oooool0
00?ooooo0ol00004ooooo`03o`000?oooooooooo00?ooooo9OooJ`0VoonI02Koo`009_o<o`1bool0
00Cooooo0Ol00001ooooo`7ooooo0004ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool00ooooolUoom[02KooiT09_oo000Volco07;oo`001?ooool1o`00007ooooo0Oooool00003oooo
ool0003o000000?o00001?ooool3o`0000?ooooo9OooJ`0VoonI02Koo`009_o<o`1bool000;ooooo
0ol00002ooooo`0000Goooooo`000?ooooooooooo`000005ooooo`03o`000?oooooooooo00?ooooo
9OooJ`0VoonI02Koo`009_o<o`1bool000Cooooo0Ol00001ooooo`7ooooo0002ooooo`03o`000?oo
oooo000000Gooooo00?o0000ooooooooool00ooooolUoom[02KooiT09_oo000Volco07;oo`001?oo
ool1o`00007ooooo0Oooool000?ooooo0_l00005ooooo`03o`000?oooooooooo00?ooooo9OooJ`0V
oonI02Koo`009_o<o`1bool000Cooooo0Ol00001ooooo`7ooooo0004ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool00ooooolUoom[02KooiT09_oo000Volco07;oo`001?ooool1o`00
007ooooo0Oooool000[ooooo00?o0000ooooooooool00ooooolUoom[02KooiT09_oo000Volco07;o
o`001?ooool1o`00007ooooo0Oooool000[ooooo00?o0000ooooooooool00ooooolUoom[02KooiT0
9_oo000Volco07;oo`001?ooool1o`00007ooooo0Oooool000[ooooo00?o0000ooooooooool00ooo
oolUoom[02KooiT09_oo000Volco07;oo`001?ooool1o`00007ooooo0Oooool000[ooooo0_l00004
ooooobGoof/09_ooV@0Vool002Koc?l0L_oo0003ooooo`;o00000_ooool000[ooooo00?o0000oooo
ooooool00ooooolUoom[02KooiT09_oo000Volco07;oo`001?ooool1o`00007ooooo0Oooool000[o
oooo00?o0000ooooooooool00ooooolUoom[02KooiT09_oo000Volco07;oo`001?ooool1o`00007o
oooo0Oooool000[ooooo00?o0000ooooooooool00ooooolUoom[02KooiT09_oo000Volco07;oo`00
1?ooool1o`00007ooooo0Oooool000[ooooo00?o0000ooooooooool00ooooolUoom[02KooiT09_oo
000Volco07;oo`001?ooool1o`00007ooooo0Oooool000[ooooo00?o0000ooooooooool00ooooolU
oom[02KooiT09_oo000Volco07;oo`001?ooool1o`00007ooooo0Oooool000[ooooo00?o0000oooo
ooooool00ooooolUoom[02KooiT09_oo000Volco07;oo`001?ooool1o`00007ooooo0Oooool000[o
oooo0_l00004ooooobGoof/09_ooV@0Vool002Koc?l0L_oo0003ooooo`;o00000_ooool000[ooooo
00?o0000ooooooooool00ooooolUoom[02KooiT09_oo000Volco07;oo`001?ooool1o`00007ooooo
0Oooool000[ooooo00?o0000ooooooooool00ooooolUoom[02KooiT09_oo000Volco07;oo`001?oo
ool1o`00007ooooo0Oooool000[ooooo00?o0000ooooooooool00ooooolUoom[02KooiT09_oo000V
olco07;oo`001?ooool1o`00007ooooo0Oooool000[ooooo00?o0000ooooooooool00ooooolUoom[
02KooiT09_oo000Volco07;oo`001?ooool1o`00007ooooo0Oooool000[ooooo00?o0000oooooooo
ool00ooooolUoom[02KooiT09_oo000Volco07;oo`001?ooool1o`00007ooooo0Oooool000[ooooo
00?o0000ooooooooool00ooooolUoom[02KooiT09_oo000Volco07;oo`001?ooool1o`00007ooooo
0Oooool000[ooooo00?o0000ooooooooool00ooooolUoom[02KooiT09_oo000Volco07;oo`001?oo
ool1o`00007ooooo0Oooool000[ooooo0_l00004ooooobGoof/09_ooV@0Vool002Koc?l0L_oo0003
ooooo`;o00000_ooool000[ooooo00?o0000ooooooooool00ooooolUoom[02KooiT09_oo000Volco
07;oo`001?ooool1o`00007ooooo0Oooool000[ooooo00?o0000ooooooooool00ooooolUoom[02Ko
oiT09_oo000Volco07;oo`001?ooool1o`00007ooooo0Oooool000[ooooo00?o0000ooooooooool0
0ooooolUoom[02KooiT09_oo000Volco07;oo`001?ooool1o`00007ooooo0Oooool000[ooooo00?o
0000ooooooooool00ooooolUoom[02KooiT09_oo000Volco07;oo`001?ooool1o`00007ooooo0Ooo
ool000[ooooo00?o0000ooooooooool00ooooolUoom[02KooiT09_oo000Volco07;oo`001?ooool1
o`00007ooooo0Oooool000[ooooo00?o0000ooooooooool00ooooolUoom[02KooiT09_oo000Volco
07;oo`001?ooool1o`00007ooooo0Oooool000[ooooo0_l00004ooooobGoof/09_ooV@0Vool002Ko
c?l0L_oo0003ooooo`;o00000_ooool000[ooooo00?o0000ooooooooool00ooooolUoom[02KooiT0
9_oo000Volco07;oo`001?ooool1o`00007ooooo0Oooool000[ooooo00?o0000ooooooooool00ooo
oolUoom[02KooiT09_oo000Volco07;oo`001?ooool1o`00007ooooo0Oooool000[ooooo00?o0000
ooooooooool00ooooolUoom[02KooiT09_oo000Volco07;oo`001?ooool1o`00007ooooo0Oooool0
00[ooooo00?o0000ooooooooool00ooooolUoom[02KooiT09_oo000Volco07;oo`001?ooool1o`00
007ooooo0Oooool000;ooooo0ol00005ooooo`03o`000?oooooooooo00?ooooo9OooJ`0VoonI02Ko
o`009_o<o`1bool000Cooooo0Ol00001ooooo`7ooooo00000ooooooo0000ooooo`02ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool00ooooolUoom[02KooiT09_oo000Volco07;oo`00
1?ooool1o`00007ooooo0Oooool000Gooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`03ooooobGoof/09_ooV@0Vool002Koc?l0L_oo0004ooooo`7o00000Oooool1ooooo`001Oooool0
0ol0003oooooooooo`02ooooo`?o00000ooooolUoomL02Koof/09_ooNP0Voon:07;oo`000_ooool3
o`0000;ooooo00000ooooooo0000o`000002o`0000Gooooo00?o0000ooooooooool00ooooolUoomL
02Koof/09_ooNP0Voon:07;oo`001?ooool1o`00007ooooo0Oooool00003ooooool0003ooooo00Oo
oooo00?o0000ooooooooool00ooooolUoomL02Koof/09_ooNP0Voon:07;oo`001?ooool1o`00007o
oooo0Oooool00003ooooool0003o000000?o00001?ooool00ol0003oooooooooo`03ooooobGooe`0
9_ooJ`0Voomj02KoohX0L_oo0004ooooo`7o00000Oooool1ooooo`002_ooool00ol0003ooooooooo
o`03ooooobGooe`09_ooJ`0Voomj02KoohX0L_oo0004ooooo`7o00000Oooool1ooooo`002_ooool0
0ol0003oooooooooo`03ooooobGooe`09_ooJ`0Voomj02KoohX0L_oo0004ooooo`7o00000Oooool1
ooooo`002_ooool00ol0003oooooooooo`03ooooobGooe`09_ooJ`0Voomj02KoohX0L_oo0004oooo
o`7o00000Oooool1ooooo`002_ooool2o`0000Cooooo9OooG00Voom[02KoogX09_ooRP1bool000?o
oooo0_l00002ooooo`002_ooool00ol0003oooooooooo`03ooooobGooe`09_ooJ`0Voomj02KoohX0
L_oo0004ooooo`7o00000Oooool1ooooo`002_ooool00ol0003oooooooooo`03ooooobGooe`09_oo
J`0Voomj02KoohX0L_oo0004ooooo`7o00000Oooool1ooooo`002_ooool00ol0003oooooooooo`03
ooooobGooe`09_ooJ`0Voomj02KoohX0L_oo0004ooooo`7o00000Oooool1ooooo`002_ooool00ol0
003oooooooooo`03ooooobGooe`09_ooJ`0Voomj02KoohX0L_oo0004ooooo`7o00000Oooool1oooo
o`002_ooool00ol0003oooooooooo`03ooooobGooe`09_ooJ`0Voomj02KoohX0L_oo0004ooooo`7o
00000Oooool1ooooo`002_ooool00ol0003oooooooooo`03ooooobGooe`09_ooJ`0Voomj02KoohX0
L_oo0004ooooo`7o00000Oooool1ooooo`002_ooool00ol0003oooooooooo`03ooooobGooe`09_oo
J`0Voomj02KoohX0L_oo0004ooooo`7o00000Oooool1ooooo`002_ooool2o`0000Cooooo9OooG00V
oom[02KoogX09_ooRP1bool000?ooooo0_l00002ooooo`002_ooool00ol0003oooooooooo`03oooo
obGooe`09_ooJ`0Voomj02KoohX0L_oo0004ooooo`7o00000Oooool1ooooo`002_ooool00ol0003o
ooooooooo`03ooooobGooe`09_ooJ`0Voomj02KoohX0L_oo0004ooooo`7o00000Oooool1ooooo`00
2_ooool00ol0003oooooooooo`03ooooobGooe`09_ooJ`0Voomj02KoohX0L_oo0004ooooo`7o0000
0Oooool1ooooo`002_ooool00ol0003oooooooooo`03ooooobGooe`09_ooJ`0Voomj02KoohX0L_oo
0004ooooo`7o00000Oooool1ooooo`002_ooool00ol0003oooooooooo`03ooooobGooe`09_ooJ`0V
oomj02KoohX0L_oo0004ooooo`7o00000Oooool1ooooo`002_ooool00ol0003oooooooooo`03oooo
obGooe`09_ooJ`0Voomj02KoohX0L_oo0004ooooo`7o00000Oooool1ooooo`002_ooool2o`0000Co
oooo9OooG00Voom[02KoogX09_ooRP1bool000?ooooo0_l00002ooooo`002_ooool00ol0003ooooo
ooooo`03ooooobGooe`09_ooJ`0Voomj02KoohX0L_oo0004ooooo`7o00000Oooool1ooooo`002_oo
ool00ol0003oooooooooo`03ooooobGooe`09_ooJ`0Voomj02KoohX0L_oo0004ooooo`7o00000Ooo
ool1ooooo`002_ooool00ol0003oooooooooo`03ooooobGooe`09_ooJ`0Voomj02KoohX0L_oo0004
ooooo`7o00000Oooool1ooooo`002_ooool00ol0003oooooooooo`03ooooobGooe`09_ooJ`0Voomj
02KoohX0L_oo0004ooooo`7o00000Oooool1ooooo`002_ooool00ol0003oooooooooo`03ooooobGo
oe`09_ooJ`0Voomj02KoohX0L_oo0004ooooo`7o00000Oooool1ooooo`002_ooool00ol0003ooooo
ooooo`03ooooobGooe`09_ooJ`0Voomj02KoohX0L_oo0004ooooo`7o00000Oooool1ooooo`002_oo
ool00ol0003oooooooooo`03ooooobGooe`09_ooJ`0Voomj02KoohX0L_oo0004ooooo`7o00000Ooo
ool1ooooo`002_ooool2o`0000Cooooo9OooG00Voom[02KoogX09_ooRP1bool000?ooooo0_l00002
ooooo`002_ooool00ol0003oooooooooo`03ooooobGooe`09_ooJ`0Voomj02KoohX0L_oo0004oooo
o`7o00000Oooool1ooooo`002_ooool00ol0003oooooooooo`03ooooobGooe`09_ooJ`0Voomj02Ko
ohX0L_oo0004ooooo`7o00000Oooool1ooooo`002_ooool00ol0003oooooooooo`03ooooobGooe`0
9_ooJ`0Voomj02KoohX0L_oo0004ooooo`7o00000Oooool1ooooo`002_ooool00ol0003ooooooooo
o`03ooooobGooe`09_ooJ`0Voomj02KoohX0L_oo0004ooooo`7o00000Oooool1ooooo`000_ooool3
o`0000Gooooo00?o0000ooooooooool00ooooolUoomL02Koof/09_ooNP0Voon:07;oo`001?ooool1
o`00007ooooo0Oooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`03ooooobGooe`09_ooJ`0Voomj02KoohX0L_oo0004ooooo`7o00000Oooool1oooo
o`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?o
oooo9OooG00Voom[02KoogX09_ooRP1bool000Cooooo0Ol00001ooooo`7ooooo00000ooooooo0000
o`000002o`0000Gooooo0ol00003ooooobGood`0L_ooG00Voomj02Kon_l09_ooJ`02ooooo`?o0000
0_ooool00003ooooool0003ooooo00Oooooo00?o0000ooooooooool00ooooolUoom<07;ooe`09_oo
NP0Voo[o02Koof/01?ooool1o`00007ooooo0Oooool000;ooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`03ooooobGood`0L_ooG00Voomj02Kon_l09_ooJ`04ooooo`7o00000Oooool1
ooooo`000oooool2o`0000Gooooo00?o0000ooooooooool00ooooolUoom<07;ooe`09_ooNP0Voo[o
02Koof/01?ooool1o`00007ooooo0Oooool000[ooooo00?o0000ooooooooool00ooooolUoom<07;o
oe`09_ooNP0Voo[o02Koof/01?ooool1o`00007ooooo0Oooool000[ooooo00?o0000ooooooooool0
0ooooolUoom<07;ooe`09_ooNP0Voo[o02Koof/01?ooool1o`00007ooooo0Oooool000[ooooo00?o
0000ooooooooool00ooooolUoom<07;ooe`09_ooNP0Voo[o02Koof/01?ooool1o`00007ooooo0Ooo
ool000[ooooo0_l00004ooooobGood`0L_ooG00Voomj02Kon_l09_ooJ`03ooooo`;o00000_ooool0
00[ooooo00?o0000ooooooooool00ooooolUoom<07;ooe`09_ooNP0Voo[o02Koof/01?ooool1o`00
007ooooo0Oooool000[ooooo00?o0000ooooooooool00ooooolUoom<07;ooe`09_ooNP0Voo[o02Ko
of/01?ooool1o`00007ooooo0Oooool000[ooooo00?o0000ooooooooool00ooooolUoom<07;ooe`0
9_ooNP0Voo[o02Koof/01?ooool1o`00007ooooo0Oooool000[ooooo00?o0000ooooooooool00ooo
oolUoom<07;ooe`09_ooNP0Voo[o02Koof/01?ooool1o`00007ooooo0Oooool000[ooooo00?o0000
ooooooooool00ooooolUoom<07;ooe`09_ooNP0Voo[o02Koof/01?ooool1o`00007ooooo0Oooool0
00[ooooo00?o0000ooooooooool00ooooolUoom<07;ooe`09_ooNP0Voo[o02Koof/01?ooool1o`00
007ooooo0Oooool000[ooooo00?o0000ooooooooool00ooooolUoom<07;ooe`09_ooNP0Voo[o02Ko
of/01?ooool1o`00007ooooo0Oooool000[ooooo0_l00004ooooobGood`0L_ooG00Voomj02Kon_l0
9_ooJ`03ooooo`;o00000_ooool000[ooooo00?o0000ooooooooool00ooooolUoom<07;ooe`09_oo
NP0Voo[o02Koof/01?ooool1o`00007ooooo0Oooool000[ooooo00?o0000ooooooooool00ooooolU
oom<07;ooe`09_ooNP0Voo[o02Koof/01?ooool1o`00007ooooo0Oooool000[ooooo00?o0000oooo
ooooool00ooooolUoom<07;ooe`09_ooNP0Voo[o02Koof/01?ooool1o`00007ooooo0Oooool000[o
oooo00?o0000ooooooooool00ooooolUoom<07;ooe`09_ooNP0Voo[o02Koof/01?ooool1o`00007o
oooo0Oooool000[ooooo00?o0000ooooooooool00ooooolUoom<07;ooe`09_ooNP0Voo[o02Koof/0
1?ooool1o`00007ooooo0Oooool000[ooooo00?o0000ooooooooool00ooooolUoom<07;ooe`09_oo
NP0Voo[o02Koof/01?ooool1o`00007ooooo0Oooool000[ooooo0_l00004ooooobGood`0L_ooG00V
oomj02Kon_l09_ooJ`03ooooo`;o00000_ooool000[ooooo00?o0000ooooooooool00ooooolUoom<
07;ooe`09_ooNP0Voo[o02Koof/01?ooool1o`00007ooooo0Oooool000[ooooo00?o0000oooooooo
ool00ooooolUoom<07;ooe`09_ooNP0Voo[o02Koof/01?ooool1o`00007ooooo0Oooool000[ooooo
00?o0000ooooooooool00ooooolUoom<07;ooe`09_ooNP0Voo[o02Koof/01?ooool1o`00007ooooo
0Oooool000[ooooo00?o0000ooooooooool00ooooolUoom<07;ooe`09_ooNP0Voo[o02Koof/01?oo
ool1o`00007ooooo0Oooool000[ooooo00?o0000ooooooooool00ooooolUoom<07;ooe`09_ooNP0V
oo[o02Koof/01?ooool1o`00007ooooo0Oooool000[ooooo00?o0000ooooooooool00ooooolUoom<
07;ooe`09_ooNP0Voo[o02Koof/01?ooool1o`00007ooooo0Oooool000[ooooo00?o0000oooooooo
ool00ooooolUoom<07;ooe`09_ooNP0Voo[o02Koof/01?ooool1o`00007ooooo0Oooool000[ooooo
0_l00004ooooobGood`0L_ooG00Voomj02Kon_l09_ooJ`03ooooo`;o00000_ooool000[ooooo00?o
0000ooooooooool00ooooolUoom<07;ooe`09_ooNP0Voo[o02Koof/01?ooool1o`00007ooooo0Ooo
ool000[ooooo00?o0000ooooooooool00ooooolUoom<07;ooe`09_ooNP0Voo[o02Koof/01?ooool1
o`00007ooooo0Oooool000[ooooo00?o0000ooooooooool00ooooolUoom<07;ooe`09_ooNP0Voo[o
02Koof/01?ooool1o`00007ooooo0Oooool000[ooooo00?o0000ooooooooool00ooooolUoom<07;o
oe`09_ooNP0Voo[o02Koof/01?ooool1o`00007ooooo0Oooool000?ooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`03ooooobGood`0L_ooG00Voomj02Kon_l09_ooJ`04ooooo`7o0000
0Oooool1ooooo`000oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo9Ooo
C01boomL02KoogX09_ojo`0Voom[00Cooooo0Ol00001ooooo`7ooooo0004ooooo`03o`000?oooooo
oooo00?ooooo0ol0003oooooo`oooooo0ol00002ooooo`001?ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo0?oooooo4Oooool1o`00007ooooo0Oooool000Gooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`3ooooooa7ooooo0Ol00001ooooo`7ooooo00000ooooooo0000
ooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0oooooolAooooo`7o0000
0Oooool1ooooo`0000?oooooo`000?l000000ol00004ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo0Ol0
0001ooooo`7ooooo000:oooooooo00005Ol00002ooooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-0.428239, -0.469668, 0.0265146, \
0.0265146}}]
}, Open  ]],

Cell[BoxData[
    \(\({tempo, matrix} = 
        Timing[mandelbrotC[{{\(-1.7\), 0.5}, {\(-1.3\), 1.3}}, 
            100]];\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(tempo\)], "Input"],

Cell[BoxData[
    \(0.08801600000015242`\ Second\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(ListDensityPlot[matrix, Mesh \[Rule] False, 
        ColorFunction \[Rule] Hue];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00961538 0.0192308 0.00961538 [
[.01923 -0.0125 -3 -9 ]
[.01923 -0.0125 3 0 ]
[.21154 -0.0125 -6 -9 ]
[.21154 -0.0125 6 0 ]
[.40385 -0.0125 -6 -9 ]
[.40385 -0.0125 6 0 ]
[.59615 -0.0125 -6 -9 ]
[.59615 -0.0125 6 0 ]
[.78846 -0.0125 -6 -9 ]
[.78846 -0.0125 6 0 ]
[.98077 -0.0125 -9 -9 ]
[.98077 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01923 -6 -4.5 ]
[-0.0125 .01923 0 4.5 ]
[-0.0125 .21154 -12 -4.5 ]
[-0.0125 .21154 0 4.5 ]
[-0.0125 .40385 -12 -4.5 ]
[-0.0125 .40385 0 4.5 ]
[-0.0125 .59615 -12 -4.5 ]
[-0.0125 .59615 0 4.5 ]
[-0.0125 .78846 -12 -4.5 ]
[-0.0125 .78846 0 4.5 ]
[-0.0125 .98077 -18 -4.5 ]
[-0.0125 .98077 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.01923 0 m
.01923 .00625 L
s
[(0)] .01923 -0.0125 0 1 Mshowa
.21154 0 m
.21154 .00625 L
s
[(20)] .21154 -0.0125 0 1 Mshowa
.40385 0 m
.40385 .00625 L
s
[(40)] .40385 -0.0125 0 1 Mshowa
.59615 0 m
.59615 .00625 L
s
[(60)] .59615 -0.0125 0 1 Mshowa
.78846 0 m
.78846 .00625 L
s
[(80)] .78846 -0.0125 0 1 Mshowa
.98077 0 m
.98077 .00625 L
s
[(100)] .98077 -0.0125 0 1 Mshowa
.125 Mabswid
.06731 0 m
.06731 .00375 L
s
.11538 0 m
.11538 .00375 L
s
.16346 0 m
.16346 .00375 L
s
.25962 0 m
.25962 .00375 L
s
.30769 0 m
.30769 .00375 L
s
.35577 0 m
.35577 .00375 L
s
.45192 0 m
.45192 .00375 L
s
.5 0 m
.5 .00375 L
s
.54808 0 m
.54808 .00375 L
s
.64423 0 m
.64423 .00375 L
s
.69231 0 m
.69231 .00375 L
s
.74038 0 m
.74038 .00375 L
s
.83654 0 m
.83654 .00375 L
s
.88462 0 m
.88462 .00375 L
s
.93269 0 m
.93269 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01923 m
.00625 .01923 L
s
[(0)] -0.0125 .01923 1 0 Mshowa
0 .21154 m
.00625 .21154 L
s
[(20)] -0.0125 .21154 1 0 Mshowa
0 .40385 m
.00625 .40385 L
s
[(40)] -0.0125 .40385 1 0 Mshowa
0 .59615 m
.00625 .59615 L
s
[(60)] -0.0125 .59615 1 0 Mshowa
0 .78846 m
.00625 .78846 L
s
[(80)] -0.0125 .78846 1 0 Mshowa
0 .98077 m
.00625 .98077 L
s
[(100)] -0.0125 .98077 1 0 Mshowa
.125 Mabswid
0 .06731 m
.00375 .06731 L
s
0 .11538 m
.00375 .11538 L
s
0 .16346 m
.00375 .16346 L
s
0 .25962 m
.00375 .25962 L
s
0 .30769 m
.00375 .30769 L
s
0 .35577 m
.00375 .35577 L
s
0 .45192 m
.00375 .45192 L
s
0 .5 m
.00375 .5 L
s
0 .54808 m
.00375 .54808 L
s
0 .64423 m
.00375 .64423 L
s
0 .69231 m
.00375 .69231 L
s
0 .74038 m
.00375 .74038 L
s
0 .83654 m
.00375 .83654 L
s
0 .88462 m
.00375 .88462 L
s
0 .93269 m
.00375 .93269 L
s
.25 Mabswid
0 0 m
0 1 L
s
.01923 .99375 m
.01923 1 L
s
.21154 .99375 m
.21154 1 L
s
.40385 .99375 m
.40385 1 L
s
.59615 .99375 m
.59615 1 L
s
.78846 .99375 m
.78846 1 L
s
.98077 .99375 m
.98077 1 L
s
.125 Mabswid
.06731 .99625 m
.06731 1 L
s
.11538 .99625 m
.11538 1 L
s
.16346 .99625 m
.16346 1 L
s
.25962 .99625 m
.25962 1 L
s
.30769 .99625 m
.30769 1 L
s
.35577 .99625 m
.35577 1 L
s
.45192 .99625 m
.45192 1 L
s
.5 .99625 m
.5 1 L
s
.54808 .99625 m
.54808 1 L
s
.64423 .99625 m
.64423 1 L
s
.69231 .99625 m
.69231 1 L
s
.74038 .99625 m
.74038 1 L
s
.83654 .99625 m
.83654 1 L
s
.88462 .99625 m
.88462 1 L
s
.93269 .99625 m
.93269 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .01923 m
1 .01923 L
s
.99375 .21154 m
1 .21154 L
s
.99375 .40385 m
1 .40385 L
s
.99375 .59615 m
1 .59615 L
s
.99375 .78846 m
1 .78846 L
s
.99375 .98077 m
1 .98077 L
s
.125 Mabswid
.99625 .06731 m
1 .06731 L
s
.99625 .11538 m
1 .11538 L
s
.99625 .16346 m
1 .16346 L
s
.99625 .25962 m
1 .25962 L
s
.99625 .30769 m
1 .30769 L
s
.99625 .35577 m
1 .35577 L
s
.99625 .45192 m
1 .45192 L
s
.99625 .5 m
1 .5 L
s
.99625 .54808 m
1 .54808 L
s
.99625 .64423 m
1 .64423 L
s
.99625 .69231 m
1 .69231 L
s
.99625 .74038 m
1 .74038 L
s
.99625 .83654 m
1 .83654 L
s
.99625 .88462 m
1 .88462 L
s
.99625 .93269 m
1 .93269 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.01923 .01923 translate
.96154 .96154 scale
300 string
100 100 8 [100 0 0 100 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF4C00FF4C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF6B00FF5C00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF5C00FF5C00FF4C00
FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF6B00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00
FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00
FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00
FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FFB800FFB800FF9900FF9900FF8A00
FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF8A00FF9900FFB8009EFF00FFC700FF9900
FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF6B00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF8A00FF8A00FFA800FFD700FFC700FFA800
FF9900FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF8A00FF8A00FF9900FFC70023FF00FFC700
FFA800FF9900FF9900FF8A00FF9900FF8A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF9900FFD700FFE60033FF00
FFB800FFA800FFA800FFA800FFC700FFB800FF8A00FF7A00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF9900FFA800FFA800FFC700EBFF00
EBFF00FFC700FFE6008FFF0080FF00FFA800FF8A00FF7A00FF7A00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF5C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF9900FF9900FFA800FFB800FFD700
CCFF00AEFF008FFF00FFC700FFB800FF9900FF8A00FF8A00FF7A00FF7A00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF9900FF9900FFA800FFB800FFC700FFD700
CCFF00CCFF00FFD700FFC700FFA800FF9900FF9900FF8A00FF8A00FF7A00FF7A00FF7A00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF8A00FF8A00FF8A00FF9900FFA800FFA800FFB800FFC700FFF500FAFF00
9EFF00CCFF00FFF500FFD700FFA800FFA800FF9900FF9900FF8A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00
FF5C00FF6B00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF8A00FF8A00FF8A00FF9900FFA80051FF00FFC700FFC700FFE600DCFF00FF00D7
AE00FF00FF9405FF00FAFF00FFB800FFA800FFA800FF9900FF8A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00
FF6B00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF4C00FF4C00FF4C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF6B00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF8A00FF8A00FF9900FF9900FFE600FAFF00EBFF00AEFF00FFF500CCFF00BDFF00FF00F5
FF0000FF000000FF66FFF500FFD700FFE600FFE600FFB800FF9900FF8A00FF8A00FF7A00
FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00
FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00
FF8A00FF8A00FF9900FFA800FFD700FFF500BDFF0080FF00EB00FF00F0FFFF0000FF0000
FF0000FF0000FF000042FF00FAFF008FFF00FFF500FFB800FF9900FF8A00FF8A00FF7A00
FF8A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF8A00FF8A00FF8A00
FF8A00FF9900FF9900FFA800FFB800FFD70061FF0000FF94FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00001400FFFF008AFAFF00FFE600FF9900FF9900FF8A00FF8A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF9900FF9900FF9900FFA800FFB800FFE600BDFF00FF00F5FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000047FFCCFF00FFD700FFB800FFA800FF9900FF9900FF8A00
FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00
FF5C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900
FF9900FF9900FFA800FFA800FFB80033FF008F00FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF000061FF00DCFF00FFB800FFA800FF9900FF9900FF9900
FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF6B00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FFA800
FFA800FFA800FFA800FFB800FFC700FFD70000FF572300FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000094FFDCFF00FFD700FFB800FFA800FFA800FF9900FF9900
FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00
FF7A00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00
FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00
FF8A00FF9900FFA800FF9900FFA800FFC700FFB800FFA800FFA800FFA800FFA800FFA800
FFB800FFB800FFB800FFC700FFC700FFE600FAFF002300FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF000042FF00FAFF00FFD700FFC700FFB800FFB800FFB800FFA800
FFA800FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF9900BDFF00FFA800FF8A00
FF7A00FF7A00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00
FF9900FFF500FFF500FFD700FFE600DCFF00FFF500FFB800FFB800FFB800FFB800FFD700
CCFF0000FFB3FFD700FFE600FFF500FFF500EBFF00CCFF000075FFFF0000FF0000FF0000
FF0000FF0000FF00002300FFCCFF00FAFF00FFF500FFE600FFE600FFC700FFD700FFF500
FFD700FFA800FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFB800BDFF00FF9900
FF8A00FF7A00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF9900
FF9900FFB800FFF5000038FF51FF00CCFF00FFF500FFE600FFC700FFC700FFD70000FF57
00FF8542FF00DCFF0000FF94FF000000FF6651FF0000FF0AFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00009EFF0000FFC2FAFF00FAFF0061FF00
00FF47FFD700FFB800FFA800FFA800FFA800FFA800FFA800FFB800FFF500FAFF00FFA800
FF8A00FF8A00FF7A00FF7A00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF9900
FF9900FFC700CCFF0080FF0000B3FF33FF008FFF00FF00F561FF00FFE600FFF500EBFF00
FF0000FF000023FF0000FFA3FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000E1FFFF000000A3FFFF0000
61FF00FFF500FFC700FFB800FFC70080FF00EBFF00FFC700FFC700FFF500EBFF00FFB800
FFC700FF8A00FF7A00FF7A00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF6B00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF9900
FFA800FFB800FFE600FAFF0000FFB3FF0000FF0000FF000000D1FFDCFF000019FF05FF00
BD00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
8FFF00BDFF00FFF500FFD700FFE600DCFF0051FF00EBFF00AEFF00EBFF009EFF00DCFF00
FFC700FF8A00FF7A00FF7A00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00
FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900
FFA800FFB800FFC7009EFF0051FF00FF0000FF0000FF0000FF000061FF00FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00009EFF00FAFF00BDFF0000C2FFFF0000FF0000FF000033FF00EBFF00DCFF00
FFA800FF8A00FF7A00FF7A00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF6B00FF7A00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF7A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FFA800
FFA800FFB800FFC7008FFF0070FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00003300FFAEFF00FFD700FFB800
FF9900FF8A00FF7A00FF7A00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF8A00FF7A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FFA800FFA800
FFB800FFC700FFD700FFF500DCFF0061FF0000FF94FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF000000B3FFFF0000FF0000FF0000FF000061FF0014FF00FFA800
FF9900FF8A00FF7A00FF7A00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00
FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FFA800FFB800FFD700
00FF85FFE600FFF500FF00008FFF0000C2FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000038FFFFF500FFB800FFA800
FF9900FF8A00FF7A00FF7A00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FFA800FFE600BDFF0023FF00
9EFF0000C2FFCCFF000500FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000AEFF00FFF500FFD700FFB800FFA800
FF9900FF8A00FF8A00FF7A00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF8A00FFA800FF9900FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FFA800FFC700BDFF0042FF00
FF0000FF000000FF47FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000CCFF00FAFF00FFC700FFA800
FF9900FF9900FF8A00FF8A00
FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF8A00FF8A00FF9900FFF500FFC700FFC700FF9900FF8A00
FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF8A00
FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFB800FFC700FFE600CCFF00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF85FFD700FFB800
FFA800FFA800FFA800FF8A00
FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF7A00FF7A00FF7A00FF8A00FF9900FFA800FFF500FFC700FFA800FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FFB800FFB800FFA800FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFB800FFD700FFF500EBFF00
70FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFF500FFF500
FFD700FFD70070FF00FF9900
FF6B00FF6B00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF9900FFB800EBFF00FFC700FFB800FFA800
FFA800FFA800FFA800FFA800FFA800FFB800BDFF0014FF00FFB800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFE60080FF0061FF0000B3FF
1400FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00B8FF0000
DCFF00CCFF00FFD700FF9900
FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF9900FFB800FAFF00FFF500FFD700FFD700
FFC700BDFF00FFB800FFB800FFB800FFD70070FF00FFF500FFD700FFB800FFB800FFB800
FFB800FFA800FFA800FFA800FFA800FFB800FFB800FFC700FFE60061FF000057FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF000051FF00FFE600FF9900
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF9900FFA800FFC700EBFF00EBFF0042FF00
EBFF0000F0FFFFE600FFD700FFD700FFE600FAFF00AEFF0000FF47FFF500FFD70005FF00
FFE600FFC700FFB800FFB800FFB800FFB800FFC700FFC700FFE600000AFFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFA3FF0000
00FF75FFD700FFA800FF8A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF8A00FF8A00FF8A00FF9900FF9900FFA800FFB800FFC700FFE600AEFF00
80FF0033FF0023FF00BDFF00FAFF00FAFF0070FF0000FF75FF00008FFF00EBFF008FFF00
DCFF00FFD700FFD700FFC700FFC700FFC700FFC700FFD70014FF00FF00005100FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000EBFF00
FFC700FFA800FF9900FF8A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF7A00FF7A00FF7A00FF7A00
FF7A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FFA800FFB800FFC700FFE60033FF00
42FF00FF0000FF000000FFA39EFF000047FF00FFFF00D1FFFF0000FF00008F00FF00FFFF
0038FFCCFF00BDFF00FFE600FFD700FFD700FFD700FFE600CCFF0033FF00FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000005FF00
FFD700FFB800FF9900FF8A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF9900FF9900FFA800FFA800FFB800FFC700DCFF00BDFF00
00FF38FF0000FF000000FF94FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF000005FF0000D1FF9EFF00FFF500FFE600FFE600FAFF0000FF66FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
05FF0005FF00FFA800FF8A00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00
FF8A00FF8A00FF9900FF9900FF9900FFA800FFA800FFC700FFC700FFD700FFF500DCFF00
80FF0000FF94FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000BDFF00FAFF00FAFF00EBFF00FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
00FF47BDFF00FF9900FF8A00
FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00
FF9900FF9900FF9900FF9900FFA800FFA800FFB800FAFF00EBFF00CCFF009EFF000057FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF000000FF19DCFF00CCFF00FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00D7
FFC700FFA800FF9900FF8A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF9900
FFA800FFC700FFB800FFB800FFB800FFB800FFC700FFD700FAFF0000FF0AFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF000000FFA3AEFF009EFF00FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000C2FF
CCFF00FF9900FF8A00FF8A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900
FFA800DCFF00EBFF00FFC700FFC700FFD700FFD700FFE600EBFF0023FF007000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF000000FFC261FF00FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000094FF00FFF0
FFC700FF9900FF8A00FF7A00
FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FFA800
FFB800FFC700BDFF00FAFF00FFE60000FF28FFF500FAFF00CCFF00FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF000014FF00FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000F0FFFFD700
FFA800FF8A00FF8A00FF7A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FFA800FFA800
FFB800FFC700DCFF0014FF0000FFB300FF858FFF00AEFF008FFF00FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF85FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000B3FFFFD700FFA800
FF9900FF8A00FF8A00FF7A00
FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFB800FFC700FFC700
FFD700FAFF00EBFF008FFF00FF0000FF0000FF0000FF000014FF00FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00003300FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFF500FFB800FF9900
FF8A00FF8A00FF8A00FF7A00
FFA800FFA800FFB800FFD700FFB800FFB800FFB800FFB800FFC700FFC700DCFF00FFE600
FFF500DCFF0070FF0000FFD1FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFD700FFB800FFA800FF9900
FF8A00FF8A00FF8A00FF7A00
AE00FFFF00F5FF0000FF0000FF006BFF002EFF003DFF003DFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF000000FF47BDFF00FAFF00FFE600FFC700FFB800FFB800
FFA800FFA800FF9900FF9900
FFA800FFA800FFB800FFD700FFB800FFB800FFB800FFB800FFC700FFC700DCFF00FFE600
FFF500DCFF0070FF0000FFD1FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFD700FFB800FFA800FF9900
FF8A00FF8A00FF8A00FF7A00
FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFB800FFC700FFC700
FFD700FAFF00EBFF008FFF00FF0000FF0000FF0000FF000014FF00FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00003300FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFF500FFB800FF9900
FF8A00FF8A00FF8A00FF7A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FFA800FFA800
FFB800FFC700DCFF0014FF0000FFB300FF858FFF00AEFF008FFF00FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF85FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000B3FFFFD700FFA800
FF9900FF8A00FF8A00FF7A00
FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FFA800
FFB800FFC700BDFF00FAFF00FFE60000FF28FFF500FAFF00CCFF00FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF000014FF00FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000F0FFFFD700
FFA800FF8A00FF8A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900
FFA800DCFF00EBFF00FFC700FFC700FFD700FFD700FFE600EBFF0023FF007000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF000000FFC261FF00FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000094FF00FFF0
FFC700FF9900FF8A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF9900
FFA800FFC700FFB800FFB800FFB800FFB800FFC700FFD700FAFF0000FF0AFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF000000FFA3AEFF009EFF00FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000C2FF
CCFF00FF9900FF8A00FF8A00
FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00
FF9900FF9900FF9900FF9900FFA800FFA800FFB800FAFF00EBFF00CCFF009EFF000057FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF000000FF19DCFF00CCFF00FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00D7
FFC700FFA800FF9900FF8A00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00
FF8A00FF8A00FF9900FF9900FF9900FFA800FFA800FFC700FFC700FFD700FFF500DCFF00
80FF0000FF94FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000BDFF00FAFF00FAFF00EBFF00FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
00FF47BDFF00FF9900FF8A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF9900FF9900FFA800FFA800FFB800FFC700DCFF00BDFF00
00FF38FF0000FF000000FF94FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF000005FF0000D1FF9EFF00FFF500FFE600FFE600FAFF0000FF66FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
05FF0005FF00FFA800FF8A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF7A00FF7A00FF7A00FF7A00
FF7A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FFA800FFB800FFC700FFE60033FF00
42FF00FF0000FF000000FFA39EFF000047FF00FFFF00D1FFFF0000FF00008F00FF00FFFF
0038FFCCFF00BDFF00FFE600FFD700FFD700FFD700FFE600CCFF0033FF00FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000005FF00
FFD700FFB800FF9900FF8A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF8A00FF8A00FF8A00FF9900FF9900FFA800FFB800FFC700FFE600AEFF00
80FF0033FF0023FF00BDFF00FAFF00FAFF0070FF0000FF75FF00008FFF00EBFF008FFF00
DCFF00FFD700FFD700FFC700FFC700FFC700FFC700FFD70014FF00FF00005100FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000EBFF00
FFC700FFA800FF9900FF8A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF9900FFA800FFC700EBFF00EBFF0042FF00
EBFF0000F0FFFFE600FFD700FFD700FFE600FAFF00AEFF0000FF47FFF500FFD70005FF00
FFE600FFC700FFB800FFB800FFB800FFB800FFC700FFC700FFE600000AFFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFA3FF0000
00FF75FFD700FFA800FF8A00
FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF9900FFB800FAFF00FFF500FFD700FFD700
FFC700BDFF00FFB800FFB800FFB800FFD70070FF00FFF500FFD700FFB800FFB800FFB800
FFB800FFA800FFA800FFA800FFA800FFB800FFB800FFC700FFE60061FF000057FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF000051FF00FFE600FF9900
FF6B00FF6B00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF9900FFB800EBFF00FFC700FFB800FFA800
FFA800FFA800FFA800FFA800FFA800FFB800BDFF0014FF00FFB800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFE60080FF0061FF0000B3FF
1400FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00B8FF0000
DCFF00CCFF00FFD700FF9900
FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF7A00FF7A00FF7A00FF8A00FF9900FFA800FFF500FFC700FFA800FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FFB800FFB800FFA800FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFB800FFD700FFF500EBFF00
70FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFF500FFF500
FFD700FFD70070FF00FF9900
FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF8A00FF8A00FF9900FFF500FFC700FFC700FF9900FF8A00
FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF8A00
FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFB800FFC700FFE600CCFF00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF85FFD700FFB800
FFA800FFA800FFA800FF8A00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF8A00FFA800FF9900FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FFA800FFC700BDFF0042FF00
FF0000FF000000FF47FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000CCFF00FAFF00FFC700FFA800
FF9900FF9900FF8A00FF8A00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FFA800FFE600BDFF0023FF00
9EFF0000C2FFCCFF000500FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000AEFF00FFF500FFD700FFB800FFA800
FF9900FF8A00FF8A00FF7A00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00
FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FFA800FFB800FFD700
00FF85FFE600FFF500FF00008FFF0000C2FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000038FFFFF500FFB800FFA800
FF9900FF8A00FF7A00FF7A00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF8A00FF7A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FFA800FFA800
FFB800FFC700FFD700FFF500DCFF0061FF0000FF94FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF000000B3FFFF0000FF0000FF0000FF000061FF0014FF00FFA800
FF9900FF8A00FF7A00FF7A00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF6B00FF7A00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF7A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FFA800
FFA800FFB800FFC7008FFF0070FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00003300FFAEFF00FFD700FFB800
FF9900FF8A00FF7A00FF7A00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00
FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900
FFA800FFB800FFC7009EFF0051FF00FF0000FF0000FF0000FF000061FF00FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00009EFF00FAFF00BDFF0000C2FFFF0000FF0000FF000033FF00EBFF00DCFF00
FFA800FF8A00FF7A00FF7A00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF6B00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF9900
FFA800FFB800FFE600FAFF0000FFB3FF0000FF0000FF000000D1FFDCFF000019FF05FF00
BD00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
8FFF00BDFF00FFF500FFD700FFE600DCFF0051FF00EBFF00AEFF00EBFF009EFF00DCFF00
FFC700FF8A00FF7A00FF7A00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF9900
FF9900FFC700CCFF0080FF0000B3FF33FF008FFF00FF00F561FF00FFE600FFF500EBFF00
FF0000FF000023FF0000FFA3FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000E1FFFF000000A3FFFF0000
61FF00FFF500FFC700FFB800FFC70080FF00EBFF00FFC700FFC700FFF500EBFF00FFB800
FFC700FF8A00FF7A00FF7A00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF9900
FF9900FFB800FFF5000038FF51FF00CCFF00FFF500FFE600FFC700FFC700FFD70000FF57
00FF8542FF00DCFF0000FF94FF000000FF6651FF0000FF0AFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00009EFF0000FFC2FAFF00FAFF0061FF00
00FF47FFD700FFB800FFA800FFA800FFA800FFA800FFA800FFB800FFF500FAFF00FFA800
FF8A00FF8A00FF7A00FF7A00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00
FF9900FFF500FFF500FFD700FFE600DCFF00FFF500FFB800FFB800FFB800FFB800FFD700
CCFF0000FFB3FFD700FFE600FFF500FFF500EBFF00CCFF000075FFFF0000FF0000FF0000
FF0000FF0000FF00002300FFCCFF00FAFF00FFF500FFE600FFE600FFC700FFD700FFF500
FFD700FFA800FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFB800BDFF00FF9900
FF8A00FF7A00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00
FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00
FF8A00FF9900FFA800FF9900FFA800FFC700FFB800FFA800FFA800FFA800FFA800FFA800
FFB800FFB800FFB800FFC700FFC700FFE600FAFF002300FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF000042FF00FAFF00FFD700FFC700FFB800FFB800FFB800FFA800
FFA800FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF9900BDFF00FFA800FF8A00
FF7A00FF7A00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF6B00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FFA800
FFA800FFA800FFA800FFB800FFC700FFD70000FF572300FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000094FFDCFF00FFD700FFB800FFA800FFA800FF9900FF9900
FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00
FF7A00FF6B00FF6B00FF6B00
FF5C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900
FF9900FF9900FFA800FFA800FFB80033FF008F00FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF000061FF00DCFF00FFB800FFA800FF9900FF9900FF9900
FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF9900FF9900FF9900FFA800FFB800FFE600BDFF00FF00F5FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000047FFCCFF00FFD700FFB800FFA800FF9900FF9900FF8A00
FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF8A00FF8A00FF8A00
FF8A00FF9900FF9900FFA800FFB800FFD70061FF0000FF94FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00001400FFFF008AFAFF00FFE600FF9900FF9900FF8A00FF8A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00
FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00
FF8A00FF8A00FF9900FFA800FFD700FFF500BDFF0080FF00EB00FF00F0FFFF0000FF0000
FF0000FF0000FF000042FF00FAFF008FFF00FFF500FFB800FF9900FF8A00FF8A00FF7A00
FF8A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF4C00FF4C00FF4C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF6B00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF8A00FF8A00FF9900FF9900FFE600FAFF00EBFF00AEFF00FFF500CCFF00BDFF00FF00F5
FF0000FF000000FF66FFF500FFD700FFE600FFE600FFB800FF9900FF8A00FF8A00FF7A00
FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF8A00FF8A00FF8A00FF9900FFA80051FF00FFC700FFC700FFE600DCFF00FF00D7
AE00FF00FF9405FF00FAFF00FFB800FFA800FFA800FF9900FF8A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00
FF6B00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF8A00FF8A00FF8A00FF9900FFA800FFA800FFB800FFC700FFF500FAFF00
9EFF00CCFF00FFF500FFD700FFA800FFA800FF9900FF9900FF8A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00
FF5C00FF6B00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF9900FF9900FFA800FFB800FFC700FFD700
CCFF00CCFF00FFD700FFC700FFA800FF9900FF9900FF8A00FF8A00FF7A00FF7A00FF7A00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF5C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF9900FF9900FFA800FFB800FFD700
CCFF00AEFF008FFF00FFC700FFB800FF9900FF8A00FF8A00FF7A00FF7A00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF9900FFA800FFA800FFC700EBFF00
EBFF00FFC700FFE6008FFF0080FF00FFA800FF8A00FF7A00FF7A00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF9900FFD700FFE60033FF00
FFB800FFA800FFA800FFA800FFC700FFB800FF8A00FF7A00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF8A00FF8A00FF9900FFC70023FF00FFC700
FFA800FF9900FF9900FF8A00FF9900FF8A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF6B00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF8A00FF8A00FFA800FFD700FFC700FFA800
FF9900FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF8A00FF9900FFB8009EFF00FFC700FF9900
FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FFB800FFB800FF9900FF9900FF8A00
FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00
FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00
FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF6B00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00
FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF6B00FF5C00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF5C00FF5C00FF4C00
FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF4C00FF4C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF4C00FF4C00FF4C00FF4C00
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`006Oooool2o`0002_ooooo1Ol00003ooooo`;o0000
:_ooool3o`0000?ooooo0_l0000Zooooo`?o00001?ooool2o`0002Wooooo0ol00004ooooo`;o0000
9oooool3o`0000Cooooo0_l00004ooooo`;o00000oooool001Sooooo00Co0000oooooooooooo0000
:oooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0002[ooooo00Go0000oooo
ooooooooooooo`000002ooooo`03o`000?oooooooooo02Kooooo00Go0000ooooooooooooooooo`00
0002ooooo`04o`000?ooooooooooo`0002Oooooo00Go0000ooooooooooooooooo`000002ooooo`04
o`000?ooooooooooo`0002Oooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00002
ooooo`04o`000?ooooooooooo`0000;ooooo000Hooooo`04o`000?ooooooooooo`0002cooooo00?o
0000ooooooooool00_ooool01?l0003oooooooooool0000Wooooo`Go00000_ooool01?l0003ooooo
ooooool0000Xooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool0000W
ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool0000Wooooo`03o`00
0?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002oooo
o`006?ooool01?l0003oooooooooool0000]ooooo`05o`000?ooooooooooooooool000000_ooool0
0ol0003oooooooooo`0Uooooo`04o`000?ooooooooooo`0000?ooooo00Co0000oooooooooooo0000
:?ooool4o`0000?ooooo00Co0000oooooooooooo0000:?ooool3o`0000?ooooo00Co0000oooooooo
oooo00009oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000
oooooooooooo00000_ooool001Sooooo00Co0000oooooooooooo0000:_ooool01Ol0003ooooooooo
oooooooo000000;ooooo00Co0000oooooooooooo0000:?ooool00ol0003oooooo`000003ooooo`04
o`000?ooooooooooo`0002Sooooo00?o0000ooooooooool01?ooool01?l0003oooooooooool0000W
ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool0000Wooooo`03o`00
0?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002oooo
o`006?ooool01?l0003oooooooooool0000Zooooo`05o`000?ooooooooooooooool000000_ooool0
1?l0003oooooooooool0000Yooooo`;o00000oooool01?l0003oooooooooool0000Yooooo`03o`00
0?oooooooooo00?ooooo00Co0000oooooooooooo00009oooool01Ol0003ooooooooooooooooo0000
00;ooooo00Co0000oooooooooooo00009_ooool2o`0000Cooooo00Co0000oooooooooooo00000_oo
ool01?l0003oooooooooool00002ooooo`006Oooool2o`0002cooooo0ol00004ooooo`;o0000:ooo
ool00ol0003oooooooooo`02ooooo`;o0000:oooool2o`0000Cooooo0_l0000Yooooo`?o00001?oo
ool2o`0002Sooooo00?o0000ooooooooool00oooool2o`0000Cooooo0_l00003ooooo`00oooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`005Oooooooo`0000So00001?oo
ool001Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`005Oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0;oooool00ol0
003oooooooooo`0`ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0<?ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo000>ooooo`;o00001Oooool00ol0003o
ooooooooo`3oooooo`Cooooo00?o0000ooooooooool00_ooool000gooooo00Co0000oooooooooooo
00001?ooool00ol0003oooooooooo`3oooooo`Cooooo00?o0000ooooooooool00_ooool000gooooo
00Co0000oooooooooooo00001?ooool2o`000?oooooo0oooool3o`0000Cooooo000=ooooo`04o`00
0?ooooooooooo`0000Cooooo00?o0000ooooooooool00_oooomR0?m<00D0oe`03@3oC01_0?mL00l0
od`00P3oG0080?m<00Gooooo00?o0000ooooooooool00_ooool000gooooo00Co0000oooooooooooo
00001?ooool00ol0003oooooooooo`02ooooof80od`01@3oG00=0?m<06l0oe`03`3oC0020?mL00P0
od`01Oooool00ol0003oooooooooo`02ooooo`003Oooool01?l0003oooooooooool00004ooooo`03
o`000?oooooooooo00;oooooHP3oC0050?mL00d0od`0K`3oG00?0?m<0080oe`0203oC005ooooo`03
o`000?oooooooooo00;ooooo000>ooooo`;o00001Oooool00ol0003oooooooooo`02ooooodh0od`0
0`3oG00D0?m<00L0oe`01@3oC01b0?mL00`0od`00`3oG00:0?m<00Gooooo00?o0000ooooooooool0
0_ooool001Gooooo00?o0000ooooooooool00_oooom>0?m<00<0oe`0503oC0070?mL00D0od`0LP3o
G00<0?m<00<0oe`02P3oC005ooooo`03o`000?oooooooooo00;ooooo000Eooooo`03o`000?oooooo
oooo00;oooooD@3oC0020?mL00l0od`0A`3oG0020?m[00<0oe`00P3oJ`030?mL0080of/0<03oG005
0?m<00D0oe`03@3oC005ooooo`03o`000?oooooooooo00;ooooo000Eooooo`03o`000?oooooooooo
00;oooooD@3oC0020?mL00l0od`0A`3oG0020?m[00<0oe`00P3oJ`030?mL0080of/0<03oG0050?m<
00D0oe`03@3oC005ooooo`03o`000?oooooooooo00;ooooo000Eooooo`03o`000?oooooooooo00;o
ooooD@3oC0020?mL00l0od`0A`3oG0020?m[00<0oe`00P3oJ`030?mL0080of/0<03oG0050?m<00D0
oe`03@3oC005ooooo`03o`000?oooooooooo00;ooooo000Eooooo`03o`000?oooooooooo00;ooooo
203oC0020?mL04L0od`01@3oG00<0?m<0480oe`00P3oJ`030?mL00`0of/00`3oG0020?m[00<0oe`0
0`3oJ`0_0?mL00d0od`01Oooool00ol0003oooooooooo`02ooooo`005Oooool00ol0003ooooooooo
o`02ooooo`P0od`00P3oG0170?m<00D0oe`0303oC0120?mL0080of/00`3oG00<0?m[00<0oe`00P3o
J`030?mL00<0of/0;`3oG00=0?m<00Gooooo00?o0000ooooooooool00_ooool001Gooooo00?o0000
ooooooooool00_ooooll0?m<00<0oe`04P3oC00:0?mL0080od`0@P3oG00Q0?m[0080oe`00`3oJ`0Z
0?mL00d0od`01Oooool00ol0003oooooooooo`02ooooo`005Oooool00ol0003oooooooooo`02oooo
oc`0od`00`3oG00B0?m<00X0oe`00P3oC0120?mL0240of/00P3oG0030?m[02X0oe`03@3oC005oooo
o`03o`000?oooooooooo00;ooooo000Eooooo`;o00000oooooll0?m<00<0oe`04P3oC00:0?mL0080
od`0@P3oG00Q0?m[0080oe`00`3oJ`0Z0?mL00d0od`01?ooool2o`0000Cooooo000Eooooo`03o`00
0?oooooooooo00;ooooo?`3oC0030?mL00l0od`0@@3oG0030?m[00D0oe`0:`3oJ`020?mL00<0of/0
:03oG0070?m<00<0oe`01Oooool00ol0003oooooooooo`02ooooo`005Oooool00ol0003ooooooooo
o`02ooooocl0od`00`3oG00?0?m<0440oe`00`3oJ`050?mL02/0of/00P3oG0030?m[02P0oe`01`3o
C0030?mL00Gooooo00?o0000ooooooooool00_ooool001Gooooo00?o0000ooooooooool00_oooolo
0?m<00D0oe`03@3oC00j0?mL0080of/0203oG00A0?m[00l0ogX06P3oJ`0]0?mL00Gooooo00?o0000
ooooooooool00_ooool001Gooooo00?o0000ooooooooool00_oooolo0?m<00D0oe`03@3oC00j0?mL
0080of/0203oG00A0?m[00l0ogX06P3oJ`0]0?mL00Gooooo00?o0000ooooooooool00_ooool001Go
oooo00?o0000ooooooooool00_oooolo0?m<00D0oe`03@3oC00j0?mL0080of/0203oG00A0?m[00l0
ogX06P3oJ`0]0?mL00Gooooo00?o0000ooooooooool00_ooool001Gooooo00?o0000ooooooooool0
0_oooolo0?m<00P0oe`01@3oC0110?mL00<0of/00P3oG00B0?m[00D0ogX01@3o^0050?nI0080ohX0
203oNP0B0?m[0080oe`00`3oJ`0X0?mL00Gooooo00?o0000ooooooooool00_ooool001Gooooo00?o
0000ooooooooool00_oooolo0?m<00P0oe`01@3oC0110?mL00<0of/00P3oG00B0?m[00D0ogX01@3o
^0050?nI0080ohX0203oNP0B0?m[0080oe`00`3oJ`0X0?mL00Gooooo00?o0000ooooooooool00_oo
ool001Gooooo00?o0000ooooooooool00_ooool[0?m<0080oe`04P3oC01>0?mL01@0of/01@3oNP03
0?n:0080oiT00`3o^00209ko00<0olL00P3oV@030?n:00l0ogX03@3oJ`020?mL00<0of/08`3oG005
ooooo`03o`000?oooooooooo00;ooooo000Eooooo`03o`000?oooooooooo00;ooooo:`3oC0020?mL
0180od`0CP3oG00D0?m[00D0ogX00`3oRP020?nI00<0okP00P2No`030?o70080oiT00`3oRP0?0?mj
00d0of/00P3oG0030?m[02<0oe`01Oooool00ol0003oooooooooo`02ooooo`005Oooool00ol0003o
ooooooooo`02ooooob/0od`00P3oG00B0?m<04h0oe`0503oJ`050?mj00<0ohX00P3oV@030?nh0080
W_l00`3oa`020?nI00<0ohX03`3oNP0=0?m[0080oe`00`3oJ`0S0?mL00Gooooo00?o0000oooooooo
ool00_ooool001Gooooo00?o0000ooooooooool00_oooolD0?m<00<0oe`05P3oC0030?mL00l0od`0
?03oG0030?m[00P0oe`06`3oJ`050?mj00D0ohX00`3oZ0020?oG00<0olL00P3oZ0030?nI00X0ohX0
1@3oNP0B0?m[02<0oe`01Oooool00ol0003oooooooooo`02ooooo`005Oooool2o`0000?ooooo503o
C0030?mL01H0od`00`3oG00?0?m<03`0oe`00`3oJ`080?mL01/0of/01@3oNP050?n:00<0ojP00P3o
e`030?o70080ojP00`3oV@0:0?n:00D0ogX04P3oJ`0S0?mL00Cooooo0_l00004ooooo`005Oooool0
0ol0003oooooooooo`02ooooobd0od`01@3oG00:0?m<0480oe`00`3oJ`050?mL01T0of/01`3oNP05
0?n:00<0oiT00P3oa`0302?o0080olL00`3oZ0050?nI00<0ohX00P3oV@030?n:00D0ogX0503oJ`0N
0?mL00Gooooo00?o0000ooooooooool00_ooool001Gooooo00?o0000ooooooooool00_ooool]0?m<
00D0oe`02P3oC0120?mL00<0of/01@3oG00I0?m[00L0ogX01@3oRP030?nI0080olL00`0So`020?o7
00<0ojP01@3oV@030?n:0080oiT00`3oRP050?mj01@0of/07P3oG005ooooo`03o`000?oooooooooo
00;ooooo000Eooooo`03o`000?oooooooooo00;ooooo;@3oC0050?mL00X0od`0@P3oG0030?m[00D0
oe`06@3oJ`070?mj00D0ohX00`3oV@020?o700<08ol00P3oa`030?nX00D0oiT00`3oRP020?nI00<0
ohX01@3oNP0D0?m[01h0oe`01Oooool00ol0003oooooooooo`02ooooo`005Oooool00ol0003ooooo
ooooo`02ooooobd0od`0D@3oG00N0?m[00X0ogX01@3oRP030?nI0080omL00`3oiP0203?o00<0okP0
203oZ0020?o700<0okP00P3oRP050?mj0180of/07P3oG005ooooo`03o`000?oooooooooo00;ooooo
000Eooooo`03o`000?oooooooooo00;ooooo;@3oC01A0?mL01h0of/02P3oNP050?n:00<0oiT00P3o
e`030?oV0080<ol00`3o^0080?nX0080olL00`3o^0020?n:00D0ogX04P3oJ`0N0?mL00Gooooo00?o
0000ooooooooool00_ooool001Gooooo00?o0000ooooooooool00_oooolI0?m<00<0oe`04@3oC019
0?mL00<0of/00P3oG00L0?m[00d0ogX01@3oRP020?nI00D0ojP00`3oa`050>_o0080olL00`3oiP03
08oo0080P?l00`3oZ0020?n:00P0ogX0503oJ`0I0?mL00Gooooo00?o0000ooooooooool00_ooool0
01Gooooo00?o0000ooooooooool00_oooolI0?m<00<0oe`04@3oC0190?mL00<0of/00P3oG00L0?m[
00d0ogX01@3oRP020?nI00D0ojP00`3oa`050>_o0080olL00`3oiP0308oo0080P?l00`3oZ0020?n:
00P0ogX0503oJ`0I0?mL00Gooooo00?o0000ooooooooool00_ooool001Gooooo00?o0000oooooooo
ool00_oooolI0?m<00<0oe`04@3oC0190?mL00<0of/00P3oG00L0?m[00d0ogX01@3oRP020?nI00D0
ojP00`3oa`050>_o0080olL00`3oiP0308oo0080P?l00`3oZ0020?n:00P0ogX0503oJ`0I0?mL00Go
oooo00?o0000ooooooooool00_ooool001Gooooo00?o0000ooooooooool00_oooolL0?m<00D0oe`0
2P3oC0110?mL00<0of/01`3oG00O0?m[00`0ogX0203oRP050?nI0080ojP00`3o^0020?oG00<0c?l0
0P2^o`0308oo00<0olL00P3o^0030?nI00D0ohX01`3oNP0B0?m[0080oe`00`3oJ`0D0?mL00Gooooo
00?o0000ooooooooool00_ooool001Gooooo00?o0000ooooooooool00_oooolL0?m<00D0oe`02P3o
C0110?mL00<0of/01`3oG00O0?m[00`0ogX0203oRP050?nI0080ojP00`3o^0020?oG00<0c?l00P2^
o`0308oo00<0olL00P3o^0030?nI00D0ohX01`3oNP0B0?m[0080oe`00`3oJ`0D0?mL00Gooooo00?o
0000ooooooooool00_ooool001Gooooo00?o0000ooooooooool00_oooolL0?m<05<0oe`08`3oJ`0=
0?mj00L0ohX01@3oV@030?nX0080okP00`3oa`020?oG00D0c?l00`3oe`030?o70080ojP01@3oV@05
0?n:00X0ogX04P3oJ`0D0?mL00Gooooo00?o0000ooooooooool00_ooool001Gooooo00?o0000oooo
ooooool00_oooolL0?m<05<0oe`08`3oJ`0=0?mj00L0ohX01@3oV@030?nX0080okP00`3oa`020?oG
00D0c?l00`3oe`030?o70080ojP01@3oV@050?n:00X0ogX04P3oJ`0D0?mL00Gooooo00?o0000oooo
ooooool00_ooool001Gooooo0_l00003oooooa`0od`0D`3oG00S0?m[00d0ogX01`3oRP050?nI00<0
ojP00P3o^0030?o70080omL01@3<o`030?oG00<0olL00P3oZ0050?nI00D0ohX02P3oNP0B0?m[01@0
oe`01?ooool2o`0000Cooooo000Eooooo`03o`000?oooooooooo00;ooooo203oC0020?mL0180od`0
B@3oG0020?m[00D0oe`08@3oJ`0?0?mj00P0ohX00P3oV@050?nX00<0okP00P3oa`030?oe0080n_l0
0`2No`020<co00<0ooD00`3oe`050?nX00D0oiT00P3oRP0=0?mj01@0of/01`3oG0030?m[00D0oe`0
1Oooool00ol0003oooooooooo`02ooooo`005Oooool00ol0003oooooooooo`02ooooo`P0od`00P3o
G00B0?m<04T0oe`00P3oJ`050?mL0240of/03`3oNP080?n:0080oiT01@3oZ0030?nh0080olL00`3o
m@020?[o00<0W_l00P3<o`030?oe00<0omL01@3oZ0050?nI0080ohX03@3oNP0D0?m[00L0oe`00`3o
J`050?mL00Gooooo00?o0000ooooooooool00_ooool001Gooooo00?o0000ooooooooool00_ooool:
0?m<00<0oe`03`3oC00o0?mL0080of/0203oG00S0?m[0180ogX01`3oRP030?nI0080ojP00`1Ao`05
0?o70080onH00`3Lo`020?l0e`<0[P3o0P00oi@300Go00<0n_l00P3o^0050?nX00<0oiT01@3oRP0:
0?mj01H0of/00`3oG0020?m[00P0oe`01Oooool00ol0003oooooooooo`02ooooo`005Oooool00ol0
003oooooooooo`02ooooo`X0od`00`3oG00?0?m<03l0oe`00P3oJ`080?mL02<0of/04P3oNP070?n:
00<0oiT00P3oZ003057o00D0olL00P3oiP030=co0080o`3G0`2^0?l2003oU0<01Ol00`3jo`020?nh
00D0ojP00`3oV@050?n:00X0ogX05P3oJ`030?mL0080of/0203oG005ooooo`03o`000?oooooooooo
00;ooooo000Eooooo`03o`000?oooooooooo00;ooooo2P3oC0030?mL00l0od`0?`3oG0020?m[00P0
oe`08`3oJ`0B0?mj00L0ohX00`3oV@020?nX00<0DOl01@3oa`020?oV00<0g?l00P3o0=L30:h0o`80
0?nD0`05o`030?[o0080okP01@3oZ0030?nI00D0ohX02P3oNP0F0?m[00<0oe`00P3oJ`080?mL00Go
oooo00?o0000ooooooooool00_ooool001Gooooo00?o0000ooooooooool00_ooool=0?m<00D0oe`0
1`3oC0140?mL00<0of/00P3oG00T0?m[0140ogX01@3oRP050?nI00<0onH00P3jo`030>_o0080[_l0
0`3om@020<co00<0_Ol00P3o0?D50?l000<00?mV0`3om@020?oG00D0onH00`3o^0020?nI00D0ohX0
2P3oNP0G0?m[00X0oe`01Oooool00ol0003oooooooooo`02ooooo`005Oooool00ol0003ooooooooo
o`02ooooo`d0od`01@3oG0070?m<04@0oe`00`3oJ`020?mL02@0of/04@3oNP050?n:00D0oiT00`3o
iP020?[o00<0jol00P2^o`030?oe0080c?l00`2mo`020?l0m@D0o`000`00ofH30?oe0080omL01@3o
iP030?nh0080oiT01@3oRP0:0?mj01L0of/02P3oG005ooooo`03o`000?oooooooooo00;ooooo000E
ooooo`03o`000?oooooooooo00;ooooo3@3oC0160?mL00<0of/01`3oG00N0?m[00<0ogX00`3oJ`0D
0?mj00L0ohX00`3oV@020?nX00<0omL00P3om@030;go0080P?l00`3[0?l2003`o`d0o`000`12o`02
0?[o00<0Sol00P3om@030?nh0080oiT01@3oRP030?mj0080ohX0203oNP0I0?m[00D0oe`01Oooool0
0ol0003oooooooooo`02ooooo`005Oooool00ol0003oooooooooo`02ooooo`d0od`0AP3oG0030?m[
00L0oe`07P3oJ`030?mj00<0of/0503oNP070?n:00<0oiT00P3oZ0030?oG0080ooD00`2mo`02083o
00<0j`3o0P00l?l=0?l000<0@_l00P3jo`0308oo0080ooD00`3o^0020?nI00D0ohX00`3oNP020?n:
00P0ogX06@3oJ`050?mL00Gooooo00?o0000ooooooooool00_ooool000Kooooo1Ol00003ooooo`;o
00001Oooool00ol0003oooooooooo`02ooooo`d0od`0AP3oG0030?m[00L0oe`07P3oJ`030?mj00<0
of/0503oNP070?n:00<0oiT00P3oZ0030?oG0080ooD00`2mo`02083o00<0j`3o0P00l?l=0?l000<0
@_l00P3jo`0308oo0080ooD00`3o^0020?nI00D0ohX00`3oNP020?n:00P0ogX06@3oJ`050?mL00Go
oooo00?o0000ooooooooool00_ooool000Oooooo00Co0000oooooooooooo00000_ooool01?l0003o
ooooooooool00004ooooo`03o`000?oooooooooo00;ooooo3@3oC0160?mL02H0of/04P3oNP020?n:
00<0ogX02P3oRP050?nI0080ojP00`3o^0020?oG00<0HOl00P00oi@E0?l00080503o0`3o08X20?[o
00<0onH01@3oV@050?n:0140ogX0503oJ`030?mL00Gooooo00?o0000ooooooooool00_ooool000So
oooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo
00;ooooo3@3oC0160?mL02H0of/04P3oNP020?n:00<0ogX02P3oRP050?nI0080ojP00`3o^0020?oG
00<0HOl00P00oi@E0?l00080503o0`3o08X20?[o00<0onH01@3oV@050?n:0140ogX0503oJ`030?mL
00Gooooo00?o0000ooooooooool00_ooool000Wooooo00Go0000ooooooooooooooooo`000002oooo
o`03o`000?oooooooooo00;ooooo0_l00003ooooo`d0od`0<P3oG0030?m[0140oe`08@3oJ`0D0?mj
00l0ohX0203oV@020?nX00<0okP00P3oiP030;go0080o`3e5@3o00020017o`<0c?l00P3oe`030?nh
0080ojP01@3oV@080?n:0140ogX00`3oJ`020?mj00d0of/00oooool3o`0000Cooooo0006ooooo`05
o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooo
oooo00;ooooo3@3oC00b0?mL00<0of/04@3oG00Q0?m[01@0ogX03`3oRP080?nI0080ojP00`3o^002
0?oV00<0_Ol00P3o0?DE0?l0008004Oo0`3<o`020?oG00<0okP00P3oZ0050?nI00P0ohX04@3oNP03
0?m[0080ogX03@3oJ`05ooooo`03o`000?oooooooooo00;ooooo0006ooooo`05o`000?oooooooooo
ooooool000000_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo00;ooooo3@3o
C00b0?mL00<0of/04@3oG00Q0?m[01@0ogX03`3oRP080?nI0080ojP00`3o^0020?oV00<0_Ol00P3o
0?DE0?l0008004Oo0`3<o`020?oG00<0okP00P3oZ0050?nI00P0ohX04@3oNP030?m[0080ogX03@3o
J`05ooooo`03o`000?oooooooooo00;ooooo0007ooooo`?o00001?ooool2o`0000Gooooo00?o0000
ooooooooool00_ooool30?mL00L0od`0@P3oG00U0?m[0100ogX0503oRP070?nI00D0ojP00`3o^002
03?o00<0S`3o6@3o0003067o0080g?l00`3o^0020?nX00P0oiT02P3oRP0A0?mj00d0of/01Oooool0
0ol0003oooooooooo`02ooooo`005Oooool00ol0003oooooooooo`02ooooo`<0oe`01`3oC0120?mL
02D0of/0403oNP0D0?n:00L0oiT01@3oZ0030?nh0080<ol00`2?0?lI0?l000<0HOl00P3Lo`030?nh
0080ojP0203oV@0:0?n:0140ogX03@3oJ`05ooooo`03o`000?oooooooooo00;ooooo000Eooooo`03
o`000?oooooooooo00;ooooo@P3oG0050?m[0080oe`08`3oJ`0=0?mj00d0ohX03`3oV@0:0?nX0080
okP00`3oa`020?oG00<00?mG0P0S0?lE0?l0008009Co0`3Lo`020?oG00<0okP01@3oZ0070?nI01L0
ohX01`3oNP080?m[00Gooooo00?o0000ooooooooool00_ooool001Gooooo00?o0000ooooooooool0
0_oooom20?mL00D0of/00P3oG00S0?m[00d0ogX03@3oRP0?0?nI00X0ojP00P3o^0030?o70080omL0
0`00oeL202<0oaD0o`000P00U?l30=co0080omL00`3o^0050?nX00L0oiT05`3oRP070?mj00P0of/0
1Oooool00ol0003oooooooooo`02ooooo`005Oooool00ol0003oooooooooo`02oooood80oe`01@3o
J`020?mL02<0of/03@3oNP0=0?n:00l0oiT02P3oZ0020?nh00<0olL00P3oe`03003oE`808`3o5@3o
0002002Do`<0g?l00P3oe`030?nh00D0ojP01`3oV@0G0?n:00L0ogX0203oJ`05ooooo`03o`000?oo
oooooooo00;ooooo000Eooooo`03o`000?oooooooooo00;ooooo=`3oG0030?m[00P0oe`0:03oJ`0<
0?mj00D0ohX00`3oV@030?nX0080oiT00`3oZ0020?o700<0okP0303oZ0080?nh00D0olL00P3oiP03
0?[o00808`3o5@3o000204;o00<0n_l00P3oe`030?o700L0okP01@3oZ0080?nI00X0ohX00P3oV@03
0;go0080ojP00`3oRP050?mj00D0of/01Oooool00ol0003oooooooooo`02ooooo`005Oooool00ol0
003oooooooooo`02ooooocL0oe`00`3oJ`080?mL02P0of/0303oNP050?n:00<0oiT00`3oZ0020?nI
00<0ojP00P3oa`030?nh00`0ojP0203o^0050?o70080onH00`3jo`0202<0oaD0o`000P12o`030?[o
0080omL00`3oa`070?nh00D0ojP0203oV@0:0?n:0080oiT00`2mo`020?nX00<0ohX01@3oNP050?m[
00Gooooo00?o0000ooooooooool00_ooool001Gooooo00?o0000ooooooooool00_oooolV0?mL0080
of/0203oG0020?m[00D0oe`0;P3oJ`0?0?mj00D0ohX00P3oV@060?oe0080omL00`3oiP020=co00<0
ooD02P3o^0020?oG00<0c?l00P00ok<30?oG0080onH01@3om@030>_o0080c?l00`00MOl?0?l000<0
8`3o0P3<o`030?[o0080ooD01@3oiP030?o70080omL00`3om@020?oG00<0ojP03`3oV@020?nX00<0
okP00P2mo`030?nI0080ohX00`3oNP050?m[00Gooooo00?o0000ooooooooool00_ooool001Gooooo
00?o0000ooooooooool00_oooolV0?mL0080of/0203oG0020?m[00D0oe`0;P3oJ`0?0?mj00D0ohX0
0P3oV@060?oe0080omL00`3oiP020=co00<0ooD02P3o^0020?oG00<0c?l00P00ok<30?oG0080onH0
1@3om@030>_o0080c?l00`00MOl?0?l000<08`3o0P3<o`030?[o0080ooD01@3oiP030?o70080omL0
0`3om@020?oG00<0ojP03`3oV@020?nX00<0okP00P2mo`030?nI0080ohX00`3oNP050?m[00Gooooo
00?o0000ooooooooool00_ooool001Gooooo0_l00003ooooobH0oe`00P3oJ`080?mL0080of/01@3o
G00^0?m[00l0ogX01@3oRP020?nI00H0ooD00P3oe`030?oV0080g?l00`3om@0:0?nh0080omL00`3<
o`02003o/`<0omL00P3oiP050?oe00<0jol00P3<o`03001eo`l0o`000`0S0?l20<co00<0n_l00P3o
m@050?oV00<0olL00P3oe`030?oe0080omL00`3oZ00?0?nI0080ojP00`3o^0020;go00<0oiT00P3o
RP030?mj00D0of/01?ooool2o`0000Cooooo000Eooooo`03o`000?oooooooooo00;ooooo<03oG00`
0?m[01@0ogX00P3oRP050?nI00<0okP00`3om@02000ho`<0DOl00P3<o`030?oe0080onH01@3oa`03
0?oG00800?mG0`00ohD204;o00<0g?l00P00oi@30?l000800?mV0`1Ao`02003o2Q`0o`000`2No`02
003o`PD0n_l00`1Qo`02003oA`<0omL00P3o^00=0?nX0080okP00`3om@020?[o00<0ojP01@3oRP05
0?mj00Gooooo00?o0000ooooooooool00_ooool001Gooooo00?o0000ooooooooool00_ooool`0?mL
0300of/0503oNP020?n:00D0oiT00`3o^0030?oe008003So0`1Ao`020<co00<0ooD00P3oiP050?o7
00<0omL00P00oeL3003oQ@80@_l00`3Lo`02003oU0<0o`000P00ofH3057o00800?l:703o000309ko
00800?o21@3jo`03067o00800?m70`3oe`020?nh00d0ojP00P3o^0030?oe0080n_l00`3oZ0050?n:
00D0ogX01Oooool00ol0003oooooooooo`02ooooo`005Oooool00ol0003oooooooooo`02oooooc00
oe`0<03oJ`0D0?mj0080ohX01@3oV@030?nh00<0ooD00P00>?l3057o0080c?l00`3om@020?oV00D0
olL00`3oe`02003oE`<00?n50P12o`030=co00800?nD0`3o0002003oIP<0DOl00P00o`XL0?l000<0
W_l00P00ol850?[o00<0HOl00P00odL30?oG0080okP03@3oZ0020?nh00<0ooD00P3jo`030?nX00D0
ohX01@3oNP05ooooo`03o`000?oooooooooo00;ooooo000Eooooo`03o`000?oooooooooo00;ooooo
:03oG00e0?m[01@0ogX01@3oRP050?nI00<0olL00`3<o`02083o00<00;?o0P0co`0308oo0080o`3e
0`1Qo`020?oV00<0ooD00P3[o`050?l000<08ol00P00oj<Y0?l000800>7o0`3o0002002So`<0o`00
0P1Qo`030?oe0080olL00`3o^0020?o700<0P?l00P3[o`050?o700<0ooD00P3[o`030?nh0080olL0
0`3oRP050?mj00Gooooo00?o0000ooooooooool00_ooool001Gooooo00?o0000ooooooooool00_oo
oolX0?mL03D0of/0503oNP050?n:00D0oiT00`3oa`030<co0080P?l00`00/ol203?o00<0Sol00P3o
0?D3067o0080onH00`3om@020>_o00D0o`000`0So`02003oXbT0o`000P00hOl30?l000800:?o0`3o
0002067o00<0ooD00P3oa`030?nh0080olL00`20o`020>_o00D0olL00`3om@020>_o00<0okP00P3o
a`030?n:00D0ogX01Oooool00ol0003oooooooooo`02ooooo`005Oooool00ol0003oooooooooo`02
ooooob40oe`00P3oJ`050?mL02/0of/00`3oNP020?m[01@0ogX02P3oRP030?nI0080ojP00`3o^003
0?oV0080n_l00`00ok<70?l000<00=7o0P3Lo`03000Io`801Ol00`2m0?lj0?l00080Sol00`2mo`02
0?oe00<0omL00P3oiP030=co0080DOl00`3[o`020:ko00<0jol00P2No`030=co0080olL00`3oRP05
0?mj00Gooooo00?o0000ooooooooool00_ooool001Gooooo00?o0000ooooooooool00_oooolQ0?mL
0080of/01@3oG00[0?m[00<0ogX00P3oJ`0D0?mj00X0ohX00`3oV@020?nX00<0okP00`3oiP020?[o
00<00?nc1`3o0003003Ao`80g?l00`006Ol200Go00<0_@3o>P3o000208oo00<0_Ol00P3om@030?oG
0080onH00`3Lo`02057o00<0jol00P2^o`030>_o0080W_l00`3Lo`020?o700<0ohX01@3oNP05oooo
o`03o`000?oooooooooo00;ooooo000Eooooo`03o`000?oooooooooo00;ooooo8@3oG0020?m[00D0
oe`0:`3oJ`030?mj0080of/0503oNP0:0?n:00<0oiT00P3oZ0030?nh00<0onH00P3jo`03003o/`L0
o`000`00dOl20=co00<001Wo0P05o`030;d0ocX0o`000P2?o`030;go0080ooD00`3oe`020?oV00<0
g?l00P1Ao`030>_o0080[_l00`3[o`0209ko00<0g?l00P3oa`030?n:00D0ogX01Oooool00ol0003o
ooooooooo`02ooooo`005Oooool00ol0003oooooooooo`02oooooaT0oe`00`3oJ`070?mL02H0of/0
0`3oNP020?m[01`0ogX02P3oRP050?nI0080ojP00`3o^0030?o70080W_l00`1Ao`0:0?l00080HOl0
A`3o000209ko00<0n_l00P2mo`030032o`L0o`000`0co`020>_o00<0g?l00P3oZ0030?n:00D0ogX0
1Oooool00ol0003oooooooooo`02ooooo`005Oooool00ol0003oooooooooo`02oooooaT0oe`00`3o
J`070?mL02H0of/00`3oNP020?m[01`0ogX02P3oRP050?nI0080ojP00`3o^0030?o70080W_l00`1A
o`0:0?l00080HOl0A`3o000209ko00<0n_l00P2mo`030032o`L0o`000`0co`020>_o00<0g?l00P3o
Z0030?n:00D0ogX01Oooool00ol0003oooooooooo`02ooooo`005Oooool00ol0003oooooooooo`02
oooooa`0oe`07P3oJ`020?mj00<0of/00`3oNP020?m[01h0ogX00`3oRP020?mj00X0ohX01@3oV@05
0?nX00<0okP00`3oa`0208oo00<0L?l0HP3o000203<0o`<0[_l00P3oe`030?nh0080oiT00`3oRP05
0?mj00Gooooo00?o0000ooooooooool00_ooool001Gooooo00?o0000ooooooooool00_oooolL0?mL
01h0of/00P3oNP030?m[00<0ogX00P3oJ`0N0?mj00<0ohX00P3oNP0:0?n:00D0oiT01@3oZ0030?nh
00<0olL00P2?o`03073o0680o`000P0c0?l30:ko0080omL00`3o^0020?nI00<0ohX01@3oNP05oooo
o`03o`000?oooooooooo00;ooooo000Eooooo`;o00000ooooolL0?mL01h0of/00P3oNP030?m[00<0
ogX00P3oJ`0N0?mj00<0ohX00P3oNP0:0?n:00D0oiT01@3oZ0030?nh00<0olL00P2?o`03073o0680
o`000P0c0?l30:ko0080omL00`3o^0020?nI00<0ohX01@3oNP04ooooo`;o00001?ooool001Gooooo
00?o0000ooooooooool00_oooolD0?mL00<0of/01@3oG00F0?m[00<0ogX00P3oJ`0Y0?mj0080ohX0
0`3oNP0:0?n:00D0oiT01@3oZ0020?nh00<0olL00`3oe`020?oe00<0g?l00P1Qo`03003oU5<0o`00
0P00/ol:0?l000<0HOl00P0Do`030?nX0080oiT00`3oRP050?mj00Gooooo00?o0000ooooooooool0
0_ooool001Gooooo00?o0000ooooooooool00_oooolD0?mL00<0of/01@3oG00F0?m[00<0ogX00P3o
J`0Y0?mj0080ohX00`3oNP0:0?n:00D0oiT01@3oZ0020?nh00<0olL00`3oe`020?oe00<0g?l00P1Q
o`03003oU5<0o`000P00/ol:0?l000<0HOl00P0Do`030?nX0080oiT00`3oRP050?mj00Gooooo00?o
0000ooooooooool00_ooool001Gooooo00?o0000ooooooooool00_oooolG0?mL01H0of/0:`3oNP03
0?n:0080ogX03@3oRP070?nI00<0ojP00P3o^0030?oG00800?n50`3oiP030?oe0080o`000`2?o`02
0032of00o`000P00>?l30?oe0080okP00`3oZ0020?nI00<0ohX01@3oNP05ooooo`03o`000?oooooo
oooo00;ooooo000Eooooo`03o`000?oooooooooo00;ooooo5`3oG00F0?m[02/0ogX00`3oRP020?mj
00d0ohX01`3oV@030?nX0080okP00`3oe`02003oQ@<0onH00`3om@020?l000<0Sol00P00`_mP0?l0
008003So0`3om@020?nh00<0ojP00P3oV@030?n:00D0ogX01Oooool00ol0003oooooooooo`02oooo
o`005Oooool00ol0003oooooooooo`02oooooaL0oe`05P3oJ`0[0?mj00<0ohX00P3oNP0=0?n:00L0
oiT00`3oZ0020?nh00<0omL00P00ohD30?oV00<0ooD00P3o000308oo00800<;oH03o0002000ho`<0
ooD00P3o^0030?nX0080oiT00`3oRP050?mj00Gooooo00?o0000ooooooooool00_ooool001Gooooo
00?o0000ooooooooool00_oooolD0?mL01@0of/03@3oNP020?n:01D0ogX07P3oRP050?nI0080ojP0
0`3oiP020;go00<08ol00P2No`030032o`<0c?l00P050?mR0?l000<0[_l00P3om@030?oG0080okP0
0`3oZ0020?nI00D0ohX00`3oNP05ooooo`03o`000?oooooooooo00;ooooo000Eooooo`03o`000?oo
oooooooo00;ooooo503oG00D0?m[00d0ogX00P3oRP0E0?mj01h0ohX01@3oV@020?nX00<0onH00P2m
o`0302?o0080W_l00`00`_l30<co00801@3oHP3o00030:ko0080ooD00`3oe`020?nh00<0ojP00P3o
V@050?n:00<0ogX01Oooool00ol0003oooooooooo`02ooooo`005Oooool00ol0003oooooooooo`02
ooooo`l0oe`05`3oJ`070?mj00<0ohX00P3oZ0030?nI0300ohX02P3oV@020?nX00<0olL00P2mo`03
04;o00D0o`000`00odMW0?l00080c?l00`3jo`020?o700<0ojP01@3oV@050?n:00Gooooo00?o0000
ooooooooool00_ooool001Gooooo00?o0000ooooooooool00_ooool?0?mL01L0of/01`3oNP030?n:
0080ojP00`3oV@0`0?n:00X0oiT00P3oZ0030?o70080_Ol00`12o`050?l000<00?m7I`3o00020<co
00<0n_l00P3oa`030?nX00D0oiT01@3oRP05ooooo`03o`000?oooooooooo00;ooooo000Eooooo`03
o`000?oooooooooo00;ooooo3`3oG00G0?m[00L0ogX00`3oRP020?nX00<0oiT0<03oRP0:0?nI0080
ojP00`3oa`020;go00<0@_l01@3o0003003oAfL0o`000P3<o`030?[o0080olL00`3oZ0050?nI00D0
ohX01Oooool00ol0003oooooooooo`02ooooo`005Oooool00ol0003oooooooooo`02ooooo`P0oe`0
0P3oJ`050?mL01@0of/01@3oNP050?n:00<0oiT00P3om@050?o700<0oiT00P3oRP030?nI00d0ohX0
303oV@050?n:00l0oiT00`3oZ0020?nh00<0olL00P3oiP030<co0740o`000`00ohD20?oG00<0okP0
1`3oZ0030?n:00Gooooo00?o0000ooooooooool00_ooool001Gooooo0_l00003ooooo`P0oe`00P3o
J`050?mL01@0of/01@3oNP050?n:00<0oiT00P3om@050?o700<0oiT00P3oRP030?nI00d0ohX0303o
V@050?n:00l0oiT00`3oZ0020?nh00<0olL00P3oiP030<co0740o`000`00ohD20?oG00<0okP01`3o
Z0030?n:00Cooooo0_l00004ooooo`005Oooool00ol0003oooooooooo`02ooooo`P0oe`06@3oJ`0:
0?mj0080ohX00`3oV@020?nX00<0ooD00P3oa`030?nX0180oiT01@3o^0020?nX01@0oiT0203oZ002
0?nh00<0omL00P3om@030>_o0080L?l0LP3o00050?oe00D0omL00P1`o`030?nI00Gooooo00?o0000
ooooooooool00_ooool001Gooooo00?o0000ooooooooool00_ooool80?mL01T0of/02P3oNP020?n:
00<0oiT00P3oZ0030?oe0080olL00`3oZ00B0?nI00D0okP00P3oZ00D0?nI00P0ojP00P3o^0030?oG
0080ooD00`3[o`02073o0780o`001@3om@050?oG0080L?l00`3oV@05ooooo`03o`000?oooooooooo
00;ooooo000Eooooo`03o`000?oooooooooo00;ooooo203oG00I0?m[00X0ogX00P3oRP030?nI0080
ojP00`3om@020?o700<0ojP04P3oV@050?nh0080ojP0503oV@080?nX0080okP00`3oe`020?oe00<0
jol00P1`o`1b0?l000D0ooD01@3oe`02073o00<0oiT01Oooool00ol0003oooooooooo`02ooooo`00
5Oooool00ol0003oooooooooo`02ooooo`D0of/00`3oG00F0?m[00X0ogX01@3oRP030?nI0080okP0
0`3[o`020?o700<0okP03`3oZ0030?nh0080_Ol00`0Do`020?nh01T0ojP00`3o^0020?oV00<0P?l0
0P1Qo`03002co`80503oLP3o00020?l0^0<0o`000P3Lo`030<co0080omL00`3oV@05ooooo`03o`00
0?oooooooooo00;ooooo000Eooooo`03o`000?oooooooooo00;ooooo1@3oJ`030?mL01H0of/02P3o
NP050?n:00<0oiT00P3o^0030>_o0080olL00`3o^00?0?nX00<0okP00P2mo`0301Co0080okP06@3o
Z0030?nh0080onH00`20o`02067o00<00;?o0P0D0?mb0?l00080o`2h0`3o00020=co00<0c?l00P3o
e`030?nI00Gooooo00?o0000ooooooooool00_ooool001Gooooo00?o0000ooooooooool00_ooool3
0?mL01T0of/0303oNP050?n:00<0oiT00P3o^0030?[o0080ooD01@3oe`030?o700<0_Ol01`3o^003
0?oG0080L?l00`3om@020?oG00X0okP02P3oZ0050?nh00<0olL00P3oiP03067o008005OoOP3o0003
057o0080onH00`3oV@05ooooo`03o`000?oooooooooo00;ooooo000Eooooo`03o`000?oooooooooo
00;ooooo0`3oG00I0?m[00`0ogX01@3oRP030?nI0080okP00`3jo`020?oe00D0omL00`3oa`030;go
00L0okP00`3oe`02073o00<0ooD00P3oe`0:0?nh00X0ojP01@3o^0030?o70080onH00`1Qo`02001G
ogh0o`000`1Ao`020?oV00<0oiT01Oooool00ol0003oooooooooo`02ooooo`005Oooool00ol0003o
ooooooooo`02ooooo`<0oe`06@3oJ`0<0?mj00D0ohX00`3oV@020?nh00<0n_l00P3om@050?oG00<0
olL00`2mo`070?nh00<0omL00P1`o`030?oe0080omL02P3o^00:0?nX00D0okP00`3oa`020?oV00<0
HOl00P00Eomn0?l000<0DOl00P3oiP030?nI00Gooooo00?o0000ooooooooool00_ooool001Gooooo
00?o0000ooooooooool00_oooolG0?m[00l0ogX01`3oRP030?nI0080ojP00`3oa`050>_o0080@_l0
0`3[o`03003`o`80onH01@3oe`030?oV0080n_l00`2^o`02003oA`<0ooD00P3oe`0300Go0080onH0
0`3oa`0:0?nh00D0olL00P3oiP03000:ogT0o`000P00oj<30?l000800?me0`3oe`020?nX00<0ohX0
1Oooool00ol0003oooooooooo`02ooooo`002?ooool3o`0000?ooooo0_l00005ooooo`03o`000?oo
oooooooo00;ooooo5`3oJ`0?0?mj00L0ohX00`3oV@020?nX00<0olL01@3[o`0204;o00<0jol00`00
l?l20?oV00D0omL00`3oiP020?[o00<0[_l00P00odL30?oe0080omL00`05o`020?oV00<0olL02P3o
^0050?o70080onH00`002_mi0?l000800?nS0`3o0002003oM@<0omL00P3oZ0030?n:00Gooooo00?o
0000ooooooooool00_ooool000Wooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool00_oooolD0?m[00l0ogX0203oRP050?nI0080ojP00`3o
^0020?o700<0onH00P2^o`03083o00<0<ol00P0So`030;go00D0n_l00P1`o`03003oM@80o`000`2?
o`020>_o00<0Sol00P3Lo`050?oG00X0olL00`3oe`0201Co00<0o`000P1A0?mi0?l000<0jol00P3o
a`030?nX0080oiT00`3oRP05ooooo`03o`000?oooooooooo00;ooooo0006ooooo`Go00000_ooool0
1?l0003oooooooooool00004ooooo`03o`000?oooooooooo00;ooooo503oJ`0?0?mj00P0ohX01@3o
V@020?nX00<0okP00P3oa`030?oV0080[_l00`20o`0303?o00808ol00`2mo`050?[o0080L?l00`00
ogD20?l000<0Sol00P3[o`0308oo0080g?l01@3oe`0:0?o700<0omL00P0Do`030?l00080D@3oN@3o
00030>_o0080olL00`3oZ0020?nI00<0ohX01Oooool00ol0003oooooooooo`02ooooo`001_ooool0
1?l0003oooooooooool00003ooooo`04o`000?ooooooooooo`0000Cooooo0_l00003oooooa@0of/0
3`3oNP080?n:00D0oiT00P3oZ0030?nh0080olL00`3oiP020:ko00<0P?l00`0co`0202?o00<0_Ol0
1@3jo`02073o00<00?me0P3o000308oo0080jol00`2?o`020=co00D0omL02P3oa`030?oG00805?l0
0`3o00020540ogT0o`000`3[o`020?o700<0ojP00P3oV@030?n:00?ooooo0ol00004ooooo`001ooo
ool00ol0003oooooo`000003ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0
0_ooool?0?m[00<0ogX00P3oJ`0=0?mj00X0ohX01@3oV@020?nX00<0okP00P3oa`030?oV0080<ol0
0`12o`050?l000<00?nS0P2No`030017o`800?oo0`00dOl50?l00080S`3o0`00ool2000ho`<0c?l0
0P2mo`030?oV00L0omL00`3oiP020<co00<0<ol0N`3o000300Go0080omL00`3o^0020?nI00<0ohX0
1Oooool00ol0003oooooooooo`02ooooo`002?ooool2o`0000?ooooo00Co0000oooooooooooo0000
1?ooool00ol0003oooooooooo`02ooooo`l0of/00`3oNP020?m[00d0ogX02P3oRP050?nI0080ojP0
0`3o^0020?o700<0onH00P0co`0304;o00D0o`000`00oj<209ko00<004Oo0P00ool3003Ao`D0o`00
0P2?0?l3003oo`8003So0`3<o`020;go00<0onH01`3oe`030?oV0080c?l00`0co`1k0?l000<01Ol0
0P3oe`030?nh0080oiT00`3oRP05ooooo`03o`000?oooooooooo00;ooooo0009ooooo`03o`000?oo
oooooooo00;ooooo0_l00005ooooo`03o`000?oooooooooo00;ooooo3`3oJ`0=0?mj00`0ohX01@3o
V@050?nX00<0okP00P3oa`030=co0080_Ol00`00ocP50?l000<00?nD5P3o000300Go00800=7o0`2N
o`020?oe00D0onH00`3jo`02003oIX40o`001@05o`020?nX00<0ohX01Oooool00ol0003ooooooooo
o`02ooooo`005Oooool00ol0003oooooooooo`02ooooo`l0of/03@3oNP0<0?n:00D0oiT01@3oZ003
0?nh0080olL00`3Lo`020;go00<00?lh1@3o0003003oU1H0o`000`05o`02003Ao`<0W_l00P3om@05
0?oV00<0n_l00P00ofJ10?l000D01Ol00P3oZ0030?n:00Gooooo00?o0000ooooooooool00_ooool0
01Gooooo00?o0000ooooooooool00_ooool?0?m[00d0ogX0303oRP050?nI00D0ojP00`3o^0020?o7
00<0g?l00P2mo`03003o>0D0o`000`00oi@F0?l000<01Ol00P00dOl309ko0080ooD01@3oiP030?[o
00800?mVP@3o000500Go0080ojP00`3oRP05ooooo`03o`000?oooooooooo00;ooooo000Eooooo`03
o`000?oooooooooo00;ooooo203oJ`0D0?mj00L0ohX0203oV@050?nX00D0olL00P3oe`030?oe0080
g?l00`20o`03003oU2<0o`000P2mo`050?[o00<0jol0P`3o0002003oA`<0_Ol00P3oV@030?n:00Go
oooo00?o0000ooooooooool00_ooool001Gooooo00?o0000ooooooooool00_ooool80?m[01@0ogX0
1`3oRP080?nI00D0ojP01@3oa`020?oG00<0ooD00P3Lo`03083o00<00?nD8`3o00020;go00D0n_l0
0`3[o`230?l000800?m70`2mo`020?nI00<0ohX01Oooool00ol0003oooooooooo`02ooooo`005Ooo
ool00ol0003oooooooooo`02ooooo`<0of/0503oNP070?n:00X0oiT01@3oZ0030?nh0080n_l00`3[
o`020<co00<0W_l00P00Eol[0?l000<00?lI0P3Lo`030<co0800o`000`3o0=L20?o700<0ojP00P3o
V@030?n:00Gooooo00?o0000ooooooooool00_ooool001Gooooo00?o0000ooooooooool00_ooool3
0?m[01@0ogX01`3oRP0:0?nI00D0ojP00`3o^0020?[o00<0jol00P3<o`0309ko008005Oo:`3o0003
003o6@80g?l00`3<o`200?l000<0o`3G0P3oa`030?nX0080oiT00`3oRP05ooooo`03o`000?oooooo
oooo00;ooooo000Eooooo`03o`000?oooooooooo00;ooooo0`3oJ`0D0?mj00L0ohX02P3oV@050?nX
00<0okP00P3jo`030>_o0080c?l00`2No`02001Gob/0o`000`00oaT20=co00<0c?l0P03o00030?l0
e`80olL00`3oZ0020?nI00<0ohX01Oooool00ol0003oooooooooo`02ooooo`005Oooool00ol0003o
ooooooooo`02oooooa@0ogX0203oRP020?nI00<0ojP00P3oa`0:0?nh00<0olL00P3oe`030?[o0080
0?l:<03o0003003oX`80[_l00`2No`200?l000<00<;o0P3<o`030?nI00D0ohX01Oooool00ol0003o
ooooooooo`02ooooo`005Oooool00ol0003oooooooooo`02oooooa@0ogX0203oRP020?nI00<0ojP0
0P3oa`0:0?nh00<0olL00P3oe`030?[o00800?l:<03o0003003oX`80[_l00`2No`200?l000<00<;o
0P3<o`030?nI00D0ohX01Oooool00ol0003oooooooooo`02ooooo`005Oooool2o`0000?ooooo3`3o
NP0:0?n:00D0oiT00`3oZ0020=co00<0jol01@3oa`050?oG0080onH00`3[o`0202?o00<0L03o<03o
0002003o`P<0HOl0OP3o0002002Do`<00?o`0P3oa`030?nI0080ohX00`3oNP04ooooo`;o00001?oo
ool001Gooooo00?o0000ooooooooool00_ooool?0?mj00X0ohX01@3oV@030?nX0080g?l00`3[o`05
0?o700D0omL00P3oiP030>_o00808ol00`1`0?l`0?l000800?o20`1Qo`1n0?l0008009Co0`00oo02
0?o700<0oiT00P3oRP030?mj00Gooooo00?o0000ooooooooool00_ooool001Gooooo00?o0000oooo
ooooool00_ooool?0?mj00X0ohX01@3oV@030?nX0080g?l00`3[o`050?o700D0omL00P3oiP030>_o
00808ol00`1`0?l`0?l000800?o20`1Qo`1n0?l0008009Co0`00oo020?o700<0oiT00P3oRP030?mj
00Gooooo00?o0000ooooooooool00_ooool001Gooooo00?o0000ooooooooool00_ooool50?mj00l0
ohX0203oV@020?nX00<0okP00P3oa`030;go0080n_l00`3oiP02003o:0<0ooD00P3jo`030<co03L0
o`000`0Do`1n0?l000800?3o0`3oe`020?nX00D0ohX00`3oNP05ooooo`03o`000?oooooooooo00;o
oooo000Eooooo`03o`000?oooooooooo00;ooooo1@3oNP0?0?n:00P0oiT00P3oZ0030?nh0080olL0
0`2mo`020?[o00<0onH00P00obP30?oe0080n_l00`3<o`0g0?l000<05?l0OP3o0002003`o`<0omL0
0P3oZ0050?n:00<0ogX01Oooool00ol0003oooooooooo`02ooooo`005Oooool00ol0003ooooooooo
o`02ooooo`l0ohX02P3oV@050?nX00<0okP00P3oa`030=co00805?l00`00ok<2003oQ@<0Sol00P2^
o`0308oo03L0o`000`00ohEk0?l000<00;?o0P3oe`030?nX0080oiT01@3oRP030?mj00Gooooo00?o
0000ooooooooool00_ooool001Gooooo00?o0000ooooooooool00_ooool?0?n:00X0oiT01@3oZ003
0?nh0080olL00`3Lo`0201Co00<00?nc0P00ohD308oo0080[_l00`2?o`0g0?l000<00?n5N`3o0003
002co`80omL00`3oZ0020?nI00D0ohX00`3oNP05ooooo`03o`000?oooooooooo00;ooooo000Eoooo
o`03o`000?oooooooooo00;ooooo3`3oRP0:0?nI00D0ojP00`3o^0020?o700<0g?l00P0Do`03003o
/`800?n50`2?o`020:ko00<0Sol0=`3o0003003oQG/0o`000`00/ol20?oG00<0ojP00P3oV@050?n:
00<0ogX01Oooool00ol0003oooooooooo`02ooooo`005Oooool00ol0003oooooooooo`02ooooo`l0
oiT0203oZ0020?nh00D0olL00`3oe`020?[o00<0jol00P2?o`0:0?l000<05?l0=`3o000303<0og/0
o`000`3om@020?nh00<0oiT01`3oRP030?mj00Gooooo00?o0000ooooooooool00_ooool001Gooooo
00?o0000ooooooooool00_ooool?0?nI00P0ojP00P3o^0050?o700<0omL00P3jo`030>_o0080Sol0
2P3o000301Co03L0o`000`0c0?mk0?l000<0ooD00P3o^0030?nI00L0ohX00`3oNP05ooooo`03o`00
0?oooooooooo00;ooooo000Eooooo`03o`000?oooooooooo00;ooooo1@3oZ0030?nh0080omL02P3o
^0050?o700<0g?l00P3oiP030?oe0080g?l00`1`o`02003odL00o`000P3oe`030?nh0080ojP00`3o
V@070?n:00<0ogX01Oooool00ol0003oooooooooo`02ooooo`005Oooool00ol0003oooooooooo`02
ooooo`D0ojP00`3o^0020?oG00X0okP01@3oa`030=co0080onH00`3om@020=co00<0L?l00P00om70
0?l00080omL00`3o^0020?nX00<0oiT01`3oRP030?mj00Gooooo00?o0000ooooooooool00_ooool0
01Gooooo0_l00003ooooo`D0ojP00`3o^0020?oG00X0okP01@3oa`030=co0080onH00`3om@020=co
00<0L?l00P00om700?l00080omL00`3o^0020?nX00<0oiT01`3oRP030?mj00Cooooo0_l00004oooo
o`005Oooool00ol0003oooooooooo`02ooooo`<0[P3o0P3o0?D50?l000<0o`1[0P3o02h50?l0?L`0
o`000`00odL20;go00<0n_l00P3oiP030?o700D0okP01@3oZ0050?nI00Gooooo00?o0000oooooooo
ool00_ooool001Gooooo00?o0000ooooooooool00_ooool30:h0o`80o`3e1@3o00030?l0J`80o`0^
1@3o03g<0?l000<00?m70P2mo`030?[o0080onH00`3oa`050?nh00D0ojP01@3oV@05ooooo`03o`00
0?oooooooooo00;ooooo000Eooooo`03o`000?oooooooooo00;ooooo0`2^0?l20?l0m@D0o`000`3o
06/20?l0;PD0o`0mc03o0003003oA`80_Ol00`3jo`020?oV00<0olL01@3o^0050?nX00D0oiT01Ooo
ool00ol0003oooooooooo`02ooooo`005Oooool00ol0003oooooooooo`02ooooo`D0ojP00`3o^002
0?oG00X0okP01@3oa`030=co0080onH00`3om@020=co00<0L?l00P00om700?l00080omL00`3o^002
0?nX00<0oiT01`3oRP030?mj00Gooooo00?o0000ooooooooool00_ooool001Gooooo00?o0000oooo
ooooool00_ooool50?nX00<0okP00P3oe`0:0?nh00D0olL00`3Lo`020?oV00<0ooD00P3Lo`03073o
00800?oA`03o00020?oG00<0okP00P3oZ0030?nI00L0ohX00`3oNP05ooooo`03o`000?oooooooooo
00;ooooo000Eooooo`03o`000?oooooooooo00;ooooo3`3oV@080?nX0080okP01@3oa`030?oG0080
n_l00`3[o`0208oo00X0o`000`0Do`0g0?l000<0<`3oN`3o00030?oe0080okP00`3oV@070?n:00<0
ogX01Oooool00ol0003oooooooooo`02ooooo`005Oooool00ol0003oooooooooo`02ooooo`l0oiT0
203oZ0020?nh00D0olL00`3oe`020?[o00<0jol00P2?o`0:0?l000<05?l0=`3o000303<0og/0o`00
0`3om@020?nh00<0oiT01`3oRP030?mj00Gooooo00?o0000ooooooooool00_ooool001Gooooo00?o
0000ooooooooool00_ooool?0?nI00P0ojP00P3o^0050?o700<0omL00P3jo`030>_o0080Sol02P3o
000301Co03L0o`000`0c0?mk0?l000<0ooD00P3o^0030?nI00L0ohX00`3oNP05ooooo`03o`000?oo
oooooooo00;ooooo000Eooooo`03o`000?oooooooooo00;ooooo3`3oRP0:0?nI00D0ojP00`3o^002
0?o700<0g?l00P0Do`03003o/`800?n50`2?o`020:ko00<0Sol0=`3o0003003oQG/0o`000`00/ol2
0?oG00<0ojP00P3oV@050?n:00<0ogX01Oooool00ol0003oooooooooo`02ooooo`005Oooool00ol0
003oooooooooo`02ooooo`l0ohX02P3oV@050?nX00<0okP00P3oa`030=co00805?l00`00ok<2003o
Q@<0Sol00P2^o`0308oo03L0o`000`00ohEk0?l000<00;?o0P3oe`030?nX0080oiT01@3oRP030?mj
00Gooooo00?o0000ooooooooool00_ooool001Gooooo00?o0000ooooooooool00_ooool50?mj00l0
ohX0203oV@020?nX00<0okP00P3oa`030;go0080n_l00`3oiP02003o:0<0ooD00P3jo`030<co03L0
o`000`0Do`1n0?l000800?3o0`3oe`020?nX00D0ohX00`3oNP05ooooo`03o`000?oooooooooo00;o
oooo000Eooooo`03o`000?oooooooooo00;ooooo1@3oNP0?0?n:00P0oiT00P3oZ0030?nh0080olL0
0`2mo`020?[o00<0onH00P00obP30?oe0080n_l00`3<o`0g0?l000<05?l0OP3o0002003`o`<0omL0
0P3oZ0050?n:00<0ogX01Oooool00ol0003oooooooooo`02ooooo`005Oooool2o`0000?ooooo1@3o
NP0?0?n:00P0oiT00P3oZ0030?nh0080olL00`2mo`020?[o00<0onH00P00obP30?oe0080n_l00`3<
o`0g0?l000<05?l0OP3o0002003`o`<0omL00P3oZ0050?n:00<0ogX01?ooool2o`0000Cooooo000E
ooooo`03o`000?oooooooooo00;ooooo3`3oNP0:0?n:00D0oiT00`3oZ0020=co00<0jol01@3oa`05
0?oG0080onH00`3[o`0202?o00<0L03o<03o0002003o`P<0HOl0OP3o0002002Do`<00?o`0P3oa`03
0?nI0080ohX00`3oNP05ooooo`03o`000?oooooooooo00;ooooo000Eooooo`03o`000?oooooooooo
00;ooooo3`3oNP0:0?n:00D0oiT00`3oZ0020=co00<0jol01@3oa`050?oG0080onH00`3[o`0202?o
00<0L03o<03o0002003o`P<0HOl0OP3o0002002Do`<00?o`0P3oa`030?nI0080ohX00`3oNP05oooo
o`03o`000?oooooooooo00;ooooo000Eooooo`03o`000?oooooooooo00;ooooo503oNP080?n:0080
oiT00`3oZ0020?o700X0okP00`3oa`020?oG00<0n_l00P00o`X`0?l000<00?nS0P2^o`0309ko0800
o`000`00`_l20<co00<0oiT01@3oRP05ooooo`03o`000?oooooooooo00;ooooo000Eooooo`03o`00
0?oooooooooo00;ooooo503oNP080?n:0080oiT00`3oZ0020?o700X0okP00`3oa`020?oG00<0n_l0
0P00o`X`0?l000<00?nS0P2^o`0309ko0800o`000`00`_l20<co00<0oiT01@3oRP05ooooo`03o`00
0?oooooooooo00;ooooo000Eooooo`03o`000?oooooooooo00;ooooo503oNP080?n:0080oiT00`3o
Z0020?o700X0okP00`3oa`020?oG00<0n_l00P00o`X`0?l000<00?nS0P2^o`0309ko0800o`000`00
`_l20<co00<0oiT01@3oRP05ooooo`03o`000?oooooooooo00;ooooo000Eooooo`03o`000?oooooo
oooo00;ooooo0`3oJ`0D0?mj00L0ohX02P3oV@050?nX00<0okP00P3jo`030>_o0080c?l00`2No`02
001Gob/0o`000`00oaT20=co00<0c?l0P03o00030?l0e`80olL00`3oZ0020?nI00<0ohX01Oooool0
0ol0003oooooooooo`02ooooo`005Oooool00ol0003oooooooooo`02ooooo`<0of/0503oNP070?n:
00X0oiT01@3oZ0030?nh0080n_l00`3[o`020<co00<0W_l00P00Eol[0?l000<00?lI0P3Lo`030<co
0800o`000`3o0=L20?o700<0ojP00P3oV@030?n:00Gooooo00?o0000ooooooooool00_ooool001Go
oooo00?o0000ooooooooool00_ooool80?m[01@0ogX01`3oRP080?nI00D0ojP01@3oa`020?oG00<0
ooD00P3Lo`03083o00<00?nD8`3o00020;go00D0n_l00`3[o`230?l000800?m70`2mo`020?nI00<0
ohX01Oooool00ol0003oooooooooo`02ooooo`005Oooool00ol0003oooooooooo`02ooooo`P0of/0
503oNP070?n:00P0oiT01@3oZ0050?o70080omL00`3om@020=co00<0P?l00`00oi@S0?l00080_Ol0
1@3jo`030>_o08<0o`000P00odL30;go0080oiT00`3oRP05ooooo`03o`000?oooooooooo00;ooooo
0007ooooo`?o00001?ooool2o`0000Gooooo00?o0000ooooooooool00_ooool80?m[01@0ogX01`3o
RP080?nI00D0ojP01@3oa`020?oG00<0ooD00P3Lo`03083o00<00?nD8`3o00020;go00D0n_l00`3[
o`230?l000800?m70`2mo`020?nI00<0ohX01Oooool00ol0003oooooooooo`02ooooo`001_ooool0
1Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00001?ooool00ol0003ooooo
ooooo`02ooooo`l0of/03@3oNP0<0?n:00D0oiT01@3oZ0030?nh0080olL00`3Lo`020;go00<00?lh
1@3o0003003oU1H0o`000`05o`02003Ao`<0W_l00P3om@050?oV00<0n_l00P00ofJ10?l000D01Ol0
0P3oZ0030?n:00Gooooo00?o0000ooooooooool00_ooool000Kooooo00Go0000oooooooooooooooo
o`000002ooooo`04o`000?ooooooooooo`0000Cooooo0_l00003ooooo`l0of/03@3oNP0<0?n:00D0
oiT01@3oZ0030?nh0080olL00`3Lo`020;go00<00?lh1@3o0003003oU1H0o`000`05o`02003Ao`<0
W_l00P3om@050?oV00<0n_l00P00ofJ10?l000D01Ol00P3oZ0030?n:00?ooooo0ol00004ooooo`00
1_ooool4o`0000?ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`02ooooo`l0
of/00`3oNP020?m[00d0ogX02P3oRP050?nI0080ojP00`3o^0020?o700<0onH00P0co`0304;o00D0
o`000`00oj<209ko00<004Oo0P00ool3003Ao`D0o`000P2?0?l3003oo`8003So0`3<o`020;go00<0
onH01`3oe`030?oV0080c?l00`0co`1k0?l000<01Ol00P3oe`030?nh0080oiT00`3oRP05ooooo`03
o`000?oooooooooo00;ooooo0006ooooo`03o`000?oooooooooo00Cooooo00Co0000oooooooooooo
00001?ooool00ol0003oooooooooo`02ooooo`l0of/00`3oNP020?m[00d0ogX02P3oRP050?nI0080
ojP00`3o^0020?o700<0onH00P0co`0304;o00D0o`000`00oj<209ko00<004Oo0P00ool3003Ao`D0
o`000P2?0?l3003oo`8003So0`3<o`020;go00<0onH01`3oe`030?oV0080c?l00`0co`1k0?l000<0
1Ol00P3oe`030?nh0080oiT00`3oRP05ooooo`03o`000?oooooooooo00;ooooo0007ooooo`03o`00
0?oooooooooo00?ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`02ooooo`l0
of/00`3oNP020?m[00d0ogX02P3oRP050?nI0080ojP00`3o^0020?o700<0onH00P0co`0304;o00D0
o`000`00oj<209ko00<004Oo0P00ool3003Ao`D0o`000P2?0?l3003oo`8003So0`3<o`020;go00<0
onH01`3oe`030?oV0080c?l00`0co`1k0?l000<01Ol00P3oe`030?nh0080oiT00`3oRP05ooooo`03
o`000?oooooooooo00;ooooo0008ooooo`;o00001?ooool2o`0000Gooooo00?o0000ooooooooool0
0_oooolD0?m[00l0ogX0203oRP050?nI0080ojP00`3o^0020?o700<0onH00P2^o`03083o00<0<ol0
0P0So`030;go00D0n_l00P1`o`03003oM@80o`000`2?o`020>_o00<0Sol00P3Lo`050?oG00X0olL0
0`3oe`0201Co00<0o`000P1A0?mi0?l000<0jol00P3oa`030?nX0080oiT00`3oRP05ooooo`03o`00
0?oooooooooo00;ooooo000Eooooo`03o`000?oooooooooo00;ooooo503oJ`0?0?mj00P0ohX01@3o
V@020?nX00<0okP00P3oa`030?oV0080[_l00`20o`0303?o00808ol00`2mo`050?[o0080L?l00`00
ogD20?l000<0Sol00P3[o`0308oo0080g?l01@3oe`0:0?o700<0omL00P0Do`030?l00080D@3oN@3o
00030>_o0080olL00`3oZ0020?nI00<0ohX01Oooool00ol0003oooooooooo`02ooooo`005Oooool0
0ol0003oooooooooo`02oooooaL0of/03`3oNP070?n:00<0oiT00P3oZ0030?o700D0jol00P12o`03
0>_o00<00?3o0P3oiP050?oG00<0onH00P3jo`030:ko00800?m70`3om@020?oG00<01Ol00P3oiP03
0?o700X0okP01@3oa`020?oV00<000[oN@3o0002003oX`<0o`000P00ogD30?oG0080ojP00`3oRP05
ooooo`03o`000?oooooooooo00;ooooo000Eooooo`03o`000?oooooooooo00;ooooo5`3oJ`0?0?mj
00L0ohX00`3oV@020?nX00<0olL01@3[o`0204;o00<0jol00`00l?l20?oV00D0omL00`3oiP020?[o
00<0[_l00P00odL30?oe0080omL00`05o`020?oV00<0olL02P3o^0050?o70080onH00`002_mi0?l0
00800?nS0`3o0002003oM@<0omL00P3oZ0030?n:00Gooooo00?o0000ooooooooool00_ooool001Go
oooo00?o0000ooooooooool00_oooolG0?m[00l0ogX01`3oRP030?nI0080ojP00`3oa`050>_o0080
@_l00`3[o`03003`o`80onH01@3oe`030?oV0080n_l00`2^o`02003oA`<0ooD00P3oe`0300Go0080
onH00`3oa`0:0?nh00D0olL00P3oiP03000:ogT0o`000P00oj<30?l000800?me0`3oe`020?nX00<0
ohX01Oooool00ol0003oooooooooo`02ooooo`005Oooool00ol0003oooooooooo`02ooooo`<0oe`0
6@3oJ`0<0?mj00D0ohX00`3oV@020?nh00<0n_l00P3om@050?oG00<0olL00`2mo`070?nh00<0omL0
0P1`o`030?oe0080omL02P3o^00:0?nX00D0okP00`3oa`020?oV00<0HOl00P00Eomn0?l000<0DOl0
0P3oiP030?nI00Gooooo00?o0000ooooooooool00_ooool001Gooooo00?o0000ooooooooool00_oo
ool30?mL01T0of/0303oNP050?n:00<0oiT00P3o^0030?[o0080ooD01@3oe`030?o700<0_Ol01`3o
^0030?oG0080L?l00`3om@020?oG00X0okP02P3oZ0050?nh00<0olL00P3oiP03067o008005OoOP3o
0003057o0080onH00`3oV@05ooooo`03o`000?oooooooooo00;ooooo000Eooooo`03o`000?oooooo
oooo00;ooooo1@3oJ`030?mL01H0of/02P3oNP050?n:00<0oiT00P3o^0030>_o0080olL00`3o^00?
0?nX00<0okP00P2mo`0301Co0080okP06@3oZ0030?nh0080onH00`20o`02067o00<00;?o0P0D0?mb
0?l00080o`2h0`3o00020=co00<0c?l00P3oe`030?nI00Gooooo00?o0000ooooooooool00_ooool0
01Gooooo00?o0000ooooooooool00_ooool50?m[00<0oe`05P3oJ`0:0?mj00D0ohX00`3oV@020?nh
00<0jol00P3oa`030?nh00l0ojP00`3o^0020;go00<05?l00P3o^00I0?nX00<0okP00P3oiP03083o
0080HOl00`00/ol201@0og80o`000P3o0;P30?l00080g?l00`3<o`020?oG00<0oiT01Oooool00ol0
003oooooooooo`02ooooo`005Oooool2o`0000?ooooo1@3oJ`030?mL01H0of/02P3oNP050?n:00<0
oiT00P3o^0030>_o0080olL00`3o^00?0?nX00<0okP00P2mo`0301Co0080okP06@3oZ0030?nh0080
onH00`20o`02067o00<00;?o0P0D0?mb0?l00080o`2h0`3o00020=co00<0c?l00P3oe`030?nI00Co
oooo0_l00004ooooo`005Oooool00ol0003oooooooooo`02ooooo`P0oe`06@3oJ`0:0?mj0080ohX0
0`3oV@020?nX00<0ooD00P3oa`030?nX0180oiT01@3o^0020?nX01@0oiT0203oZ0020?nh00<0omL0
0P3om@030>_o0080L?l0LP3o00050?oe00D0omL00P1`o`030?nI00Gooooo00?o0000ooooooooool0
0_ooool001Gooooo00?o0000ooooooooool00_ooool80?mL01T0of/02P3oNP020?n:00<0oiT00P3o
Z0030?oe0080olL00`3oZ00B0?nI00D0okP00P3oZ00D0?nI00P0ojP00P3o^0030?oG0080ooD00`3[
o`02073o0780o`001@3om@050?oG0080L?l00`3oV@05ooooo`03o`000?oooooooooo00;ooooo000E
ooooo`03o`000?oooooooooo00;ooooo203oG0020?m[00D0oe`0503oJ`050?mj00D0ohX00`3oV@02
0?oe00D0olL00`3oV@020?n:00<0oiT03@3oRP0<0?nI00D0ohX03`3oV@030?nX0080okP00`3oa`02
0?oV00<0c?l0L@3o0003003oQ@80omL00`3o^0070?nX00<0ohX01Oooool00ol0003oooooooooo`02
ooooo`005Oooool00ol0003oooooooooo`02ooooo`P0oe`00P3oJ`050?mL01@0of/01@3oNP050?n:
00<0oiT00P3om@050?o700<0oiT00P3oRP030?nI00d0ohX0303oV@050?n:00l0oiT00`3oZ0020?nh
00<0olL00P3oiP030<co0740o`000`00ohD20?oG00<0okP01`3oZ0030?n:00Gooooo00?o0000oooo
ooooool00_ooool001Gooooo00?o0000ooooooooool00_ooool80?mL0080of/01@3oG00D0?m[00D0
ogX01@3oRP030?nI0080ooD01@3oa`030?nI0080ohX00`3oV@0=0?n:00`0oiT01@3oRP0?0?nI00<0
ojP00P3o^0030?o70080onH00`3<o`1a0?l000<00?n50P3oe`030?nh00L0ojP00`3oRP05ooooo`03
o`000?oooooooooo00;ooooo000Eooooo`03o`000?oooooooooo00;ooooo3`3oG00G0?m[00L0ogX0
0`3oRP020?nX00<0oiT0<03oRP0:0?nI0080ojP00`3oa`020;go00<0@_l01@3o0003003oAfL0o`00
0P3<o`030?[o0080olL00`3oZ0050?nI00D0ohX01Oooool00ol0003oooooooooo`02ooooo`005Ooo
ool00ol0003oooooooooo`02ooooo`l0oe`05`3oJ`070?mj00<0ohX00P3oZ0030?nI0300ohX02P3o
V@020?nX00<0olL00P2mo`0304;o00D0o`000`00odMW0?l00080c?l00`3jo`020?o700<0ojP01@3o
V@050?n:00Gooooo00?o0000ooooooooool00_ooool001Gooooo00?o0000ooooooooool00_oooolD
0?mL01@0of/03@3oNP020?n:01D0ogX07P3oRP050?nI0080ojP00`3oiP020;go00<08ol00P2No`03
0032o`<0c?l00P050?mR0?l000<0[_l00P3om@030?oG0080okP00`3oZ0020?nI00D0ohX00`3oNP05
ooooo`03o`000?oooooooooo00;ooooo000Eooooo`03o`000?oooooooooo00;ooooo503oG00D0?m[
00d0ogX00P3oRP0E0?mj01h0ohX01@3oV@020?nX00<0onH00P2mo`0302?o0080W_l00`00`_l30<co
00801@3oHP3o00030:ko0080ooD00`3oe`020?nh00<0ojP00P3oV@050?n:00<0ogX01Oooool00ol0
003oooooooooo`02ooooo`005Oooool00ol0003oooooooooo`02oooooa@0oe`0503oJ`0=0?mj0080
ohX05@3oNP0N0?n:00D0oiT00P3oZ0030?oV0080_Ol00`0So`0209ko00<00<;o0`3<o`0200D0of80
o`000`2^o`020?oe00<0omL00P3o^0030?nX0080oiT01@3oRP030?mj00Gooooo00?o0000oooooooo
ool00_ooool001Gooooo00?o0000ooooooooool00_oooolG0?mL01H0of/0:`3oNP030?n:0080ogX0
3@3oRP070?nI00<0ojP00P3o^0030?oG00800?n50`3oiP030?oe0080o`000`2?o`020032of00o`00
0P00>?l30?oe0080okP00`3oZ0020?nI00<0ohX01@3oNP05ooooo`03o`000?oooooooooo00;ooooo
000Eooooo`;o00000ooooolG0?mL01H0of/0:`3oNP030?n:0080ogX03@3oRP070?nI00<0ojP00P3o
^0030?oG00800?n50`3oiP030?oe0080o`000`2?o`020032of00o`000P00>?l30?oe0080okP00`3o
Z0020?nI00<0ohX01@3oNP04ooooo`;o00001?ooool001Gooooo00?o0000ooooooooool00_oooolD
0?mL00<0of/01@3oG00F0?m[00<0ogX00P3oJ`0Y0?mj0080ohX00`3oNP0:0?n:00D0oiT01@3oZ002
0?nh00<0olL00`3oe`020?oe00<0g?l00P1Qo`03003oU5<0o`000P00/ol:0?l000<0HOl00P0Do`03
0?nX0080oiT00`3oRP050?mj00Gooooo00?o0000ooooooooool00_ooool001Gooooo00?o0000oooo
ooooool00_oooolD0?mL00<0of/01@3oG00F0?m[00<0ogX00P3oJ`0Y0?mj0080ohX00`3oNP0:0?n:
00D0oiT01@3oZ0020?nh00<0olL00`3oe`020?oe00<0g?l00P1Qo`03003oU5<0o`000P00/ol:0?l0
00<0HOl00P0Do`030?nX0080oiT00`3oRP050?mj00Gooooo00?o0000ooooooooool00_ooool001Go
oooo00?o0000ooooooooool00_oooolD0?mL00<0of/01@3oG00F0?m[00<0ogX00P3oJ`0Y0?mj0080
ohX00`3oNP0:0?n:00D0oiT01@3oZ0020?nh00<0olL00`3oe`020?oe00<0g?l00P1Qo`03003oU5<0
o`000P00/ol:0?l000<0HOl00P0Do`030?nX0080oiT00`3oRP050?mj00Gooooo00?o0000oooooooo
ool00_ooool001Gooooo00?o0000ooooooooool00_oooolL0?mL01h0of/00P3oNP030?m[00<0ogX0
0P3oJ`0N0?mj00<0ohX00P3oNP0:0?n:00D0oiT01@3oZ0030?nh00<0olL00P2?o`03073o0680o`00
0P0c0?l30:ko0080omL00`3o^0020?nI00<0ohX01@3oNP05ooooo`03o`000?oooooooooo00;ooooo
000Eooooo`03o`000?oooooooooo00;ooooo703oG00N0?m[0080ogX00`3oJ`030?mj0080of/07P3o
NP030?n:0080ogX02P3oRP050?nI00D0ojP00`3o^0030?o70080Sol00`1`o`1R0?l00080<`3o0`2^
o`020?oG00<0okP00P3oV@030?n:00D0ogX01Oooool00ol0003oooooooooo`02ooooo`005Oooool0
0ol0003oooooooooo`02oooooaT0oe`00`3oJ`070?mL02H0of/00`3oNP020?m[01`0ogX02P3oRP05
0?nI0080ojP00`3o^0030?o70080W_l00`1Ao`0:0?l00080HOl0A`3o000209ko00<0n_l00P2mo`03
0032o`L0o`000`0co`020>_o00<0g?l00P3oZ0030?n:00D0ogX01Oooool00ol0003oooooooooo`02
ooooo`005Oooool00ol0003oooooooooo`02oooooaT0oe`00`3oJ`070?mL02H0of/00`3oNP020?m[
01`0ogX02P3oRP050?nI0080ojP00`3o^0030?o70080W_l00`1Ao`0:0?l00080HOl0A`3o000209ko
00<0n_l00P2mo`030032o`L0o`000`0co`020>_o00<0g?l00P3oZ0030?n:00D0ogX01Oooool00ol0
003oooooooooo`02ooooo`005Oooool00ol0003oooooooooo`02oooooaT0oe`00`3oJ`070?mL02H0
of/00`3oNP020?m[01`0ogX02P3oRP050?nI0080ojP00`3o^0030?o70080W_l00`1Ao`0:0?l00080
HOl0A`3o000209ko00<0n_l00P2mo`030032o`L0o`000`0co`020>_o00<0g?l00P3oZ0030?n:00D0
ogX01Oooool00ol0003oooooooooo`02ooooo`005Oooool00ol0003oooooooooo`02ooooob40oe`0
0P3oJ`050?mL02/0of/00`3oNP020?m[01@0ogX02P3oRP030?nI0080ojP00`3o^0030?oV0080n_l0
0`00ok<70?l000<00=7o0P3Lo`03000Io`801Ol00`2m0?lj0?l00080Sol00`2mo`020?oe00<0omL0
0P3oiP030=co0080DOl00`3[o`020:ko00<0jol00P2No`030=co0080olL00`3oRP050?mj00Gooooo
00?o0000ooooooooool00_ooool001Gooooo00?o0000ooooooooool00_oooolQ0?mL0080of/01@3o
G00[0?m[00<0ogX00P3oJ`0D0?mj00X0ohX00`3oV@020?nX00<0okP00`3oiP020?[o00<00?nc1`3o
0003003Ao`80g?l00`006Ol200Go00<0_@3o>P3o000208oo00<0_Ol00P3om@030?oG0080onH00`3L
o`02057o00<0jol00P2^o`030>_o0080W_l00`3Lo`020?o700<0ohX01@3oNP05ooooo`03o`000?oo
oooooooo00;ooooo000Eooooo`03o`000?oooooooooo00;ooooo:03oG00e0?m[01@0ogX01@3oRP05
0?nI00<0olL00`3<o`02083o00<00;?o0P0co`0308oo0080o`3e0`1Qo`020?oV00<0ooD00P3[o`05
0?l000<08ol00P00oj<Y0?l000800>7o0`3o0002002So`<0o`000P1Qo`030?oe0080olL00`3o^002
0?o700<0P?l00P3[o`050?o700<0ooD00P3[o`030?nh0080olL00`3oRP050?mj00Gooooo00?o0000
ooooooooool00_ooool001Gooooo00?o0000ooooooooool00_oooolX0?mL03D0of/0503oNP050?n:
00D0oiT00`3oa`030<co0080P?l00`00/ol203?o00<0Sol00P3o0?D3067o0080onH00`3om@020>_o
00D0o`000`0So`02003oXbT0o`000P00hOl30?l000800:?o0`3o0002067o00<0ooD00P3oa`030?nh
0080olL00`20o`020>_o00D0olL00`3om@020>_o00<0okP00P3oa`030?n:00D0ogX01Oooool00ol0
003oooooooooo`02ooooo`005Oooool2o`0000?ooooo:03oG00e0?m[01@0ogX01@3oRP050?nI00<0
olL00`3<o`02083o00<00;?o0P0co`0308oo0080o`3e0`1Qo`020?oV00<0ooD00P3[o`050?l000<0
8ol00P00oj<Y0?l000800>7o0`3o0002002So`<0o`000P1Qo`030?oe0080olL00`3o^0020?o700<0
P?l00P3[o`050?o700<0ooD00P3[o`030?nh0080olL00`3oRP050?mj00Cooooo0_l00004ooooo`00
5Oooool00ol0003oooooooooo`02oooooc00oe`0<03oJ`0D0?mj0080ohX01@3oV@030?nh00<0ooD0
0P00>?l3057o0080c?l00`3om@020?oV00D0olL00`3oe`02003oE`<00?n50P12o`030=co00800?nD
0`3o0002003oIP<0DOl00P00o`XL0?l000<0W_l00P00ol850?[o00<0HOl00P00odL30?oG0080okP0
3@3oZ0020?nh00<0ooD00P3jo`030?nX00D0ohX01@3oNP05ooooo`03o`000?oooooooooo00;ooooo
000Eooooo`03o`000?oooooooooo00;ooooo<03oG00`0?m[01@0ogX00P3oRP050?nI00<0okP00`3o
m@02000ho`<0DOl00P3<o`030?oe0080onH01@3oa`030?oG00800?mG0`00ohD204;o00<0g?l00P00
oi@30?l000800?mV0`1Ao`02003o2Q`0o`000`2No`02003o`PD0n_l00`1Qo`02003oA`<0omL00P3o
^00=0?nX0080okP00`3om@020?[o00<0ojP01@3oRP050?mj00Gooooo00?o0000ooooooooool00_oo
ool001Gooooo00?o0000ooooooooool00_ooool`0?mL0300of/0503oNP020?n:00D0oiT00`3o^003
0?oe008003So0`1Ao`020<co00<0ooD00P3oiP050?o700<0omL00P00oeL3003oQ@80@_l00`3Lo`02
003oU0<0o`000P00ofH3057o00800?l:703o000309ko00800?o21@3jo`03067o00800?m70`3oe`02
0?nh00d0ojP00P3o^0030?oe0080n_l00`3oZ0050?n:00D0ogX01Oooool00ol0003oooooooooo`02
ooooo`005Oooool00ol0003oooooooooo`02ooooobH0oe`00P3oJ`080?mL0080of/01@3oG00^0?m[
00l0ogX01@3oRP020?nI00H0ooD00P3oe`030?oV0080g?l00`3om@0:0?nh0080omL00`3<o`02003o
/`<0omL00P3oiP050?oe00<0jol00P3<o`03001eo`l0o`000`0S0?l20<co00<0n_l00P3om@050?oV
00<0olL00P3oe`030?oe0080omL00`3oZ00?0?nI0080ojP00`3o^0020;go00<0oiT00P3oRP030?mj
00D0of/01Oooool00ol0003oooooooooo`02ooooo`005Oooool00ol0003oooooooooo`02ooooobH0
oe`00P3oJ`080?mL0080of/01@3oG00^0?m[00l0ogX01@3oRP020?nI00H0ooD00P3oe`030?oV0080
g?l00`3om@0:0?nh0080omL00`3<o`02003o/`<0omL00P3oiP050?oe00<0jol00P3<o`03001eo`l0
o`000`0S0?l20<co00<0n_l00P3om@050?oV00<0olL00P3oe`030?oe0080omL00`3oZ00?0?nI0080
ojP00`3o^0020;go00<0oiT00P3oRP030?mj00D0of/01Oooool00ol0003oooooooooo`02ooooo`00
5Oooool00ol0003oooooooooo`02ooooocL0oe`00`3oJ`080?mL02P0of/0303oNP050?n:00<0oiT0
0`3oZ0020?nI00<0ojP00P3oa`030?nh00`0ojP0203o^0050?o70080onH00`3jo`0202<0oaD0o`00
0P12o`030?[o0080omL00`3oa`070?nh00D0ojP0203oV@0:0?n:0080oiT00`2mo`020?nX00<0ohX0
1@3oNP050?m[00Gooooo00?o0000ooooooooool00_ooool001Gooooo00?o0000ooooooooool00_oo
oolg0?mL00<0of/0203oG00X0?m[00`0ogX01@3oRP030?nI00<0ojP00P3oV@030?nX0080olL00`3o
^00<0?nX00P0okP01@3oa`020?oV00<0n_l00P0S0?lE0?l00080@_l00`3jo`020?oG00<0olL01`3o
^0050?nX00P0oiT02P3oRP020?nI00<0_Ol00P3oZ0030?n:00D0ogX01@3oJ`05ooooo`03o`000?oo
oooooooo00;ooooo000Eooooo`03o`000?oooooooooo00;ooooo=`3oG0030?m[00P0oe`0:03oJ`0<
0?mj00D0ohX00`3oV@030?nX0080oiT00`3oZ0020?o700<0okP0303oZ0080?nh00D0olL00P3oiP03
0?[o00808`3o5@3o000204;o00<0n_l00P3oe`030?o700L0okP01@3oZ0080?nI00X0ohX00P3oV@03
0;go0080ojP00`3oRP050?mj00D0of/01Oooool00ol0003oooooooooo`02ooooo`005Oooool00ol0
003oooooooooo`02oooood80oe`01@3oJ`020?mL02<0of/03@3oNP0=0?n:00l0oiT02P3oZ0020?nh
00<0olL00P3oe`03003oE`808`3o5@3o0002002Do`<0g?l00P3oe`030?nh00D0ojP01`3oV@0G0?n:
00L0ogX0203oJ`05ooooo`03o`000?oooooooooo00;ooooo0007ooooo`?o00001?ooool2o`0000Go
oooo00?o0000ooooooooool00_oooom20?mL00D0of/00P3oG00S0?m[00d0ogX03@3oRP0?0?nI00X0
ojP00P3o^0030?o70080omL00`00oeL202<0oaD0o`000P00U?l30=co0080omL00`3o^0050?nX00L0
oiT05`3oRP070?mj00P0of/01Oooool00ol0003oooooooooo`02ooooo`001_ooool01Ol0003ooooo
oooooooooooo000000;ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`02oooo
o`<0oe`01`3oC0120?mL02D0of/0403oNP0D0?n:00L0oiT01@3oZ0030?nh0080<ol00`2?0?lI0?l0
00<0HOl00P3Lo`030?nh0080ojP0203oV@0:0?n:0140ogX03@3oJ`05ooooo`03o`000?oooooooooo
00;ooooo0006ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00004
ooooo`03o`000?oooooooooo00;ooooo0`3oG0070?m<0480oe`09@3oJ`0@0?mj01@0ohX01`3oV@05
0?nX00<0okP00P0co`0308l0oaT0o`000`1Qo`020=co00<0okP00P3oZ0080?nI00X0ohX04@3oNP0=
0?m[00Gooooo00?o0000ooooooooool00_ooool000Oooooo0ol00003ooooo`04o`000?oooooooooo
o`0000Cooooo0_l00003ooooo`<0oe`01`3oC0120?mL02D0of/0403oNP0D0?n:00L0oiT01@3oZ003
0?nh0080<ol00`2?0?lI0?l000<0HOl00P3Lo`030?nh0080ojP0203oV@0:0?n:0140ogX03@3oJ`03
ooooo`?o00001?ooool000Kooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?oooooo
ooooo`0000Cooooo00?o0000ooooooooool00_ooool=0?m<0380oe`00`3oJ`0A0?mL0240of/0503o
NP0?0?n:00P0oiT00P3oZ0030?nh0080onH00`2mo`020?l0mAD0o`000P00Aol30<co0080omL00`3o
^0020?nX00D0oiT0203oRP0A0?mj00<0of/00P3oNP0=0?m[00Gooooo00?o0000ooooooooool00_oo
ool000Kooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000Cooooo
00?o0000ooooooooool00_ooool=0?m<0380oe`00`3oJ`0A0?mL0240of/0503oNP0?0?n:00P0oiT0
0P3oZ0030?nh0080onH00`2mo`020?l0mAD0o`000P00Aol30<co0080omL00`3o^0020?nX00D0oiT0
203oRP0A0?mj00<0of/00P3oNP0=0?m[00Gooooo00?o0000ooooooooool00_ooool000Oooooo0ol0
0004ooooo`;o00001Oooool00ol0003oooooooooo`02ooooo`d0od`0AP3oG00V0?m[0180ogX00P3o
RP030?mj00X0ohX01@3oV@020?nX00<0okP00P3oe`03067o00800?nD5@3o000201@0o`<0o`2:0P3j
o`030?oV00D0oiT01@3oRP0A0?mj01@0of/00`3oG005ooooo`03o`000?oooooooooo00;ooooo000E
ooooo`03o`000?oooooooooo00;ooooo3@3oC0160?mL02H0of/04P3oNP020?n:00<0ogX02P3oRP05
0?nI0080ojP00`3o^0020?oG00<0HOl00P00oi@E0?l00080503o0`3o08X20?[o00<0onH01@3oV@05
0?n:0140ogX0503oJ`030?mL00Gooooo00?o0000ooooooooool00_ooool001Gooooo00?o0000oooo
ooooool00_ooool=0?m<04H0oe`09P3oJ`0B0?mj0080ohX00`3oNP0:0?n:00D0oiT00P3oZ0030?nh
0080omL00`1Qo`02003oU1D0o`000P0D0?l30?l0RP80n_l00`3oiP050?nI00D0ohX04@3oNP0D0?m[
00<0oe`01Oooool00ol0003oooooooooo`02ooooo`005Oooool00ol0003oooooooooo`02ooooo`d0
od`0AP3oG0030?m[00L0oe`07P3oJ`030?mj00<0of/0503oNP070?n:00<0oiT00P3oZ0030?oG0080
ooD00`2mo`02083o00<0j`3o0P00l?l=0?l000<0@_l00P3jo`0308oo0080ooD00`3o^0020?nI00D0
ohX00`3oNP020?n:00P0ogX06@3oJ`050?mL00Gooooo00?o0000ooooooooool00_ooool001Gooooo
00?o0000ooooooooool00_ooool=0?m<04H0oe`00`3oJ`070?mL01h0of/00`3oNP030?m[01@0ogX0
1`3oRP030?nI0080ojP00`3oe`020?oe00<0_Ol00P20o`030>/0o`800?3o3@3o000304;o0080n_l0
0`2?o`020?oe00<0okP00P3oV@050?n:00<0ogX00P3oRP080?mj01T0of/01@3oG005ooooo`03o`00
0?oooooooooo00;ooooo000Eooooo`03o`000?oooooooooo00;ooooo3@3oC0050?mL00L0od`0A03o
G0030?m[0080oe`0903oJ`0A0?mj00D0ohX01@3oV@030?oV0080n_l00`3[o`020:ko00<0ooD00P3<
o`030;go0080o`3e1@3o0003003oIP<0ooD00P3oe`050?oV00<0okP00P3oV@050?n:00X0ogX05`3o
J`0:0?mL00Gooooo00?o0000ooooooooool00_ooool001Gooooo00?o0000ooooooooool00_ooool=
0?m<00D0oe`01`3oC0140?mL00<0of/00P3oG00T0?m[0140ogX01@3oRP050?nI00<0onH00P3jo`03
0>_o0080[_l00`3om@020<co00<0_Ol00P3o0?D50?l000<00?mV0`3om@020?oG00D0onH00`3o^002
0?nI00D0ohX02P3oNP0G0?m[00X0oe`01Oooool00ol0003oooooooooo`02ooooo`005Oooool00ol0
003oooooooooo`02ooooo`d0od`01@3oG0070?m<04@0oe`00`3oJ`020?mL02@0of/04@3oNP050?n:
00D0oiT00`3oiP020?[o00<0jol00P2^o`030?oe0080c?l00`2mo`020?l0m@D0o`000`00ofH30?oe
0080omL01@3oiP030?nh0080oiT01@3oRP0:0?mj01L0of/02P3oG005ooooo`03o`000?oooooooooo
00;ooooo000Eooooo`03o`000?oooooooooo00;ooooo2P3oC0030?mL00l0od`0?`3oG0020?m[00P0
oe`08`3oJ`0B0?mj00L0ohX00`3oV@020?nX00<0DOl01@3oa`020?oV00<0g?l00P3o0=L30:h0o`80
0?nD0`05o`030?[o0080okP01@3oZ0030?nI00D0ohX02P3oNP0F0?m[00<0oe`00P3oJ`080?mL00Go
oooo00?o0000ooooooooool00_ooool001Gooooo0_l00003ooooo`X0od`00`3oG00?0?m<03l0oe`0
0P3oJ`080?mL02<0of/04P3oNP070?n:00<0oiT00P3oZ003057o00D0olL00P3oiP030=co0080o`3G
0`2^0?l2003oU0<01Ol00`3jo`020?nh00D0ojP00`3oV@050?n:00X0ogX05P3oJ`030?mL0080of/0
203oG004ooooo`;o00001?ooool001Gooooo00?o0000ooooooooool00_ooool80?m<0080oe`04P3o
C0190?mL0080of/01@3oG00Q0?m[00l0ogX0203oRP020?nI00D0ojP00`3o^0020?o700<0ooD00P3j
o`0309ko0080c?l00`3om@030?oG00D0ojP01@3oV@020?n:00d0ogX0503oJ`070?mL00<0of/01@3o
G005ooooo`03o`000?oooooooooo00;ooooo000Eooooo`03o`000?oooooooooo00;ooooo203oC002
0?mL0180od`0B@3oG0020?m[00D0oe`08@3oJ`0?0?mj00P0ohX00P3oV@050?nX00<0okP00P3oa`03
0?oe0080n_l00`2No`020<co00<0ooD00`3oe`050?nX00D0oiT00P3oRP0=0?mj01@0of/01`3oG003
0?m[00D0oe`01Oooool00ol0003oooooooooo`02ooooo`005Oooool00ol0003oooooooooo`02oooo
o`P0od`00P3oG00B0?m<04T0oe`00P3oJ`050?mL0240of/03`3oNP080?n:0080oiT01@3oZ0030?nh
0080olL00`3om@020?[o00<0W_l00P3<o`030?oe00<0omL01@3oZ0050?nI0080ohX03@3oNP0D0?m[
00L0oe`00`3oJ`050?mL00Gooooo00?o0000ooooooooool00_ooool001Gooooo00?o0000oooooooo
ool00_oooolL0?m<05<0oe`08`3oJ`0=0?mj00L0ohX01@3oV@030?nX0080okP00`3oa`020?oG00D0
c?l00`3oe`030?o70080ojP01@3oV@050?n:00X0ogX04P3oJ`0D0?mL00Gooooo00?o0000oooooooo
ool00_ooool001Gooooo00?o0000ooooooooool00_oooolL0?m<05<0oe`08`3oJ`0=0?mj00L0ohX0
1@3oV@030?nX0080okP00`3oa`020?oG00D0c?l00`3oe`030?o70080ojP01@3oV@050?n:00X0ogX0
4P3oJ`0D0?mL00Gooooo00?o0000ooooooooool00_ooool001Gooooo00?o0000ooooooooool00_oo
oolL0?m<00D0oe`02P3oC0110?mL00<0of/01`3oG00O0?m[00`0ogX0203oRP050?nI0080ojP00`3o
^0020?oG00<0c?l00P2^o`0308oo00<0olL00P3o^0030?nI00D0ohX01`3oNP0B0?m[0080oe`00`3o
J`0D0?mL00Gooooo00?o0000ooooooooool00_ooool001Gooooo00?o0000ooooooooool00_oooolL
0?m<00D0oe`02P3oC0110?mL00<0of/01`3oG00O0?m[00`0ogX0203oRP050?nI0080ojP00`3o^002
0?oG00<0c?l00P2^o`0308oo00<0olL00P3o^0030?nI00D0ohX01`3oNP0B0?m[0080oe`00`3oJ`0D
0?mL00Gooooo00?o0000ooooooooool00_ooool001Gooooo00?o0000ooooooooool00_oooolL0?m<
00D0oe`02P3oC0110?mL00<0of/01`3oG00O0?m[00`0ogX0203oRP050?nI0080ojP00`3o^0020?oG
00<0c?l00P2^o`0308oo00<0olL00P3o^0030?nI00D0ohX01`3oNP0B0?m[0080oe`00`3oJ`0D0?mL
00Gooooo00?o0000ooooooooool00_ooool001Gooooo00?o0000ooooooooool00_oooolI0?m<00<0
oe`04@3oC0190?mL00<0of/00P3oG00L0?m[00d0ogX01@3oRP020?nI00D0ojP00`3oa`050>_o0080
olL00`3oiP0308oo0080P?l00`3oZ0020?n:00P0ogX0503oJ`0I0?mL00Gooooo00?o0000oooooooo
ool00_ooool001Gooooo00?o0000ooooooooool00_oooolI0?m<00<0oe`04@3oC0190?mL00<0of/0
0P3oG00L0?m[00d0ogX01@3oRP020?nI00D0ojP00`3oa`050>_o0080olL00`3oiP0308oo0080P?l0
0`3oZ0020?n:00P0ogX0503oJ`0I0?mL00Gooooo00?o0000ooooooooool00_ooool001Gooooo00?o
0000ooooooooool00_ooool]0?m<0540oe`07P3oJ`0:0?mj00D0ohX00`3oV@020?oG00<0onH00P0c
o`030?nh00P0ojP00P3oa`030?nh0080ohX01@3oNP0B0?m[01h0oe`01Oooool00ol0003ooooooooo
o`02ooooo`005Oooool00ol0003oooooooooo`02ooooobd0od`0D@3oG00N0?m[00X0ogX01@3oRP03
0?nI0080omL00`3oiP0203?o00<0okP0203oZ0020?o700<0okP00P3oRP050?mj0180of/07P3oG005
ooooo`03o`000?oooooooooo00;ooooo000Eooooo`;o00000oooool]0?m<0540oe`07P3oJ`0:0?mj
00D0ohX00`3oV@020?oG00<0onH00P0co`030?nh00P0ojP00P3oa`030?nh0080ohX01@3oNP0B0?m[
01h0oe`01?ooool2o`0000Cooooo000Eooooo`03o`000?oooooooooo00;ooooo;@3oC0050?mL00X0
od`0@P3oG0030?m[00D0oe`06@3oJ`070?mj00D0ohX00`3oV@020?o700<08ol00P3oa`030?nX00D0
oiT00`3oRP020?nI00<0ohX01@3oNP0D0?m[01h0oe`01Oooool00ol0003oooooooooo`02ooooo`00
5Oooool00ol0003oooooooooo`02ooooobd0od`01@3oG00:0?m<0480oe`00`3oJ`050?mL01T0of/0
1`3oNP050?n:00<0oiT00P3oa`0302?o0080olL00`3oZ0050?nI00<0ohX00P3oV@030?n:00D0ogX0
503oJ`0N0?mL00Gooooo00?o0000ooooooooool00_ooool001Gooooo00?o0000ooooooooool00_oo
oolD0?m<00<0oe`05P3oC0030?mL00l0od`0?03oG0030?m[00P0oe`06`3oJ`050?mj00D0ohX00`3o
Z0020?oG00<0olL00P3oZ0030?nI00X0ohX01@3oNP0B0?m[02<0oe`01Oooool00ol0003ooooooooo
o`02ooooo`005Oooool00ol0003oooooooooo`02oooooa@0od`00`3oG00F0?m<00<0oe`03`3oC00l
0?mL00<0of/0203oG00K0?m[00D0ogX01@3oRP030?nX0080omL00`3oa`020?nX00<0oiT02P3oRP05
0?mj0180of/08`3oG005ooooo`03o`000?oooooooooo00;ooooo000Eooooo`03o`000?oooooooooo
00;ooooo503oC0030?mL01H0od`00`3oG00?0?m<03`0oe`00`3oJ`080?mL01/0of/01@3oNP050?n:
00<0ojP00P3oe`030?o70080ojP00`3oV@0:0?n:00D0ogX04P3oJ`0S0?mL00Gooooo00?o0000oooo
ooooool00_ooool001Gooooo00?o0000ooooooooool00_ooool[0?m<0080oe`04P3oC01>0?mL01@0
of/01@3oNP030?n:0080oiT00`3o^00209ko00<0olL00P3oV@030?n:00l0ogX03@3oJ`020?mL00<0
of/08`3oG005ooooo`03o`000?oooooooooo00;ooooo000Eooooo`03o`000?oooooooooo00;ooooo
:`3oC0020?mL0180od`0CP3oG00D0?m[00D0ogX00`3oRP020?nI00<0okP00P2No`030?o70080oiT0
0`3oRP0?0?mj00d0of/00P3oG0030?m[02<0oe`01Oooool00ol0003oooooooooo`02ooooo`005Ooo
ool00ol0003oooooooooo`02ooooocl0od`0203oG0050?m<0440oe`00`3oJ`020?mL0180of/01@3o
NP050?nh00D0oiT00P3oRP080?mj0180of/00P3oG0030?m[02P0oe`01Oooool00ol0003ooooooooo
o`02ooooo`005Oooool00ol0003oooooooooo`02ooooocl0od`0203oG0050?m<0440oe`00`3oJ`02
0?mL0180of/01@3oNP050?nh00D0oiT00P3oRP080?mj0180of/00P3oG0030?m[02P0oe`01Oooool0
0ol0003oooooooooo`02ooooo`005Oooool00ol0003oooooooooo`02ooooocl0od`0203oG0050?m<
0440oe`00`3oJ`020?mL0180of/01@3oNP050?nh00D0oiT00P3oRP080?mj0180of/00P3oG0030?m[
02P0oe`01Oooool00ol0003oooooooooo`02ooooo`005Oooool00ol0003oooooooooo`02ooooocl0
od`01@3oG00=0?m<03X0oe`00P3oJ`080?mL0140of/03`3oNP0J0?m[02d0oe`01Oooool00ol0003o
ooooooooo`02ooooo`005Oooool2o`0000?ooooo?`3oC0050?mL00d0od`0>P3oG0020?m[00P0oe`0
4@3oJ`0?0?mj01X0of/0;@3oG004ooooo`;o00001?ooool001Gooooo00?o0000ooooooooool00_oo
oolo0?m<00<0oe`03`3oC0110?mL00<0of/01@3oG00[0?m[0080oe`00`3oJ`0X0?mL00L0od`00`3o
G005ooooo`03o`000?oooooooooo00;ooooo000Eooooo`03o`000?oooooooooo00;ooooo?`3oC003
0?mL00l0od`0@@3oG0030?m[00D0oe`0:`3oJ`020?mL00<0of/0:03oG0070?m<00<0oe`01Oooool0
0ol0003oooooooooo`02ooooo`005Oooool00ol0003oooooooooo`02ooooocl0od`00`3oG00?0?m<
0440oe`00`3oJ`050?mL02/0of/00P3oG0030?m[02P0oe`01`3oC0030?mL00Gooooo00?o0000oooo
ooooool00_ooool001Gooooo00?o0000ooooooooool00_ooooll0?m<00<0oe`04P3oC00:0?mL0080
od`0@P3oG00Q0?m[0080oe`00`3oJ`0Z0?mL00d0od`01Oooool00ol0003oooooooooo`02ooooo`00
5Oooool00ol0003oooooooooo`02oooooc`0od`00`3oG00B0?m<00X0oe`00P3oC0120?mL0240of/0
0P3oG0030?m[02X0oe`03@3oC005ooooo`03o`000?oooooooooo00;ooooo000Eooooo`03o`000?oo
oooooooo00;ooooo203oC0020?mL04L0od`01@3oG00<0?m<0480oe`00P3oJ`030?mL00`0of/00`3o
G0020?m[00<0oe`00`3oJ`0_0?mL00d0od`01Oooool00ol0003oooooooooo`02ooooo`005Oooool0
0ol0003oooooooooo`02ooooo`P0od`00P3oG0170?m<00D0oe`0303oC0120?mL0080of/00`3oG00<
0?m[00<0oe`00P3oJ`030?mL00<0of/0;`3oG00=0?m<00Gooooo00?o0000ooooooooool00_ooool0
01Gooooo00?o0000ooooooooool00_ooool80?m<0080oe`0A`3oC0050?mL00`0od`0@P3oG0020?m[
00<0oe`0303oJ`030?mL0080of/00`3oG0030?m[02l0oe`03@3oC005ooooo`03o`000?oooooooooo
00;ooooo000Eooooo`03o`000?oooooooooo00;oooooD@3oC0020?mL00l0od`0A`3oG0020?m[00<0
oe`00P3oJ`030?mL0080of/0<03oG0050?m<00D0oe`03@3oC005ooooo`03o`000?oooooooooo00;o
oooo00001?oooooo0000o`000?l00004ooooo`;o00001?ooool2o`0000Gooooo00?o0000oooooooo
ool00_oooomA0?m<0080oe`03`3oC0170?mL0080of/00`3oG0020?m[00<0oe`00P3oJ`0`0?mL00D0
od`01@3oG00=0?m<00Gooooo00?o0000ooooooooool00_ooool000;ooooo00?o0000ooooooooool0
0_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000oooo
ooooool00_oooom>0?m<00<0oe`0503oC0070?mL00D0od`0LP3oG00<0?m<00<0oe`02P3oC005oooo
o`03o`000?oooooooooo00;ooooo0002ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooo
oooo00000_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo00;oooooCP3oC003
0?mL01@0od`01`3oG0050?m<0780oe`0303oC0030?mL00X0od`01Oooool00ol0003oooooooooo`02
ooooo`000_ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000
oooooooooooo00001?ooool2o`0000?oooooCP3oC0030?mL01@0od`01`3oG0050?m<0780oe`0303o
C0030?mL00X0od`00oooool3o`0000Cooooo0002ooooo`03o`000?oooooooooo00;ooooo00Co0000
oooooooooooo00000_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo0?oooooo
1?ooool00ol0003oooooooooo`02ooooo`0000?oooooo`000?l000001?ooool01?l0003ooooooooo
ool00002ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0ooooool4ooooo`03
o`000?oooooooooo00;ooooo0002ooooo`03o`000?oooooooooo00?ooooo0_l00004ooooo`;o0000
1Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0
;oooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0
<?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo000Eooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool00_ooool001Goooooool00008o`0000Cooooo003ooooo
ob7ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo003ooooo
ob7ooooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-10.4521, -9.45218, 0.397312, \
0.397312}}]
}, Open  ]],

Cell["\<\
Attrezziamoci ora per poter visualizzare comodamente alcune parti \
di questo grafico. La seguente funzione permette di impostare i limiti \
sinistro, destro, superiore e inferiore e il numero di punti da inserire nel \
grafico, unitamente alla gestione di alcuni argomenti con valore predefinito \
e alla presenza di eventuali opzioni per ListDensityPlot:\
\>", "Text"],

Cell[BoxData[
    \(mandelbrotSet[{{x0_, x1_}, {y0_, y1_}}, steps_, {min_:  0, max_:  100}, 
        opts___] := \[IndentingNewLine]Block[{matrix}, \
\[IndentingNewLine]matrix = 
          mandelbrotC[{{x0, x1}, {y0, y1}}, 
            steps]; \[IndentingNewLine]ListDensityPlot[matrix, 
          Mesh \[Rule] False, AspectRatio \[Rule] Automatic, 
          MeshRange \[Rule] {{x0, x1}, {y0, y1}}, 
          PlotRange \[Rule] {min, max}, opts]\[IndentingNewLine]]\)], "Input"],

Cell["\[CapitalEGrave] quindi facile ottenere l'ultimo dei grafici \
generati:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(mandelbrotSet[{{\(-2.5\), 0.7}, {\(-1.3\), 1.3}}, 100, {0, 100}, 
        ColorFunction \[Rule] Hue];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .8125 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.770433 0.300481 0.40625 0.300481 [
[.01923 -0.0125 -12 -9 ]
[.01923 -0.0125 12 0 ]
[.16947 -0.0125 -6 -9 ]
[.16947 -0.0125 6 0 ]
[.31971 -0.0125 -12 -9 ]
[.31971 -0.0125 12 0 ]
[.46995 -0.0125 -6 -9 ]
[.46995 -0.0125 6 0 ]
[.62019 -0.0125 -12 -9 ]
[.62019 -0.0125 12 0 ]
[.77043 -0.0125 -3 -9 ]
[.77043 -0.0125 3 0 ]
[.92067 -0.0125 -9 -9 ]
[.92067 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .10577 -12 -4.5 ]
[-0.0125 .10577 0 4.5 ]
[-0.0125 .25601 -24 -4.5 ]
[-0.0125 .25601 0 4.5 ]
[-0.0125 .40625 -6 -4.5 ]
[-0.0125 .40625 0 4.5 ]
[-0.0125 .55649 -18 -4.5 ]
[-0.0125 .55649 0 4.5 ]
[-0.0125 .70673 -6 -4.5 ]
[-0.0125 .70673 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .8125 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .8125 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.01923 0 m
.01923 .00625 L
s
[(-2.5)] .01923 -0.0125 0 1 Mshowa
.16947 0 m
.16947 .00625 L
s
[(-2)] .16947 -0.0125 0 1 Mshowa
.31971 0 m
.31971 .00625 L
s
[(-1.5)] .31971 -0.0125 0 1 Mshowa
.46995 0 m
.46995 .00625 L
s
[(-1)] .46995 -0.0125 0 1 Mshowa
.62019 0 m
.62019 .00625 L
s
[(-0.5)] .62019 -0.0125 0 1 Mshowa
.77043 0 m
.77043 .00625 L
s
[(0)] .77043 -0.0125 0 1 Mshowa
.92067 0 m
.92067 .00625 L
s
[(0.5)] .92067 -0.0125 0 1 Mshowa
.125 Mabswid
.04928 0 m
.04928 .00375 L
s
.07933 0 m
.07933 .00375 L
s
.10938 0 m
.10938 .00375 L
s
.13942 0 m
.13942 .00375 L
s
.19952 0 m
.19952 .00375 L
s
.22957 0 m
.22957 .00375 L
s
.25962 0 m
.25962 .00375 L
s
.28966 0 m
.28966 .00375 L
s
.34976 0 m
.34976 .00375 L
s
.37981 0 m
.37981 .00375 L
s
.40986 0 m
.40986 .00375 L
s
.4399 0 m
.4399 .00375 L
s
.5 0 m
.5 .00375 L
s
.53005 0 m
.53005 .00375 L
s
.5601 0 m
.5601 .00375 L
s
.59014 0 m
.59014 .00375 L
s
.65024 0 m
.65024 .00375 L
s
.68029 0 m
.68029 .00375 L
s
.71034 0 m
.71034 .00375 L
s
.74038 0 m
.74038 .00375 L
s
.80048 0 m
.80048 .00375 L
s
.83053 0 m
.83053 .00375 L
s
.86058 0 m
.86058 .00375 L
s
.89063 0 m
.89063 .00375 L
s
.95072 0 m
.95072 .00375 L
s
.98077 0 m
.98077 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .10577 m
.00625 .10577 L
s
[(-1)] -0.0125 .10577 1 0 Mshowa
0 .25601 m
.00625 .25601 L
s
[(-0.5)] -0.0125 .25601 1 0 Mshowa
0 .40625 m
.00625 .40625 L
s
[(0)] -0.0125 .40625 1 0 Mshowa
0 .55649 m
.00625 .55649 L
s
[(0.5)] -0.0125 .55649 1 0 Mshowa
0 .70673 m
.00625 .70673 L
s
[(1)] -0.0125 .70673 1 0 Mshowa
.125 Mabswid
0 .13582 m
.00375 .13582 L
s
0 .16587 m
.00375 .16587 L
s
0 .19591 m
.00375 .19591 L
s
0 .22596 m
.00375 .22596 L
s
0 .28606 m
.00375 .28606 L
s
0 .31611 m
.00375 .31611 L
s
0 .34615 m
.00375 .34615 L
s
0 .3762 m
.00375 .3762 L
s
0 .4363 m
.00375 .4363 L
s
0 .46635 m
.00375 .46635 L
s
0 .49639 m
.00375 .49639 L
s
0 .52644 m
.00375 .52644 L
s
0 .58654 m
.00375 .58654 L
s
0 .61659 m
.00375 .61659 L
s
0 .64663 m
.00375 .64663 L
s
0 .67668 m
.00375 .67668 L
s
0 .07572 m
.00375 .07572 L
s
0 .04567 m
.00375 .04567 L
s
0 .01562 m
.00375 .01562 L
s
0 .73678 m
.00375 .73678 L
s
0 .76683 m
.00375 .76683 L
s
0 .79688 m
.00375 .79688 L
s
.25 Mabswid
0 0 m
0 .8125 L
s
.01923 .80625 m
.01923 .8125 L
s
.16947 .80625 m
.16947 .8125 L
s
.31971 .80625 m
.31971 .8125 L
s
.46995 .80625 m
.46995 .8125 L
s
.62019 .80625 m
.62019 .8125 L
s
.77043 .80625 m
.77043 .8125 L
s
.92067 .80625 m
.92067 .8125 L
s
.125 Mabswid
.04928 .80875 m
.04928 .8125 L
s
.07933 .80875 m
.07933 .8125 L
s
.10938 .80875 m
.10938 .8125 L
s
.13942 .80875 m
.13942 .8125 L
s
.19952 .80875 m
.19952 .8125 L
s
.22957 .80875 m
.22957 .8125 L
s
.25962 .80875 m
.25962 .8125 L
s
.28966 .80875 m
.28966 .8125 L
s
.34976 .80875 m
.34976 .8125 L
s
.37981 .80875 m
.37981 .8125 L
s
.40986 .80875 m
.40986 .8125 L
s
.4399 .80875 m
.4399 .8125 L
s
.5 .80875 m
.5 .8125 L
s
.53005 .80875 m
.53005 .8125 L
s
.5601 .80875 m
.5601 .8125 L
s
.59014 .80875 m
.59014 .8125 L
s
.65024 .80875 m
.65024 .8125 L
s
.68029 .80875 m
.68029 .8125 L
s
.71034 .80875 m
.71034 .8125 L
s
.74038 .80875 m
.74038 .8125 L
s
.80048 .80875 m
.80048 .8125 L
s
.83053 .80875 m
.83053 .8125 L
s
.86058 .80875 m
.86058 .8125 L
s
.89063 .80875 m
.89063 .8125 L
s
.95072 .80875 m
.95072 .8125 L
s
.98077 .80875 m
.98077 .8125 L
s
.25 Mabswid
0 .8125 m
1 .8125 L
s
.99375 .10577 m
1 .10577 L
s
.99375 .25601 m
1 .25601 L
s
.99375 .40625 m
1 .40625 L
s
.99375 .55649 m
1 .55649 L
s
.99375 .70673 m
1 .70673 L
s
.125 Mabswid
.99625 .13582 m
1 .13582 L
s
.99625 .16587 m
1 .16587 L
s
.99625 .19591 m
1 .19591 L
s
.99625 .22596 m
1 .22596 L
s
.99625 .28606 m
1 .28606 L
s
.99625 .31611 m
1 .31611 L
s
.99625 .34615 m
1 .34615 L
s
.99625 .3762 m
1 .3762 L
s
.99625 .4363 m
1 .4363 L
s
.99625 .46635 m
1 .46635 L
s
.99625 .49639 m
1 .49639 L
s
.99625 .52644 m
1 .52644 L
s
.99625 .58654 m
1 .58654 L
s
.99625 .61659 m
1 .61659 L
s
.99625 .64663 m
1 .64663 L
s
.99625 .67668 m
1 .67668 L
s
.99625 .07572 m
1 .07572 L
s
.99625 .04567 m
1 .04567 L
s
.99625 .01562 m
1 .01562 L
s
.99625 .73678 m
1 .73678 L
s
.99625 .76683 m
1 .76683 L
s
.99625 .79688 m
1 .79688 L
s
.25 Mabswid
1 0 m
1 .8125 L
s
0 0 m
1 0 L
1 .8125 L
0 .8125 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.01923 .01563 translate
.96154 .78125 scale
300 string
100 100 8 [100 0 0 100 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF4C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00
FF4C00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF5C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF5C00FF5C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF5C00FF4C00
FF4C00FF4C00FF4C00FF4C00
FF3D00FF4C00FF4C00FF4C00FF4C00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF5C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00
FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF4C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FFA800
FF9900FF9900FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF4C00
FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF6B00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF9900
FFC700FFE600FF8A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00
FF4C00FF5C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF8A00
FFA800FFC700FF9900FF8A00FF8A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF8A00
FFA80000E1FFFFB800FF9900FF8A00FF8A00FF8A00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF8A00FF8A00
FFA800FFD700FAFF00FFA800FFA800FFB800FFA800FF7A00FF7A00FF6B00FF6B00FF6B00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF8A00FF9900
FFA800FFC70042FF00FFC700FFE600BDFF00FFA800FF8A00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF8A00FF8A00FF9900
FFA800FFB800FFE600CCFF00FAFF00FFB800FF9900FF8A00FF7A00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF9900
FFA800FFB800FFE60061FF00FFD700FFB800FF9900FF8A00FF8A00FF7A00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF9900FFA800
FFB800FFE600EBFF0000FF66FFE600FFB800FF9900FF8A00FF8A00FF7A00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF9900FFB800FFC700
FFC700EBFF00FF007A00FFB342FF00FFC700FFA800FF9900FF8A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF9900FFE600FFF50070FF00
DCFF00CCFF00FF0000FF0000CCFF00FFD70000FFA39EFF00FF9900FF8A00FF7A00FF7A00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF9900FFD700FAFF0033FF00
9EFF00FF0000FF0000FF000000FF47EBFF0051FF00FFC700FF9900FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF9900FF9900FFB800FFE6000085FF
FF0000FF0000FF0000FF0000FF000000FF5700FF2823FF00FF9900FF9900FF8A00FF8A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF9900FFA800FFB800BDFF0000FF28
FF0000FF0000FF0000FF0000FF0000BD00FFDCFF00FFC700FFA800FF9900FF8A00FF8A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF5C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FFA800FFB800BDFF00FF0000
FF0000FF0000FF0000FF0000FF0000FF000023FF00FFC700FFA800FF9900FF9900FF8A00
FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF6B00FF5C00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF8A00FF8A00
FF8A00FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFB800FFC700FFF50000FF0A
FF0000FF0000FF0000FF0000FF0000FF0000EBFF00FFC700FFA800FFA800FF9900FF9900
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF6B00FF6B00FF6B00FF5C00
FF6B00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF8A00FF9900
FFA800FFA800FFB800FFA800FFA800FFA800FFA800FFB800FFC700FFC700FFE60000FF47
FF0000FF0000FF0000FF0000FF0000FF0000FAFF00FFC700FFB800FFA800FFB800FF9900
FF9900FF8A00FF8A00FF8A00FF99009EFF00FF8A00FF7A00FF7A00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF8A00FF990042FF00
FFD700FFE600DCFF00FFB800FFB800FFB80080FF0000FF85FFD700FFF500FAFF00CCFF00
FF0000FF0000FF0000FF0000FF0000AEFF00FAFF00FFE600FFE600FFC700FFF500FFC700
FFA800FF9900FF9900FF9900FF9900FFC700FFD700FF8A00FF7A00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF4C00FF4C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF9900FFC700
42FF0014FF00FFF500FFE600FFC700FFD70000F0FF61FF00DCFF00FF00000066FF00FF19
FF0000FF0000FF0000AE00FFFF000000FF28FF000000D1FF00FFC2FFF50070FF0000FF94
FFB800FFA800FFA800FFA800FFB800FAFF00FFB800FF8A00FF7A00FF7A00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF990080FF00
70FF000047FF0094FFFF0000FFF500FFF5008000FFFF00002300FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000E1FF8FFF00FF0000CCFF00
FFC700FFB80000FF0AFFE600FFC700FFF500FFC700FFC700FF8A00FF7A00FF6B00FF6B00
FF6B00FF6B00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF9900FFA800FFD700
FAFF0000C2FFFF0000FF0000CCFF000094FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000CCFF00
DCFF00FFD700FAFF0080FF0000FF19DCFF0042FF00FFC700FF8A00FF7A00FF6B00FF6B00
FF6B00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF6B00FF5C00FF5C00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF9900FFA800FFB800
DCFF0000FF94FF0000FF000070FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
61FF00FAFF00FF0099FF0000FF000061FF00CCFF00FFA800FF8A00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF9900FF9900FFA800FFC700
EBFF0000FF19FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00008FFF00FF0000FF0000FF000000FF19FFC700FF9900FF8A00FF7A00FF6B00FF6B00
FF6B00FF6B00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FFA800FFB800FFC700
FFF500BDFF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FFB800FF9900FF8A00FF7A00FF6B00FF6B00
FF6B00FF6B00FF5C00FF6B00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FFA800FFC70000FF85FFE600
000AFFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000500FFFAFF00FFA800FF9900FF8A00FF7A00FF7A00FF6B00
FF6B00FF6B00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FFA800BDFF0000F0FF9EFF00BDFF00
51FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF000000A3FFEBFF00FFC700FFA800FF9900FF8A00FF7A00FF7A00FF6B00
FF6B00FF6B00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF8A00FFA800FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FFA800FFC70000FF66FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF000000FFF0EBFF00FFB800FF9900FF8A00FF8A00FF7A00FF6B00
FF6B00FF6B00FF6B00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF8A00FF8A00FFD700FFC700FF9900FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900
FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FFA800FFC700FAFF00FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF000000FF47FFC700FFA800FFA800FF8A00FF7A00FF6B00
FF6B00FF6B00FF6B00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00
FF7A00FF8A00FFA800AEFF00FFA800FF9900FF9900FF9900FF9900FFA80061FF00FFA800
FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFB800FFD700FAFF0070FF00FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF000033FF00FFF500FFD700FFF500FF9900FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF6B00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00
FF8A00FF9900FFB800FAFF00FFB800FFA800FFA800FFA800FFA800FFB80033FF00FFB800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFC70000FF661400FF1400FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF000000FF75FF0000DCFF0000FF38FF9900FF7A00FF7A00
FF6B00FF6B00FF6B00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00
FF8A00FF9900FFB8008FFF00FFD700FFC700FFF500FFB800FFB800FFD700EBFF00FFD700
FFB800FFB800FFB800FFA800FFA800FFA800FFB800FFD70023FF00FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF94FF9900FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00
FF8A00FF9900FFA800FFD700EBFF009EFF00AEFF00FFE600FFD700FFE600DCFF0000FF47
FFD70080FF00FFC700FFB800FFB800FFB800FFC700FFD7009EFF00FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF75FFB800FF9900FF8A00FF7A00
FF6B00FF6B00FF6B00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF8A00
FF8A00FF9900FFA800FFB800FFD700CCFF004200FF00A3FFFAFF00FAFF008FFF00FF0000
DCFF009EFF00DCFF00FFD700FFC700FFC700FFC700DCFF00FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF000000FFF0FFC700FFA800FF8A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00
FF8A00FF9900FFA800FFB800FFD700AEFF00FF0000FF0000AEFF00FF000023FF00FF0000
00FFB300FFB370FF009EFF00FFE600FFD700FFD700FAFF00FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFD700FFA800FF8A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00
FF9900FF9900FFB800FFB800FFF5008FFF00FF0000FF0000FF008AFF0000FF0000FF0000
FF0000FF000000FFE100E1FF0066FFFFF500FFF500AEFF00FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF000005FF0005FF008FFF00FF8A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF9900
FF9900FFA800FFC700FFD700FFF500BDFF0000FF28FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF000000FFF0EBFF00FAFF00000AFFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF47DCFF00FF8A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF9900FF9900FF9900
FFA800FFA800FFF500EBFF001400FF00FFF0FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000DCFF00FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000CC00FFFFC700FF9900FF8A00FF8A00FF7A00
FF6B00FF6B00FF6B00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF9900FFC700FFA800
FFB800FFB800FFD700DCFF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000AEFF0000FFC2FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF005CCCFF00FF9900FF8A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF9900FFA800BDFF00FFC700
FFC700FFD700FFE600CCFF005100FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF000061FF00FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFC700FF9900FF7A00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FFA800FFD700EBFF00
FFE600EBFF00FAFF009EFF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000CCFF00FFA800FF8A00FF8A00FF7A00FF6B00
FF6B00FF6B00FF6B00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FFA800FFB800FFD70033FF00
00FFB30085FFAEFF0042FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FFB800FF9900FF8A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF6B00FF7A00FF7A00FF7A00FF8A00FF8A00FF9900FFC700
FF9900FF9900FF9900FFA800FF9900FF9900FFA800FFA800FFC700FFC700FFF500BDFF00
FF0000FF0000FF00005100FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FFE600FFA800FF8A00FF8A00FF7A00FF7A00FF6B00
FF6B00FF6B00FF6B00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF6B00FF7A00FF7A00FF8A00FF8A00FF9900FF9900FFA800DCFF00
FFB800FFA800FFA800FFC700FFB800FFB800FFB800FFC700FAFF00FFE600BDFF0051FF00
FF0000FF0000FF00000047FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FAFF00FFB800FF9900FF8A00FF8A00FF7A00FF7A00FF6B00
FF6B00FF6B00FF6B00FF5C00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF7A00FF7A00FF8A0000B3FF0085FF0047FF4200FFFF00B87000FFFF00B8FF0000
FF00008000FFFF003DFF0000FF008AFF001EFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00006100FFCCFF00FFE600FFC700FFB800FFA800FF9900FF9900FF9900FF8A00
FF8A00FF8A00FF7A00FF7A00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF6B00FF7A00FF7A00FF8A00FF8A00FF9900FF9900FFA800DCFF00
FFB800FFA800FFA800FFC700FFB800FFB800FFB800FFC700FAFF00FFE600BDFF0051FF00
FF0000FF0000FF00000047FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FAFF00FFB800FF9900FF8A00FF8A00FF7A00FF7A00FF6B00
FF6B00FF6B00FF6B00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF6B00FF7A00FF7A00FF7A00FF8A00FF8A00FF9900FFC700
FF9900FF9900FF9900FFA800FF9900FF9900FFA800FFA800FFC700FFC700FFF500BDFF00
FF0000FF0000FF00005100FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FFE600FFA800FF8A00FF8A00FF7A00FF7A00FF6B00
FF6B00FF6B00FF6B00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FFA800FFB800FFD70033FF00
00FFB30085FFAEFF0042FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FFB800FF9900FF8A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FFA800FFD700EBFF00
FFE600EBFF00FAFF009EFF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000CCFF00FFA800FF8A00FF8A00FF7A00FF6B00
FF6B00FF6B00FF6B00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF9900FFA800BDFF00FFC700
FFC700FFD700FFE600CCFF005100FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF000061FF00FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFC700FF9900FF7A00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF9900FFC700FFA800
FFB800FFB800FFD700DCFF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000AEFF0000FFC2FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF005CCCFF00FF9900FF8A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF9900FF9900FF9900
FFA800FFA800FFF500EBFF001400FF00FFF0FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000DCFF00FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000CC00FFFFC700FF9900FF8A00FF8A00FF7A00
FF6B00FF6B00FF6B00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF9900
FF9900FFA800FFC700FFD700FFF500BDFF0000FF28FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF000000FFF0EBFF00FAFF00000AFFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF47DCFF00FF8A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00
FF9900FF9900FFB800FFB800FFF5008FFF00FF0000FF0000FF008AFF0000FF0000FF0000
FF0000FF000000FFE100E1FF0066FFFFF500FFF500AEFF00FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF000005FF0005FF008FFF00FF8A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00
FF8A00FF9900FFA800FFB800FFD700AEFF00FF0000FF0000AEFF00FF000023FF00FF0000
00FFB300FFB370FF009EFF00FFE600FFD700FFD700FAFF00FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFD700FFA800FF8A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF8A00
FF8A00FF9900FFA800FFB800FFD700CCFF004200FF00A3FFFAFF00FAFF008FFF00FF0000
DCFF009EFF00DCFF00FFD700FFC700FFC700FFC700DCFF00FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF000000FFF0FFC700FFA800FF8A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00
FF8A00FF9900FFA800FFD700EBFF009EFF00AEFF00FFE600FFD700FFE600DCFF0000FF47
FFD70080FF00FFC700FFB800FFB800FFB800FFC700FFD7009EFF00FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF75FFB800FF9900FF8A00FF7A00
FF6B00FF6B00FF6B00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00
FF8A00FF9900FFB8008FFF00FFD700FFC700FFF500FFB800FFB800FFD700EBFF00FFD700
FFB800FFB800FFB800FFA800FFA800FFA800FFB800FFD70023FF00FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF94FF9900FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF6B00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00
FF8A00FF9900FFB800FAFF00FFB800FFA800FFA800FFA800FFA800FFB80033FF00FFB800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFC70000FF661400FF1400FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF000000FF75FF0000DCFF0000FF38FF9900FF7A00FF7A00
FF6B00FF6B00FF6B00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00
FF7A00FF8A00FFA800AEFF00FFA800FF9900FF9900FF9900FF9900FFA80061FF00FFA800
FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFB800FFD700FAFF0070FF00FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF000033FF00FFF500FFD700FFF500FF9900FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF8A00FF8A00FFD700FFC700FF9900FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900
FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FFA800FFC700FAFF00FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF000000FF47FFC700FFA800FFA800FF8A00FF7A00FF6B00
FF6B00FF6B00FF6B00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF8A00FFA800FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FFA800FFC70000FF66FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF000000FFF0EBFF00FFB800FF9900FF8A00FF8A00FF7A00FF6B00
FF6B00FF6B00FF6B00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FFA800BDFF0000F0FF9EFF00BDFF00
51FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF000000A3FFEBFF00FFC700FFA800FF9900FF8A00FF7A00FF7A00FF6B00
FF6B00FF6B00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FFA800FFC70000FF85FFE600
000AFFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000500FFFAFF00FFA800FF9900FF8A00FF7A00FF7A00FF6B00
FF6B00FF6B00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FFA800FFB800FFC700
FFF500BDFF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FFB800FF9900FF8A00FF7A00FF6B00FF6B00
FF6B00FF6B00FF5C00FF6B00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF9900FF9900FFA800FFC700
EBFF0000FF19FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00008FFF00FF0000FF0000FF000000FF19FFC700FF9900FF8A00FF7A00FF6B00FF6B00
FF6B00FF6B00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF6B00FF5C00FF5C00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF9900FFA800FFB800
DCFF0000FF94FF0000FF000070FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
61FF00FAFF00FF0099FF0000FF000061FF00CCFF00FFA800FF8A00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF9900FFA800FFD700
FAFF0000C2FFFF0000FF0000CCFF000094FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000CCFF00
DCFF00FFD700FAFF0080FF0000FF19DCFF0042FF00FFC700FF8A00FF7A00FF6B00FF6B00
FF6B00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF990080FF00
70FF000047FF0094FFFF0000FFF500FFF5008000FFFF00002300FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000E1FF8FFF00FF0000CCFF00
FFC700FFB80000FF0AFFE600FFC700FFF500FFC700FFC700FF8A00FF7A00FF6B00FF6B00
FF6B00FF6B00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF4C00FF4C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF9900FFC700
42FF0014FF00FFF500FFE600FFC700FFD70000F0FF61FF00DCFF00FF00000066FF00FF19
FF0000FF0000FF0000AE00FFFF000000FF28FF000000D1FF00FFC2FFF50070FF0000FF94
FFB800FFA800FFA800FFA800FFB800FAFF00FFB800FF8A00FF7A00FF7A00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF8A00FF990042FF00
FFD700FFE600DCFF00FFB800FFB800FFB80080FF0000FF85FFD700FFF500FAFF00CCFF00
FF0000FF0000FF0000FF0000FF0000AEFF00FAFF00FFE600FFE600FFC700FFF500FFC700
FFA800FF9900FF9900FF9900FF9900FFC700FFD700FF8A00FF7A00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF8A00FF9900
FFA800FFA800FFB800FFA800FFA800FFA800FFA800FFB800FFC700FFC700FFE60000FF47
FF0000FF0000FF0000FF0000FF0000FF0000FAFF00FFC700FFB800FFA800FFB800FF9900
FF9900FF8A00FF8A00FF8A00FF99009EFF00FF8A00FF7A00FF7A00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF6B00FF5C00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF8A00FF8A00
FF8A00FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFB800FFC700FFF50000FF0A
FF0000FF0000FF0000FF0000FF0000FF0000EBFF00FFC700FFA800FFA800FF9900FF9900
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF6B00FF6B00FF6B00FF5C00
FF6B00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF5C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FFA800FFB800BDFF00FF0000
FF0000FF0000FF0000FF0000FF0000FF000023FF00FFC700FFA800FF9900FF9900FF8A00
FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF9900FFA800FFB800BDFF0000FF28
FF0000FF0000FF0000FF0000FF0000BD00FFDCFF00FFC700FFA800FF9900FF8A00FF8A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF9900FF9900FFB800FFE6000085FF
FF0000FF0000FF0000FF0000FF000000FF5700FF2823FF00FF9900FF9900FF8A00FF8A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF9900FFD700FAFF0033FF00
9EFF00FF0000FF0000FF000000FF47EBFF0051FF00FFC700FF9900FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF9900FFE600FFF50070FF00
DCFF00CCFF00FF0000FF0000CCFF00FFD70000FFA39EFF00FF9900FF8A00FF7A00FF7A00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF9900FFB800FFC700
FFC700EBFF00FF007A00FFB342FF00FFC700FFA800FF9900FF8A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF9900FFA800
FFB800FFE600EBFF0000FF66FFE600FFB800FF9900FF8A00FF8A00FF7A00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF9900
FFA800FFB800FFE60061FF00FFD700FFB800FF9900FF8A00FF8A00FF7A00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF8A00FF8A00FF9900
FFA800FFB800FFE600CCFF00FAFF00FFB800FF9900FF8A00FF7A00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00
FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF8A00FF9900
FFA800FFC70042FF00FFC700FFE600BDFF00FFA800FF8A00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF8A00FF8A00
FFA800FFD700FAFF00FFA800FFA800FFB800FFA800FF7A00FF7A00FF6B00FF6B00FF6B00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF8A00
FFA80000E1FFFFB800FF9900FF8A00FF8A00FF8A00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF8A00
FFA800FFC700FF9900FF8A00FF8A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF6B00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF9900
FFC700FFE600FF8A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00
FF4C00FF5C00FF4C00FF4C00
FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF4C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FFA800
FF9900FF9900FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF4C00
FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00
FF3D00FF4C00FF4C00FF4C00FF4C00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF5C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF5C00FF5C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF5C00FF4C00
FF4C00FF4C00FF4C00FF4C00
FF4C00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF5C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF4C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 234},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000jR000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQ
ooooo`006_ooool5o`0000?ooooo00?o0000ooooooooool00_ooool3o`0001gooooo1Ol0000Moooo
o`?o00001?ooool00ol0003oooooooooo`02ooooo`?o00007_ooool3o`0001oooooo0_l00004oooo
o`03o`000?oooooooooo00;ooooo0ol0000Looooo`;o00007oooool2o`0000Cooooo00?o0000oooo
ooooool00_ooool3o`0000oooooo000Kooooo`04o`000?ooooooooooo`0000Oooooo00Go0000oooo
ooooooooooooo`00000Mooooo`04o`000?ooooooooooo`0001kooooo00?o0000ooooooooool01ooo
ool01Ol0003ooooooooooooooooo000001kooooo00?o0000ooooooooool07Oooool01?l0003ooooo
ooooool00007ooooo`05o`000?ooooooooooooooool000006_ooool01?l0003oooooooooool0000M
ooooo`04o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`00000>ooooo`005?oo
ool5o`0000?ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Dooooo`Go00000ooo
ool00ol0003oooooooooo`0Fooooo`Go00000oooool00ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo01Cooooo1Ol00003ooooo`03o`000?oooooooooo01Kooooo1Ol00002ooooo`04o`000?oo
ooooooooo`0000_ooooo00?o0000ooooooooool06?ooool01?l0003oooooooooool0000Mooooo`04
o`000?ooooooooooo`0000_ooooo00?o0000ooooooooool03?ooool001gooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo01gooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01gooooo00Co0000oooooooo
oooo00002oooool00ol0003oooooooooo`0Hooooo`04o`000?ooooooooooo`0001gooooo00Co0000
oooooooooooo00002oooool00ol0003oooooooooo`0<ooooo`006_ooool01Ol0003ooooooooooooo
oooo000000Oooooo1?l0000Mooooo`05o`000?ooooooooooooooool000007_ooool00ol0003ooooo
ooooo`07ooooo`Co00007oooool00ol0003oooooooooo`0Mooooo`04o`000?ooooooooooo`0000Oo
oooo1?l0000Kooooo`04o`000?ooooooooooo`0001gooooo00Co0000oooooooooooo00001oooool4
o`0000oooooo000Jooooo`05o`000?ooooooooooooooool000001oooool00ol0003oooooooooo`0N
ooooo`05o`000?ooooooooooooooool000007Oooool2o`0000Wooooo00?o0000ooooooooool07ooo
ool2o`0001oooooo00Co0000oooooooooooo00001oooool00ol0003oooooooooo`0Looooo`04o`00
0?ooooooooooo`0001gooooo00Co0000oooooooooooo00001oooool00ol0003oooooooooo`0@oooo
o`006oooool3o`0000Sooooo1Ol0000Mooooo`?o00007oooool00ol0003oooooooooo`07ooooo`Go
00007_ooool00ol0003oooooooooo`0Nooooo`;o00002?ooool5o`0001_ooooo0_l0000Oooooo`;o
00002?ooool5o`0000kooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo003ooooo
ob7ooooo003oooooob7ooooo000Koooooooo00001Ol00001ooooo`006oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`02ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool0ooooool1ooooo`7o00000Oooool0
01_ooooo00?o0000ooooooooool0ooooool1ooooo`7o00000Oooool001_ooooo0_l0003oooooo`7o
oooo0_l00001ooooo`006oooool00ol0003oooooooooo`02ooooob00ocd0D`3oC0020?mL00`0od`0
0`3oG00:0?m<04/0oe`02P3oC0020?mL01@0od`01Oooool1o`00007ooooo000Kooooo`03o`000?oo
oooooooo00;ooooo803o?@1C0?m<0080oe`0303oC0030?mL00X0od`0B`3oG00:0?m<0080oe`0503o
C005ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool00_oooolP0?lm0640od`01@3oG005
0?m<04h0oe`01`3oC0030?mL01H0od`01Oooool1o`00007ooooo000Kooooo`03o`000?oooooooooo
00;ooooo803o?@1Q0?m<00D0oe`01@3oC01>0?mL00L0od`00`3oG00F0?m<00Gooooo0Ol00001oooo
o`006oooool00ol0003oooooooooo`02ooooob00ocd0E@3oC0030?mL00T0od`0<03oG0020?m[02P0
oe`00`3oC0050?mL01H0od`01Oooool1o`00007ooooo000Kooooo`03o`000?oooooooooo00;ooooo
803o?@1E0?m<00<0oe`02@3oC00`0?mL0080of/0:03oG0030?m<00D0oe`05P3oC005ooooo`7o0000
0Oooool001_ooooo00?o0000ooooooooool00_ooool20?m<01`0ocd0B03oC0030?mL00`0od`01@3o
G0070?m<0300oe`0303oJ`0V0?mL01H0od`01Oooool1o`00007ooooo000Kooooo`;o00000oooool2
0?m<01`0ocd0B03oC0030?mL00`0od`01@3oG0070?m<0300oe`0303oJ`0V0?mL01H0od`01?ooool2
o`00007ooooo000Kooooo`03o`000?oooooooooo00;ooooo1`3oC00G0?lm05L0od`0203oG0020?m<
02d0oe`0503oJ`020?mL00<0of/07P3oG0070?m<00<0oe`0303oC005ooooo`7o00000Oooool001_o
oooo00?o0000ooooooooool00_ooool70?m<01L0ocd0E`3oC0080?mL0080od`0;@3oG00D0?m[0080
oe`00`3oJ`0N0?mL00L0od`00`3oG00<0?m<00Gooooo0Ol00001ooooo`006oooool00ol0003ooooo
ooooo`02ooooo`80ocd02P3oC00?0?lm04h0od`00P3oG00:0?m<0380oe`0803oJ`0L0?mL00D0od`0
0P3oG00?0?m<00Gooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`02ooooo`80ocd02P3o
C00?0?lm04h0od`00P3oG00:0?m<0380oe`0803oJ`0L0?mL00D0od`00P3oG00?0?m<00Gooooo0Ol0
0001ooooo`006oooool00ol0003oooooooooo`02ooooo`D0ocd0I03oC0020?mL00X0od`0;`3oG00=
0?m[00`0ogX03@3oJ`0P0?mL00d0od`00P3oG005ooooo`7o00000Oooool001_ooooo00?o0000oooo
ooooool00_ooool50?lm06@0od`00P3oG00:0?m<02l0oe`03@3oJ`0<0?mj00d0of/0803oG00=0?m<
0080oe`01Oooool1o`00007ooooo000Kooooo`;o00000oooool50?lm06@0od`01`3oG0030?m<02l0
oe`0303oJ`030?mj0080ojP01@3oV@080?mj00l0of/06`3oG00:0?m<00<0oe`00P3oC004ooooo`;o
00000Oooool001_ooooo00?o0000ooooooooool00_ooool50?lm06@0od`01`3oG0030?m<02l0oe`0
303oJ`030?mj0080ojP01@3oV@080?mj00l0of/06`3oG00:0?m<00<0oe`00P3oC005ooooo`7o0000
0Oooool001_ooooo00?o0000ooooooooool00_ooool70?lm0680od`0;`3oG0020?m[00D0oe`03@3o
J`050?mj0080oiT00`3oa`020?oV00<0ohX02P3oNP0:0?m[01/0oe`0203oC0020?mL00D0od`01Ooo
ool1o`00007ooooo000Kooooo`03o`000?oooooooooo00;ooooo1`3o?@1R0?m<02l0oe`00P3oJ`05
0?mL00d0of/01@3oNP020?nI00<0olL00P3oiP030?n:00X0ogX02P3oJ`0K0?mL00P0od`00P3oG005
0?m<00Gooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`02ooooo`L0ocd0E@3oC0030?mL
00X0od`0<@3oG00B0?m[00D0ogX00P3oRP030?nX0080olL00`3oV@050?n:00L0ogX02P3oJ`0S0?mL
00D0od`01Oooool1o`00007ooooo000Kooooo`03o`000?oooooooooo00;ooooo1`3o?@1E0?m<00<0
oe`02P3oC00a0?mL0180of/01@3oNP020?n:00<0ojP00P3oa`030?nI00D0ohX01`3oNP0:0?m[02<0
oe`01@3oC005ooooo`7o00000Oooool001?ooooo0ol00005ooooo`03o`000?oooooooooo00;ooooo
2P3o?@130?m<00<0oe`0303oC0050?mL00P0od`0<@3oG00?0?m[00P0ogX00P3oRP030?nX00800>7o
0`3o^0020?nI00P0ohX00P3oNP0=0?m[01h0oe`01`3oC005ooooo`7o00000Oooool001Cooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`X0ocd0@`3oC0030?mL00`0od`01@3o
G0080?m<0340oe`03`3oJ`080?mj0080ohX00`3oZ002003Qo`<0okP00P3oV@080?n:0080ogX03@3o
J`0N0?mL00L0od`01Oooool1o`00007ooooo000<ooooo`Go00000oooool00ol0003oooooooooo`04
ooooo`;o00000oooool:0?lm05D0od`0=P3oG00D0?m[00D0ogX01@3oRP030?nX0080omL00`3jo`05
0?nX0080okP00`3oZ0050?mj00X0of/07P3oG0070?m<00Cooooo0_l00001ooooo`005?ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo2P3o?@1E0?m<03H0oe`0503oJ`050?mj
00D0ohX00`3oZ0020?oG00<0n_l01@3oZ0020?nh00<0ojP01@3oNP0:0?m[01h0oe`01`3oC005oooo
o`7o00000Oooool001Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`X0
ocd0AP3oC0020?mL00d0od`0;`3oG0020?m[00<0oe`0503oJ`070?mj00<0ohX00P3oV@030?nX0080
olL00`12o`020?o700<0onH00P2mo`030?nX0080ohX00`3oNP0?0?m[01T0oe`01`3oC005ooooo`7o
00000Oooool001?ooooo0_l00006ooooo`03o`000?oooooooooo00;ooooo2P3o?@160?m<0080oe`0
3@3oC00_0?mL0080of/00`3oG00D0?m[00L0ogX00`3oRP020?nI00<0ojP00P3oa`0304;o0080olL0
0`3oiP020;go00<0ojP00P3oRP030?mj00l0of/06@3oG0070?m<00Gooooo0Ol00001ooooo`005?oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo2P3o?@180?m<00<0oe`01`3o
C00b0?mL01H0of/0203oNP050?n:0080oiT00`3oZ0020?nh00<0onH00P3<o`030?[o0080okP00`3o
V@020?n:00D0ogX03@3oJ`020?mL00<0of/06`3oG005ooooo`7o00000Oooool001_ooooo00?o0000
ooooooooool00_ooool:0?lm04P0od`00`3oG0070?m<0380oe`05P3oJ`080?mj00D0ohX00P3oV@03
0?nX0080okP00`3oiP020<co00<0n_l00P3o^0030?nI0080ohX01@3oNP0=0?m[0080oe`00`3oJ`0K
0?mL00Gooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`02ooooo`X0ocd0B03oC00_0?mL
00<0of/01@3oG00I0?m[00X0ogX01@3oRP020?nI00<0ojP00P3o^0030?oV0080HOl00`3oe`020?nh
00<0oiT01@3oRP050?mj00`0of/07P3oG005ooooo`7o00000Oooool001_ooooo00?o0000oooooooo
ool00_ooool:0?lm04P0od`0;`3oG0030?m[00D0oe`06@3oJ`0:0?mj00D0ohX00P3oV@030?nX0080
okP00`3oiP02067o00<0omL00P3o^0030?nI00D0ohX01@3oNP0<0?m[01h0oe`01Oooool1o`00007o
oooo000Kooooo`;o00000oooool:0?lm03T0od`00`3oG00<0?m<03L0oe`05P3oJ`0:0?mj00D0ohX0
0`3oV@020?nX00<0okP00P3oiP030>_o00800?mV0`3oiP020?nh00<0oiT01@3oRP050?mj0140of/0
6@3oG004ooooo`;o00000Oooool001_ooooo00?o0000ooooooooool00_ooool:0?lm03T0od`00`3o
G00<0?m<03L0oe`05P3oJ`0:0?mj00D0ohX00`3oV@020?nX00<0okP00P3oiP030>_o00800?mV0`3o
iP020?nh00<0oiT01@3oRP050?mj0140of/06@3oG005ooooo`7o00000Oooool001_ooooo00?o0000
ooooooooool00_ooool:0?lm03`0od`00P3oG00:0?m<02/0oe`00P3oJ`050?mL01T0of/02P3oNP05
0?n:0080oiT00`3o^0050?o70080jol00`3o07X2003o/`<0@_l00P3oa`030?nX0080oiT00`3oRP07
0?mj00l0of/00`3oG0020?m[01@0oe`01Oooool1o`00007ooooo000Kooooo`03o`000?oooooooooo
00;ooooo2P3o?@0l0?m<0080oe`02P3oC00[0?mL0080of/01@3oG00I0?m[00X0ogX01@3oRP020?nI
00<0okP01@3oa`020>_o00<0o`1j0P00ok<304;o0080olL00`3oZ0020?nI00<0ohX01`3oNP0?0?m[
00<0oe`00P3oJ`0D0?mL00Gooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`02ooooo`X0
ocd0?03oC0020?mL00X0od`0:`3oG0020?m[00D0oe`06@3oJ`0:0?mj00D0ohX00P3oV@030?nh00D0
olL00P3[o`030?l0NP800?nc0`12o`020?o700<0ojP00P3oV@030?n:00L0ogX03`3oJ`030?mL0080
of/0503oG005ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool00_ooool70?lm03l0od`0
1@3oG0050?m<02d0oe`06`3oJ`0<0?mj00D0ohX00`3oV@020?oV00<0ooD00P1`o`030=co0080c?l0
1@3o00030<co0080omL00`00oj<209ko00<0oiT00P3oRP080?mj00l0of/05P3oG005ooooo`7o0000
0Oooool001_ooooo00?o0000ooooooooool00_ooool70?lm03l0od`01@3oG0050?m<02d0oe`06`3o
J`0<0?mj00D0ohX00`3oV@020?oV00<0ooD00P1`o`030=co0080c?l01@3o00030<co0080omL00`00
oj<209ko00<0oiT00P3oRP080?mj00l0of/05P3oG005ooooo`7o00000Oooool001_ooooo00?o0000
ooooooooool00_ooool50?lm04<0od`0=@3oG00H0?m[00l0ogX01@3oRP030?nI0080omL00`3jo`02
03?o00<0W_l01`3o0003003oA`80jol00`1Ao`020?o700<0oiT00P3oRP0=0?mj00l0of/04@3oG005
ooooo`7o00000Oooool001_ooooo0_l00003ooooo`D0ocd0@`3oC00e0?mL01P0of/03`3oNP050?n:
00<0oiT00P3oe`030?[o0080<ol00`2No`070?l000<00?m70P3[o`03057o0080olL00`3oV@020?n:
00d0ogX03`3oJ`0A0?mL00Cooooo0_l00001ooooo`006oooool00ol0003oooooooooo`02ooooocT0
od`00`3oG00<0?m<0300oe`0603oJ`0?0?mj00P0ohX01@3oV@020?nh00<0onH00P00QOl=0?l00080
0?mG0`00obP202?o00D0oiT01@3oRP0=0?mj00X0of/04@3oG005ooooo`7o00000Oooool001_ooooo
00?o0000ooooooooool00_ooooli0?m<00<0oe`0303oC00`0?mL01P0of/03`3oNP080?n:00D0oiT0
0P3o^0030?oV008008Go3@3o0002003oE`<00?lX0P0So`050?nI00D0ohX03@3oNP0:0?m[0140oe`0
1Oooool1o`00007ooooo000Kooooo`03o`000?oooooooooo00;ooooo?03oC0020?mL00X0od`0:03o
G0030?m[00D0oe`05P3oJ`0?0?mj00X0ohX00P3oV@030?nX0080okP00`2mo`02003o:0d0o`000P2m
0?l30=co0080olL00`3oZ0020?nI00D0ohX03@3oNP0<0?m[00l0oe`01Oooool1o`00007ooooo000K
ooooo`03o`000?oooooooooo00;ooooo?03oC0020?mL00X0od`0:03oG0030?m[00D0oe`05P3oJ`0?
0?mj00X0ohX00P3oV@030?nX0080okP00`2mo`02003o:0d0o`000P2m0?l30=co0080olL00`3oZ002
0?nI00D0ohX03@3oNP0<0?m[00l0oe`01Oooool1o`00007ooooo000Kooooo`03o`000?oooooooooo
00;ooooo?03oC0050?mL00D0od`0:P3oG00K0?m[00X0ogX03@3oRP070?nI00<0ojP00P3o^0030;go
0140o`000`0So`020?o700<0ojP01@3oV@050?n:00l0ogX02P3oJ`0<0?mL00Gooooo0Ol00001oooo
o`006oooool00ol0003oooooooooo`02oooooc`0od`01@3oG0050?m<02X0oe`06`3oJ`0:0?mj00d0
ohX01`3oV@030?nX0080okP00`2mo`0A0?l000<08ol00P3oa`030?nX00D0oiT01@3oRP0?0?mj00X0
of/0303oG005ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool00_ooool]0?m<0080oe`0
3`3oC00V0?mL0080of/01@3oG0030?m[0080oe`06@3oJ`070?mj00P0ohX0303oV@050?nX00<0okP0
0P3oa`030?oe00800?l:3`3o00030>_o0080olL01@3oZ0050?nI00l0ohX01@3oNP080?m[0080oe`0
0`3oJ`070?mL00Gooooo0Ol00001ooooo`006oooool2o`0000?ooooo;@3oC0020?mL00l0od`09P3o
G0020?m[00D0oe`00`3oJ`020?mL01T0of/01`3oNP080?n:00`0oiT01@3oZ0030?nh0080olL00`3o
m@02003o2Pl0o`000`3[o`020?o700D0ojP01@3oV@0?0?n:00D0ogX0203oJ`020?mL00<0of/01`3o
G004ooooo`;o00000Oooool001_ooooo00?o0000ooooooooool00_ooooln0?m<02d0oe`06`3oJ`0:
0?mj00<0ohX00P3oV@050?nX00<0okP02P3oZ0020?nh00D0olL00`3oiP02003oA`l0o`000`3jo`02
0?o700<0okP00P3oZ0030?nh00D0oiT01`3oRP030?nI0080W_l00`3oRP050?mj00L0of/02P3oG005
ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool00_ooooln0?m<02d0oe`06`3oJ`0:0?mj
00<0ohX00P3oV@050?nX00<0okP02P3oZ0020?nh00D0olL00`3oiP02003oA`l0o`000`3jo`020?o7
00<0okP00P3oZ0030?nh00D0oiT01`3oRP030?nI0080W_l00`3oRP050?mj00L0of/02P3oG005oooo
o`7o00000Oooool001_ooooo00?o0000ooooooooool00_ooooln0?m<0240oe`00P3oJ`050?mL01h0
of/02P3oNP020?n:00<0oiT00P12o`030?oG0080onH00`3Lo`070?nh00<0P?l00P00ohD30?oG0080
ooD00`3jo`020<co00d0o`000P2^o`030?[o00D0onH00P3oa`030?oe0080olL00`3oZ00:0?nI0080
olL00`3oe`020?n:00<0ogX01`3oJ`0:0?mL00Gooooo0Ol00001ooooo`006oooool00ol0003ooooo
ooooo`02oooooch0od`08@3oG0020?m[00D0oe`07P3oJ`0:0?mj0080ohX00`3oV@0204;o00<0omL0
0P3oiP030=co00L0okP00`20o`02003oQ@<0omL00P3om@030?[o0080c?l03@3o00020:ko00<0n_l0
1@3oiP020?o700<0ooD00P3oa`030?nX00X0oiT00P3oa`030?oG0080ohX00`3oNP070?m[00X0oe`0
1Oooool1o`00007ooooo000Kooooo`03o`000?oooooooooo00;ooooo<P3oC0050?mL00D0od`08`3o
G00P0?m[00`0ogX01@3oRP030?nI0080olL00`12o`0201Co00<0ooD00P3oiP030?o70080omL00`00
l?l2067o00<0g?l00P3o0003001Vo`800?lI203o00020:h0o`<0o`000P00obP30?l000800=7o0`00
ol820?oe00<0L?l00P00oi@30?nh00L0ojP00`3o^0020?[o00<0okP00P3oRP050?mj00D0of/02P3o
G005ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool00_oooolb0?m<00D0oe`01@3oC00S
0?mL0200of/0303oNP050?n:00<0oiT00P3oa`0304;o00805?l00`3om@020?oV00<0olL00P3oe`03
003`o`80HOl00`3Lo`020?l000<006Ko0P00oaT80?l00080[P3o0`3o0002003o:0<0o`000P00dOl3
003o`P80ooD00`1`o`02003oU0<0okP01`3oZ0030?nh0080n_l00`3o^0020?n:00D0ogX01@3oJ`0:
0?mL00Gooooo0Ol00001ooooo`006oooool2o`0000?ooooo8`3oC0020?mL00l0od`09P3oG00U0?m[
00`0ogX01@3oRP030?nI0080P?l00`1`o`020017o`<009Co0P3o00050?oe00<0P03o0P3o000302<0
oa/0o`000`00hOl208oo00<0o`000P3<o`030?o70080okP00`00o`X20?oV00<0olL00P3om@050?o7
00<0ohX00P3oNP0:0?m[00D0oe`01?ooool2o`00007ooooo000Kooooo`03o`000?oooooooooo00;o
oooo8`3oC0020?mL00l0od`09P3oG00U0?m[00`0ogX01@3oRP030?nI0080P?l00`1`o`020017o`<0
09Co0P3o00050?oe00<0P03o0P3o000302<0oa/0o`000`00hOl208oo00<0o`000P3<o`030?o70080
okP00`00o`X20?oV00<0olL00P3om@050?o700<0ohX00P3oNP0:0?m[00D0oe`01Oooool1o`00007o
oooo000Kooooo`03o`000?oooooooooo00;ooooo9@3oC0030?mL00`0od`08@3oG0020?m[00<0oe`0
7P3oJ`0A0?mj00D0ohX00P3oV@030?nX0080omL00`3jo`020032o`D0o`000`3<o`02002Dob/0o`00
0P3<o`030=co0080omL00`3jo`02083o00<00?lI0P3Lo`0304;o0080olL00`3oRP020?mj00P0of/0
1`3oG005ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool00_oooolU0?m<00<0oe`0303o
C00Q0?mL0080of/00`3oG00N0?m[0140ogX01@3oRP020?nI00<0ojP00P3oe`030?[o00800<;o1@3o
00030<co008009Co:`3o00020<co00<0g?l00P3oe`030?[o0080P?l00`00oaT20=co00<0@_l00P3o
a`030?n:0080ogX0203oJ`070?mL00Gooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`02
ooooobP0od`00P3oG00:0?m<01@0oe`00`3oJ`050?mL0080of/01@3oG00N0?m[0140ogX0203oRP02
0?nI00<0ojP00P3o^0030=co00800?nD1@3o0003073o02l0o`000`1Qo`020?[o00<0o`2I1@3o0002
067o00<0c?l00P3oZ0030?n:0080ogX03@3oJ`020?mL00Gooooo0Ol00001ooooo`006oooool00ol0
003oooooooooo`02ooooobP0od`00P3oG00:0?m<01@0oe`00`3oJ`050?mL0080of/01@3oG00N0?m[
0140ogX0203oRP020?nI00<0ojP00P3o^0030=co00800?nD1@3o0003073o02l0o`000`1Qo`020?[o
00<0o`2I1@3o0002067o00<0c?l00P3oZ0030?n:0080ogX03@3oJ`020?mL00Gooooo0Ol00001oooo
o`002?ooool2o`0000Cooooo00?o0000ooooooooool00_ooool3o`0000Gooooo00?o0000oooooooo
ool00_oooolZ0?m<00<0oe`01`3oC00N0?mL01L0of/00P3oNP030?m[01H0ogX01`3oRP050?nI00<0
ojP00P3oa`030>_o00800?lI>P3o000208oo00P0o`000P00oaT30?o70080oiT00`3oRP020?mj00X0
of/01@3oG005ooooo`7o00000Oooool000Oooooo00Co0000oooooooooooo00001oooool01Ol0003o
oooooooooooooooo000000Cooooo00?o0000ooooooooool00_oooolZ0?m<00<0oe`01`3oC00N0?mL
01L0of/00P3oNP030?m[01H0ogX01`3oRP050?nI00<0ojP00P3oa`030>_o00800?lI>P3o000208oo
00P0o`000P00oaT30?o70080oiT00`3oRP020?mj00X0of/01@3oG005ooooo`7o00000Oooool000Go
00000_ooool01?l0003oooooooooool0000;ooooo`03o`000?oooooooooo00;ooooo0_l00003oooo
obX0od`0:03oG00?0?m[01h0ogX0303oRP030?nI0080ojP00`3o^0020?o700<0ooD00P2mo`160?l0
00<0okP00P3oV@030?n:0080ogX02P3oJ`030?mL0080of/01?ooool2o`00007ooooo0007ooooo`04
o`000?ooooooooooo`0000_ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02oooo
obX0od`0:03oG00?0?m[01h0ogX0303oRP030?nI0080ojP00`3o^0020?o700<0ooD00P2mo`160?l0
00<0okP00P3oV@030?n:0080ogX02P3oJ`030?mL0080of/01Oooool1o`00007ooooo0007ooooo`04
o`000?ooooooooooo`0000Oooooo1?l00005ooooo`03o`000?oooooooooo00;ooooo;@3oC00I0?mL
0080of/01@3oG00?0?m[01h0ogX03`3oRP020?nI00<0ojP00P3oa`03003oQ@80onH00`002_m30?l0
00<01@3o0P3jo`030?nX0080oiT00`3oRP050?mj00L0of/01@3oG005ooooo`7o00000Oooool000Oo
oooo00Co0000oooooooooooo00001oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00;ooooo;@3oC00I0?mL0080of/01@3oG00?0?m[01h0ogX03`3oRP020?nI00<0ojP00P3oa`03003o
Q@80onH00`002_m30?l000<01@3o0P3jo`030?nX0080oiT00`3oRP050?mj00L0of/01@3oG005oooo
o`7o00000Oooool000Sooooo0_l00008ooooo`Go00001?ooool00ol0003oooooooooo`02ooooobd0
od`0803oG00=0?m[00L0ogX00`3oRP0:0?mj0080ohX01@3oNP0A0?n:00<0oiT00P3oZ0030;go0080
0?3o0`2No`020;go00<0DOl0@@3o0002002So`<0jol00P3oa`030?nX0080oiT00`3oRP050?mj00L0
of/01@3oG005ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool00_ooool]0?m<0200oe`0
3@3oJ`070?mj00<0ohX02P3oNP020?n:00D0ogX04@3oRP030?nI0080ojP00`2mo`02003`o`<0W_l0
0P2mo`03057o0440o`000P00Xol30>_o0080olL00`3oZ0020?nI00<0ohX01@3oNP070?m[00D0oe`0
1Oooool1o`00007ooooo000Kooooo`03o`000?oooooooooo00;ooooo8`3oC0020?mL00D0od`07P3o
G00B0?m[0080ogX00`3oRP020?nX02<0ohX01@3oV@020?nX00<0olL00P00ofI;0?l000<00?o`0P3[
o`030?nh0080oiT01@3oRP030?mj00X0of/00P3oG005ooooo`7o00000Oooool001_ooooo00?o0000
ooooooooool00_oooolS0?m<0080oe`01@3oC00N0?mL0180of/00P3oNP030?n:0080ojP08`3oRP05
0?nI0080ojP00`3oa`02003oIT/0o`000`00oo020>_o00<0okP00P3oV@050?n:00<0ogX02P3oJ`02
0?mL00Gooooo0Ol00001ooooo`006oooool2o`0000?ooooo8`3oC00P0?mL00<0of/00P3oG00?0?m[
00<0ogX01@3oRP020?oG00<0olL00P3oV@0:0?n:00P0oiT01`3oRP0:0?nI0080ojP00`3oa`020?[o
04h0o`000P00odL30?o700D0ojP00P3oRP030?mj00X0of/00P3oG004ooooo`;o00000Oooool001_o
oooo00?o0000ooooooooool00_oooolS0?m<0200oe`00`3oJ`020?mL00l0of/00`3oNP050?n:0080
omL00`3oa`020?nI00X0ohX0203oV@070?n:00X0oiT00P3oZ0030?o70080n_l0CP3o0002003oA`<0
olL01@3oZ0020?n:00<0ogX02P3oJ`020?mL00Gooooo0Ol00001ooooo`006oooool00ol0003ooooo
ooooo`02ooooobD0od`07P3oG00B0?m[00L0ogX00`3oRP020?nX00<0[_l00P3oZ00:0?nI00<0ojP0
0P1Qo`030?nX00`0oiT01@3oZ0020?nh00<0omL00P3jo`03073o04/0o`000P0co`030?oe0080omL0
0`3om@020?nI00D0ogX02P3oJ`05ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool00_oo
oolU0?m<01h0oe`04P3oJ`070?mj00<0ohX00P3oZ0030:ko0080ojP02P3oV@030?nX0080HOl00`3o
Z00<0?nI00D0ojP00P3o^0030?oG0080n_l00`1`o`1;0?l00080<ol00`3om@020?oG00<0ooD00P3o
V@050?mj00X0of/01Oooool1o`00007ooooo000Kooooo`03o`000?oooooooooo00;ooooo9@3oC00I
0?mL00<0of/00P3oG00B0?m[00D0ogX00P3oRP030?nI0080okP00`3jo`020?nh00X0ojP00`3o^002
03?o00<0okP04@3oZ0020?o700<00?mV1@0D0?m;0?l000800?me0`3o00020=co00<00?lh0P3oV@05
0?mj00P0of/00P3oG005ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool00_oooolU0?m<
01T0oe`00`3oJ`020?mL0180of/01@3oNP020?n:00<0oiT00P3o^0030?[o0080okP02P3oZ0030?nh
0080<ol00`3o^00A0?nX0080olL00`00ofH501@0od/0o`000P00ogD30?l00080g?l00`00ocP20?nI
00D0ogX0203oJ`020?mL00Gooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`02oooooa/0
od`00`3oG0070?m<01@0oe`00`3oJ`050?mL0140of/0203oNP020?n:00<0oiT00P3o^00308oo0080
omL00`3oa`020?oe00D0okP00`3oe`020>_o00<0omL01`3o^0070?nX00<0okP00P3oe`0302?o05L0
o`000`00oi@20?nI00D0ogX02P3oJ`05ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool0
0_oooolK0?m<00<0oe`01`3oC00D0?mL00<0of/01@3oG00A0?m[00P0ogX00P3oRP030?nI0080okP0
0`2?o`020?oG00<0olL00P3om@050?nh00<0omL00P3[o`030?oG00L0okP01`3oZ0030?nh0080omL0
0`0So`1G0?l000<00?nD0P3oV@050?mj00X0of/01Oooool1o`00007ooooo000Kooooo`;o00000ooo
oolN0?m<01h0oe`0503oJ`0:0?mj0080ohX00`3oV@020?nX00<0omL00P3[o`0309ko0080[_l00`3o
iP020?oG00<0onH00P3Lo`03003oA`80omL00`20o`020?o700L0okP00`3oa`020?oG00<0W_l0E@3o
0002003oM@<0okP00P3oV@030?n:0080ogX0203oJ`020?mL00Cooooo0_l00001ooooo`006oooool0
0ol0003oooooooooo`02oooooah0od`07P3oG00D0?m[00X0ogX00P3oRP030?nI0080ojP00`3oe`02
0>_o00<0W_l00P2^o`030?oV0080omL00`3oiP020=co00<00?m70P3oe`03083o0080olL01`3o^003
0?o70080omL00`2No`1E0?l000800?me0`3o^0020?nI00<0ohX00P3oNP080?m[0080oe`01Oooool1
o`00007ooooo000Kooooo`03o`000?oooooooooo00;ooooo803oC00L0?mL0140of/02P3oNP050?n:
00<0oiT00P3oZ0030?nh0080omL00`3<o`020480o`<00:?o1@3jo`0208oo00<0o`000P3Lo`0309ko
0080g?l00P3oe`080?o70080g?l0E@3o0003003ol080olL00`3oZ0020?n:00D0ogX0203oJ`020?mL
00Gooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`02ooooob00od`0703oG00A0?m[00X0
ogX01@3oRP030?nI0080ojP00`3o^0020?oG00<0c?l00P120?l3002So`D0n_l00P2?o`030?l00080
g?l00`2No`020=co0080omL0203oa`020=co05D0o`000`00oo020?o700<0ojP00P3oRP050?mj00P0
of/00P3oG005ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool00_oooolP0?m<01L0oe`0
4@3oJ`0=0?mj00L0ohX00`3oV@020?nX00<0okP00P3oe`030:ko00D0o`000P2^o`030?l000808ol0
0`3o0005003o/`80L?l00P2No`030?oV00D0omL00P3jo`1H0?l00080omL00`3oZ0020?n:00D0ogX0
2P3oJ`05ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool00_oooolP0?m<01L0oe`04@3o
J`0=0?mj00L0ohX00`3oV@020?nX00<0okP00P3oe`030:ko00D0o`000P2^o`030?l000808ol00`3o
0005003o/`80L?l00P2No`030?oV00D0omL00P3jo`1H0?l00080omL00`3oZ0020?n:00D0ogX02P3o
J`05ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool00_oooolN0?m<00l0oe`00P3oJ`03
0?mL01@0of/03`3oNP050?n:00D0oiT01@3o^0020?oe00<0Sol01@3o00020?l0RPd0o`000P00on42
003Qo`<006Ko1@3om@020:ko05D0o`001@05o`0308oo0080ohX01@3oNP080?m[0080oe`01Oooool1
o`00007ooooo000Kooooo`03o`000?oooooooooo00;ooooo7P3oC00?0?mL0080of/00`3oG00D0?m[
00l0ogX01@3oRP050?nI00D0okP00P3om@0308oo00D0o`000P3o08X=0?l000800?oQ0P00hOl3001V
o`D0ooD00P2^o`1E0?l000D01Ol00`2?o`020?n:00D0ogX0203oJ`020?mL00Gooooo0Ol00001oooo
o`006oooool2o`0000?ooooo6@3oC00F0?mL01@0of/03`3oNP050?n:00D0oiT00`3oZ0020?o700<0
omL00P3om@030;go00800?lX5P3o0003003ol080jol00`3jo`02000:oeP0o`000P00odL30=co0080
ohX01@3oNP0:0?m[00Cooooo0_l00001ooooo`006oooool00ol0003oooooooooo`02oooooaT0od`0
5P3oG00D0?m[00l0ogX01@3oRP050?nI00<0ojP00P3oa`030?oG0080ooD00`2mo`02003o:1H0o`00
0`00oo020>_o00<0n_l00P002_mH0?l000800?m70`3Lo`020?n:00D0ogX02P3oJ`05ooooo`7o0000
0Oooool001_ooooo00?o0000ooooooooool00_oooolK0?m<01@0oe`04P3oJ`0:0?mj00L0ohX0203o
V@050?nX0080ooD00`3[o`0201@0o`<00?o`7@3o00030=co05L0o`000`3<0?l20?o700<0oiT01@3o
RP020?mj00P0of/00P3oG005ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool00_oooolK
0?m<01@0oe`04P3oJ`0:0?mj00L0ohX0203oV@050?nX0080ooD00`3[o`0201@0o`<00?o`7@3o0003
0=co05L0o`000`3<0?l20?o700<0oiT01@3oRP020?mj00P0of/00P3oG005ooooo`7o00000Oooool0
01_ooooo00?o0000ooooooooool00_oooolK0?m<00d0oe`00P3oJ`030?mL00l0of/04@3oNP050?n:
00<0oiT00P3oa`030?nX00D0okP00P3oe`030=co0280o`000`2^o`02003o`UD0o`000`3o05`20<co
00<0oiT00P3oRP050?mj00X0of/01Oooool1o`00007ooooo000Kooooo`03o`000?oooooooooo00;o
oooo6`3oC00=0?mL0080of/00`3oG00?0?m[0140ogX01@3oRP030?nI0080olL00`3oZ0050?nh0080
omL00`3Lo`0R0?l000<0[_l00P00ol9E0?l000<0o`1L0P3<o`030?nI0080ohX01@3oNP0:0?m[00Go
oooo0Ol00001ooooo`006oooool00ol0003oooooooooo`02ooooo``0od`00`3oG00<0?m<00l0oe`0
3@3oJ`0A0?mj00P0ohX00P3oV@030?nX0080_Ol01@3oa`030?oG0080onH00`3<o`020540ob00o`00
0`1Qo`1J0?l00080olL00`3oV@050?mj00`0of/01Oooool1o`00007ooooo000Kooooo`;o00000ooo
ool<0?m<00<0oe`0303oC00?0?mL00d0of/04@3oNP080?n:0080oiT00`3oZ0020;go00D0olL00`3o
e`020?oV00<0c?l00P1A0?lP0?l000<0HOl0FP3o00020?o700<0oiT01@3oNP0<0?m[00Cooooo0_l0
0001ooooo`006oooool00ol0003oooooooooo`02oooooaH0od`04P3oG00:0?m[00l0ogX0303oRP05
0?nI00<0ojP00P3oe`030>_o0080onH00`3[o`020?[o00<0W_l0O03o00030<co0080ojP01@3oRP03
0?mj00X0of/00P3oG005ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool00_oooolF0?m<
0180oe`02P3oJ`0?0?mj00`0ohX01@3oV@030?nX0080omL00`3[o`020?oV00<0jol00P3jo`0309ko
07`0o`000`3<o`020?nX00D0ohX00`3oNP0:0?m[0080oe`01Oooool1o`00007ooooo000Kooooo`03
o`000?oooooooooo00;ooooo6@3oC00<0?mL00X0of/0203oNP0A0?n:00P0oiT00P3oZ0030?nh0080
omL00`0co`02003o/`<008Go0P2^o`0304;o07`0o`000`3o^0020?nI00<0ohX01`3oNP0:0?m[00Go
oooo0Ol00001ooooo`006oooool00ol0003oooooooooo`02oooooaT0od`0303oG00:0?m[00P0ogX0
4@3oRP080?nI0080ojP00`3o^0020?oG00<0<ol00P00ok<30025o`80[_l00`12o`1l0?l000<0okP0
0P3oV@030?n:00L0ogX02P3oJ`05ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool00_oo
oolK0?m<00X0oe`01@3oJ`080?mj00D0ohX00P3oV@030?o700L0oiT00`3oZ0050?nI00D0ojP01@3o
a`020?oe00<0_Ol01`3o00030540ogX0o`000P3oiP030?nX00D0ohX01@3oNP0:0?m[0080oe`01Ooo
ool1o`00007ooooo000Dooooo`;o00001Oooool00ol0003oooooooooo`02oooooa/0od`02P3oG005
0?m[00P0ogX01@3oRP020?nI00<0olL01`3oV@030?nX00D0oiT01@3oZ0050?o70080ooD00`2mo`07
0?l000<0D@3oNP3o00020?oV00<0ojP01@3oRP050?mj00X0of/00P3oG005ooooo`7o00000Oooool0
01?ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`02oooooaT0od`02P3oG005
0?m[00D0ogX01@3oRP050?nI0080ojP00`3Lo`020?nh00D0ojP00`3oa`070?nh00<0olL00P3jo`03
0?oV0080_Ol00`1Ao`070?l000<004OoM`3o00030?[o0080okP00`3oV@050?n:00D0ogX02P3oJ`02
0?mL00Gooooo0Ol00001ooooo`004oooool01?l0003oooooooooool00004ooooo`;o00000ooooolI
0?m<00X0oe`01@3oJ`050?mj00D0ohX01@3oV@020?nX00<0g?l00P3o^0050?nX00<0olL01`3o^003
0?o70080n_l00`3oiP020;go00<0DOl01`3o00030017ogL0o`000`3jo`020?nh00<0oiT01@3oRP05
0?mj00X0of/00P3oG004ooooo`;o00000Oooool001?ooooo00Co0000oooooooooooo00001?ooool0
0ol0003oooooooooo`02oooooah0of/01`3oNP030?n:00800;?o0`00QOl20017o`<0@P3o0P3o0;P3
0700o`80o`2h1@3o00030800o`80o`0m0`3o00020?l0RP<0o`0NR`3o00030640o`80c?l00`3oiP02
0?o700<0okP00P3oZ0080?nI00L0ohX01@3oNP05ooooo`7o00000Oooool001?ooooo00Co0000oooo
oooooooo00001?ooool00ol0003oooooooooo`02oooooah0of/01`3oNP030?n:00800;?o0`00QOl2
0017o`<0@P3o0P3o0;P30700o`80o`2h1@3o00030800o`80o`0m0`3o00020?l0RP<0o`0NR`3o0003
0640o`80c?l00`3oiP020?o700<0okP00P3oZ0080?nI00L0ohX01@3oNP05ooooo`7o00000Oooool0
01?ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`02oooooah0of/01`3oNP03
0?n:00800;?o0`00QOl20017o`<0@P3o0P3o0;P30700o`80o`2h1@3o00030800o`80o`0m0`3o0002
0?l0RP<0o`0NR`3o00030640o`80c?l00`3oiP020?o700<0okP00P3oZ0080?nI00L0ohX01@3oNP05
ooooo`7o00000Oooool001Cooooo0_l00005ooooo`03o`000?oooooooooo00;ooooo6@3oC00:0?mL
00D0of/01@3oNP050?n:00D0oiT00P3oZ0030=co0080okP01@3oZ0030?o700L0okP00`3oa`020?[o
00<0onH00P2mo`03057o00L0o`000`00Aomg0?l000<0n_l00P3o^0030?nI00D0ohX01@3oNP0:0?m[
0080oe`01Oooool1o`00007ooooo000Kooooo`03o`000?oooooooooo00;ooooo6@3oC00:0?mL00D0
of/01@3oNP050?n:00D0oiT00P3oZ0030=co0080okP01@3oZ0030?o700L0okP00`3oa`020?[o00<0
onH00P2mo`03057o00L0o`000`00Aomg0?l000<0n_l00P3o^0030?nI00D0ohX01@3oNP0:0?m[0080
oe`01Oooool1o`00007ooooo000Kooooo`03o`000?oooooooooo00;ooooo6`3oC00:0?mL00D0of/0
203oNP050?n:0080oiT00`3oa`070?nI00<0ojP01@3oV@050?nX00D0olL00P3om@030;go00L0o`00
0`1A0?mj0?l00080onH00`3oZ0050?n:00D0ogX02P3oJ`020?mL00Gooooo0Ol00001ooooo`006ooo
ool00ol0003oooooooooo`02oooooa/0od`02P3oG0050?m[00P0ogX01@3oRP020?nI00<0olL01`3o
V@030?nX00D0oiT01@3oZ0050?o70080ooD00`2mo`070?l000<0D@3oNP3o00020?oV00<0ojP01@3o
RP050?mj00X0of/00P3oG005ooooo`7o00000Oooool001_ooooo0_l00003oooooaT0od`0303oG00:
0?m[00P0ogX04@3oRP080?nI0080ojP00`3o^0020?oG00<0<ol00P00ok<30025o`80[_l00`12o`1l
0?l000<0okP00P3oV@030?n:00L0ogX02P3oJ`04ooooo`;o00000Oooool001_ooooo00?o0000oooo
ooooool00_oooolI0?m<00`0oe`02P3oJ`080?mj0140ohX0203oV@020?nX00<0okP00P3oe`0303?o
00800?nc0`00QOl20:ko00<0@_l0O03o00030?nh0080oiT00`3oRP070?mj00X0of/01Oooool1o`00
007ooooo000Kooooo`03o`000?oooooooooo00;ooooo5P3oC00B0?mL00X0of/03`3oNP0<0?n:00D0
oiT00`3oZ0020?oG00<0jol00P3oiP030>_o0080n_l00`2No`1l0?l000<0c?l00P3oZ0050?n:00<0
ogX02P3oJ`020?mL00Gooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`02oooooaH0od`0
4P3oG00:0?m[00l0ogX0303oRP050?nI00<0ojP00P3oe`030>_o0080onH00`3[o`020?[o00<0W_l0
O03o00030<co0080ojP01@3oRP030?mj00X0of/00P3oG005ooooo`7o00000Oooool001_ooooo00?o
0000ooooooooool00_ooool<0?m<00<0oe`0303oC00?0?mL00d0of/04@3oNP080?n:0080oiT00`3o
Z0020;go00D0olL00`3oe`020?oV00<0c?l00P1A0?lP0?l000<0HOl0FP3o00020?o700<0oiT01@3o
NP0<0?m[00Gooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`02ooooo``0od`00`3oG00<
0?m<00l0oe`03@3oJ`0A0?mj00P0ohX00P3oV@030?nX0080_Ol01@3oa`030?oG0080onH00`3<o`02
0540ob00o`000`1Qo`1J0?l00080olL00`3oV@050?mj00`0of/01Oooool1o`00007ooooo000Koooo
o`03o`000?oooooooooo00;ooooo6`3oC00=0?mL0080of/00`3oG00?0?m[0140ogX01@3oRP030?nI
0080olL00`3oZ0050?nh0080omL00`3Lo`0R0?l000<0[_l00P00ol9E0?l000<0o`1L0P3<o`030?nI
0080ohX01@3oNP0:0?m[00Gooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`02oooooa/0
od`03@3oG0020?m[00<0oe`03`3oJ`0A0?mj00D0ohX00`3oV@020?o700<0ojP01@3o^0020?oG00<0
g?l08P3o00030:ko00800?o2E@3o00030?l0G080c?l00`3oV@020?n:00D0ogX02P3oJ`05ooooo`7o
00000Oooool001_ooooo0_l00003oooooa/0od`0503oG00B0?m[00X0ogX01`3oRP080?nI00D0ojP0
0P3om@030>_o0080503o0`00oo0M0?l000<0g?l0E`3o00030<`0o`80olL00`3oV@050?n:0080ogX0
203oJ`020?mL00Cooooo0_l00001ooooo`006oooool00ol0003oooooooooo`02oooooa/0od`0503o
G00B0?m[00X0ogX01`3oRP080?nI00D0ojP00P3om@030>_o0080503o0`00oo0M0?l000<0g?l0E`3o
00030<`0o`80olL00`3oV@050?n:0080ogX0203oJ`020?mL00Gooooo0Ol00001ooooo`006oooool0
0ol0003oooooooooo`02oooooaT0od`05P3oG00D0?m[00l0ogX01@3oRP050?nI00<0ojP00P3oa`03
0?oG0080ooD00`2mo`02003o:1H0o`000`00oo020>_o00<0n_l00P002_mH0?l000800?m70`3Lo`02
0?n:00D0ogX02P3oJ`05ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool00_oooolI0?m<
01H0oe`0503oJ`0?0?mj00D0ohX01@3oV@030?nX0080olL00`3oe`020?oe00<0_Ol00P00obPF0?l0
00<00?o`0P3[o`030?[o008000[oF03o0002003oA`<0g?l00P3oRP050?mj00X0of/01Oooool1o`00
007ooooo000Kooooo`03o`000?oooooooooo00;ooooo7P3oC00?0?mL0080of/00`3oG00D0?m[00l0
ogX01@3oRP050?nI00D0okP00P3om@0308oo00D0o`000P3o08X=0?l000800?oQ0P00hOl3001Vo`D0
ooD00P2^o`1E0?l000D01Ol00`2?o`020?n:00D0ogX0203oJ`020?mL00Gooooo0Ol00001ooooo`00
6oooool00ol0003oooooooooo`02oooooah0od`03`3oG0020?m[00<0oe`0503oJ`0?0?mj00D0ohX0
1@3oV@050?nh0080ooD00`2?o`050?l00080o`2:3@3o0002003oh@800>7o0`00I_l50?oe0080[_l0
E@3o000500Go00<0Sol00P3oRP050?mj00P0of/00P3oG005ooooo`7o00000Oooool001_ooooo00?o
0000ooooooooool00_oooolP0?m<01L0oe`04@3oJ`0=0?mj00L0ohX00`3oV@020?nX00<0okP00P3o
e`030:ko00D0o`000P2^o`030?l000808ol00`3o0005003o/`80L?l00P2No`030?oV00D0omL00P3j
o`1H0?l00080omL00`3oZ0020?n:00D0ogX02P3oJ`05ooooo`7o00000Oooool001_ooooo00?o0000
ooooooooool00_oooolP0?m<01L0oe`04@3oJ`0=0?mj00L0ohX00`3oV@020?nX00<0okP00P3oe`03
0:ko00D0o`000P2^o`030?l000808ol00`3o0005003o/`80L?l00P2No`030?oV00D0omL00P3jo`1H
0?l00080omL00`3oZ0020?n:00D0ogX02P3oJ`05ooooo`7o00000Oooool001_ooooo0_l00003oooo
ob00od`0703oG00A0?m[00X0ogX01@3oRP030?nI0080ojP00`3o^0020?oG00<0c?l00P120?l3002S
o`D0n_l00P2?o`030?l00080g?l00`2No`020=co0080omL0203oa`020=co05D0o`000`00oo020?o7
00<0ojP00P3oRP050?mj00P0of/00P3oG004ooooo`;o00000Oooool001_ooooo00?o0000oooooooo
ool00_oooolP0?m<01`0oe`04@3oJ`0:0?mj00D0ohX00`3oV@020?nX00<0okP00P3oe`030<co0080
@P3o0`00Xol50?[o0080Sol00`3o00020=co00<0W_l00P3Lo`020?oG00P0olL00P3Lo`1E0?l000<0
0?o`0P3oa`030?nX0080ohX01@3oNP080?m[0080oe`01Oooool1o`00007ooooo000Kooooo`03o`00
0?oooooooooo00;ooooo7P3oC00N0?mL01@0of/02P3oNP020?n:00<0oiT00P3oZ0030?oG0080jol0
0`2No`020:ko00<0onH00P3oe`030?oV0080g?l00`00odL20?oG00<0P?l00P3oa`070?nh00<0olL0
0P3oe`0309ko05D0o`000P00ogD30?nh0080oiT00`3oRP020?mj00P0of/00P3oG005ooooo`7o0000
0Oooool001_ooooo00?o0000ooooooooool00_oooolN0?m<01h0oe`0503oJ`0:0?mj0080ohX00`3o
V@020?nX00<0omL00P3[o`0309ko0080[_l00`3oiP020?oG00<0onH00P3Lo`03003oA`80omL00`20
o`020?o700L0okP00`3oa`020?oG00<0W_l0E@3o0002003oM@<0okP00P3oV@030?n:0080ogX0203o
J`020?mL00Gooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`02oooooa/0od`00`3oG007
0?m<01@0oe`00`3oJ`050?mL0140of/0203oNP020?n:00<0oiT00P3o^00308oo0080omL00`3oa`02
0?oe00D0okP00`3oe`020>_o00<0omL01`3o^0070?nX00<0okP00P3oe`0302?o05L0o`000`00oi@2
0?nI00D0ogX02P3oJ`05ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool00_oooolK0?m<
00<0oe`01`3oC00D0?mL00<0of/01@3oG00A0?m[00P0ogX00P3oRP030?nI0080okP00`2?o`020?oG
00<0olL00P3om@050?nh00<0omL00P3[o`030?oG00L0okP01`3oZ0030?nh0080omL00`0So`1G0?l0
00<00?nD0P3oV@050?mj00X0of/01Oooool1o`00007ooooo000Kooooo`03o`000?oooooooooo00;o
oooo9@3oC00I0?mL00<0of/00P3oG00B0?m[00D0ogX00P3oRP030?nI0080okP00`3jo`020?nh00X0
ojP00`3o^00203?o00<0okP04@3oZ0020?o700<00?mV1@0D0?m;0?l000800?me0`3o00020=co00<0
0?lh0P3oV@050?mj00P0of/00P3oG005ooooo`7o00000Oooool001_ooooo0_l00003ooooobD0od`0
6@3oG0030?m[0080oe`04P3oJ`050?mj0080ohX00`3oV@020?nh00<0n_l00P3o^00:0?nX00<0okP0
0P0co`030?nh0140ojP00P3oa`03003oIPD0503oB`3o0002003oM@<0o`000P3Lo`03003o>080oiT0
1@3oNP080?m[0080oe`01?ooool2o`00007ooooo000Kooooo`03o`000?oooooooooo00;ooooo9@3o
C00N0?mL0180of/01`3oNP030?n:0080ojP00`2^o`020?nX00X0oiT00`3oZ002067o00<0ojP0303o
V@050?nX0080okP00`3oe`020?[o00<0L?l0B`3o000203?o00<0ooD00P3oe`030?oe0080oiT01@3o
NP0:0?m[00Gooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`02ooooobD0od`07P3oG00B
0?m[00L0ogX00`3oRP020?nX00<0[_l00P3oZ00:0?nI00<0ojP00P1Qo`030?nX00`0oiT01@3oZ002
0?nh00<0omL00P3jo`03073o04/0o`000P0co`030?oe0080omL00`3om@020?nI00D0ogX02P3oJ`05
ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool00_oooolS0?m<0200oe`00`3oJ`020?mL
00l0of/00`3oNP050?n:0080omL00`3oa`020?nI00X0ohX0203oV@070?n:00X0oiT00P3oZ0030?o7
0080n_l0CP3o0002003oA`<0olL01@3oZ0020?n:00<0ogX02P3oJ`020?mL00Gooooo0Ol00001oooo
o`006oooool00ol0003oooooooooo`02ooooob<0od`0803oG0030?m[0080oe`03`3oJ`030?mj00D0
ohX00P3oe`030?o70080oiT02P3oRP080?nI00L0ohX02P3oV@020?nX00<0olL00P3jo`1>0?l00080
0?m70`3oa`050?nX0080ohX00`3oNP0:0?m[0080oe`01Oooool1o`00007ooooo000Kooooo`03o`00
0?oooooooooo00;ooooo8`3oC0020?mL00D0od`07P3oG00B0?m[0080ogX00`3oRP020?nX02<0ohX0
1@3oV@020?nX00<0olL00P00ofI;0?l000<00?o`0P3[o`030?nh0080oiT01@3oRP030?mj00X0of/0
0P3oG005ooooo`7o00000Oooool000Sooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo0ol0
0005ooooo`03o`000?oooooooooo00;ooooo8`3oC0020?mL00D0od`07P3oG00B0?m[0080ogX00`3o
RP020?nX02<0ohX01@3oV@020?nX00<0olL00P00ofI;0?l000<00?o`0P3[o`030?nh0080oiT01@3o
RP030?mj00X0of/00P3oG005ooooo`7o00000Oooool000Oooooo00Co0000oooooooooooo00001ooo
ool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool00_ooool]0?m<0200oe`0
3@3oJ`070?mj00<0ohX02P3oNP020?n:00D0ogX04@3oRP030?nI0080ojP00`2mo`02003`o`<0W_l0
0P2mo`03057o0440o`000P00Xol30>_o0080olL00`3oZ0020?nI00<0ohX01@3oNP070?m[00D0oe`0
1Oooool1o`00007ooooo0007ooooo`04o`000?ooooooooooo`0000_ooooo00?o0000ooooooooool0
0_ooool2o`0000?ooooo;@3oC00P0?mL00d0of/01`3oNP030?n:00X0ogX00P3oRP050?mj0140ohX0
0`3oV@020?nX00<0_Ol00P00l?l309ko0080_Ol00`1Ao`110?l000800:?o0`3[o`020?o700<0ojP0
0P3oV@030?n:00D0ogX01`3oJ`050?mL00Cooooo0_l00001ooooo`001oooool01?l0003ooooooooo
ool0000;ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool]0?m<01T0oe`0
0P3oJ`050?mL00l0of/07P3oNP0?0?n:0080oiT00`3oZ0020?o700<00?n50P3oiP03000:od<0o`00
0`050?l20?[o00<0ojP00P3oV@030?n:00D0ogX01`3oJ`050?mL00Gooooo0Ol00001ooooo`001ooo
ool01?l0003oooooooooool00007ooooo`Co00001Oooool00ol0003oooooooooo`02ooooobd0od`0
6@3oG0020?m[00D0oe`03`3oJ`0N0?mj00l0ohX00P3oV@030?nX0080olL00`00ohD20?oV00<000[o
@`3o000300D0o`80n_l00`3oZ0020?nI00<0ohX01@3oNP070?m[00D0oe`01Oooool1o`00007ooooo
0007ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`02ooooobX0od`0:03oG00?0?m[01h0ogX0303oRP030?nI0080ojP00`3o^0020?o700<0ooD0
0P2mo`160?l000<0okP00P3oV@030?n:0080ogX02P3oJ`030?mL0080of/01Oooool1o`00007ooooo
0008ooooo`;o00002?ooool5o`0000Cooooo00?o0000ooooooooool00_oooolZ0?m<02P0oe`03`3o
J`0N0?mj00`0ohX00`3oV@020?nX00<0okP00P3oa`030?oe0080_Ol0AP3o00030?nh0080oiT00`3o
RP020?mj00X0of/00`3oG0020?m[00Gooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`02
ooooobX0od`00`3oG0070?m<01h0oe`05`3oJ`020?mj00<0of/05P3oNP070?n:00D0oiT00`3oZ002
0?o700<0jol00P00oaTj0?l00080Sol0203o0002003o6@<0olL00P3oV@030?n:0080ogX02P3oJ`05
0?mL00Gooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`02ooooobX0od`00`3oG0070?m<
01h0oe`05`3oJ`020?mj00<0of/05P3oNP070?n:00D0oiT00`3oZ0020?o700<0jol00P00oaTj0?l0
0080Sol0203o0002003o6@<0olL00P3oV@030?n:0080ogX02P3oJ`050?mL00Gooooo0Ol00001oooo
o`006oooool00ol0003oooooooooo`02ooooobP0od`00P3oG00:0?m<01@0oe`00`3oJ`050?mL0080
of/01@3oG00N0?m[0140ogX0203oRP020?nI00<0ojP00P3o^0030=co00800?nD1@3o0003073o02l0
o`000`1Qo`020?[o00<0o`2I1@3o0002067o00<0c?l00P3oZ0030?n:0080ogX03@3oJ`020?mL00Go
oooo0Ol00001ooooo`006oooool2o`0000?ooooo:03oC0020?mL00X0od`0503oG0030?m[00D0oe`0
0P3oJ`050?mL01h0of/04@3oNP080?n:0080oiT00`3oZ0020?nh00<0g?l00P00oi@50?l000<0L?l0
;`3o0003067o0080n_l00`3o09T50?l00080HOl00`3<o`020?nX00<0ohX00P3oNP0=0?m[0080oe`0
1?ooool2o`00007ooooo000Kooooo`03o`000?oooooooooo00;ooooo9@3oC0030?mL00`0od`08@3o
G0020?m[00<0oe`07P3oJ`0A0?mj00D0ohX00P3oV@030?nX0080omL00`3jo`020032o`D0o`000`3<
o`02002Dob/0o`000P3<o`030=co0080omL00`3jo`02083o00<00?lI0P3Lo`0304;o0080olL00`3o
RP020?mj00P0of/01`3oG005ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool00_oooolU
0?m<00<0oe`0303oC00Q0?mL0080of/00`3oG00N0?m[0140ogX01@3oRP020?nI00<0ojP00P3oe`03
0?[o00800<;o1@3o00030<co008009Co:`3o00020<co00<0g?l00P3oe`030?[o0080P?l00`00oaT2
0=co00<0@_l00P3oa`030?n:0080ogX0203oJ`070?mL00Gooooo0Ol00001ooooo`006oooool00ol0
003oooooooooo`02ooooob<0od`00P3oG00?0?m<02H0oe`09@3oJ`0<0?mj00D0ohX00`3oV@02083o
00<0L?l00P00Aol3002Do`80o`001@3om@030800o`80o`000`0S0?lK0?l000<00>7o0P2?o`030?l0
0080c?l00`3oa`020?nh00<00?l:0P3oiP030?o70080ooD01@3oa`030?n:0080ogX02P3oJ`050?mL
00Gooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`02ooooob<0od`00P3oG00?0?m<02H0
oe`09@3oJ`0<0?mj00D0ohX00`3oV@02083o00<0L?l00P00Aol3002Do`80o`001@3om@030800o`80
o`000`0S0?lK0?l000<00>7o0P2?o`030?l00080c?l00`3oa`020?nh00<00?l:0P3oiP030?o70080
ooD01@3oa`030?n:0080ogX02P3oJ`050?mL00Gooooo0Ol00001ooooo`006oooool00ol0003ooooo
ooooo`02oooooc80od`01@3oG0050?m<02<0oe`0803oJ`0<0?mj00D0ohX00`3oV@020?o700<0@_l0
0P0Do`030?oe0080onH00`3oa`020?oG00<00?3o0P1Qo`030=co0080o`000`00I_l2003o6@P0o`00
0P2^0?l30?l000800?lX0`3o0002003Ao`<00?o20P3om@03073o00800?nD0`3o^0070?nX00<0okP0
0P3jo`030?nh0080ohX01@3oNP050?m[00X0oe`01Oooool1o`00007ooooo000Kooooo`03o`000?oo
oooooooo00;ooooo<P3oC0050?mL00D0od`08`3oG00P0?m[00`0ogX01@3oRP030?nI0080olL00`12
o`0201Co00<0ooD00P3oiP030?o70080omL00`00l?l2067o00<0g?l00P3o0003001Vo`800?lI203o
00020:h0o`<0o`000P00obP30?l000800=7o0`00ol820?oe00<0L?l00P00oi@30?nh00L0ojP00`3o
^0020?[o00<0okP00P3oRP050?mj00D0of/02P3oG005ooooo`7o00000Oooool001_ooooo00?o0000
ooooooooool00_ooooln0?m<0240oe`00P3oJ`050?mL01h0of/02P3oNP020?n:00<0oiT00P12o`03
0?oG0080onH00`3Lo`070?nh00<0P?l00P00ohD30?oG0080ooD00`3jo`020<co00d0o`000P2^o`03
0?[o00D0onH00P3oa`030?oe0080olL00`3oZ00:0?nI0080olL00`3oe`020?n:00<0ogX01`3oJ`0:
0?mL00Gooooo0Ol00001ooooo`006oooool2o`0000?ooooo?P3oC00Q0?mL0080of/01@3oG00N0?m[
00X0ogX00P3oRP030?nI0080@_l00`3oe`020?oV00<0g?l01`3o^003083o00800?n50`3oe`020?oe
00<0n_l00P3<o`0=0?l00080[_l00`3jo`050?oV0080olL00`3om@020?o700<0ojP02P3oV@020?o7
00<0omL00P3oRP030?mj00L0of/02P3oG004ooooo`;o00000Oooool001_ooooo00?o0000oooooooo
ool00_ooooln0?m<02d0oe`06`3oJ`0:0?mj00<0ohX00P3oV@050?nX00<0okP02P3oZ0020?nh00D0
olL00`3oiP02003oA`l0o`000`3jo`020?o700<0okP00P3oZ0030?nh00D0oiT01`3oRP030?nI0080
W_l00`3oRP050?mj00L0of/02P3oG005ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool0
0_ooooln0?m<02d0oe`06`3oJ`0:0?mj00<0ohX00P3oV@050?nX00<0okP02P3oZ0020?nh00D0olL0
0`3oiP02003oA`l0o`000`3jo`020?o700<0okP00P3oZ0030?nh00D0oiT01`3oRP030?nI0080W_l0
0`3oRP050?mj00L0of/02P3oG005ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool00_oo
ool]0?m<0080oe`03`3oC00V0?mL0080of/01@3oG0030?m[0080oe`06@3oJ`070?mj00P0ohX0303o
V@050?nX00<0okP00P3oa`030?oe00800?l:3`3o00030>_o0080olL01@3oZ0050?nI00l0ohX01@3o
NP080?m[0080oe`00`3oJ`070?mL00Gooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`02
ooooobd0od`00P3oG00?0?m<02H0oe`00P3oJ`050?mL00<0of/00P3oG00I0?m[00L0ogX0203oRP0<
0?nI00D0ojP00`3o^0020?o700<0ooD00P00o`X?0?l000<0jol00P3oa`050?nX00D0oiT03`3oRP05
0?mj00P0of/00P3oG0030?m[00L0oe`01Oooool1o`00007ooooo000Kooooo`03o`000?oooooooooo
00;ooooo?03oC0050?mL00D0od`0:P3oG00K0?m[00X0ogX03@3oRP070?nI00<0ojP00P3o^0030;go
0140o`000`0So`020?o700<0ojP01@3oV@050?n:00l0ogX02P3oJ`0<0?mL00Gooooo0Ol00001oooo
o`006oooool00ol0003oooooooooo`02oooooc`0od`01@3oG0050?m<02X0oe`06`3oJ`0:0?mj00d0
ohX01`3oV@030?nX0080okP00`2mo`0A0?l000<08ol00P3oa`030?nX00D0oiT01@3oRP0?0?mj00X0
of/0303oG005ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool00_ooooll0?m<0080oe`0
2P3oC00X0?mL00<0of/01@3oG00F0?m[00l0ogX02P3oRP020?nI00<0ojP00P3o^0030;go00800?lX
3@3o00020;d0o`<0g?l00P3oa`030?nX0080oiT01@3oRP0=0?mj00`0of/03`3oG005ooooo`7o0000
0Oooool001_ooooo0_l00003oooooc`0od`00P3oG00:0?m<02P0oe`00`3oJ`050?mL01H0of/03`3o
NP0:0?n:0080oiT00`3oZ0020?nh00<0_Ol00P00obP=0?l00080_@3o0`3Lo`020?o700<0ojP00P3o
V@050?n:00d0ogX0303oJ`0?0?mL00Cooooo0_l00001ooooo`006oooool00ol0003oooooooooo`02
ooooocT0od`00`3oG00<0?m<0300oe`0603oJ`0?0?mj00P0ohX01@3oV@020?nh00<0onH00P00QOl=
0?l000800?mG0`00obP202?o00D0oiT01@3oRP0=0?mj00X0of/04@3oG005ooooo`7o00000Oooool0
01_ooooo00?o0000ooooooooool00_ooooli0?m<00<0oe`0303oC00`0?mL01P0of/03`3oNP080?n:
00D0oiT00P3o^0030?oV008008Go3@3o0002003oE`<00?lX0P0So`050?nI00D0ohX03@3oNP0:0?m[
0140oe`01Oooool1o`00007ooooo000Kooooo`03o`000?oooooooooo00;ooooo1@3o?@130?m<03D0
oe`0603oJ`0?0?mj00D0ohX00`3oV@020?oG00<0n_l00P0co`0309ko00L0o`000`00odL20>_o00<0
DOl00P3oa`030?nI0080ohX03@3oNP0?0?m[0140oe`01Oooool1o`00007ooooo000Kooooo`03o`00
0?oooooooooo00;ooooo1@3o?@130?m<03D0oe`0603oJ`0?0?mj00D0ohX00`3oV@020?oG00<0n_l0
0P0co`0309ko00L0o`000`00odL20>_o00<0DOl00P3oa`030?nI0080ohX03@3oNP0?0?m[0140oe`0
1Oooool1o`00007ooooo000Kooooo`03o`000?oooooooooo00;ooooo1`3o?@0o0?m<00D0oe`01@3o
C00]0?mL01/0of/0303oNP050?n:00<0oiT00P3oiP030?oe0080L?l00`3Lo`020<co00D0o`000`3<
o`020?oG00<00?nS0P2No`030?nI0080ohX0203oNP0?0?m[01H0oe`01Oooool1o`00007ooooo000K
ooooo`03o`000?oooooooooo00;ooooo1`3o?@0o0?m<00D0oe`01@3oC00]0?mL01/0of/0303oNP05
0?n:00<0oiT00P3oiP030?oe0080L?l00`3Lo`020<co00D0o`000`3<o`020?oG00<00?nS0P2No`03
0?nI0080ohX0203oNP0?0?m[01H0oe`01Oooool1o`00007ooooo000Kooooo`;o00000oooool70?lm
03l0od`01@3oG0050?m<02d0oe`06`3oJ`0<0?mj00D0ohX00`3oV@020?oV00<0ooD00P1`o`030=co
0080c?l01@3o00030<co0080omL00`00oj<209ko00<0oiT00P3oRP080?mj00l0of/05P3oG004oooo
o`;o00000Oooool001_ooooo00?o0000ooooooooool00_ooool:0?lm03`0od`00P3oG00:0?m<02/0
oe`00P3oJ`050?mL01T0of/02P3oNP050?n:0080oiT00`3o^0050?o70080jol00`3o07X2003o/`<0
@_l00P3oa`030?nX0080oiT00`3oRP070?mj00l0of/00`3oG0020?m[01@0oe`01Oooool1o`00007o
oooo000Kooooo`03o`000?oooooooooo00;ooooo2P3o?@0l0?m<0080oe`02P3oC00[0?mL0080of/0
1@3oG00I0?m[00X0ogX01@3oRP020?nI00<0okP01@3oa`020>_o00<0o`1j0P00ok<304;o0080olL0
0`3oZ0020?nI00<0ohX01`3oNP0?0?m[00<0oe`00P3oJ`0D0?mL00Gooooo0Ol00001ooooo`006ooo
ool00ol0003oooooooooo`02ooooo`X0ocd0>@3oC0030?mL00`0od`0=`3oG00F0?m[00X0ogX01@3o
RP030?nI0080ojP00`3o^0020?oV00<0jol00P00ofH30?oV0080okP00`3oV@050?n:00D0ogX04@3o
J`0I0?mL00Gooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`02ooooo`X0ocd0>@3oC003
0?mL00`0od`0=`3oG00F0?m[00X0ogX01@3oRP030?nI0080ojP00`3o^0020?oV00<0jol00P00ofH3
0?oV0080okP00`3oV@050?n:00D0ogX04@3oJ`0I0?mL00Gooooo0Ol00001ooooo`006oooool00ol0
003oooooooooo`02ooooo`X0ocd0B03oC00_0?mL00<0of/01@3oG00I0?m[00X0ogX01@3oRP020?nI
00<0ojP00P3o^0030?oV0080HOl00`3oe`020?nh00<0oiT01@3oRP050?mj00`0of/07P3oG005oooo
o`7o00000Oooool001?ooooo0ol00005ooooo`03o`000?oooooooooo00;ooooo2P3o?@180?m<02l0
oe`00`3oJ`050?mL01T0of/02P3oNP050?n:0080oiT00`3oZ0020?nh00<0onH00P1Qo`030?oG0080
okP00`3oV@050?n:00D0ogX0303oJ`0N0?mL00Gooooo0Ol00001ooooo`005?ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00;ooooo2P3o?@180?m<00<0oe`01`3oC00b0?mL01H0of/0
203oNP050?n:0080oiT00`3oZ0020?nh00<0onH00P3<o`030?[o0080okP00`3oV@020?n:00D0ogX0
3@3oJ`020?mL00<0of/06`3oG005ooooo`7o00000Oooool001Cooooo00?o0000ooooooooool01?oo
ool2o`0000?ooooo2P3o?@180?m<00<0oe`01`3oC00b0?mL01H0of/0203oNP050?n:0080oiT00`3o
Z0020?nh00<0onH00P3<o`030?[o0080okP00`3oV@020?n:00D0ogX03@3oJ`020?mL00<0of/06`3o
G004ooooo`;o00000Oooool001Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02
ooooo`X0ocd0AP3oC0020?mL00d0od`0;`3oG0020?m[00<0oe`0503oJ`070?mj00<0ohX00P3oV@03
0?nX0080olL00`12o`020?o700<0onH00P2mo`030?nX0080ohX00`3oNP0?0?m[01T0oe`01`3oC005
ooooo`7o00000Oooool001Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02oooo
o`X0ocd0AP3oC0020?mL00d0od`0;`3oG0020?m[00<0oe`0503oJ`070?mj00<0ohX00P3oV@030?nX
0080olL00`12o`020?o700<0onH00P2mo`030?nX0080ohX00`3oNP0?0?m[01T0oe`01`3oC005oooo
o`7o00000Oooool001?ooooo0_l00006ooooo`03o`000?oooooooooo00;ooooo2P3o?@1E0?m<03H0
oe`0503oJ`050?mj00D0ohX00`3oZ0020?oG00<0n_l01@3oZ0020?nh00<0ojP01@3oNP0:0?m[01h0
oe`01`3oC005ooooo`7o00000Oooool001Cooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`02ooooo`X0ocd0E@3oC00f0?mL01@0of/01@3oNP050?n:00<0ojP00P3oe`030?[o00D0ojP0
0P3o^0030?nX00D0ogX02P3oJ`0N0?mL00L0od`01Oooool1o`00007ooooo000Kooooo`03o`000?oo
oooooooo00;ooooo2P3o?@130?m<00<0oe`0303oC0050?mL00P0od`0<@3oG00?0?m[00P0ogX00P3o
RP030?nX00800>7o0`3o^0020?nI00P0ohX00P3oNP0=0?m[01h0oe`01`3oC005ooooo`7o00000Ooo
ool001_ooooo00?o0000ooooooooool00_ooool:0?lm04<0od`00`3oG00<0?m<00D0oe`0203oC00a
0?mL00l0of/0203oNP020?n:00<0ojP00P00hOl30?nh0080oiT0203oRP020?mj00d0of/07P3oG007
0?m<00Gooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`02ooooo`L0ocd0E@3oC0030?mL
00X0od`0<@3oG00B0?m[00D0ogX00P3oRP030?nX0080olL00`3oV@050?n:00L0ogX02P3oJ`0S0?mL
00D0od`01Oooool1o`00007ooooo000Kooooo`;o00000oooool70?lm05D0od`00`3oG00:0?m<0340
oe`04P3oJ`050?mj0080ohX00`3oZ0020?o700<0oiT01@3oRP070?mj00X0of/08`3oG0050?m<00Co
oooo0_l00001ooooo`006oooool00ol0003oooooooooo`02ooooo`L0ocd0HP3oC00_0?mL0080of/0
1@3oG00=0?m[00D0ogX00P3oV@030?o70080onH00`3oRP0:0?mj00X0of/06`3oG0080?m<0080oe`0
1@3oC005ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool00_ooool70?lm0680od`0;`3o
G0020?m[00D0oe`03@3oJ`050?mj0080oiT00`3oa`020?oV00<0ohX02P3oNP0:0?m[01/0oe`0203o
C0020?mL00D0od`01Oooool1o`00007ooooo000Kooooo`03o`000?oooooooooo00;ooooo1@3o?@1T
0?m<00L0oe`00`3oC00_0?mL00`0of/00`3oNP020?nX00D0oiT0203oNP0?0?m[01/0oe`02P3oC003
0?mL0080od`01Oooool1o`00007ooooo000Kooooo`03o`000?oooooooooo00;ooooo1@3o?@1T0?m<
00L0oe`00`3oC00_0?mL00`0of/00`3oNP020?nX00D0oiT0203oNP0?0?m[01/0oe`02P3oC0030?mL
0080od`01Oooool1o`00007ooooo000Kooooo`03o`000?oooooooooo00;ooooo1@3o?@1T0?m<0080
oe`02P3oC00_0?mL00d0of/0303oNP0=0?m[0200oe`03@3oC0020?mL00Gooooo0Ol00001ooooo`00
6oooool00ol0003oooooooooo`02ooooo`D0ocd0I03oC0020?mL00X0od`0;`3oG00=0?m[00`0ogX0
3@3oJ`0P0?mL00d0od`00P3oG005ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool00_oo
ool20?lm00X0od`03`3o?@1>0?m<0080oe`02P3oC00b0?mL0200of/0703oG0050?m<0080oe`03`3o
C005ooooo`7o00000Oooool001_ooooo0_l00003ooooo`80ocd02P3oC00?0?lm04h0od`00P3oG00:
0?m<0380oe`0803oJ`0L0?mL00D0od`00P3oG00?0?m<00Cooooo0_l00001ooooo`006oooool00ol0
003oooooooooo`02ooooo`L0od`05`3o?@1G0?m<00P0oe`00P3oC00]0?mL01@0of/00P3oG0030?m[
01h0oe`01`3oC0030?mL00`0od`01Oooool1o`00007ooooo000Kooooo`03o`000?oooooooooo00;o
oooo1`3oC00G0?lm05L0od`0203oG0020?m<02d0oe`0503oJ`020?mL00<0of/07P3oG0070?m<00<0
oe`0303oC005ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool00_ooool20?m<01`0ocd0
B03oC0030?mL00`0od`01@3oG0070?m<0300oe`0303oJ`0V0?mL01H0od`01Oooool1o`00007ooooo
000Kooooo`03o`000?oooooooooo00;ooooo0P3oC00L0?lm04P0od`00`3oG00<0?m<00D0oe`01`3o
C00`0?mL00`0of/09P3oG00F0?m<00Gooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`02
ooooob00ocd0E@3oC0030?mL00T0od`0<03oG0020?m[02P0oe`00`3oC0050?mL01H0od`01Oooool1
o`00007ooooo000Kooooo`03o`000?oooooooooo00;ooooo803o?@1E0?m<00<0oe`02@3oC00`0?mL
0080of/0:03oG0030?m<00D0oe`05P3oC005ooooo`7o00000Oooool001_ooooo00?o0000oooooooo
ool00_oooolP0?lm0640od`01@3oG0050?m<04h0oe`01`3oC0030?mL01H0od`01Oooool1o`00007o
oooo000Kooooo`;o00000ooooolP0?lm0640od`01@3oG0050?m<04h0oe`01`3oC0030?mL01H0od`0
1?ooool2o`00007ooooo000Kooooo`03o`000?oooooooooo0?oooooo0Oooool1o`00007ooooo000K
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0T
ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0T
ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool04Oooool1o`00007ooooo000Koooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00;ooooo0Ol00001ooooo`006oooooooo`0000Go00000Oooool00?oooooo
8Oooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {233, 0}} -> {-2.91326, -1.57182, 0.0128184, \
0.0128184}}]
}, Open  ]],

Cell["\<\
E anche possibile aumentare il numero di punti al fine di \
migliorare la resa grafica, ottenendo il grafico che abbiamo mostrato \
all'inizio di questo paragrafo:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(mandelbrotSet[{{\(-2.5\), 0.7}, {\(-1.3\), 1.3}}, 500, {0, 100}, 
        ColorFunction \[Rule] Hue];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .8125 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.770433 0.300481 0.40625 0.300481 [
[.01923 -0.0125 -12 -9 ]
[.01923 -0.0125 12 0 ]
[.16947 -0.0125 -6 -9 ]
[.16947 -0.0125 6 0 ]
[.31971 -0.0125 -12 -9 ]
[.31971 -0.0125 12 0 ]
[.46995 -0.0125 -6 -9 ]
[.46995 -0.0125 6 0 ]
[.62019 -0.0125 -12 -9 ]
[.62019 -0.0125 12 0 ]
[.77043 -0.0125 -3 -9 ]
[.77043 -0.0125 3 0 ]
[.92067 -0.0125 -9 -9 ]
[.92067 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .10577 -12 -4.5 ]
[-0.0125 .10577 0 4.5 ]
[-0.0125 .25601 -24 -4.5 ]
[-0.0125 .25601 0 4.5 ]
[-0.0125 .40625 -6 -4.5 ]
[-0.0125 .40625 0 4.5 ]
[-0.0125 .55649 -18 -4.5 ]
[-0.0125 .55649 0 4.5 ]
[-0.0125 .70673 -6 -4.5 ]
[-0.0125 .70673 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .8125 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .8125 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.01923 0 m
.01923 .00625 L
s
[(-2.5)] .01923 -0.0125 0 1 Mshowa
.16947 0 m
.16947 .00625 L
s
[(-2)] .16947 -0.0125 0 1 Mshowa
.31971 0 m
.31971 .00625 L
s
[(-1.5)] .31971 -0.0125 0 1 Mshowa
.46995 0 m
.46995 .00625 L
s
[(-1)] .46995 -0.0125 0 1 Mshowa
.62019 0 m
.62019 .00625 L
s
[(-0.5)] .62019 -0.0125 0 1 Mshowa
.77043 0 m
.77043 .00625 L
s
[(0)] .77043 -0.0125 0 1 Mshowa
.92067 0 m
.92067 .00625 L
s
[(0.5)] .92067 -0.0125 0 1 Mshowa
.125 Mabswid
.04928 0 m
.04928 .00375 L
s
.07933 0 m
.07933 .00375 L
s
.10938 0 m
.10938 .00375 L
s
.13942 0 m
.13942 .00375 L
s
.19952 0 m
.19952 .00375 L
s
.22957 0 m
.22957 .00375 L
s
.25962 0 m
.25962 .00375 L
s
.28966 0 m
.28966 .00375 L
s
.34976 0 m
.34976 .00375 L
s
.37981 0 m
.37981 .00375 L
s
.40986 0 m
.40986 .00375 L
s
.4399 0 m
.4399 .00375 L
s
.5 0 m
.5 .00375 L
s
.53005 0 m
.53005 .00375 L
s
.5601 0 m
.5601 .00375 L
s
.59014 0 m
.59014 .00375 L
s
.65024 0 m
.65024 .00375 L
s
.68029 0 m
.68029 .00375 L
s
.71034 0 m
.71034 .00375 L
s
.74038 0 m
.74038 .00375 L
s
.80048 0 m
.80048 .00375 L
s
.83053 0 m
.83053 .00375 L
s
.86058 0 m
.86058 .00375 L
s
.89063 0 m
.89063 .00375 L
s
.95072 0 m
.95072 .00375 L
s
.98077 0 m
.98077 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .10577 m
.00625 .10577 L
s
[(-1)] -0.0125 .10577 1 0 Mshowa
0 .25601 m
.00625 .25601 L
s
[(-0.5)] -0.0125 .25601 1 0 Mshowa
0 .40625 m
.00625 .40625 L
s
[(0)] -0.0125 .40625 1 0 Mshowa
0 .55649 m
.00625 .55649 L
s
[(0.5)] -0.0125 .55649 1 0 Mshowa
0 .70673 m
.00625 .70673 L
s
[(1)] -0.0125 .70673 1 0 Mshowa
.125 Mabswid
0 .13582 m
.00375 .13582 L
s
0 .16587 m
.00375 .16587 L
s
0 .19591 m
.00375 .19591 L
s
0 .22596 m
.00375 .22596 L
s
0 .28606 m
.00375 .28606 L
s
0 .31611 m
.00375 .31611 L
s
0 .34615 m
.00375 .34615 L
s
0 .3762 m
.00375 .3762 L
s
0 .4363 m
.00375 .4363 L
s
0 .46635 m
.00375 .46635 L
s
0 .49639 m
.00375 .49639 L
s
0 .52644 m
.00375 .52644 L
s
0 .58654 m
.00375 .58654 L
s
0 .61659 m
.00375 .61659 L
s
0 .64663 m
.00375 .64663 L
s
0 .67668 m
.00375 .67668 L
s
0 .07572 m
.00375 .07572 L
s
0 .04567 m
.00375 .04567 L
s
0 .01562 m
.00375 .01562 L
s
0 .73678 m
.00375 .73678 L
s
0 .76683 m
.00375 .76683 L
s
0 .79688 m
.00375 .79688 L
s
.25 Mabswid
0 0 m
0 .8125 L
s
.01923 .80625 m
.01923 .8125 L
s
.16947 .80625 m
.16947 .8125 L
s
.31971 .80625 m
.31971 .8125 L
s
.46995 .80625 m
.46995 .8125 L
s
.62019 .80625 m
.62019 .8125 L
s
.77043 .80625 m
.77043 .8125 L
s
.92067 .80625 m
.92067 .8125 L
s
.125 Mabswid
.04928 .80875 m
.04928 .8125 L
s
.07933 .80875 m
.07933 .8125 L
s
.10938 .80875 m
.10938 .8125 L
s
.13942 .80875 m
.13942 .8125 L
s
.19952 .80875 m
.19952 .8125 L
s
.22957 .80875 m
.22957 .8125 L
s
.25962 .80875 m
.25962 .8125 L
s
.28966 .80875 m
.28966 .8125 L
s
.34976 .80875 m
.34976 .8125 L
s
.37981 .80875 m
.37981 .8125 L
s
.40986 .80875 m
.40986 .8125 L
s
.4399 .80875 m
.4399 .8125 L
s
.5 .80875 m
.5 .8125 L
s
.53005 .80875 m
.53005 .8125 L
s
.5601 .80875 m
.5601 .8125 L
s
.59014 .80875 m
.59014 .8125 L
s
.65024 .80875 m
.65024 .8125 L
s
.68029 .80875 m
.68029 .8125 L
s
.71034 .80875 m
.71034 .8125 L
s
.74038 .80875 m
.74038 .8125 L
s
.80048 .80875 m
.80048 .8125 L
s
.83053 .80875 m
.83053 .8125 L
s
.86058 .80875 m
.86058 .8125 L
s
.89063 .80875 m
.89063 .8125 L
s
.95072 .80875 m
.95072 .8125 L
s
.98077 .80875 m
.98077 .8125 L
s
.25 Mabswid
0 .8125 m
1 .8125 L
s
.99375 .10577 m
1 .10577 L
s
.99375 .25601 m
1 .25601 L
s
.99375 .40625 m
1 .40625 L
s
.99375 .55649 m
1 .55649 L
s
.99375 .70673 m
1 .70673 L
s
.125 Mabswid
.99625 .13582 m
1 .13582 L
s
.99625 .16587 m
1 .16587 L
s
.99625 .19591 m
1 .19591 L
s
.99625 .22596 m
1 .22596 L
s
.99625 .28606 m
1 .28606 L
s
.99625 .31611 m
1 .31611 L
s
.99625 .34615 m
1 .34615 L
s
.99625 .3762 m
1 .3762 L
s
.99625 .4363 m
1 .4363 L
s
.99625 .46635 m
1 .46635 L
s
.99625 .49639 m
1 .49639 L
s
.99625 .52644 m
1 .52644 L
s
.99625 .58654 m
1 .58654 L
s
.99625 .61659 m
1 .61659 L
s
.99625 .64663 m
1 .64663 L
s
.99625 .67668 m
1 .67668 L
s
.99625 .07572 m
1 .07572 L
s
.99625 .04567 m
1 .04567 L
s
.99625 .01562 m
1 .01562 L
s
.99625 .73678 m
1 .73678 L
s
.99625 .76683 m
1 .76683 L
s
.99625 .79688 m
1 .79688 L
s
.25 Mabswid
1 0 m
1 .8125 L
s
0 0 m
1 0 L
1 .8125 L
0 .8125 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.01923 .01563 translate
.96154 .78125 scale
1500 string
500 500 8 [500 0 0 500 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF5C00FF5C00
FF5C00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF5C00
FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00
FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF6B00FF6B00FF6B00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF5C00FF5C00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF6B00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00
FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00
FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF6B00FF6B00
FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF7A00FF6B00FF7A00
FF7A00FF6B00FF7A00FF6B00FF7A00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00
FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF9900FF9900FFA800FF9900
FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FFA800FFE600FFB800FFC700FFA800
FF9900FF9900FF9900FF8A00FF9900FF9900FF9900FF8A00FF8A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00
FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FFA800FFB800FFD700FAFF00FFB800
FFA800FF9900FF9900FF9900FF9900FF9900FFF500FF9900FF8A00FF8A00FF8A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF9900FFA800FFB800FFE600FFC700
FFB800FFA800FFA800FFA800FFA800FFB800EBFF00FFA800FF9900FF8A00FF8A00FF8A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF9900FF9900FFA800FFD700DCFF00
FFE600FFC700FFB800FFB800FFB800FFC700FFE600FFB800FF9900FF9900FF8A00FF8A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF9900FF9900FFA800FFB800FFD700
FFF5008FFF00FFD700FFC700FFC700BDFF00FFC700FFA800FF9900FF9900FF8A00FF8A00
FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FFA800FFB800
FFC700FFD70061FF00FFE600FFF500FFE600FFB800FFA800FF9900FF9900FF8A00FF8A00
FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF9900FF9900FFA800FFA800
FFB800FFC700FFE600CCFF00FFF500FFC700FFB800FFA800FF9900FF9900FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FFA800
FFB800FFB800FFD700AEFF00FFD700FFC700FFB800FFA800FFA800FF9900FF9900FF8A00
FF8A00FF8A00FF8A00FF8A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FFA800
FFA800FFB800FFD70080FF00FFE600FFC700FFB800FFA800FFA800FF9900FF9900FF9900
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FFA800
FFA800FFB800FFC70051FF0000FF75FFC700FFB800FFA800FFA800FF9900FF9900FF9900
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF8A00FF7A00FF8A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FFA800
FFA800FFB800FFC700FFF500FAFF00FFC700FFB800FFB800FFA800FFA800FF9900FF9900
FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FFA800
FFA800FFB800FFD700FFF500FFF500FFD700FFC700FFB800FFB800FFA800FFA800FF9900
FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FFA800
FFA800FFC700FFF500DCFF00FFF500FFD700FFD700FFC700FFC700FFB800FFA800FFA800
FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FFA800
FFA800FFC700FFE600FAFF00EBFF00FFF500FFE600FFE600FAFF00FFC700FFA800FFA800
FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900
FFA800FFB800FFC700FFE6009EFF00DCFF00EBFF00AEFF00EBFF00FFD700FFB800FFA800
FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900
FFA800FFB800FFC700FFE600BDFF0000E1FF14FF008FFF00FFF500FFC700FFB800FFA800
FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF9900FF8A00FF8A00
FF8A00FF8A00FF9900FF9900FFA800FF9900FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900
FFA800FFB800FFC700FFE600BDFF0000FFC2FF000000FFFFFAFF00FFC700FFB800FFB800
FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FFA800FFC700FFA800FF9900FF8A00FF8A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00
FF6B00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900
FFA800FFB800FFD700FFF500DCFF0014FF00FF000080FF00FAFF00FFD700FFC700FFC700
FFB800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FFA800FFC7009EFF00FF9900FF8A00FF8A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900
FFA800FFB800FFF500BDFF0061FF009EFF0080FF00CCFF00CCFF00FFE600FFE600DCFF00
FFB800FFB800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FFA800FFA800FFB800FFD700FFD700FFA800FF9900FF8A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900
FFA800FFB800EBFF00FFF500FFF500FAFF00EBFF00FAFF008FFF00EBFF00CCFF00FFF500
FFC700FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFB800FFD700EBFF00FFC700FFA800FF9900FF8A00FF8A00FF8A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900
FFA800FFB800FFD700FFD700FFD700FFD700FFF500FFF500FAFF008FFF00FAFF00FFE600
FFC700FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFB800FFB800FFD700CCFF00FFC700FFA800FF9900FF9900FF8A00FF8A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900
FFA800FFA800FFB800FFC700FFC700FFD700FFD700FFE600FFF5009EFF00FAFF00FFD700
FFC700FFC700FFB800FFB800FFB800FFA800FFA800FFA800FFB800FFB800FFB800FFB800
FFB800FFB800FFC700FFD700DCFF00FFE600FFB800FFA800FF9900FF8A00FF8A00FF8A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FFA800
FFA800FFB800FFB800FFB800FFC700FFC700FFD700FFD700FFF50000FFA3DCFF00FFE600
FFD700FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFC700
FFC700FFC700FFD700FFF5009EFF00FAFF00FAFF00FFC700FF9900FF8A00FF8A00FF8A00
FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF6B00FF6B00FF6B00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900
FFA800FFA800FFA800FFB800FFB800FFC700FFC700FFD700FFE600EBFF00DCFF00FAFF00
CCFF00FFD700FFC700FFB800FFB800FFB800FFB800FFC700FFD700FAFF00FFD700FFE600
FAFF00FFE600FAFF0061FF00FFF500FFC700FFC700FFB800FF9900FF8A00FF8A00FF8A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900
FFA800FFA800FFA800FFB800FFB800FFC700FFC700FFD700FFF5009EFF009EFF009EFF00
FAFF00FFD700FFC700FFC700FFC700FFC700FFC700FFC700FFE60080FF00FFF500FAFF00
8FFF00FAFF008FFF00FFE600FFC700FFB800FFA800FF9900FF9900FF8A00FF8A00FF8A00
FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00
FF6B00FF6B00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FFA800
FFA800FFA800FFA800FFB800FFB800FFC700FFC700FFD700FFE600EBFF0042FF0000FF0A
DCFF00EBFF00FFD700FFC700FFC700FFC700FFD700FFD700FFE600AEFF00DCFF009EFF00
FF0000BDFF00BDFF00FFF500FFC700FFB800FFA800FF9900FF9900FF8A00FF8A00FF8A00
FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900
FFA800FFA800FFA800FFA800FFB800FFB800FFC700FFC700FFE600EBFF0080FF009EFF00
9EFF00FAFF00FFE600FFD700FFD700FFD700FFE600FFE600FFF500CCFF00CCFF00CCFF00
42FF00DCFF00FFF5009EFF00FFC700FFA800FFA800FF9900FF9900FF8A00FF8A00FF8A00
FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900
FFA800FFA800FFA800FFA800FFB800FFB800FFC700FFC700FFE6008FFF00CCFF00DCFF00
33FF00EBFF00FFF500FFE600FFE600FFF500EBFF009EFF00CCFF0061FF00FAFF00FAFF00
CCFF00FFF500FFD700FFC700FFB800FFA800FF9900FF9900FF9900FF8A00FF8A00FF8A00
FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900
FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFC700FFD700FFF500FFF500FAFF00
AEFF0000FF66FAFF00FFF500FFF500FAFF0051FF0023FF0070FF00FAFF00FFF500FFE600
FFF500FFE600FFC700FFB800FFB800FFA800FF9900FF9900FF9900FF8A00FF8A00FF8A00
FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900
FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFC700FFD700FFE600FFE600FFF500
CCFF0061FF00DCFF00FAFF00DCFF00CCFF0070FF0051FF00CCFF00EBFF00FFE600FFD700
FFD700FFC700FFB800FFB800FFA800FFA800FF9900FF9900FF9900FF8A00FF8A00FF8A00
FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900
FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFC700FFD700FFD700FFE600FFF500
33FF00CCFF0033FF00CCFF009EFF0042FF00DCFF00CCFF00FAFF00FFE600FFD700FFC700
FFC700FFB800FFB800FFA800FFA800FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FFA800
FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFC700FFC700FFD700FFE600FFE600
FAFF00EBFF00BDFF0000FF949EFF00CCFF00FAFF00FFF500FFE600FFD700FFC700FFC700
FFB800FFB800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00
FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800
FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFC700FFC700FFD700FFE600FFE600
FFF500EBFF00CCFF0033FF00DCFF00FAFF00FFF500FFE600FFD700FFD700FFC700FFC700
FFB800FFB800FFA800FFA800FFA800FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF6B00
FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800
FFA800FFA800FFA800FFB800FFB800FFB800FFC700FFC700FFC700FFD700FFE600FFE600
FFF500EBFF0005FF0080FF00DCFF00FAFF00FFE600FFE600FFD700FFC700FFC700FFC700
FFB800FFB800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800
FFA800FFA800FFA800FFB800FFB800FFB800FFC700FFC700FFC700FFD700FFE600FFF500
FAFF00DCFF008FFF0080FF00DCFF00FAFF00FFE600FFD700FFD700FFC700FFC700FFC700
FFB800FFB800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800
FFA800FFA800FFB800FFB800FFB800FFB800FFC700FFC700FFD700FFE600FFE600FFF500
AEFF00CCFF0051FF0061FF00DCFF00FAFF00FFF500FFD700FFD700FFC700FFC700FFB800
FFB800FFB800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF8A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800
FFA800FFA800FFB800FFB800FFB800FFC700FFC700FFD700FFD700FFE600FFE600FAFF00
BDFF0080FF0042FF008FFF009EFF0033FF00FFF500FFE600FFD700FFC700FFC700FFB800
FFB800FFB800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900
FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800
FFA800FFB800FFB800FFB800FFC700FFC700FFD700FFD700FFE600FFE600FFF50070FF00
0019FF33FF00FF000005FF0080FF00EBFF00FFF500FFE600FFD700FFC700FFC700FFB800
FFB800FFB800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF8A00
FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800
FFA800FFB800FFB800FFB800FFC700FFD700FFD700FFE600FFE600FFF500FAFF00DCFF00
BDFF008FFF0000FF7542FF0005FF0005FF00FFF500FFE600FFD700FFD700FFC700FFC700
FFB800FFB800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00
FF5C00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF8A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00
FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800
FFB800FFB800FFB800FFC700FFC700FFD70051FF00FAFF00FFF500FAFF00FAFF00EBFF00
CCFF0000FF8500FF9480FF00CCFF00EBFF00FFF500FFE600FFE600FFD700FFD700FFC700
FFB800FFB800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900
FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800
FFB800FFB800FFC700FFD700FFD700FFE600EBFF008FFF00EBFF00FAFF00EBFF00DCFF00
BDFF0061FF0000FF9400FF66CCFF00EBFF00FAFF00FFF500FFE600FFE600FFE600FFC700
FFB800FFB800FFB800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900
FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800
FFB800FFC700FFD700FFE600FFF500FFF500EBFF0000FF38CCFF00DCFF0070FF009EFF00
8FFF00FF00F500FF668FFF00AEFF00DCFF00FAFF00FAFF00EBFF00FAFF0042FF00FFD700
FFC700FFB800FFB800FFA800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00
FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900
FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800
FFC700FFC700FFF50023FF00CCFF00BDFF00BDFF0042FF00BDFF00CCFF00AEFF0000FF75
00FF4700FF1900FF7561FF0000FF19CCFF00DCFF00EBFF00CCFF0061FF00EBFF00FFD700
FFC700FFB800FFB800FFB800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900
FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900
FF9900FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFC700FFD700FFE600FAFF0000FF9405FF0000E1FF00FF2880FF0080FF008FFF0061FF00
00FF570094FFFF005C00FFE151FF00AEFF00CCFF00CCFF0000FF389EFF00FFF500FFD700
FFC700FFB800FFB800FFB800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900
FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900
FF9900FFA800FFA800FFC700FFC700FFD700FFC700FFC700FFB800FFB800FFC700FFC700
FFC700FFD700FFD700FFF500DCFF00BDFF00BDFF008FFF0000FF5714FF0042FF0005FF00
FF00E6FF0000FF000000FF5751FF009EFF00AEFF00AEFF0051FF00DCFF00FFF500FFD700
FFC700FFC700FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FF9900FF9900
FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF9900FF9900FF9900FF9900FFA800
FFA800FFA800FFB800FFD70070FF009EFF00FFD700FFC700FFC700FFC700FFC700FFC700
FFC700FFD700FFE600FFF500FAFF00EBFF00CCFF008FFF0033FF000075FFFF007AFF0000
0047FFFF0000FF000000FFB3000AFF61FF0000FF4700FF6642FF0061FF00CCFF00DCFF00
FFD700FFC700FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FF9900
FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00
FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF7A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FFA800FFA800
FFA800FFB800FFB800FFD700EBFF00EBFF00FFF500FFE600FFD700FFC700FFC700FFD700
FFD700FFD700FFE600FFF500FAFF00EBFF00DCFF00AEFF0042FF000038FFFF00D7FF0000
FF0000FF0000FF0000FF000000FFB300FF1900FF6600FF94AEFF0070FF0033FF00DCFF00
FFD700FFC700FFC700FFC700FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800
FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FFA800FFA800FFA800
FFB800FFB800FFC700FFD70033FF0080FF00EBFF00FAFF00FFE600FFD700FFD700FFD700
FFD700FFE600FFE600FFF500FAFF00EBFF00CCFF0061FF0051FF0000FFC2FF0000FF0000
FF0000FF0000FF0000FF0000BD00FFFF00F533FF008FFF00CCFF00DCFF00FAFF00FFE600
FFD700FFC700FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700
FFA800FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF6B00FF6B00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF9900FF8A00FF9900FF9900FF9900FFA800FFA800FFA800FFB800
FFB800FFB800FFC700FFD700FAFF0080FF0080FF0000FF28FFF500FFE600FFD700FFE600
FFE600FFE600FFF500FFF500FAFF00EBFF009EFF000066FFEB00FF00FFFFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000000AFF42FF009EFF00CCFF00EBFF00FFF500FFE600
FFD700FFD700FFC700FFC700FFC700FFC700FFC700FFC700FFB800FFC700FFD70000FF38
FFB800FFA800FF9900FF9900FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FFA800FFA800FFB800FFB800FFB800
FFC700FFC700FFD700FFE600FAFF00BDFF0023FF00DCFF00FFF500FFF500FFE600FFE600
FFF500FFF500FAFF00EBFF00EBFF00DCFF0080FF0070FF0000FF19FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF000000FFC200FF5700A3FF9EFF00EBFF00FFF500FFE600
FFD700FFD700FFD700FFC700FFC700FFC700FFC700FFC700FFC700FFD70014FF00FFF500
FFB800FFA800FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FFA800FFB800FFE600FFD700FFC700
FFD700FFF500FFF500FFF500EBFF00CCFF0000FF0A70FF00FAFF00FFF500FFF500FFF500
DCFF00DCFF00DCFF009EFF00CCFF00CCFF00AEFF008FFF0000FF38FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF000000FF280094FFCCFF00EBFF00FAFF00FFF500
FFE600FFD700FFD700FFD700FFD700FFD70000FFA3FFF500FFE600FFE600EBFF009EFF00
EBFF00FFA800FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF9900FF9900FF9900FFA800FFB800FFC700FFE6009EFF00FFE600
FFF50080FF00DCFF0000FF5733FF00BDFF0000FF19BDFF00EBFF00FAFF00FFF500FAFF00
DCFF00FF00C780FF000094FFBDFF00AEFF008FFF0070FF0023FF00FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF000000FF199EFF00CCFF00EBFF00EBFF00DCFF00
FFF500FFE600FFD700FFD700FFD700FFE600FAFF0070FF00EBFF00EBFF00AEFF00FFF500
FFC700FFA800FFA800FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF7A00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF8A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF9900FF9900FF9900FF9900FFA800FFC700FFF5008FFF00BDFF00FAFF00
EBFF0070FF0014FF0061FF0061FF0000FF85FF0000BDFF00EBFF00EBFF00FAFF00EBFF00
DCFF00AEFF0051FF0070FF008FFF0033FF0000FF8551FF0023FF0000FFB3FF0000FF0000
FF0000FF0000FF0000FF0000FF000000FF1933FF009EFF00BDFF00CCFF0000FF8500FF19
FAFF00FFF500FFE600FFE600FFE600FFF500FAFF00BDFF009EFF00FF0000BDFF00BDFF00
FFB800FFA800FFA800FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF8A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF9900FF9900FF9900FF9900FFA800FFF50000FF38FAFF008FFF00CCFF00
FF0000AEFF00CCFF00CCFF00AEFF0000FF0A8FFF00BDFF00DCFF00DCFF00DCFF00DCFF00
CCFF00AEFF0023FF0000FF1900FF9400FFD10057FF00FF1900FF4700FFC200C2FFFF0000
FF0000FF0000FF0000FF000000FFB314FF0061FF0051FF009EFF00BDFF0000FFE19EFF00
EBFF00FFF500FFF500FFE600FFF500EBFF00BDFF0000FFD1AEFF00EBFF00FFF500FFD700
FFB800FFA800FFA800FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF5C00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF9900FF9900FF9900FF9900FFA800FFA800FFB800FFD700FFE600DCFF008FFF00
BDFF00DCFF00EBFF00DCFF00BDFF0000FF478FFF00AEFF00CCFF00AEFF00AEFF009EFF00
BDFF0000D1FF0038FF0066FF00FF6600FFF0FF00000028FFFF0000FF0000FF0000FF0000
FF0000FF0000FF00000047FF00A3FF00FF4700FF1914FF0042FF008FFF0061FF0000B3FF
00FF85FAFF00FFF500FFF500FAFF00DCFF0070FF0051FF00DCFF00FFF500FFE600FFC700
FFB800FFA800FFA800FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF9900FF9900FF9900FF9900FFA800FFA800FFB800FFB800FFD700EBFF00EBFF00
FFF500FAFF00FAFF00EBFF0070FF0000FF2800FFB333FF00AEFF008FFF0000FFC233FF00
9EFF0070FF0000FF47FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00002300FFFF000000FF4700B3FF00FF0A70FF00
BDFF00EBFF00FAFF00FAFF00EBFF00DCFF0051FF00AEFF00DCFF00FAFF00FFE600FFC700
FFB800FFB800FFA800FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF7A00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF6B00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00
FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF9900FF9900FF9900FF9900FFA800FFA800FFB800FFB800FFC700FFD700FFE600
FFE600FFE600FFF500FAFF00BDFF0000FF57FF000005FF0070FF000085FF00FFA361FF00
61FF006100FF00FF57FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF57FF004CFF000051FF00
BDFF00DCFF00EBFF00EBFF00EBFF00CCFF000075FF80FF0051FF0080FF00EBFF00FFD700
FFC700FFB800FFA800FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFB800FFB800FFC700FFD700
FFD700FFE600FFF500FAFF00DCFF008FFF0000FF5700FF475100FFCC00FF00FF8500FF19
33FF00FF003D0085FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000A3FF00FF47
9EFF00AEFF00AEFF00CCFF00DCFF00BDFF008FFF0000FFF080FF0000A3FF33FF00FFE600
FFD700FFC700FFA800FFA800FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFB800FFB800FFC700FFC700
FFD700FFD700FFE600FAFF0000D1FF80FF0000FF7500E1FF0057FFFF0000FF000000B3FF
00FF380085FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000023FF00
80FF0000FF3805FF009EFF00BDFF00AEFF0080FF0000FF19BDFF00BDFF0000FF28FAFF00
61FF00EBFF00FFB800FFA800FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFB800FFB800FFB800FFC700
FFC700FFD700FFE600FAFF0005FF0000FFA300FF0A00FFC2FF0000FF0000FF0000FF0000
0019FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
51FF0051FF0000FFC200FF7580FF0000FF2814FF0080FF00DCFF00DCFF009EFF0080FF00
80FF00FFC700FFA800FFA800FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900
FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFB800FFB800FFB800FFB800FFC700
FFC700FFD700FFE600FAFF00AEFF00AEFF0070FF000085FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000000AFF
00FF0A00FF57FF000000FFC251FF0000FF3800FF288FFF00EBFF00FAFF00FAFF0023FF00
FFE600FFC700FFA800FFA800FF9900FF9900FF9900FF9900FF8A00FF9900FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF6B00FF6B00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900
FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFB800FFB800FFB800FFC700
FFC700FFD700FFE600FFF500FAFF00CCFF0000FF7500F0FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
00FFA3FF0000FF000000E1FF00FF570047FF80FF00CCFF00FAFF00FFF500FFE600FFD700
FFC700FFB800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00
FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900
FF9900FF9900FFA800FF9900FF9900FFA800FFA800FFA800FFA800FFB800FFC700FFC700
FFC700FFD700FFE600FFF500FAFF00DCFF0042FF0000FF1900FFC2FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0500FFFF0000FF0000FF0000FA00FF00FFFF61FF0000FF57FAFF00FFE600FFD700FFC700
FFC700FFB800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF6B00FF6B00FF6B00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF8A00
FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFC700
FFC700FFD700FFE600FFF500FAFF00DCFF00AEFF0080FF0005FF0000FF75FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000094FF51FF0005FF0023FF00FFF500FFD700FFD700FFC700
FFB800FFB800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00
FF7A00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00
FF8A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFC700
FFD700FFE600FAFF00EBFF00EBFF00DCFF00BDFF0033FF0023FF000085FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000BD00FF00FF57CCFF00FAFF00FFF500FFD700FFC700FFC700
FFB800FFB800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF7A00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00
FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFC700
FFD7009EFF00BDFF0061FF00BDFF00CCFF009EFF0000FF2800FF85FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000BD00FFFF000000F0FF05FF00FF00F5DCFF00FFF500FFE600FFD700FFC700FFC700
FFB800FFB800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF8A00FF9900
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00
FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00
FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFC700
FFD700FFF5008FFF0000FFF061FF00AEFF009EFF0051FF00FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF000000FF6642FF008FFF00BDFF00EBFF00FAFF00FFF500FFD700FFC700FFC700
FFB800FFB800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00
FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF8A00FF7A00FF7A00FF8A00FF8A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFC700FFC700
FFD700FAFF00AEFF0000FFB300D1FF8FFF0080FF0033FF0000FF94FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF000014FF00EB00FFCCFF00DCFF00EBFF00FAFF00FFE600FFD700FFC700
FFB800FFB800FFA800FFA800FFA800FF9900FFA800FF9900FF9900FF9900FF9900FF8A00
FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF7A00FF7A00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF8A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF9900FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFC700FFD700
FFE60080FF0000FF0A00FFD142FF0061FF0014FF0000FF3800D1FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000EB00FF00FF57BDFF00BDFF0033FF0014FF00EBFF00BDFF00FFC700
FFB800FFB800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF5C00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFC700FFD700
51FF009EFF008FFF0000FF190085FF0085FF00F0FF5100FF0057FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00006100FF80FF009EFF0000FF4700FF4714FF008FFF00FAFF00FFC700
FFB800FFB800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900
FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFC700FFF500
8FFF000057FFBDFF00AEFF0000FF1900FFFFFF008AFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF000000FF19FF000080FF0023FF0000FF94BDFF00DCFF00FFD700FFC700
FFB800FFB800FFB800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFC700FFE600
FFF50005FF00EBFF00DCFF000057FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF000000FF7533FF0033FF0000FF0A00FFA3FFF500FFD700FFC700
FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF7A00FF6B00FF6B00
FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00
FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900
FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FF9900FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFC700FFC700FFD700
FFE600FFF500FAFF00EBFF009EFF0000A3FF00FF750019FF1400FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF000000D1FF00FF940019FF9EFF000019FFFAFF00FFD700FFC700
FFC700FFB800FFB800FFA800FFA800FFA800FFA800FFA800FF9900FFA800FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF8A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF8A00FF7A00FF7A00FF8A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF9900
FF8A00FF9900FF8A00FF9900FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800
FFA800FFA800FFA800FFA800FFB800FFA800FFB800FFB800FFB800FFC700FFC700FFD700
FFD700FFE600FFF500FAFF00DCFF00AEFF0051FF0000FF66FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00D780FF00DCFF0061FF00FAFF00FFD700FFC700
FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00
FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFC700FFC700FFD700
FFD700FFE600FFF500FAFF00CCFF0080FF0070FF0000FF19FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000075FF00FF57FF00A8BDFF00FAFF00FFF500FFE600FFD700FFC700
FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FF9900FFA800FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF7A00FF8A00FF8A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FFA800FF9900FF9900FF9900FFA800FF9900FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700
FFD700FFE600FFF500FAFF0000FF0A00FF2833FF0000FF0AFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000000AFF0085FF70FF00BDFF00EBFF00FFF500FFE600FFD700FFD700FFC700
FFC700FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FFA800FF9900FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFD700
FFD700FFE600FFE600FAFF00AEFF00DC00FF00FF0A00FF66FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF000023FF0061FF0000FFE1DCFF00FFF500FFE600FFD700FFC700FFC700
FFC700FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFD700
FFD700FFE600FFE600FAFF0061FF0061FF00FF00B80085FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF000000FF0A00FF9423FF0000FF0AFFF500FFE600FFD700FFC700FFC700
FFC700FFB800FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FF9900FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00
FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800
FFA800FF9900FF9900FFA800FF9900FF9900FFA800FF9900FF9900FF9900FF9900FF9900
FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFD700
FFD700FFE600FFF500FAFF008FFF00AEFF0000FFA3FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF000000FF57FF001EEBFF00FFF500FFE600FFD700FFD700FFC700
FFC700FFB800FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFB800FFC700FFB800FFA800FFA800
FFA800FFA800FFA800FFA800FF9900FF9900FFA800FF9900FF9900FF9900FF9900FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFD700FFD700
FFD700FFE600FFF500FAFF00EBFF00DCFF00BDFF0070FF0005FF00FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000038FF2300FF8FFF0005FF00FAFF00FFF500FFE600FFD700FFD700FFC700
FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900
FF9900FFA800FFA800FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FFA800FFA800FF9900FF9900
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800DCFF00FFF500FFB800FFB800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFD700FFC700FFD700FFD700
FFD700FFE600FFE600FFF500FAFF00EBFF00BDFF0000FF4700FF389E00FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF000023FF008FFF00CCFF00EBFF00FAFF00FFE600FFE600FFD700FFD700FFC700
FFC700FFC700FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFA800FFB800FFB800
FFB800FFA800FFB800FFA800FFB800FFA800FFA800FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900
FFA8009EFF00FFC700FFD700FF9900FF9900FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00
FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF8A00FF8A00FF8A00
FF8A00FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFB800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFC700FAFF00FFF500FFD700FFC700
FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFD700
FFE600FFE600FFF500FFF500FAFF00EBFF00CCFF0000FF380057FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF000000FFC2CC00FF0028FFDCFF00FAFF00FFF500FFE600FFE600FFD700FFD700FFD700
FFC700FFC700FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFA800FFA800FFA800FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF9900FF9900FF9900FF9900FF9900
FFA800FFC700FAFF00FFF500FFA800FF9900FF9900FF8A00FF8A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF9900FFA800FFA800FFB800FFB800FFB800FFF500FFC700FFB800FFB800
FFA800FFA800FFB800FFB800FFB800FFB800FFC700DCFF00DCFF0070FF00FAFF00DCFF00
FFC700FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFB800FFB800FFC700FFB800FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFD700FFD700FFE600
FFE600FFE600FFF500FFF500FAFF00EBFF00DCFF00000AFF80FF0014FF0000FFD1FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF000000FFFFAEFF00EBFF00FAFF00FFF500FFF500FFE600FFE600FFD700FFD700
FFD700FFC700FFC700FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFC700EBFF00FFC700FFB800FFB800FFA800FFA800FFA800FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00
FF8A00FF9900FF8A00FF9900FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FFA800
FFA800FFC700FAFF00FFE600FFB800FFA800FF9900FF9900FF8A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF9900FF9900FFB800FFE600FFE600FFD700FFE60070FF00FFF500FFC700FFB800
FFB800FFB800FFB800FFB800FFB800FFC700FFD700EBFF0033FF007000FF9EFF009EFF00
FFE600FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFB800FFA800FFA800
FFA800FFB800FFB800FFB800FFC700FFD700FFD700FFD700FFC700FFD700FFD700FFD700
FFD700FFC700FFC700FFC700FFD700FFC700FFD700FFD700FFD700FFD700FFD700FFE600
FFE600FFF500FFF500FAFF00FAFF00EBFF00DCFF00CCFF00AEFF000094FF00FFC2FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0099
00FF6661FF00AEFF00CCFF00EBFF00FAFF00FFF500FFF500FFE600FFE600FFE600FFD700
FFD700FFD700FFD700FFC700FFC700FFC700FFC700FFC700FFC700FFB800FFB800FFB800
FFC700FFC700FFD700DCFF0000FF57FFD700FFB800FFB800FFA800FFA800FFA800FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800
FFB800FFB800FFE60000FF28FFC700FFB800FFF500FFA800FF8A00FF8A00FF8A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF6B00
FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF9900FF9900FFA8008FFF0042FF00CCFF00BDFF00EBFF00FFE600FFC700FFC700
FFC700FFC7008FFF00FFD700FFD700FFD700FFD700FFF500DCFF0023FF00EBFF00FFF500
FFD700FFC700FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFB800FFA800FFA800
FFB800FFB800FFB800FFC700FFE600CCFF0000FF38FFE600FFE600FFE600FAFF00BDFF00
FFE600FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFE600FFE600FFE600FFE600
FFF500FFF500FFF500FAFF00FAFF00EBFF00DCFF00CCFF00BDFF0000FFB300C2FF00FFA3
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
00D1FF00C2FFBDFF00DCFF00EBFF00FAFF00FAFF00FFF500FFF500FFE600FFE600FFE600
FFE600FFD700FFD700FFD700FFD700FFC700FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFD700FFE60042FF0000FFA3FAFF00FFC700FFB800FFB800FFA800FFA800FFA800
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800
FFB800FFB800FFD700EBFF00FAFF00FFD7008FFF00FFA800FF9900FF8A00FF8A00FF8A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF9900FF9900FFA800FFC700FFE600DCFF0042FF00EBFF00FFE600FFE600FFD700
FFD700FFE60070FF00CCFF00FFE600FFE600FFF500EBFF00BDFF0051FF00DCFF00FFE600
FFD700FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFC700FFC700FFE60080FF0080FF00EBFF0000FF57FAFF0080FF0000FF85
FAFF00FFE600FFE600FFD700FFD700FFE600FFE600FFE600FFF500FFF500FFF500FFF500
FFF500FFF500FAFF00FAFF00EBFF00EBFF00DCFF00CCFF00BDFF009EFF0080FF000047FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000085FF
80FF00AEFF00CCFF00DCFF00EBFF00EBFF00FAFF00FAFF00FFF500FFF500FFE600FFE600
FFE600FFE600FAFF00FFF500FFE600FFD700FFD700FFC700FFC700FFC700FFC700FFC700
FFD700FFD700FFF500DCFF0070FF00EBFF00FFD700FFC700FFB800FFB800FFA800FFA800
FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800
FFB800FFC700FFD700FFF50061FF00EBFF00FFD700FFA800FF9900FF8A00FF8A00FF8A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00
FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900
FF9900FF9900FF9900FFA800FFB800EBFF0014FF00DCFF009EFF00EBFF00FAFF00FFE600
FFE600FFF5008FFF0080FF00FFF500FFF5009EFF00AEFF0000FF2851FF0061FF00FFE600
FFD700FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFC700FFC700FFC700FFE60023FF000075FF8FFF0000FF2861FF0023FF00AEFF00
FAFF00FFF500FFE600FFE600FFE600FFE600DCFF0000FFE1FAFF00CCFF00FAFF00FAFF00
FAFF00FAFF00EBFF00EBFF00EBFF00DCFF00DCFF00CCFF00BDFF009EFF008FFF0061FF00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF1900FF28
9EFF00AEFF00CCFF00DCFF00DCFF00EBFF00EBFF00FAFF00FAFF00FAFF00FFF500FFF500
FFF500FAFF00CCFF00FF0000FFF500FFE600FFD700FFD700FFD700FFD700FFD700FFD700
FFE600FFF500FAFF00CCFF000094FFFAFF00FFE600FFE600FFE600FFB800FFA800FFA800
FFA800FFA800FF9900FFA800FF9900FF9900FF9900FF9900FF9900FFA800FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800
FFB800FFC700FFD700FFF500AEFF00EBFF00FFD700FFA800FF9900FF9900FF8A00FF8A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF9900FF9900FF9900FFA800FFB8009EFF00FFF500FAFF0000FFC200FF19CCFF00FAFF00
FAFF00FAFF0070FF008FFF00EBFF00DCFF0000FF3805FF0000FF47AEFF00FAFF00FFE600
FFD700FFC700FFC700FFC700FFB800FFB800FFC700FFB800FFB800FFB800FFB800FFB800
FFB800FFC700FFC700FFD700FFE600FAFF00AEFF00FF008A00FFA300D1FF42FF009EFF00
BDFF00FAFF00FFF500FFE600FFF500FFF500CCFF0000FF3800FF0A23FF00CCFF00EBFF00
EBFF00DCFF00DCFF00CCFF00DCFF00DCFF00CCFF00BDFF00BDFF009EFF008FFF0070FF00
42FF0000FF19FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF7551FF0080FF00
9EFF00AEFF00BDFF00CCFF00CCFF00DCFF00DCFF00DCFF0000FF0AEBFF00FAFF00FAFF00
FAFF00DCFF0061FF0000FF0A8FFF0000FF94FFE600FFD700FFD700FFD700FFD700FFE600
00FF6623FF00BDFF00BDFF0005FF00BDFF0061FF00DCFF008FFF00FFC700FFB800FFA800
FFA800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFB800
FFB800FFC700FFF500CCFF00DCFF00EBFF00CCFF00FFB800FF9900FF9900FF8A00FF8A00
FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900
FF9900FF9900FF9900FFA800FFA800FFC700FFD700FFE600FAFF0000FF1933FF0000FFC2
DCFF00EBFF008FFF008FFF00CCFF00BDFF000047FF8FFF009EFF00BDFF00FAFF00FFE600
FFD700FFD700FFC700FFC700FFC700FFC700FFC700FFB800FFB800FFB800FFB800FFC700
FFC700FFC700FFD700FFD700FFF500CCFF0000FF4700FFFFFF000000FFA300FF6600FF28
00FFD1BDFF00FAFF00FFF500FAFF00FAFF00CCFF00FF0000FF000000FF85FF0000DCFF00
DCFF00AEFF00FF0000FF0000BDFF00BDFF009EFF009EFF009EFF008FFF0080FF0070FF00
51FF0033FF0000FF19FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0A33FF0051FF0070FF00
8FFF008FFF00AEFF00AEFF000094FFBDFF00CCFF009EFF0014FF00FF002EDCFF00EBFF00
EBFF00AEFF00FF001E00FF6600FF948FFF00FFF500FFE600FFE600FFE600FFE600FFF500
AEFF0000FFA361FF0061FF0014FF0042FF008FFF00FF000000FF19FFC700FFB800FFB800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900FF9900FFA800FF9900FF9900
FF9900FFA800FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800
FFC700FFE600BDFF0061FF00FFF500FFE600FFC700FFA800FF9900FF9900FF8A00FF8A00
FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF9900FF9900FF9900FFA800FFA800FFB800FFC700FFD700FFE600EBFF0080FF0042FF00
00FF57AEFF008FFF0000D1FF9EFF0000FFA300FFF09EFF00CCFF00EBFF00FFF500FFE600
FFE600FFD700FFD700FFD700FFD700FFC700FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFD700FFE60070FF00CCFF0070FF0000D1FF00FFE100FF853300FF0028FF
80FF00CCFF00FAFF00FAFF00EBFF000500FF80FF0000FF753300FF8000FF00A3FFBDFF00
23FF00FF0000FF0000FF00008FFF0080FF00FF000000FF0A70FF0000FF8561FF0000C2FF
33FF0014FF0000FF0A00FF3800FF94FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000075FF00FF9400FF3800FF0A14FF0005FF0051FF00
51FF0000FF1900FF858FFF000066FF00FFA3AEFF0080FF00FF0000FF00009EFF00CCFF00
DCFF0014FF00FF003DFF0000FF000000FF85DCFF00FFF500FFE600FFE600FFF500FAFF00
CCFF000038FF00FFFF9E00FF00FF1900FF9400FF19BDFF00FFF500FFD700FFC700FFB800
FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800
FFC700FFE600BDFF00DCFF00FFF500FFD700FFB800FFA800FF9900FF9900FF8A00FF8A00
FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF7A00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900
FF9900FF9900FF9900FFA800FFA800FFB800FFB800FFC700FFD700FFF500EBFF00CCFF00
42FF0014FF0070FF0005FF00FF002E14FF0023FF00BDFF00DCFF00EBFF00FFF500FFF500
FFE600FFE600FFE600FFE600FFD700FFD700FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFD700FFE600CCFF0000FF6670FF0000F0FFFF000000FF751400FF00FF2861FF00
9EFF00CCFF00DCFF00EBFF00DCFF0014FF000075FFFF002EFF0000FF000033FF009EFF00
1400FFFF00000066FF00FFFF51FF00FF0000FF000000FF194200FFCC00FFFF00003300FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000EB00FFFF003DFF0000FF0000FF0000
FF0000FF0000FF0000AE00FF3300FFFF0000FF0000FF00C7FF0000FF0000BD00FFFF0000
FF000000FF28FF00006100FFFF00002300FFFF000051FF0000FFF000B3FF8000FF00D1FF
BDFF0070FF0000FF19FF000000FFC20500FF00E1FFEBFF00FFF500FFF500FFF500FAFF00
DCFF00AEFF0070FF0000FF0A00FF4700F0FF00FFB300FF94FFF500FFD700FFC700FFB800
FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFC700
FFE600FAFF0042FF0000FF28FAFF00FFD700FFB800FFA800FF9900FF9900FF9900FF8A00
FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF8A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00
FF9900FF9900FF9900FFA800FFA800FFB800FFC700FFC700FFD700FFE600FAFF00DCFF00
AEFF0000FF0A0066FF00FF3800FFFF70FF009EFF00BDFF00DCFF00EBFF00FAFF00FAFF00
FFF500FFF500FFF500FAFF00FFF500FFD700FFD700FFD700FFC700FFC700FFC700FFD700
FFD700FFD700FFE600CCFF0000FF190066FF00FF8533FF0000FF38FF000000FFFF0019FF
00FF0A61FF00CCFF00CCFF00CCFF0000FFD142FF0000FF28FF0000FF0000FF000070FF00
51FF00FF0000FF0000FF000000FF0A00FF75FF000000C2FF000AFFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000028FFFF0000FF0000FF0000FF000000FF0A8000FFFF007AFF00005100FF70FF00
8FFF0000FF6600FFB3FF0000EB00FF00FF8533FF00DCFF00FAFF00FAFF00EBFF00DCFF00
8FFF009EFF0070FF0023FF000085FF00FF38FF009970FF00DCFF00FAFF00FFD700FFC700
FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFB800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFD700
FAFF0014FF0000FF19FF0000AEFF00FFD700FFB800FFA800FFA800FF9900FF9900FF8A00
FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900
FF9900FF9900FF9900FFA800FFA800FFB800FFB800FFC700FFE600FFE600FAFF00DCFF00
BDFF0080FF0000FF3800FFA342FF0080FF009EFF00BDFF00CCFF00DCFF00EBFF00FAFF00
EBFF00AEFF00EBFF00AEFF00CCFF00FFE600FFD700FFD700FFD700FFD700FFD700FFD700
FFD700FFE600FFE600EBFF0051FF008FFF0080FF0051FF000028FFFF0000FF000000FF57
FF00F5FF0000FF0000BDFF00BDFF009EFF0033FF0000B3FFFF0000FF0000FF000023FF00
FF0000FF0000FF0000FF000000A3FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF007AFF002E00FFB3FF0000FF0000FF0000FF0000
51FF00FF0000FF0000FF000000FFC200FF199EFF00CCFF00EBFF00EBFF0000FFE100FFA3
FF000061FF0000C2FF00FF94FF00C714FF0014FF0000FF5770FF0070FF00FFD700FFC700
FFB800FFB800FFB800FFB800FFB800FFB800FFA800FFA800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFD700
FAFF00DCFF0033FF0000FF38FAFF00FFD700FFB800FFA800FFA800FF9900FF9900FF9900
FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900
FF9900FF9900FF9900FFA800FFA800FFB800FFC700FFD700FFE600FFF500EBFF009EFF00
000AFF00FFA300FF0A23FF0000FF570085FF8FFF009EFF009EFF0005FF00DCFF00EBFF00
CCFF0061FF009EFF0000FF85BDFF00FAFF00FFF500FFE600FFD700FFD700FFD700FFD700
FFE600FFE600FFF500FAFF00DCFF00BDFF008FFF0042FF0000FFB3FF0000FF00008000FF
FF0000FF00000500FF9EFF008FFF0070FF00CC00FFFF0000FF0000FF0000FF000000FF75
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
00FF0AFA00FFFF0000FF0000FF0000FF00009EFF00BDFF00CCFF00CCFF0042FF000094FF
00FF8500FF284200FFFF0000EB00FFFF004C80FF0042FF0033FF0000A3FFFFE600FFC700
FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFD700
FFE600FAFF0061FF0023FF00DCFF00FFE600FFB800FFB800FFA800FFA800FF9900FF9900
FF9900FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900
FF9900FF9900FF9900FFA800FFA800FFB800FFD70033FF00FFF500EBFF0000D1FF33FF00
00FF190066FF80FF0051FF0000FF85FF000000D1FF70FF000066FF42FF00BDFF00CCFF00
BDFF0000A3FF33FF0000FF3833FF00DCFF00DCFF00FFF500FFE600FFE600FFE600FFE600
FFE600FFE600FFF500FAFF00EBFF00CCFF0000F0FF1400FFBD00FFFF0000FF0000FF0000
FF000000FFC251FF0061FF00FF00C7FF000014FF007000FFFF0000FF0000FF00A8FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000066FF80FF0000FF38AEFF00BDFF0070FF00FF000F
FF0000FF0000FF0000FF0000FF000000A3FF9EFF00BDFF00DCFF00EBFF00FFD700FFC700
FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFD700
FFE600FFF500EBFF00AEFF00AEFF00FFE600FFC700FFB800FFB800FFA800FFA800FFA800
FF9900FF9900FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00
FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00
FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900
FF9900FF9900FF9900FFA800FFB800FFB800FFD70080FF00DCFF00BDFF0000FF0A70FF00
70FF008FFF009EFF0070FF0000FFFF0047FF14FF0033FF0000FF2800FFE10094FFAEFF00
AEFF0070FF00FF0000FF000000FF195100FF00FF66DCFF00FFF500FFE600FFE600FFE600
FFE600FFF500FFF500FAFF00EBFF00BDFF008000FF00FFF0FF0000FF0000FF0000FF0000
FF0000FF000014FF0033FF002300FF8F00FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF000000E1FF00FF3800FFE1FF00000019FF8FFF0042FF0000FFB3
FF0000FF0000FF0000FF00000075FF23FF0000FFC2CCFF00EBFF00FFF500FFE600FFD700
FFC700FFC700FFC700FFC700FFB800FFB800FFB800FFC700FFC700FFD70000FF0AAEFF00
FFE600FFD700CCFF00FFE600FFD700FFC700FFC700FFC700FFC700FFD700FFD700FFD700
FFE600FFF500DCFF0042FF00DCFF00FFE600FFC700FFB800FFB800FFB800FFB800FFC700
FFA800FF9900FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF9900FF9900
FF9900FF9900FFA800FFA800FFB800FFC700FFE60051FF009EFF008FFF00FF000080FF00
BDFF00BDFF00AEFF008FFF0000FF5700FFA300FFF000FF753300FF00FF0A61FF0080FF00
8FFF0070FF0033FF0000FF4700FFB370FF0000FF28EBFF00FFF500FFF500FFF500FFF500
FFF500FAFF00FAFF00EBFF00DCFF00BDFF00FF005CFF0000FF0000FF0000FF0000FF0000
FF0000FF000000FF19FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF000FFF000000D1FF61FF0000FFE1FF0000
FF0000FF0000FF0000FF0000FF000000FF3800FFA300F0FFFAFF00FFF500FFE600FFD700
FFD700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFE600CCFF0000FF85
EBFF00FFF50061FF00EBFF00FFE600FFE600FFD700FFD700FFD700FFD700FFD700FFE600
FFE600FAFF0051FF0070FF0070FF00FFE600FFD700FFC700FFC700FFC700FFC700FFD700
FFD700FF9900FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900
FF9900FF9900FFA800FFA800FFB800FFC700DCFF008FFF0061FF0000FF198FFF00BDFF00
DCFF00DCFF00BDFF008FFF0051FF0000FFC2FF0000FF0000FF000000FFF023FF00FF0000
AE00FF33FF000019FF00A3FF00FF198FFF00BDFF00EBFF00FAFF00FFF500FFF500FAFF00
EBFF00EBFF00AEFF00CCFF00CCFF00BDFF0000FFF0FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF28FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00009EFF00FAFF00FFF500FFE600FFD700
FFD700FFD700FFC700FFC700FFC700FFC700FFC700FFC700FFD700FFE600EBFF0000FF28
23FF009EFF00AEFF00AEFF00CCFF0070FF00FFE600FFD700FFD700FFD700FFE600FFE600
FFF500EBFF0000FFC200FFB351FF00FFF500FFE600FFF500FFD700FFD700FFD700AEFF00
FFB800FF9900FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900
FF9900FF9900FFA800FFA800FFB800FFF500FAFF00DCFF00DCFF00EBFF0005FF00EBFF00
EBFF00DCFF00AEFF0000FFA323FF0000FFA3FF0000FF0000FF0000FF000000FF4700FF57
FF000000FF478F00FFFF000000B3FF80FF00AEFF00DCFF00EBFF00FAFF00FAFF00EBFF00
80FF0070FF0014FF009EFF00AEFF00AEFF0080FF0000FF280066FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000047FF00FF66FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00C7CCFF00EBFF00FFF500FFF500FFF500
FFE600FFD700FFD700FFC700FFC700FFC700FFC700FFD700FFD700FFE600EBFF00BDFF00
8FFF0042FF0000FF8570FF0000FFE1DCFF00FFF500FFE600FFE600FFE600FFE600FFF500
FAFF00EBFF00BDFF0000FF75CCFF00FAFF00FFF500EBFF00EBFF00FAFF00FAFF00BDFF00
FFF500FF9900FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900
FF9900FF9900FFA800FFA800FFB800FFC700FFD700FFF500FFF500FFF500FFF500FAFF00
FAFF00EBFF00CCFF0000FFA300FF660500FFFF0000FF0000FF0000FF0000FF003DAE00FF
FF0000FF0000FF0000FF0000FF000042FF0005FF0000FF85DCFF00EBFF00EBFF00DCFF00
AEFF00FF0000FF000000FF94FF000080FF00FF000033FF0000FF38000AFFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000047FF80FF00CCFF00EBFF00FAFF00FAFF00AEFF00
FFF500FFE600FFD700FFD700FFD700FFD700FFD700FFD700FFE600FFE600FAFF00DCFF00
BDFF0070FF0000FF3800FFE180FF00DCFF00FAFF00FFF500FFF500FFF500FFF500FFF500
FAFF00EBFF00CCFF0000FF38BDFF00DCFF009EFF00AEFF0000FF1970FF00EBFF00BDFF00
FFB800FF9900FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF7A00FF7A00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900
FF9900FF9900FFA800FFA800FFB800FFB800FFC700FFD700FFD700FFE600FFE600FFF500
FAFF00EBFF00AEFF0014FF0000FF1900C2FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000066FF00FF191400FF70FF00CCFF00DCFF00DCFF00BDFF00
FF00E60094FFFF002E00FF8523FF000075FFFF000000FF6600E1FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00E633FF009EFF00CCFF00DCFF00AEFF00CCFF0061FF00
DCFF00FFF500FFE600FFD700FFD700FFD700FFD700FFE600FFE600FFF500FAFF00DCFF00
00FFFF0085FF05FF0080FF00BDFF00DCFF00EBFF00EBFF0000FF19DCFF00DCFF00EBFF00
EBFF00DCFF00CCFF0070FF009EFF0061FF0042FF00BDFF00AEFF00FFF500FFD700FFC700
FFA800FF9900FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900
FF9900FF9900FFA800FFA800FFB800FFB800FFB800FFC700FFD700FFD700FFE600FFF500
FFF500EBFF00CCFF009E00FF42FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000057FFFA00FFBDFF00CCFF00CCFF00BDFF00
70FF000075FFFF0000FF00F5FF000000FF47FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00002300FF00FFA305FF0051FF0061FF009EFF00BDFF00DC00FF14FF0000FF75
00FF0A00D1FFFFF500FFE600FFE600FFE600FFE600FFF500FFF500FAFF00DCFF00BDFF00
00FF4700F0FF00FFF042FF009EFF00BDFF00DCFF00CCFF0061FF0061FF0070FF00BDFF00
CCFF00CCFF00AEFF0080FF0000FF0A8FFF00DCFF00FAFF00FFE600FFC700FFB800FFA800
FFA800FF9900FF9900FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF9900FF9900FF9900FF9900
FF9900FFA800FFA800FFA800FFA800FFB800FFB800FFC700FFC700FFD700FFD700FFE600
FAFF00EBFF00CCFF00AEFF0070FF0023FF0000FF85FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF009970FF00AEFF00BDFF00BDFF00AEFF00
80FF0000FF75FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00003300FF8FFF0061FF0000FFB3FF0000
000AFFCCFF00FFF500FFF500FFE600FFE600FFF500FAFF00EBFF0000FF9423FF00AEFF00
4200FFFF000000FFD100FFC280FF0000FFE19EFF00AEFF008FFF0033FF0051FF009EFF00
8FFF0000FF1970FF000057FF61FF008FFF00DCFF00FFF500FFD700FFC700FFB800FFA800
FF9900FF9900FF9900FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FFA800FFA800FFA800FFB800FFB800FFB800FFC700FFD700FFD700FFF500
00E1FFCCFF00BDFF00AEFF0051FF0000FF38FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF000000FF9400C2FF9EFF00AEFF000075FFFF00A8
DC00FF00FF38FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000042FF00CC00FFFF0000FF0000
00FFD1FF0000FAFF00FFF500FFF500FFF500FAFF00FF008A00FFC20057FF00FF4770FF00
00FFE1FF0000FF000000FF4714FF00FF000023FF0080FF0033FF0000FF1900FF5700FF19
61FF0000FFB300FF388FFF00AEFF0000FF669EFF00EBFF00FFE600FFC700FFB800FFA800
FF9900FF9900FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900
FF9900FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFC700FFC700FFD700FFF500
00FFB361FF0061FF008FFF000028FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFA380FF008FFF00FF00D7FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF28FF0000FF0000FF0000
FF0000AEFF00EBFF00FAFF00FAFF00FAFF00FAFF00CCFF0080FF000028FF14FF0000FF85
00FF75FF0000FF0000FF000000FFFF6100FF00FF1942FF000047FFFF000000FFF000A3FF
00FF6600FF2800FF8551FF00CCFF009EFF0000FF5751FF00FFE600FFC700FFB800FFA800
FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFC700FFD700FFD700FFF500
DCFF0005FF000028FF61FF0033FF0000FF94FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00D700FF1970FF0061FF0014FF008F00FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000B3FFFF0000FF00000085FF
61FF00BDFF00DCFF00EBFF00FAFF00FAFF00EBFF00CCFF008FFF00FF0000FF0099FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF38FF0000FF0000FF0000FF0000
00FF9461FF009EFF00DCFF00EBFF00EBFF00CCFF0014FF00FFF500FFD700FFD700FFA800
FF9900FF9900FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF6B00FF6B00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFC700FFC700FFD700FFF500
00C2FF00E1FFCC00FF33FF00EB00FF0066FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000042FF00FF00000075FF0019FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
61FF00FF000000FFC2CCFF00DCFF00EBFF00DCFF0061FF0005FF00FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000066FFFF0000FF0000FF0000FF0000
00FF3880FF00BDFF00EBFF00FAFF00FAFF00EBFF0005FF00DCFF00DCFF00DCFF00FFB800
FF9900FF9900FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF6B00
FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF8A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFC700FFC700FFD700FAFF00
61FF0000FF6600FFE1FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0AFF00A8FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFA3
05FF0000FF85FF000005FF00CCFF00DCFF00BDFF0000FF6600FF750047FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
00FF1970FF0000FFE1DCFF00FFF500FFF500FFF5009EFF00BDFF0080FF00FFD700FFA800
FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00
FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800
FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFC700FFD700FFE60000FF85
00FF5700FFA300FF47FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF47FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
00FFC2FF00001400FF05FF00BDFF00BDFF00AEFF0061FF00FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
00A3FF00FFC28FFF00CCFF00FFE600FFE600FFD700FFE600FFE600FFE600FFC700FFA800
FF9900FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00
FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFC700FFC700FFD700FFE6000057FF
CCFF0000D1FF51FF00FF00F500FF85FF008AFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF000014FF008FFF00AEFF009EFF000038FF0028FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000028FFFF00E62300FF
61FF0000FFA333FF00FFF500FFE600FFD700FFC700FFC700FFC700FFB800FFA800FF9900
FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF9900FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800
FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFC700FFC700FFD700FFD700FFF500
EBFF0000FF2851FF008FFF0051FF0000FF19FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF000000B3FFFF00008FFF0080FF000028FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF1961FF00
AEFF0000FF19FAFF00FFE600FFD700FFC700FFC700FFB800FFB800FFA800FFA800FF9900
FF9900FF9900FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800
FFA800FFA800FFA800FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFD700FFE600
FAFF00AEFF00CCFF00BDFF0000FF8500FF572300FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00B8FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF000000FF2861FF0061FF00FF005CFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFC261FF00
8FFF00EBFF00FFF500FFE600FFD700FFC700FFC700FFB800FFB800FFA800FFA800FF9900
FF9900FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00
FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FFA800FF9900FFA800FFA800FFA800
FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFD700FFD700FFE600
FFF500FAFF00EBFF00CCFF00FF0000FF0000FF00008F00FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000057FF42FF000047FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00004200FF00FF57
AEFF00EBFF00FAFF00FFE600FFD700FFC700FFB800FFB800FFA800FFA800FFA800FF9900
FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00
FF7A00FF7A00FF7A00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800
FFA800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFD700FFD700FFE600
FFF500FFF500FAFF00DCFF0000FF1900FF5700FF9400FFA3FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF000005FF0000FF66FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000042FF00
BDFF00DCFF00EBFF00FAFF00FFE600FFD700FFB800FFB800FFA800FF9900FF9900FF9900
FF9900FF9900FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00
FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF6B00FF6B00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800
FFA800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFD700FFD700FFD700FFE600
FFE600FFF500FAFF00EBFF00BDFF0042FF0080FF00FF00C7FF00003300FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000075FF00FF66FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFA300FFA3
AEFF0070FF00AEFF0061FF00DCFF00EBFF00FFB800FFA800FFA800FF9900FF9900FF9900
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF8A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800
FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFD700FFD700FFD700FFE600
FFF500FFF500FAFF00EBFF00DCFF00BDFF009EFF0070FF0051FF005100FFFF000000FF94
00E1FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFFFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000057FF00FFFF
8FFF00FF000000FF5700FF2861FF00FFE600FFB800FFA800FFA800FFA800FF9900FF9900
FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF6B00
FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900
FF9900FF9900FF9900FF9900FFA800FF9900FFA800FFA800FFA800FFA800FFB800FFB800
FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFD700FFD700FFD700FFE600FFE600
FFF500FAFF00FAFF00EBFF00DCFF00BDFF009EFF008FFF0061FF0033FF0000FF19FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFC2
42FF00FF008A61FF00DCFF00FFE600FFC700FFB800FFA800FFA800FF9900FF9900FF9900
FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFB800FFB800
FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFD700FFD700FFD700FFE600FFF500
FFF500FAFF00EBFF00DCFF00CCFF00BDFF008FFF0080FF00FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000094FFFF0000FF004C
1400FF00FFC270FF00DCFF00FFD700FFB800FFB800FFA800FFA800FF9900FF9900FF9900
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00
FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFC700
FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFE600FFD700FFE600FFE600FFF500
FAFF00BDFF00CCFF00CCFF00BDFF00CC00FF00B3FF42FF00FF000000E1FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFB300FF570057FF
9EFF0070FF00BDFF0014FF00FFD700FFB800FFB800FFA800FF9900FF9900FF9900FF9900
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF8A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00
FF8A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFC700FFD700
00FF94EBFF00FAFF00DCFF00FFE600FFE600FFE600FFE600FFE600FFE600FAFF00EBFF00
CCFF0000FFC29EFF00BDFF008FFF00FF0000FF00F500FF28FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000075FF33FF008FFF00CCFF00
DCFF0000FFB3FAFF00FFD700FFC700FFB800FFA800FFA800FF9900FF9900FF9900FF9900
FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF7A00FF7A00FF7A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900
FF9900FF9900FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFC700FFC700FFE600
8FFF0000FF6600FF8561FF00FAFF00FFE600FFE600FFE600FFE600FFF500CCFF0061FF00
000AFF00FFD1FA00FF80FF0070FF00FF0000FF00000075FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000500FF00FF380057FFDCFF00
FAFF00FAFF00FFE600FFC700FFB800FFB800FFA800FFA800FFA800FF9900FF9900FF9900
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF7A00FF7A00FF7A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FFA800FFA800FFA800FFB800FFB800FFB800FFC700FFC700FFC700FFD700FFE600
05FF0023FF008FFF00CCFF00FAFF00FFF500FFF500FFF500FFF500FAFF00DCFF00FF0000
FF00007000FF0066FF42FF0051FF0000FF57FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0028FFFF0000FF0000FF0000FF0000CC00FFFF000005FF0000FFA300FFFF80FF00DCFF00
FFE600FFD700FFD700FFC700FFB800FFB800FFA800FFA800FF9900FF9900FF9900FF9900
FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00
FF7A00FF8A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900
FFA800FFA800FFA800FFA800FFB800FFC700FFD700FFC700FFD700FFE600FAFF00FAFF00
CCFF0051FF005100FFDCFF00EBFF00FAFF00FFF500FFF500FAFF00FAFF0070FF0000FF0A
FF0000FF00B86100FFFF000000FF0AFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF000000FF94FF000000FFB300FF660047FF00FF2800FF47BDFF0000FF19DCFF00FFF500
FFE600FFD700FFC700FFB800FFB800FFB800FFA800FFA800FF9900FF9900FF9900FF9900
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00
FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00
FF8A00FF8A00FF8A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900
FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FFA800FFA800FFB800FFD700FFE60000FFF0FFE600FFE600FAFF0042FF00CCFF00
80FF00FF000080FF00CCFF00EBFF00EBFF00FAFF00FAFF00FAFF00EBFF00CCFF0000FF19
00FFB3FF0000FF0000FF000000F0FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF000000FF2842FF0070FF008FFF00AEFF00BDFF00DCFF00FAFF00FFF500FFE600
FFD700FFC700FFC700FFC700FFB800FFA800FFA800FFA800FFA800FF9900FF9900FF9900
FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF8A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF8A00FF8A00FF7A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FFA800FFA800FFB800FFC70080FF0061FF00BDFF00FAFF00EBFF00AEFF0000B3FF8FFF00
00C2FF33FF0070FF00CCFF00DCFF00CCFF00DCFF00EBFF00EBFF00DCFF00CCFF00FF0000
05FF00FF0099FF0000FF00008000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF000000FF2870FF009EFF00BDFF00DCFF00EBFF00FAFF00FFE600FFE600
FFD700FFC700FFC700FFB800FFB800FFA800FFA800FFA800FF9900FF9900FF9900FF9900
FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF8A00FF7A00FF8A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00
FF8A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00
FF8A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800
FFA800FFA800FFB800FFC700BDFF0000FF3800FF1933FF00BDFF0000F0FF0085FF33FF00
FF000061FF009EFF00AEFF00AEFF0042FF0070FF00BDFF00CCFF00CCFF00BDFF008FFF00
51FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF000000A3FFFA00FF8FFF00BDFF00DCFF00EBFF00FFF500FFE600FFE600
FFD700FFC700FFC700FFB800FFB800FFA800FFA800FFA800FFA800FF9900FF9900FF9900
FF9900FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF8A00FF7A00FF7A00FF8A00FF7A00
FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00
FF8A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF9900FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800
FFA800FFA800FFB800FFC700FFD70080FF00DCFF0000FF5700FF3814FF0000FFC25100FF
00FF0A61FF0080FF008FFF0000FF75FF0000FF000000FF190028FFBDFF00AEFF0070FF00
42FF0000FF28FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF000000FF389EFF00CCFF00EBFF00FAFF00FFE600FFE600
FFD700FFC700FFC700FFB800FFB800FFB800FFA800FFA800FFA800FF9900FF9900FF9900
FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF8A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00
FF7A00FF8A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00
FF8A00FF7A00FF7A00FF7A00FF8A00FF8A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF9900FF8A00FF8A00
FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800
FFA800FFA800FFB800FFB800FFD700FFE600EBFF00BDFF0070FF0000FF38FF00D700FF57
14FF0000FF28FF000014FF0023FF0000FFB3FF000014FF0080FF009EFF0080FF00FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF004CFF0000AEFF00AEFF00EBFF00FFF500FFE600
FFD700FFD700FFC700FFC700FFB800FFB800FFA800FFA800FFA800FF9900FF9900FF9900
FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF8A00FF8A00FF8A00FF7A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FF9900FF9900FFA800
FFA800FFA800FFB800FFB800FFC700FFF500CCFF0080FF0000FF5700FF1900FF94FF0000
0028FF00FF47FF000000FF38FF0000FF001EFF000000FF280057FF80FF0061FF00FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF000061FF0000FF19CCFF00FAFF00FFE600
FFE600FFD700FFD700FFC700FFB800FFB800FFA800FFA800FFA800FFA800FF9900FF9900
FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF9900FF9900FF9900FF9900
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800
FFA800FFA800FFB800FFC700FFC700FFF50023FF00FF000070FF0000FF2800FF3800FFD1
FF0000FF0099FF000000C2FFFF00F5FF0000FF0000FF0000FF000000FF0A42FF0000FF57
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF000000FF6600FF66EB00FF51FF00FAFF00FFF500
FFF500FFF500FAFF00FFC700FFB800FFB800FFB800FFA800FFA800FFA800FF9900FF9900
FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FFA800FFA800FFA800FF9900
FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800
FFA800FFA800FFB800FFB800FFC70061FF000057FFBDFF00AEFF0000FF6614FF0023FF00
00FFA3FF0000FF0000FF004CFF0000FF0000FF0000FF00008000FF05FF000028FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFF09EFF00EBFF00FAFF00
FAFF00EBFF0000FF38FFD700FFC700FFB800FFB800FFA800FFA800FFA800FFA800FF9900
FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF9900FFA800FFE600FFC700FFA800
FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800
FFA800FFB800FFB800FFC700FFC700FFE600FFF500EBFF009EFF00FF000061FF000038FF
0047FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF66FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF2861FF00DCFF00BDFF00
FF00E6BDFF0014FF00FFE600FFC700FFB800FFB800FFB800FFA800FFA800FFA800FFA800
FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF9900FFA800FFC700EBFF00FFB800
FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800
FFA800FFB800FFB800FFB800FFC700FFD700FFE600FAFF0033FF0000FF198FFF008FFF00
00FF750085FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00F5FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000005FF009EFF00AEFF009EFF00
000AFF61FF009EFF00FFF500FFD700FFC700FFB800FFB800FFA800FFA800FFA800FFA800
FFA800FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF9900FFA800FFB800AEFF00FFC700
FFB800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF8A00FF9900FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900
FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFB800
FFA800FFB800FFB800FFB800FFC700FFC700FFD700FFF50000D1FFCC00FFBDFF008FFF00
51FF000066FFFF0000FF0000FF0000FF0000FF0000FF0000FF00000075FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000051FF000038FFFF0000
05FF000500FF0075FF23FF00FFD700FFC700FFB800FFB800FFB800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF9900FFA800FFC700AEFF00FFD700
FFC700FFC700FFB800FFA800FFB800FFA800FFA800FF9900FF9900FF9900FF9900FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900
FF8A00FF9900FF9900FF8A00FF9900FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF9900
FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800
FFA800FFB800FFB800FFB800FFC700FFD700FFD700FFE600FAFF00EBFF00DCFF00EB00FF
00FF4700FF47FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFE1
00F0FF8000FF00FFFFDCFF00FFE600FFC700FFC700FFB800FFB800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF8A00FF7A00FF7A00FF8A00FF8A00FF8A00FF9900FF9900FFA800FFC700FFD700EBFF00
8FFF0061FF00FFC700FFC700FFD700FFE600FFA800FFA800FF9900FF9900FF9900FF9900
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF9900
FF9900FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FFA800FF9900FFA800FFA800FFA800FFA800FFA800
FFB800FFB800FFB800FFB800FFC700FFC700FFD700FFE600FFF500FAFF00EBFF008FFF00
00D1FF00FFB3FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF000000FF4700FF4700FF38FFD700FFC700FFC700FFB800FFB800FFB800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900FF8A00FF8A00FF8A00FF8A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FFA800FFA800FFB800FFD700
FFE600DCFF00FFE600FFD700EBFF00FFD700FFB800FFA800FF9900FF9900FF9900FF9900
FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFB800FFB800FFB800FFC700FFC700FFC700FFD700FFE600FFE600FFF500EBFF0070FF00
FF00000038FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
00FF9433FF0042FF00FAFF00FFE600FFC700FFC700FFC700FFB800FFB800FFB800FFB800
FFA800FFB800FFB800FFB800FFE60000FF0AFFB800FF9900FF9900FF8A00FF8A00FF8A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FFA800FFB800FFC700
FFD7009EFF00EBFF00DCFF00FFF500FFC700FFB800FFA800FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF8A00FF9900FF8A00FF8A00FF9900FF8A00FF9900FF8A00
FF8A00FF9900FF8A00FF9900FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FFA800FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFB800
FFB800FFB800FFB800FFC700FFC700FFD700FFD700FFE600FFF500FFF500FAFF00BDFF00
FF0000000AFFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00008FFF0023FF00FFF500FFE600FFD700FFD700FFC700FFC700FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFD700EBFF00FFF500FFA800FF9900FF8A00FF8A00FF8A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FFA800FFA800FFB800
FFC700FFD700EBFF00FAFF00FFD700FFC700FFB800FFA800FFA800FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800
FFB800FFB800FFB800FFC700FFC700FFD700FFD700FFE600FFF500FAFF00FAFF00DCFF00
BDFF009EFF0000FFC2CC00FFFF000000D1FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFF0FF0000
51FF00BDFF00EBFF00FFF500FFE600FFD700FFD700FFC700FFC700FFC700FFB800FFC700
FFB800FFB800FFC700FFC700FFD70000FF28DCFF00FFB800FF9900FF9900FF8A00FF8A00
FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF6B00FF6B00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FFA800FFA800FFA800FFB800
FFC700FFD700EBFF00FAFF00FFD700FFC700FFB800FFA800FFA800FFA800FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800
FFA800FFB800FFC700FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800
FFB800FFB800FFC700FFC700FFC700FFD700FFE600FFE600FFF500FAFF00FAFF00EBFF00
CCFF00AEFF008FFF0051FF0005FF0000FFD1FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
80FF00BDFF00EBFF00FFF500FFE600FFE600FFE600FFD700FFD700FFC700FFC700FFC700
FFC700FFC700FFC700FFD700FFE60080FF00FFF500FFD700FFA800FF9900FF8A00FF8A00
FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FFA800FFA800FFB800
FFC700FFD700FAFF00AEFF00FFD700FFC700FFB800FFA800FFA800FFA800FFA800FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800
FFB800FFC70061FF00FFB800FFB800FFB800FFA800FFA800FFA800FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FF9900
FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800
FFB800FFB800FFC700FFC700FFD700FFE600FFE600FFF500FAFF00FAFF00EBFF00DCFF00
CCFF00FF006B70FF0000F0FF00FF75FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000028FF
23FF0033FF00BDFF00FAFF00FFF500FFF500FFF500EBFF00FFE600FFD700FFD700FFD700
FFC700FFC700FFD700FFD700FFF500EBFF00CCFF00DCFF00FFA800FF9900FF8A00FF8A00
FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FFA800FFA800FFB800
FFC700FAFF00AEFF009EFF00FFF500FFD700FFB800FFB800FFA800FFA800FFA800FFA800
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800
FFB800FAFF00EBFF00FFC700FFB800FFB800FFA800FFA800FFA800FFA800FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800
FFB800FFC700FFC700FFD700FFE600EBFF00EBFF0033FF00DCFF00EBFF00DCFF00CCFF00
AEFF00FF001E33FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00003300FF00FF85EBFF00FAFF00FAFF00EBFF0061FF00DCFF00FAFF00FFE600FFD700
FFD700FFD700FFD700FFF50070FF0000FF5733FF00FAFF00FFA800FF9900FF8A00FF8A00
FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF6B00FF6B00
FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FFA800FFA800FFB800
FFC700FFF50000FF1942FF00DCFF00FFD700FFB800FFB800FFA800FFA800FFA800FFA800
FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFB800
FFC700FFE6009EFF00EBFF00FFC700FFB800FFB800FFA800FFA800FFA800FFA800FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FFA800FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800
FFC700FFC700FFD700FFD700FFE60051FF0000FF5705FF00BDFF00DCFF00DCFF00AEFF00
FF0000FF000000FF8500FF75FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00004200FF8FFF00DCFF00EBFF00EBFF00DCFF0061FF000057FFFF004CFAFF00FFE600
FFE600FFE600FFF50080FF0051FF00DCFF00CCFF00FFC700FFA800FF9900FF8A00FF8A00
FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FFA800FFA800FFB800
FFC700FFF50070FF00EBFF00FFF500FFD700FFC700FFB800FFB800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FF9900FF9900FFA800FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFB800FFB800
FFC700FFE600FAFF0000FF38FAFF00FFD700FFB800FFA800FFA800FFA800FFA800FFA800
FFA800FF9900FFA800FF9900FFA800FF9900FFA800FF9900FF9900FF9900FFA800FF9900
FF9900FF9900FF9900FF9900FF9900FFA800FF9900FF9900FFA800FF9900FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800
FFC700FFD700FFD700FFE600FFF5009EFF002300FF61FF00BDFF00CCFF00CCFF009EFF00
00A3FFFF0000FF0000000AFFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
00E1FF42FF00AEFF00CCFF00BDFF00AEFF00BDFF008FFF0033FF0000D1FFCCFF00FFF500
FFE600FFF500CCFF0000FFE1FF0000AEFF00FFD700FFB800FFA800FF9900FF8A00FF8A00
FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FFA800FFA800FFB800FFB800
FFC700FFE6009EFF00FAFF00FFE600FFC700FFC700FFC700FFB800FFB800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900
FF9900FFA800FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFC700
FFD700FFE600FAFF0070FF0000FF75FFD700FFC700FFB800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FF9900FFA800FF9900FFA800FF9900FFA800FF9900
FFA800FF9900FF9900FF9900FF9900FFA800FF9900FF9900FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFA800FFB800FFB800FFB800FFC700
FFC700FFD700FFE600FFF50023FF009EFF00FF000061FF009EFF009EFF00AEFF009EFF00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00004200FF8FFF00AEFF0042FF00FF00004200FF6100FFAE00FF5100FF00FF28FAFF00
FAFF00FAFF00EBFF00AEFF0000FF38FFF500FFC700FFB800FFA800FF9900FF9900FF8A00
FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FFA800FFA800FFB800FFC700
FFE600FFF500DCFF00FAFF00FFE600FFD700FFC700FFC700FFB800FFB800FFB800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFD700FFD700
80FF00FAFF0033FF00AEFF008FFF00FFD700FFC700FFB800FFB800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFC700FFC700
FFD700FAFF0000F0FFDCFF0000FF6633FF0000FF3842FF0042FF001400FF00FF4761FF00
51FF0000FF381400FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF000000FF7580FF0061FF0000E1FF0019FFFF0000FF00000500FF61FF00AEFF00DCFF00
EBFF00EBFF00DCFF009EFF0000FF38FFF500FFC700FFB800FFA800FF9900FF9900FF8A00
FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FFA800FFB800FFC700FFE600
EBFF00DCFF0000FF19FAFF00FFE600FFD700FFC700FFC700FFB800FFB800FFB800FFB800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFC700FAFF0061FF00
9EFF009EFF0061FF00EBFF00FFE600FFD700FFC700FFC700FFB800FFB800FFB800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFC700FFC700
AEFF000047FF9EFF00FF006B00D1FF00FFC200FF4733FF0000FFE1FF000000FF8533FF00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF000042FF0023FF00FF0000FF0000FF0000FF00001400FF00FF0A8FFF0000FF75
CCFF00DCFF00AEFF000047FFBDFF00FFF500FFD700FFC700FFC700FFA800FF9900FF8A00
FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FFB800DCFF009EFF00DCFF00
DCFF00CCFF00AEFF00FAFF00FFE600FFD700FFD700FFC700FFC700FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFC700FFE600EBFF00
80FF00AEFF00EBFF00FFF500FFE600FFD700FFC700FFC700FFB800FFB800FFB800FFB800
FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFB800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFC700FFD700
FFE600CCFF0070FF0000F0FFFA00FF00FFF000FF57FF0000FF0000FA00FF0019FF0028FF
00FF287000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF000005FF00FF0000FF0000FF0000FF0000FF0000FF00005100FF42FF0005FF00
05FF00BDFF009EFF001400FFCCFF00EBFF00FFF500FFE60042FF00FFA800FF9900FF8A00
FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FFA800FFA800FFC700AEFF00FFF500
FFE600FFF5009EFF00CCFF00EBFF00FFE600FFD700FFC700FFC700FFC700FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFB800FFB800FFB800FFA800
FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFC700FFC700FFE600FAFF00
00FFE1BDFF00FAFF00FFF500FFE600FFD700FFC700FFC700FFB800FFB800FFB800FFB800
FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFD700
FFE600DCFF0051FF0000FF750094FF00C2FFFF0000FF0000FF0000FF0000FF0000FF0000
00FFB3FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF000000FF75FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF006B0094FF
14FF0080FF0080FF0000FF6680FF008FFF000075FFBDFF00FFF500FFA800FF9900FF8A00
FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FFA800FFB800FFC700FFC700
FFD700FFF500AEFF008F00FF70FF00FFF500FFD700FFD700FFC700FFC700FFC700FFC700
FFC700FFB800FFC700FFB800FFB800FFC700FFD70014FF00FFC700FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFE600BDFF00
33FF00DCFF00FAFF00FFF500FFE600FFD700FFD700FFC700FFC700FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFB800FFA800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFD700
FFE60000FF858FFF000028FF00FF6600FF4700F0FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF000000D1FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
00E1FF00FF660075FF4200FF70FF00CCFF00FFF500FFF500FFB800FF9900FF9900FF8A00
FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FFA800FFA800FFB800FFC700
FFC700FFE600EBFF008FFF00DCFF00FFF500FFE600FFD700FFD700FFD700FFC700FFD700
FFD700FFC700FFC700FFC700FFC700FFD700FFF5009EFF00FFE600FFC700FFC700FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFD700DCFF00BDFF00
42FF00CCFF00EBFF00FAFF00FFF500FFE600FFD700FFD700FFC700FFC700FFC700FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFB800FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFD700
FFD700FFF500EBFF0000FF9423FF0000FF0AFF000000B3FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000DC00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
CC00FF00FF8542FF003300FF00FF94BDFF00FFE600FFC700FFA800FF9900FF9900FF8A00
FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FFA800FFA800FFB800FFB800
FFC700FFD700FFF500DCFF00BDFF00FAFF00FFF500FFE600FFE600FFD700FFD700FFE600
8FFF00FFD700FFD700FFD700FFD700FFE600BDFF00EBFF00FFE600FFC700FFC700FFC700
FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFD700FFE600EBFF00
00FF28BDFF00CCFF00CCFF00FAFF00EBFF00FFE600FFD700FFD700FFD700FFC700FFC700
FFB800FFB800FFB800FFB800FFC700FFB800FFC700FFC700FFC700FFB800FFB800FFB800
FFB800FFA800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFA800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFD700
FFD700FFE600FAFF00CCFF0051FF0080FF00FF000000FFFFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000094FF4200FF
05FF008FFF009EFF000094FFCCFF0000FF85FFF500FFB800FFA800FF9900FF8A00FF8A00
FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FFA800FFB800FFB800
FFC700FFD700FAFF0033FF009EFF0080FF00FAFF00FFF500FFF500FAFF00FFF500FFF500
DCFF00FFE600FFD700FFD700FFE600FFF50033FF00FAFF00FFE600FFD700FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFE600EBFF00
80FF0080FF0061FF0000FF0AAEFF0000FF57FFF500FFF500FFF500FFF500FFD700FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFD7009EFF00FFD700FFC700FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFA800FFB800FFA800FFB800FFA800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFD700
FFD700FFE600FFF500EBFF00DCFF00BDFF00FF00000019FFCC00FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF9451FF00
00FF0A42FF00CCFF0000FF0AFAFF00FAFF008FFF00FFB800FFA800FF9900FF8A00FF8A00
FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFB800
FFC700FFD700DCFF00EBFF00AEFF0033FF00EBFF00FAFF00BDFF00BDFF00DCFF00DCFF00
00FF47FAFF00FFF500FFF500FFF500FFF500DCFF0070FF00FFF500FFE600FFD700FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFD700FFE600FFE600FFF500
DCFF00AEFF00BDFF009EFF0000FF0A23FF00DCFF00EBFF0080FF00FAFF00FFD700FFD700
FFC700FFC700FFC700FFC700FFD700FFD700FFE600BDFF00FFE600FFC700FFC700FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFD700
FFD700FFF500FFF500EBFF00DCFF00BDFF0051FF0000FF66FF0000FF00000075FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF859EFF00
DCFF00EBFF00EBFF0051FF00FFF500FFD700FFB800FFA800FF9900FF9900FF8A00FF8A00
FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00
FF6B00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF7A00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FFA800FFA800FFB800
FFB800FFE600FFF500FFE600FAFF008FFF0000FFA3BDFF009EFF009EFF0005FF0070FF00
8FFF00DCFF0000FF0AFAFF00FFF500FAFF00CCFF0042FF00AEFF00FFE600FFD700FFD700
FFD700FFD700FFD700FFC700FFD700FFC700FFC700FFD700FFD700FFD700FFE600FFF500
FAFF00EBFF00CCFF00BDFF0080FF0042FF0000FF57CCFF0080FF00FAFF00FFE600FFD700
FFD700FFD700FFD700FFD700FFF500FFF500FAFF00AEFF00FAFF00FFD700FFC700FFC700
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFC700FFD700FFD700
FFE600FFF500FAFF00EBFF00DCFF00BDFF009EFF0070FF0023FF0000FFA3FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000051FF008FFF00
DCFF00FFF500FFF50070FF00BDFF00FFB800FFA800FFA800FF9900FF9900FF8A00FF8A00
FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FFA800FFA800FFA800
FFB800FFC700FFD700FFD700FFE6009EFF00EBFF00DCFF00EBFF00DCFF0061FF009EFF00
23FF009EFF00AEFF00EBFF00EBFF0080FF00AEFF000066FFDCFF00FFF500FFE600FFE600
FFF500FAFF00FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFE600FFE600FFF500
FAFF00EBFF00DCFF00BDFF0061FF00FF000000FF3800FF4742FF00DCFF00FFF500FFE600
FFD700FFD700FFD700FFE600FAFF0080FF0080FF0033FF0000FF28FFE600FFC700FFC700
FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFC700FFD700FFD700
FFE600FFF500EBFF0000FF0A9EFF00AEFF009EFF0000A3FF00FF28FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF000000FF66FF0000FF0000FF000000D1FFFF000000FFC200FF75
9EFF00FFE600FFD700FFC700FFB800FFA800FFA800FF9900FF9900FF9900FF8A00FF8A00
FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800
FFB800FFC700FFC700FFC700FFD700FFE600FFF500FFF500FFF500FAFF00DCFF00CCFF00
00FF1900FF3814FF009EFF00CCFF0080FF0000FF5700D1FFBDFF00FAFF00FFF500FAFF00
80FF00CCFF00FFE600FFD700FFD700FFD700FFD700FFD700FFE600FFE600FFF500FFF500
FAFF00EBFF00DCFF009EFF0051FF0000FF0A00FFB333FF0000FF0AAEFF0061FF00FFF500
FFE600FFE600FFE600FFF5008FFF0000FF85AEFF00CCFF00EBFF00FFE600FFD700FFC700
FFC700FFC700FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFC700FFB800FFC700FFC700FFC700FFC700FFD700FFD700FFD700FFE600
FFE600FAFF0000FF28BD00FF70FF009EFF0080FF00FF00008000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF000000FF3842FF00FF0000FF00000075FF23FF0000FF6600FF0A
FAFF00FFD700FFC700FFB800FFB800FFA800FFA800FF9900FF9900FF8A00FF8A00FF8A00
FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800
FFB800FFB800FFB800FFC700FFC700FFD700FFD700FFE600FFE600FFF500FAFF00DCFF00
8FFF000075FF6100FF61FF008FFF0061FF0000FF199EFF00CCFF00EBFF00EBFF008FFF00
80FF00EBFF00FFF500FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF500FFF500
FAFF00EBFF00DCFF00AEFF0042FF0051FF00FF000000FF9400FF3842FF00CCFF00FAFF00
FFF500FFF500FFF500FAFF008FFF008FFF00BDFF00EBFF00FFF500FFE600FFD700FFD700
FFC700FFC700FFC700FFC700FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFE600
FFF500EBFF008FFF0000E1FF61FF0070FF0061FF00FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000DC00FF42FF009EFF00AEFF00CCFF00DCFF00CCFF00FAFF00
FFD700FFC700FFB800FFB800FFA800FFA800FF9900FF9900FF9900FF8A00FF8A00FF8A00
FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800
FFB800FFB800FFB800FFC700FFC700FFC700FFD700FFD700FFE600FFF500FAFF00DCFF00
9EFF0061FF0061FF0000D1FF00FF0A00FF0A33FF009EFF00BDFF00DCFF00DCFF0080FF00
BDFF00EBFF00FFF500FFE600FFE600FFE600FFE600FFF500FFF500FFF500FFF500FAFF00
EBFF00EBFF00CCFF00BDFF008FFF0061FF0014FF0000F0FF00FF1900FF47BDFF00EBFF00
FAFF00FFF500FAFF00EBFF0005FF0080FF009EFF00DCFF00FAFF00FFE600FFD700FFD700
FFD700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFB800FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFE600FFF500
EBFF00BDFF0023FF0000FF9423FF00FF000000FF9400FF28FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF000000FF75AEFF00DCFF00FAFF00FFF500FFE600FFD700
FFC700FFC700FFB800FFB800FFA800FFA800FF9900FF9900FF9900FF8A00FF8A00FF8A00
FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800
FFA800FFB800FFB800FFB800FFC700FFC700FFC700FFD700FFE600FFF500FAFF009EFF00
80FF00AEFF009EFF0014FF0014FF0000C2FF23FF0080FF0051FF00BDFF00BDFF009EFF00
70FF00EBFF00FAFF00FFF500FFF500FFF500FFF500FAFF00FFF500FFF500FAFF00EBFF00
CCFF00CCFF00BDFF009EFF0070FF0014FF00FF0000FF000000FF7570FF0042FF0042FF00
EBFF00FAFF00FAFF00EBFF0023FF0023FF0042FF000019FFCCFF00FFF500FFE600FFD700
FFD700FFD700FFD700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFD700FFE600FFE60033FF00
61FF00BD00FF00FFF000FF8500FF66FF0000FF000000FF94FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF000000A3FFDCFF00FAFF00FFF500FFE600FFD700
FFC700FFB800FFB800FFA800FFA800FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00
FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800
FFA800FFB800FFB800FFB800FFB800FFC700FFC700FFD700FFD700FFE600FAFF00CCFF00
BDFF00CCFF00BDFF0080FF0070FF0000FF754200FF23FF000066FF9EFF0080FF0000A3FF
00FFFFCCFF009EFF00FAFF00FAFF00FAFF00EBFF0000FF75EBFF00FAFF00EBFF00EBFF00
AEFF008FFF008FFF0000FFE10075FF00FF281400FFFF00000094FF23FF0000FF19BDFF00
DCFF00EBFF00EBFF00DCFF00BDFF009EFF0080FF0000FF6600FF66DCFF00DCFF00FFE600
FFD700FFD700FFD700FFD700FFD700FFD700FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFE600FFF500DCFF00
61FF000066FF5100FFFF0000FF0000FF0000FF00000066FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF000000FFF0DCFF00FAFF00FFF500FFD700FFC700
FFC700FFB800FFB800FFA800FFA800FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF9900FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800
FFA800FFB800FFB800FFB800FFB800FFC700FFC700FFD700FFD700FFE600FFF500FAFF00
EBFF00DCFF00BDFF00AEFF0070FF0000FF3800C2FF00FF6600D1FF61FF0070FF0000FF57
00FF1951FF00CCFF00EBFF00FAFF00EBFF008FFF0051FF00DCFF00EBFF00EBFF00DCFF00
AEFF0033FF0000FF3800FFB300D1FF9E00FFFF0000FF000000D1FF00FFC200FF28AEFF00
DCFF00DCFF00DCFF00CCFF00CCFF00AEFF008FFF0000FFB30094FF70FF00EBFF00FFF500
FFE600FFE600FFE600FFE600FFE600FFD700FFD700FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFD700FFC700FFD700FFD700FFD700FFE600FFE600FAFF00
00FF4700FFC26100FF0075FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF000000FF388FFF00AEFF00CCFF00FAFF00FFD700FFC700
FFC700FFB800FFB800FFA800FFA800FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00
FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800
FFA800FFB800FFB800FFB800FFC700FFC700FFC700FFD700FFD700FFE600FFE600FFF500
EBFF00DCFF00CCFF009EFF0000FF3800FF66FF0000FF00000066FF00FF1923FF0000FF66
00FFE114FF00BDFF00DCFF00EBFF00DCFF0070FF0080FF00BDFF00BDFF00CCFF00CCFF00
AEFF0080FF0042FF0000FF75FF0000FF0000FF0000FF0000FF00000066FFFF00009EFF00
BDFF0080FF00CCFF00CCFF00BDFF00AEFF0000FF4700FFA300FFC20094FFCCFF00FAFF00
FFF500FFF500FFF500FAFF0033FF00FFE600FFD700FFD700FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFD700FFD700FFD700FFD700FFD700FFE600FFE600FFF500FAFF00
CCFF0000FF5700FF3800FF28CC00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF000000FFD1FF0000FF000014FF00FAFF00FFD700FFC700
FFC700FFC700FFB800FFA800FFA800FFA800FF9900FF9900FF8A00FF8A00FF8A00FF8A00
FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF8A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800
FFA800FFA800FFB800FFB800FFB800FFC700FFC700FFD700FFD700FFE600FFE600FFF500
FAFF00DCFF009EFF0070FF000066FF4200FFFF0000FF0000AE00FFFF0000FF000000B3FF
FF005C61FF0051FF00BDFF00DCFF00CCFF00AEFF0070FF00FF00A870FF009EFF00AEFF00
9EFF008FFF0051FF008F00FFFF0000FF0000FF0000FF0000FF0000FA00FF00FF198FFF00
42FF0061FF00AEFF00AEFF008FFF008FFF0061FF0005FF000075FF00FF943300FFEBFF00
FAFF00FAFF0014FF00AEFF0000FF94FFF500FFD700FFD700FFD700FFD700FFD700FFD700
FFD700FFC700FFD700FFD700FFD700FFD700FFD700FFD700FFE600FFE600FFF500FAFF00
EBFF00CCFF009EFF0061FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF9400FF75EBFF00FFD700FFC700
FFC700FFB800FFB800FFA800FFA800FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF9900FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800
FFA800FFB800FFB800FFB800FFB800FFC700FFC700FFD700FFD700FFE600FFF500FFF500
EBFF00DCFF00BDFF0080FF0023FF00BD00FFFF0000FF0000FF0000FF0000FF0000FF0000
FF000000FF0A42FF00AEFF00BDFF00BDFF00AEFF0080FF0000D1FFFF001E00FF1980FF00
8000FF70FF000057FF00FF85FF0000FF0000FF0000FF0000FF0000FF000000FF0A61FF00
51FF0000FFA370FF008FFF0023FF0042FF0000FF2800FF2800FFD1FF000023FF00DCFF00
EBFF00BDFF0000FF9405FF0000FF94FFF500FFE600FFE600FFD700FFD700FFD700FFD700
FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFE600FFE600FFE600FFF500FAFF00
EBFF00CCFF009EFF0080FF0023FF0000FF66FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFFF00D1FFFAFF00FFD700FFD700
FFC700FFB800FFB800FFA800FFA800FFA800FF9900FF9900FF8A00FF8A00FF8A00FF8A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF7A00FF7A00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800
FFA800FFA800FFB800FFB800FFB800FFC700FFC700FFD700FFD700FFE600FFF500FAFF00
BDFF00AEFF008FFF0070FF0005FF00EB00FFFF0000FF0000FF0000FF0000FF0000FF0000
1400FFFF00A800D1FF9EFF00AEFF009EFF009EFF0014FF00FF0000FF000000FFB323FF00
00FF3814FF0023FF0000FF75FF0000FF0000FF0000FF0000FF0000FF001E05FF0014FF00
00FFB300FFF000E1FF61FF0014FF0000FFB30019FF0047FFFF0000FF000070FF00CCFF00
CCFF0070FF0051FF009EFF00DCFF00FAFF00FFE600FFE600FFE600FFD700FFD700FFD700
FFD700FFD700FFD700FFD700FFD700FFE600FFD700FFE600FFE600FFE600FFF500FAFF00
DCFF0000FFE100F0FF61FF00FF000000F0FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFF0CCFF00FFF500FFE600FFD700
FFC700FFC700FFB800FFB800FFA800FFA800FF9900FF9900FF8A00FF8A00FF8A00FF8A00
FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00
FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800
FFA800FFB800FFB800FFB800FFB800FFC700FFC700FFD700FFE600FFF500FFF500FAFF00
DCFF008FFF0000FF9433FF0000FF47FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF000033FF0080FF0070FF0061FF0070FF0051FF0000FF66FF0000FF0000FF0000
EB00FFFF0000FF000000FFB3FF0000FF0000FF0000FF0000FF000000FFE100FFF0FF0000
00FF575100FF00A3FF00FFE105FF00FF0000FF0000FF0000FF000000FF8533FF00AEFF00
BDFF0080FF0000FF6600FFD1DCFF00FAFF00FFF500FFE600FFE600FFE600FFD700FFE600
FFD700FFD700FFD700FFD700FFD700FFD700FFE600FFE600FFE600FFF500FAFF00FAFF00
BDFF00FF00E633FF0042FF008F00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF000023FF00AEFF00EBFF00FFF500FFE600FFE600
FFD700FFC700FFC700FFC700FFB800FFA800FF9900FF9900FF8A00FF8A00FF8A00FF8A00
FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00
FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900
FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800
FFA800FFB800FFB800FFB800FFC700FFC700FFD700FFE600FFF500FAFF00FAFF00EBFF00
CCFF0070FF0000F0FF00FF4700B3FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000028FF00FF2861FF0061FF0000FF857000FF00FF0A4200FFFF0000FF000000E1FF
0066FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00F53300FF00FF47FF0000FF0000FF0000FF0000FF000051FF009EFF00
9EFF008FFF0061FF0000FF190066FFDCFF00FFF500FFF500FFE600FFE600FFE600FFE600
FFE600FFD700FFE600FFE600FFE600FFE600FFE600FFE600FFF500FFF500FAFF00DCFF00
FF002E6100FF00FF28FF000000FF75FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000028FFAEFF00DCFF00EBFF00FFF500FFE600
FFD700FFD700FFD700FFF500BDFF00FFB800FF9900FF9900FF9900FF8A00FF8A00FF8A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800
FFA800FFB800FFB800FFB800FFC700FFC700FFD700FFF50061FF009EFF00CCFF00CCFF00
51FF0000FFD100FF0AFF00D7FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF000000FF8523FF0023FF0000FF66FF000000FFD100A3FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000047FFFF0000FF0000FF0000FF000033FF00DC00FF
8FFF0080FF0061FF0000FFE142FF009EFF00FAFF00FFF500FFF500FFF500FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF500FFF500DCFF0005FF00
FF008AFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000AEFF00CCFF00AEFF00DCFF00FFF500
FFE600FFE600FFE600FFF50080FF00FFB800FFA800FF9900FF8A00FF8A00FF8A00FF8A00
FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00
FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800
FFB800FFB800FFB800FFB800FFC700FFC700FFD700FFE600FAFF0023FF0000FF578FFF00
00FF4700FF7551FF0000FFA3FF003DFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF000000FF3800FF19FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF7500FF19FF0000
61FF0005FF0033FF0000FF6600FF7533FF00DCFF00EBFF00FAFF00EBFF00FFF500FFF500
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF500FFF500FAFF00EBFF0014FF00
FF0099FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF000070FF00FF000070FF0000B3FFEBFF00
FFF500FFF500FFF500EBFF00EBFF00FFC700FFA800FF9900FF8A00FF8A00FF8A00FF8A00
FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF6B00FF6B00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFB800FFA800
FFB800FFB800FFC700FFB800FFC700FFC700FFD700FFE600FFF500DCFF0042FF00AEFF00
BDFF008FFF0080FF0014FF00FA00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF002E00FFB3FF0000FF008AFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFE1FF004C
05FF0000FF75FF000000E1FF1400FFBD00FFCCFF00AEFF000066FF00FF66FAFF00FFF500
FFF500FFF500FFE600FFE600FFE600FFE600FFF500FFF500FAFF00FAFF00EBFF00AEFF00
FF0000FF00C70075FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF000005FF00FF000000FFFF00FF7500D1FF05FF00
FAFF00FAFF00AEFF009EFF008FFF00FFD700FFA800FF9900FF8A00FF8A00FF8A00FF8A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFB800
FFB800FFB800FFB800FFC700FFC700FFC700FFD700FFD700FFF500FAFF00EBFF00DCFF00
CCFF00BDFF0080FF0000FF7500B3FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000066FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF004C51FF009EFF000066FF51FF0014FF00EBFF00FFF500
FFF500FFF500FFF500FFF500FFF500FFF500FFF500FFF500FAFF00FAFF00EBFF00CCFF00
9EFF0061FF00EB00FF00FFFFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000005FF0061FF00
DCFF00AEFF0000FFC2AEFF00AEFF00FFB800FFA800FF9900FF9900FF8A00FF8A00FF8A00
FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00
FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FFA800FF9900FFA800FFA800FFA800FFA800FFB800FFB800
FFB800FFC700FFC700FFC700FFC700FFC700FFD700FFE600FFE600FFF500FAFF00EBFF00
DCFF00BDFF008FFF0000FFC20075FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000038FFFF0000FF0000000AFF51FF0070FF0000FFB3FF0000CCFF00EBFF00FAFF00
FFF500FFF500FFF500FFF500FFF500FFF500FFF500FFF500FAFF00FAFF00EBFF00CCFF00
FF00D723FF0005FF000066FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00E600FFD1
BDFF00AEFF000085FFFAFF00FFD700FFB800FF9900FF9900FF9900FF8A00FF8A00FF8A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFB800FFB800FFB800
FFB800FFB800FFC700FFC700FFC700FFD700FFD700FFE600FFF500FFF500FAFF00EBFF00
DCFF0000FF470028FF61FF0023FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF000000A3FFFF007A51FF0033FF000057FFAEFF00DCFF00EBFF00
FAFF00FAFF00FFF500FFF500FFF500FFF500FFF500FAFF00FAFF00EBFF00DCFF00BDFF00
7000FF00FF1900FF47FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000057FF0047FF
8FFF0000FFB39EFF00FFF500FFD700FFB800FF9900FF9900FF8A00FF8A00FF8A00FF8A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800
FFC700FFC700FFC700FFD700FFD700FFD700FFD700FFE600FFE600FFF500FAFF00EBFF00
DCFF00BDFF009EFF0080FF0000FF3800FF0A00E1FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000BD00FFFF000014FF0014FF000085FF00FF0ACCFF00EBFF00
EBFF00FAFF00FAFF00FAFF00FAFF00FAFF00FAFF00FAFF00FAFF00EBFF00CCFF008FFF00
FF0000000AFFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00007000FF
00FF0A000AFF9EFF00DCFF00DCFF00FFB800FFA800FF9900FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFB800FFB800FFB800FFC700FFC700
FFC700FFC700FFC700FFD700FFD700FFD700FFE600FFE600FFF500FFF500FAFF00EBFF00
DCFF00BDFF00AEFF008FFF0061FF0033FF0000FF2800FF940028FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF000000FF85FF000000FFF0CC00FFAEFF00AEFF00
AEFF00EBFF00FAFF00FAFF00FAFF00FAFF00FAFF00FAFF00EBFF00DCFF008FFF00000AFF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF47
00FF579E00FF8FFF00DCFF00DCFF00FFA800FF9900FF9900FF8A00FF8A00FF8A00FF8A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF8A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFC700FFD700FFD700
FFD700FFD700FFD700FFD700FFE600FFE600FFE600FFF500FFF500FAFF00DCFF00CCFF00
CCFF00AEFF009EFF0061FF0033FF0000FF3800FF75FF0099FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000085FFFF0000FF0000FF000070FF0000FF19
00FF47DCFF00EBFF00EBFF00FAFF00EBFF00FAFF00EBFF00EBFF00DCFF00BDFF0000FFC2
00FFFFFF00D7FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000094FFFF0000FF000000FFD170FF0051FF00
51FF0033FF0000FFD1FFF500FFB800FFA800FF9900FF9900FF8A00FF8A00FF8A00FF8A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FFA800FF9900FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFE600FAFF00FFF500
FFF500FFE600FFE600FFE600FFE600FFE600EBFF00FAFF00FAFF00EBFF00CCFF0042FF00
AEFF00DC00FF70FF0023FF00FF003D00FFE1FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000014FF0023FF0000FF75
AEFF00DCFF00EBFF00EBFF00EBFF00EBFF00EBFF00EBFF00EBFF00DCFF00CCFF009EFF00
05FF0000FF47FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF000000FFC25100FF23FF000057FF6100FFDCFF00
61FF00AEFF00FFF500FFD700FFA800FFA800FF9900FF9900FF8A00FF8A00FF8A00FF8A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF6B00
FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFC700FFD700FAFF0000FF66
EBFF00FFF500FFE600FFE600FFF500FFF500AEFF00DCFF00EBFF00DCFF00CCFF0042FF00
FF000F0094FF00FFE100FF19CC00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000047FFFA00FF05FF0000FF38
70FF00BDFF00DCFF00DCFF00EBFF00EBFF00EBFF00DCFF00DCFF00CCFF00BDFF00FF0000
00FF4700FFB3FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000500FFAEFF00CCFF0051FF00DCFF00FFF500
FAFF00FFE600FFC700FFB800FFA800FF9900FF9900FF9900FF8A00FF8A00FF8A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00
FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFC700FFD700FFF500BDFF00
AEFF00EBFF00FFF500FAFF00FAFF00FAFF00CCFF0080FF0070FF00CCFF00BDFF009EFF00
33FF00FF000000A3FF00FF947000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF005C0028FF00FFFF
00FFFFAEFF00CCFF00DCFF00DCFF00DCFF00DCFF00DCFF00DCFF00CCFF009EFF00FF0000
00A3FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF000000FF66BDFF00EBFF00FFF500FFE600FFD700
FFC700FFC700FFB800FFA800FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFC700FFD700FFF50005FF00
00FF75BDFF00EBFF00EBFF00AEFF00DCFF00BDFF0000FF661400FF9EFF009EFF0080FF00
00FFC200FFF0FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
00FFC2FF000000FF38CCFF00DCFF00DCFF00DCFF00DCFF00CCFF00BDFF0005FF00FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000CC00FF70FF00EBFF00FFE600FFE600FFC700
FFC700FFB800FFA800FFA800FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00
FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFC700FFC700FFE600FAFF00
AEFF0033FF00BDFF0080FF0000C2FF9EFF0000FFF000FFA342FF0061FF0070FF0070FF00
33FF0000FFD1FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
00FF190038FF80FF00BDFF00CCFF00CCFF00CCFF00CCFF00CCFF00BDFF009EFF0042FF00
00FF66FF003DFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF000000E1FFFAFF00FFE600FFD700FFC700
FFB800FFB800FFA800FFA800FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFC700FFC700FFD700FFE600
DCFF00CCFF00BDFF0080FF0000F0FF00FF28FF0099FF00000057FFFF0000FF000033FF00
4200FF0057FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
00FF7500FF94FF0000AEFF00BDFF00CCFF00CCFF00CCFF00BDFF00BDFF009EFF000085FF
00FF85FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF000005FF009EFF00FAFF00FFE600FFD700FFD700
FFB800FFA800FFA800FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFD700FFE600
FFF500FAFF00EBFF00AEFF0080FF0005FF0000A3FFFF0000FA00FFFF0000FF000000FF38
00FFB3FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
3300FFFF00B8FF000080FF00AEFF00BDFF00BDFF00BDFF00BDFF00AEFF0000E1FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00008FFF00DCFF00FAFF00FFE600FFE600FFD700
FFB800FFA800FFA800FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00
FF7A00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FFA800FFA800FFB800
FFD700FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFD700FFE600
FFE600FFF500FAFF00DCFF009EFF0000FF1900FF85FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF000000FF380028FF8FFF00AEFF00BDFF00BDFF00AEFF009EFF0023FF00FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF000080FF0080FF00EBFF00FFF500FFF500CCFF00
FFC700FFA800FFA800FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FFA800FFB800
FFF500FFD700FFC700FFC700FFB800FFB800FFB800FFA800FFA800FFA800FFB800FFA800
FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFD700FFD700FFE600
FFE600FFF500FAFF00DCFF009EFF0000FF4723FF00FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF000000FFA300E1FF8FFF009EFF00AEFF00AEFF00AEFF009EFF0070FF0000FFC2
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF005C00FF0A80FF00EBFF00EBFF00CCFF00
FFD700FFB800FFA800FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF6B00FF6B00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FFA800FFB800
FFD70051FF00FFE600FFD700FAFF00FFC700FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFD700FFD700FFE600
FFE600FFF500FAFF00BDFF008FFF0080FF0042FF007000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF000051FF008FFF009EFF009EFF009EFF008FFF0051FF00FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF19BDFF0000FF0A80FF00
FFE600FFA800FFA800FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00
FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF8A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFB800
FFC700FFF500BDFF00DCFF00FFE600FFC700FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFE600
FFE600FFF500FAFF00EBFF00CCFF00AEFF0061FF00FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF000000FFF0FF000070FF008FFF009EFF008FFF0080FF00CC00FF00FFE1
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00006100FF61FF0080FF00FF000070FF00
FFC700FFA800FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF8A00FF8A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FFA800FFA800FFB800
FFC700FFE600EBFF00EBFF00FFE600FFD700FFC700FFC700FFB800FFB800FFB800FFB800
FFB800FFB800FFC700FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFD700FFE600
FFF500FFF500FAFF00EBFF00CCFF00AEFF0061FF0000FF38FF00000094FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00004200FF61FF0080FF008FFF008FFF0070FF0042FF0000E1FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000075FFFF0000FF0000FF000000FF1900FF85CCFF00FFE600
FFB800FFA800FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFB800
FFC700FFD700EBFF00BDFF00FFE600FFD700FFD700FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFD700FFE600FFE600
FFF500FAFF00FAFF00DCFF00CCFF00AEFF0080FF0042FF0000FF280057FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF000070FF0080FF0080FF0070FF00FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000057FF0075FF0094FF00FF8500FF2800FF85
FFB800FFA800FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00
FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00
FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFB800
FFC700FAFF00BDFF00CCFF00FAFF00EBFF00FFD700FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFD700FFD700FFD700FFD700FFD700FFD700FFE600FFF500
FAFF00EBFF00EBFF00CCFF0000FF7561FF0061FF00FF00005100FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF000061FF0070FF0070FF0061FF0014FF00FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00009EFF00FF00009EFF0000FFB300FFE1CCFF00FFC700
FFA800FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFB800
FFC700FFF500FAFF0080FF0000FF57FAFF00FFE600FFD700FFD700FFC700FFC700FFC700
FFC700FFC700FFD700FFD700FFD700FFD700FFD700FFD700FFE600FFE600FFE600FFF500
BDFF008FFF00CCFF00BDFF0080FF0000A3FFFF000000FF47FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF000061FF0061FF0051FF00FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF000000FF4780FF00EBFF00FAFF00FFF500FFF500FFD700FFB800
FFA800FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFB800
FFC700FFD700FFE600EBFF0014FF00FAFF00FFE600FFE600FFD700FFD700FFD700FFD700
FFD700FFD700FFD700FFF500FFF500FFE600FFE600FFE600FFE600FFE600FFF500FAFF00
CCFF0051FF0080FF0000FF7500FF8500C2FFFF005C00FFD1FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000CC00FF000AFF42FF0051FF0042FF0000FF66FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000094FFAE00FFDCFF00FFF500FFE600FFD700FFC700FFB800FFA800
FFA800FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00
FF7A00FF7A00FF8A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFB800
FFB800FFC700FFD700EBFF0000FF28BDFF00FFF500FFE600FFE600FFD700FFD700FFD700
FFD700FFD700FFE600FAFF00BDFF00FFF500FFF500FFE600FFF500FFF500FFF500FAFF00
EBFF00CCFF00AEFF0042FF00FF008AFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00008000FF33FF0042FF0033FF00FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00009EFF00EBFF00FAFF00FFE600FFC700FFB800FFB800FFA800
FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF8A00FF7A00FF7A00FF8A00FF8A00
FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFB800
FFB800FFC700FFD700FFF500EBFF0080FF00FAFF00FFF500FFE600FFE600FFE600FFE600
FFE600FFE600FFF5008FFF00AEFF00FAFF00FFF500FFF500FFF500FFF500FFF500FAFF00
EBFF00DCFF00BDFF0033FF00000AFF00FFFFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF2823FF0023FF00FF002EFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF000000FF47DCFF00EBFF000066FFFFC700FFB800FFA800FFA800
FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF8A00FF7A00FF7A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFB800
FFB800FFC700FFD700FFE600FFF500DCFF00CCFF00EBFF00FFF500FAFF00FFF500FFE600
FFE600FFF500FAFF00CCFF0070FF00EBFF00FAFF00FAFF00FFF500FAFF00FAFF00EBFF00
EBFF00DCFF00BDFF009EFF0051FF00CC00FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF2814FF0005FF004200FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000019FFAEFF00CCFF00AE00FFFFC700FFB800FFA800FFA800
FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00
FF7A00FF8A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFB800FFB800
FFB800FFC700FFC700FFD700FFE600FAFF009EFF009EFF00DCFF0070FF00FAFF00FFF500
FFF500FFF500FAFF00DCFF0080FF00DCFF00EBFF00FAFF00FAFF00EBFF00EBFF00EBFF00
DCFF00CCFF00BDFF008FFF0014FF00FF0000AE00FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0A00FF0AFF00B8FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FA00FF61FF0000FF38AEFF00FFB800FFA800FFA800FF9900
FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFB800FFB800FFB800
FFB800FFC700FFD700FFD700FFE600FFF500CCFF0000FF2861FF00BDFF00EBFF00FAFF00
FAFF00FAFF00EBFF00CCFF000075FFCCFF00DCFF00EBFF00DCFF00CCFF00EBFF00DCFF00
DCFF008FFF0080FF0070FF00FF000000F0FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00002300FF00FF2800FF28FF004CFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF000005FF00FF000000E1FFBD00FFCCFF00FFD700FFB800FFA800FF9900FF9900
FF9900FF9900FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF6B00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF8A00FF7A00FF8A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800
FFB800FFC700FFC700FFD700FFE600FFF500EBFF00BDFF0000FF0A9EFF00DCFF00EBFF00
00FF38EBFF00DCFF00BDFF0051FF0000FFE1CCFF00CCFF00AEFF009EFF00CCFF00DCFF00
CCFF00AEFF0061FF0000FF94FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF4700FF47FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF000042FF00AEFF0023FF000085FFFAFF00FFB800FFA800FFA800FF9900FF9900
FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00
FF8A00FF8A00FF9900FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800
FFC700FFC700FFC700FFD700FFE600FFF500EBFF00AEFF000075FF8FFF00BDFF00CCFF00
00FFB3CCFF00CCFF0080FF005100FF70FF00AEFF00BDFF009EFF009EFF00BDFF00CCFF00
BDFF00AEFF008FFF0042FF00FF001EFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF8500FF66BD00FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF000000FF19BDFF00EBFF00FFF500FFE600FFC700FFB800FFA800FFA800FF9900FF9900
FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF9900FF8A00FF9900FF8A00FF8A00
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800
FFC700FFC700FFD700FFD700FFE600EBFF0080FF0033FF000075FF00FF199EFF009EFF00
00FFB3AEFF00AEFF0033FF0000E1FF0085FF00FF198FFF0061FF0080FF00AEFF00AEFF00
AEFF00AEFF008FFF0042FF000019FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000D1FF00FF85FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000BDFF00DCFF00FFE600FFC700FFB800FFB800FFA800FF9900FF9900FF9900
FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF9900FF8A00FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FF9900
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFC700
FFC700FFC700FFD700FFD700FFE600FAFF00DCFF00BDFF0061FF0000FF3800FFE123FF00
00E1FF61FF0080FF0061FF0014FF007000FF00FF8551FF0000FFFF61FF008FFF0000FF19
9EFF008FFF0023FF001400FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00D700FFB3FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF000080FF008FFF00FFD700FFB800FFB800FFA800FFA800FF9900FF9900FF9900
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF9900FF9900FFA800FF9900FF9900FF9900FF9900FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00
FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFC700
FFC700FFD700FFD700FFE600FFE600FFF500EBFF00CCFF008FFF0051FF0014FF000066FF
00FFD100D1FF23FF0005FF000038FF0019FF0500FF00FF2800FF94FF00B833FF0051FF00
80FF0080FF0061FF0014FF0000D1FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFE1FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF000000D1FF51FF00FFC700FFB800FFA800FFA800FF9900FF9900FF9900FF9900
FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00
FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF9900FFA8008FFF00FFA800FF9900FF9900FF9900FF9900
FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF9900FF8A00FF9900FF8A00
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800
FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700
FFD700FFD700FFE600FFE600FFE600FFF500FAFF00DCFF00BDFF008FFF0033FF0000FF66
FF0000EB00FF00FF572300FF00D1FFFF0000FF0000FF0000FF0000FF0000FF008A23FF00
33FF0061FF0051FF0000FF28FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000E1FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
BDFF0070FF0000F0FFFFD700FFB800FFB800FFA800FFA800FF9900FF9900FF9900FF9900
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF9900FF9900FF9900FFA800FFE600FFB800FFA800FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FFA800FF9900FFA800FFA800FFA800FFA800
FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFD700
FFE600FFE600FFE600FFE600FFF500FAFF00EBFF00DCFF00BDFF0061FF0023FF00FF00D7
FF0000FF000000C2FFEB00FFFF0000FF0000FF0000FF0000FF0000FF0000FF00002300FF
FF000042FF0033FF0000FF191400FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000094FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
BDFF00FFF500FFD700FFC700FFB800FFA800FFA800FFA800FF9900FF9900FF9900FF9900
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF9900FF9900FF9900FF9900FFA800FFD700FFC700FFA800FFA800FFA800FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FFA800FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFB800FFB800FFC700FFC700FFC700FFB800FFC700FFC700FFC700FFC700FFC700FFD700
DCFF00EBFF00FFF500FFF500FAFF00EBFF00AEFF00BDFF00AEFF0080FF0000FF0A00FFB3
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
BD00FF00FF3814FF005100FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000038FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
33FF00FFE600FFC700FFB800FFB800FFA800FFA800FF9900FF9900FF9900FF9900FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00
FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF9900FF9900FF9900FF9900FFA800FFB800FFC700FFC700FFB800FFA800FFA800FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FFA800
FFA800FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800
FFB800FFC700FAFF00FFD700FFC700FFC700FFC700FFC700FFC700FFC700FFD700FFD700
FAFF0070FF00DCFF00FAFF00EBFF00EBFF00AEFF0070FF0051FF0000FF6600FF6600FF75
9E00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF000000FF7500FF1900FF85FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00004200FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000085FF9EFF00FF0000
BDFF00FFC700FFB800FFB800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900
FF9900FF9900FF9900FF9900FFA800FFB800FFD700FFE600FFB800FFB800FFA800FFA800
FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FFA800FFA800FFA800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800
FFB800FFC700CCFF00FAFF00FFD700FFD700FFC700FFC700FFC700FFD700FFD700FFE600
FFF500CCFF00AEFF00DCFF00DCFF00DCFF00BDFF008FFF0000FFB305FF0000FF75FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF000000FF8500FFD1FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000080FF00FFE600
FFD700FFC700FFB800FFB800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900
FF9900FF9900FF9900FFA800FFA800FFB800FFD700FFF500FFC700FFB800FFB800FFB800
FFA800FFA800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FFA800FFA800
FFA800FFA800FFA800FFB800FFF500FFB800FFB800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800
FFC700FFD700BDFF00EBFF00FFE600FFD700FFD700FFD700FFD700FFD700FFD700FFE600
FFF500EBFF00AEFF00AEFF008FFF00CCFF00AEFF008FFF0033FF0000FFE1FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF000000FFE1FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000051FF00FF0000EBFF00FFD700
FFC700FFC700FFB800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00
FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF8A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900
FF9900FFA800FFA800FFA800FFB800FFB800FFD700EBFF00FFD700FFC700FFC700FFB800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFB800FFB800FFB800FFF500FFC700FFB800FFB800FFB800FFA800FFA800FFB800
FFA800FFA800FFB800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFC700
FFC700FFD700FAFF00BDFF00FFF500FFE600FFE600FFE600FFE600FFE600FFE600FFF500
FFF500EBFF00CCFF0000E1FF80FF00AEFF0061FF0080FF0033FF0000FF57FF0099FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF000000B3FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000051FF00FFF500FFD700FFC700
FFB800FFB800FFB800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FFA800FFA800FFB800FFB800FFC700FFD700DCFF00FFE600FFD700FFE600FFD700
FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFB800FFB800FFB800FFC700FAFF00FFE600FFC700FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700
FFD700FFE600FFF50051FF00FAFF00FFE600FFE600FFE600FFE600FFE600FFF500FFF500
FAFF00EBFF00BDFF0051FF0023FF0070FF0023FF0051FF0000FF28FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000047FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000AEFF00FAFF00FFD700FFD700FFC700
FFB800FFB800FFB800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FF9900FFA800FFA800
FFA800FFA800FFB800FFD700FFD700FFD700FFE600EBFF00BDFF00FAFF00DCFF00FFD700
FFC700FFB800FFB800FFB800FFA800FFB800FFA800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFC700FFD7008FFF00FFF500FFD700FFC700FFB800FFB800FFB800FFB800
FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFD700
FFD700FFE600FFF500BDFF00EBFF00FFF500FFF500FFF500EBFF00FAFF00FFF500FAFF00
EBFF00DCFF00BDFF008FFF0014FF0005FF0000FF1900FF1900FF38FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000AE00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00005100FFFFF500FFE600FFD700FFC700FFC700
FFB800FFB800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF8A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFB800FFB800FFD700CCFF00FFF500AEFF00AEFF00FF0000AEFF00FAFF00FFD700
FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFC700FFC700FFC700FFE600EBFF00FFF500FFD700FFC700FFC700FFC700FFC700FFC700
FFD700FFD700FFC700FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFD700FFD700
FFE600FFE600FAFF00BDFF00DCFF00EBFF00FAFF00FAFF00BDFF00EBFF00EBFF00EBFF00
61FF00BDFF00AEFF0080FF0000FF38EB00FF00A3FF0075FF00FFE1FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000CCFF00FFF500FFE600FFD700FFC700FFC700FFB800
FFB800FFB800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF9900
FF9900FF9900FF9900FFA800FF9900FF9900FF9900FFA800FF9900FFA800FFA800FFA800
FFA800FFA800FFA800FFB800FFC700FFA800FFA800FFA800FFA800FFB800FFB800FFB800
FFB800FFB800FFC700FFD700FAFF00DCFF0051FF00FF0000FF0000FF0000AEFF00FFE600
FFD700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700DCFF00FFC700FFC700
FFD700FFD700FFD700FFF500EBFF00FAFF00FFE600FFD700FFD700FFD700FFD700FFD700
FFF500FFF500FFD700FFD700FFD700FFD700FFD700FFD700FFE600EBFF00FFE600FFF500
FAFF00FAFF00BDFF00AEFF00AEFF0070FF00EBFF00DCFF00BDFF00CCFF00DCFF00CCFF00
BDFF0080FF008FFF0000FFFF00FF280075FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF000000FF85DCFF00FAFF00FFF500FFD700FFD700FFC700FFC700FFB800
FFB800FFA800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF8A00FF8A00FF9900FF9900FF9900FFA800
FFA800FFA800FFA800FFC700FFB800FFA800FFA800FFA800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFC700FFE600FFC700FFC700FFB800FFC700FFC700FFC700FFC700
FFC700FFD700FFD700FAFF00BDFF0000FFA300FFE1FF0000FF0000FF00009EFF00FFF500
FFE600FFE600FFD700FFE600FFD700FFD700FFD700FFD700FFE60080FF00FFE600FFE600
FFE600FFE600FFE600EBFF0005FF008FFF00FAFF00FFE600FFE600FFF500FFF500FFF500
EBFF00EBFF00FFF500FFF500FFF500FFE600FFE600FFF500FAFF00CCFF00FAFF00FAFF00
AEFF00DCFF00BDFF0061FF0000FF859EFF00BDFF00AEFF0070FF008FFF008FFF00AEFF00
8FFF000019FF14FF0000FF0A00B3FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000057FFBDFF00DCFF00FAFF00FFF500FFE600FFD700FFD700FFC700FFC700FFB800
FFB800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00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FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF8A00FF8A00FF9900FF9900FF9900FFA800
FFA800FFA800FFA800FFC700FFB800FFA800FFA800FFA800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFC700FFE600FFC700FFC700FFB800FFC700FFC700FFC700FFC700
FFC700FFD700FFD700FAFF00BDFF0000FFA300FFE1FF0000FF0000FF00009EFF00FFF500
FFE600FFE600FFD700FFE600FFD700FFD700FFD700FFD700FFE60080FF00FFE600FFE600
FFE600FFE600FFE600EBFF0005FF008FFF00FAFF00FFE600FFE600FFF500FFF500FFF500
EBFF00EBFF00FFF500FFF500FFF500FFE600FFE600FFF500FAFF00CCFF00FAFF00FAFF00
AEFF00DCFF00BDFF0061FF0000FF859EFF00BDFF00AEFF0070FF008FFF008FFF00AEFF00
8FFF000019FF14FF0000FF0A00B3FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000057FFBDFF00DCFF00FAFF00FFF500FFE600FFD700FFD700FFC700FFC700FFB800
FFB800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF9900
FF9900FF9900FF9900FFA800FF9900FF9900FF9900FFA800FF9900FFA800FFA800FFA800
FFA800FFA800FFA800FFB800FFC700FFA800FFA800FFA800FFA800FFB800FFB800FFB800
FFB800FFB800FFC700FFD700FAFF00DCFF0051FF00FF0000FF0000FF0000AEFF00FFE600
FFD700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700DCFF00FFC700FFC700
FFD700FFD700FFD700FFF500EBFF00FAFF00FFE600FFD700FFD700FFD700FFD700FFD700
FFF500FFF500FFD700FFD700FFD700FFD700FFD700FFD700FFE600EBFF00FFE600FFF500
FAFF00FAFF00BDFF00AEFF00AEFF0070FF00EBFF00DCFF00BDFF00CCFF00DCFF00CCFF00
BDFF0080FF008FFF0000FFFF00FF280075FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF000000FF85DCFF00FAFF00FFF500FFD700FFD700FFC700FFC700FFB800
FFB800FFA800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFB800FFB800FFD700CCFF00FFF500AEFF00AEFF00FF0000AEFF00FAFF00FFD700
FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFC700FFC700FFC700FFE600EBFF00FFF500FFD700FFC700FFC700FFC700FFC700FFC700
FFD700FFD700FFC700FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFD700FFD700
FFE600FFE600FAFF00BDFF00DCFF00EBFF00FAFF00FAFF00BDFF00EBFF00EBFF00EBFF00
61FF00BDFF00AEFF0080FF0000FF38EB00FF00A3FF0075FF00FFE1FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000CCFF00FFF500FFE600FFD700FFC700FFC700FFB800
FFB800FFB800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FF9900FFA800FFA800
FFA800FFA800FFB800FFD700FFD700FFD700FFE600EBFF00BDFF00FAFF00DCFF00FFD700
FFC700FFB800FFB800FFB800FFA800FFB800FFA800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFC700FFD7008FFF00FFF500FFD700FFC700FFB800FFB800FFB800FFB800
FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFD700
FFD700FFE600FFF500BDFF00EBFF00FFF500FFF500FFF500EBFF00FAFF00FFF500FAFF00
EBFF00DCFF00BDFF008FFF0014FF0005FF0000FF1900FF1900FF38FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000AE00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00005100FFFFF500FFE600FFD700FFC700FFC700
FFB800FFB800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF8A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FFA800FFA800FFB800FFB800FFC700FFD700DCFF00FFE600FFD700FFE600FFD700
FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFB800FFB800FFB800FFC700FAFF00FFE600FFC700FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700
FFD700FFE600FFF50051FF00FAFF00FFE600FFE600FFE600FFE600FFE600FFF500FFF500
FAFF00EBFF00BDFF0051FF0023FF0070FF0023FF0051FF0000FF28FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000047FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000AEFF00FAFF00FFD700FFD700FFC700
FFB800FFB800FFB800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF8A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900
FF9900FFA800FFA800FFA800FFB800FFB800FFD700EBFF00FFD700FFC700FFC700FFB800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFB800FFB800FFB800FFF500FFC700FFB800FFB800FFB800FFA800FFA800FFB800
FFA800FFA800FFB800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFC700
FFC700FFD700FAFF00BDFF00FFF500FFE600FFE600FFE600FFE600FFE600FFE600FFF500
FFF500EBFF00CCFF0000E1FF80FF00AEFF0061FF0080FF0033FF0000FF57FF0099FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF000000B3FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000051FF00FFF500FFD700FFC700
FFB800FFB800FFB800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900
FF9900FF9900FF9900FFA800FFA800FFB800FFD700FFF500FFC700FFB800FFB800FFB800
FFA800FFA800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FFA800FFA800
FFA800FFA800FFA800FFB800FFF500FFB800FFB800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800
FFC700FFD700BDFF00EBFF00FFE600FFD700FFD700FFD700FFD700FFD700FFD700FFE600
FFF500EBFF00AEFF00AEFF008FFF00CCFF00AEFF008FFF0033FF0000FFE1FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF000000FFE1FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000051FF00FF0000EBFF00FFD700
FFC700FFC700FFB800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00
FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900
FF9900FF9900FF9900FF9900FFA800FFB800FFD700FFE600FFB800FFB800FFA800FFA800
FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FFA800FFA800FFA800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800
FFB800FFC700CCFF00FAFF00FFD700FFD700FFC700FFC700FFC700FFD700FFD700FFE600
FFF500CCFF00AEFF00DCFF00DCFF00DCFF00BDFF008FFF0000FFB305FF0000FF75FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF000000FF8500FFD1FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000080FF00FFE600
FFD700FFC700FFB800FFB800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00
FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF9900FF9900FF9900FF9900FFA800FFB800FFC700FFC700FFB800FFA800FFA800FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FFA800
FFA800FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800
FFB800FFC700FAFF00FFD700FFC700FFC700FFC700FFC700FFC700FFC700FFD700FFD700
FAFF0070FF00DCFF00FAFF00EBFF00EBFF00AEFF0070FF0051FF0000FF6600FF6600FF75
9E00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF000000FF7500FF1900FF85FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00004200FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000085FF9EFF00FF0000
BDFF00FFC700FFB800FFB800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF9900FF9900FF9900FF9900FFA800FFD700FFC700FFA800FFA800FFA800FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FFA800FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFB800FFB800FFC700FFC700FFC700FFB800FFC700FFC700FFC700FFC700FFC700FFD700
DCFF00EBFF00FFF500FFF500FAFF00EBFF00AEFF00BDFF00AEFF0080FF0000FF0A00FFB3
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
BD00FF00FF3814FF005100FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000038FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
33FF00FFE600FFC700FFB800FFB800FFA800FFA800FF9900FF9900FF9900FF9900FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF9900FF9900FF9900FFA800FFE600FFB800FFA800FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FFA800FF9900FFA800FFA800FFA800FFA800
FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFD700
FFE600FFE600FFE600FFE600FFF500FAFF00EBFF00DCFF00BDFF0061FF0023FF00FF00D7
FF0000FF000000C2FFEB00FFFF0000FF0000FF0000FF0000FF0000FF0000FF00002300FF
FF000042FF0033FF0000FF191400FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000094FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
BDFF00FFF500FFD700FFC700FFB800FFA800FFA800FFA800FF9900FF9900FF9900FF9900
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00
FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF9900FFA8008FFF00FFA800FF9900FF9900FF9900FF9900
FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF9900FF8A00FF9900FF8A00
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800
FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700
FFD700FFD700FFE600FFE600FFE600FFF500FAFF00DCFF00BDFF008FFF0033FF0000FF66
FF0000EB00FF00FF572300FF00D1FFFF0000FF0000FF0000FF0000FF0000FF008A23FF00
33FF0061FF0051FF0000FF28FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000E1FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
BDFF0070FF0000F0FFFFD700FFB800FFB800FFA800FFA800FF9900FF9900FF9900FF9900
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF9900FF9900FFA800FF9900FF9900FF9900FF9900FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00
FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFC700
FFC700FFD700FFD700FFE600FFE600FFF500EBFF00CCFF008FFF0051FF0014FF000066FF
00FFD100D1FF23FF0005FF000038FF0019FF0500FF00FF2800FF94FF00B833FF0051FF00
80FF0080FF0061FF0014FF0000D1FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFE1FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF000000D1FF51FF00FFC700FFB800FFA800FFA800FF9900FF9900FF9900FF9900
FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF9900FF8A00FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FF9900
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFC700
FFC700FFC700FFD700FFD700FFE600FAFF00DCFF00BDFF0061FF0000FF3800FFE123FF00
00E1FF61FF0080FF0061FF0014FF007000FF00FF8551FF0000FFFF61FF008FFF0000FF19
9EFF008FFF0023FF001400FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00D700FFB3FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF000080FF008FFF00FFD700FFB800FFB800FFA800FFA800FF9900FF9900FF9900
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF9900FF8A00FF9900FF8A00FF8A00
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800
FFC700FFC700FFD700FFD700FFE600EBFF0080FF0033FF000075FF00FF199EFF009EFF00
00FFB3AEFF00AEFF0033FF0000E1FF0085FF00FF198FFF0061FF0080FF00AEFF00AEFF00
AEFF00AEFF008FFF0042FF000019FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000D1FF00FF85FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000BDFF00DCFF00FFE600FFC700FFB800FFB800FFA800FF9900FF9900FF9900
FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00
FF8A00FF8A00FF9900FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800
FFC700FFC700FFC700FFD700FFE600FFF500EBFF00AEFF000075FF8FFF00BDFF00CCFF00
00FFB3CCFF00CCFF0080FF005100FF70FF00AEFF00BDFF009EFF009EFF00BDFF00CCFF00
BDFF00AEFF008FFF0042FF00FF001EFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF8500FF66BD00FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF000000FF19BDFF00EBFF00FFF500FFE600FFC700FFB800FFA800FFA800FF9900FF9900
FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF6B00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF8A00FF7A00FF8A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800
FFB800FFC700FFC700FFD700FFE600FFF500EBFF00BDFF0000FF0A9EFF00DCFF00EBFF00
00FF38EBFF00DCFF00BDFF0051FF0000FFE1CCFF00CCFF00AEFF009EFF00CCFF00DCFF00
CCFF00AEFF0061FF0000FF94FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF4700FF47FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF000042FF00AEFF0023FF000085FFFAFF00FFB800FFA800FFA800FF9900FF9900
FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFB800FFB800FFB800
FFB800FFC700FFD700FFD700FFE600FFF500CCFF0000FF2861FF00BDFF00EBFF00FAFF00
FAFF00FAFF00EBFF00CCFF000075FFCCFF00DCFF00EBFF00DCFF00CCFF00EBFF00DCFF00
DCFF008FFF0080FF0070FF00FF000000F0FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00002300FF00FF2800FF28FF004CFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF000005FF00FF000000E1FFBD00FFCCFF00FFD700FFB800FFA800FF9900FF9900
FF9900FF9900FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00
FF7A00FF8A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFB800FFB800
FFB800FFC700FFC700FFD700FFE600FAFF009EFF009EFF00DCFF0070FF00FAFF00FFF500
FFF500FFF500FAFF00DCFF0080FF00DCFF00EBFF00FAFF00FAFF00EBFF00EBFF00EBFF00
DCFF00CCFF00BDFF008FFF0014FF00FF0000AE00FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0A00FF0AFF00B8FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FA00FF61FF0000FF38AEFF00FFB800FFA800FFA800FF9900
FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF8A00FF7A00FF7A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFB800
FFB800FFC700FFD700FFE600FFF500DCFF00CCFF00EBFF00FFF500FAFF00FFF500FFE600
FFE600FFF500FAFF00CCFF0070FF00EBFF00FAFF00FAFF00FFF500FAFF00FAFF00EBFF00
EBFF00DCFF00BDFF009EFF0051FF00CC00FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF2814FF0005FF004200FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000019FFAEFF00CCFF00AE00FFFFC700FFB800FFA800FFA800
FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF8A00FF7A00FF7A00FF8A00FF8A00
FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFB800
FFB800FFC700FFD700FFF500EBFF0080FF00FAFF00FFF500FFE600FFE600FFE600FFE600
FFE600FFE600FFF5008FFF00AEFF00FAFF00FFF500FFF500FFF500FFF500FFF500FAFF00
EBFF00DCFF00BDFF0033FF00000AFF00FFFFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF2823FF0023FF00FF002EFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF000000FF47DCFF00EBFF000066FFFFC700FFB800FFA800FFA800
FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00
FF7A00FF7A00FF8A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFB800
FFB800FFC700FFD700EBFF0000FF28BDFF00FFF500FFE600FFE600FFD700FFD700FFD700
FFD700FFD700FFE600FAFF00BDFF00FFF500FFF500FFE600FFF500FFF500FFF500FAFF00
EBFF00CCFF00AEFF0042FF00FF008AFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00008000FF33FF0042FF0033FF00FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00009EFF00EBFF00FAFF00FFE600FFC700FFB800FFB800FFA800
FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFB800
FFC700FFD700FFE600EBFF0014FF00FAFF00FFE600FFE600FFD700FFD700FFD700FFD700
FFD700FFD700FFD700FFF500FFF500FFE600FFE600FFE600FFE600FFE600FFF500FAFF00
CCFF0051FF0080FF0000FF7500FF8500C2FFFF005C00FFD1FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000CC00FF000AFF42FF0051FF0042FF0000FF66FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000094FFAE00FFDCFF00FFF500FFE600FFD700FFC700FFB800FFA800
FFA800FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFB800
FFC700FFF500FAFF0080FF0000FF57FAFF00FFE600FFD700FFD700FFC700FFC700FFC700
FFC700FFC700FFD700FFD700FFD700FFD700FFD700FFD700FFE600FFE600FFE600FFF500
BDFF008FFF00CCFF00BDFF0080FF0000A3FFFF000000FF47FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF000061FF0061FF0051FF00FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF000000FF4780FF00EBFF00FAFF00FFF500FFF500FFD700FFB800
FFA800FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00
FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFB800
FFC700FAFF00BDFF00CCFF00FAFF00EBFF00FFD700FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFD700FFD700FFD700FFD700FFD700FFD700FFE600FFF500
FAFF00EBFF00EBFF00CCFF0000FF7561FF0061FF00FF00005100FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF000061FF0070FF0070FF0061FF0014FF00FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00009EFF00FF00009EFF0000FFB300FFE1CCFF00FFC700
FFA800FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFB800
FFC700FFD700EBFF00BDFF00FFE600FFD700FFD700FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFD700FFE600FFE600
FFF500FAFF00FAFF00DCFF00CCFF00AEFF0080FF0042FF0000FF280057FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF000070FF0080FF0080FF0070FF00FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000057FF0075FF0094FF00FF8500FF2800FF85
FFB800FFA800FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00
FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF8A00FF8A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FFA800FFA800FFB800
FFC700FFE600EBFF00EBFF00FFE600FFD700FFC700FFC700FFB800FFB800FFB800FFB800
FFB800FFB800FFC700FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFD700FFE600
FFF500FFF500FAFF00EBFF00CCFF00AEFF0061FF0000FF38FF00000094FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00004200FF61FF0080FF008FFF008FFF0070FF0042FF0000E1FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000075FFFF0000FF0000FF000000FF1900FF85CCFF00FFE600
FFB800FFA800FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00
FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF8A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFB800
FFC700FFF500BDFF00DCFF00FFE600FFC700FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFE600
FFE600FFF500FAFF00EBFF00CCFF00AEFF0061FF00FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF000000FFF0FF000070FF008FFF009EFF008FFF0080FF00CC00FF00FFE1
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00006100FF61FF0080FF00FF000070FF00
FFC700FFA800FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF6B00FF6B00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FFA800FFB800
FFD70051FF00FFE600FFD700FAFF00FFC700FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFD700FFD700FFE600
FFE600FFF500FAFF00BDFF008FFF0080FF0042FF007000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF000051FF008FFF009EFF009EFF009EFF008FFF0051FF00FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF19BDFF0000FF0A80FF00
FFE600FFA800FFA800FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FFA800FFB800
FFF500FFD700FFC700FFC700FFB800FFB800FFB800FFA800FFA800FFA800FFB800FFA800
FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFD700FFD700FFE600
FFE600FFF500FAFF00DCFF009EFF0000FF4723FF00FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF000000FFA300E1FF8FFF009EFF00AEFF00AEFF00AEFF009EFF0070FF0000FFC2
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF005C00FF0A80FF00EBFF00EBFF00CCFF00
FFD700FFB800FFA800FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00
FF7A00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FFA800FFA800FFB800
FFD700FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFD700FFE600
FFE600FFF500FAFF00DCFF009EFF0000FF1900FF85FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF000000FF380028FF8FFF00AEFF00BDFF00BDFF00AEFF009EFF0023FF00FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF000080FF0080FF00EBFF00FFF500FFF500CCFF00
FFC700FFA800FFA800FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFD700FFE600
FFF500FAFF00EBFF00AEFF0080FF0005FF0000A3FFFF0000FA00FFFF0000FF000000FF38
00FFB3FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
3300FFFF00B8FF000080FF00AEFF00BDFF00BDFF00BDFF00BDFF00AEFF0000E1FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00008FFF00DCFF00FAFF00FFE600FFE600FFD700
FFB800FFA800FFA800FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFC700FFC700FFD700FFE600
DCFF00CCFF00BDFF0080FF0000F0FF00FF28FF0099FF00000057FFFF0000FF000033FF00
4200FF0057FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
00FF7500FF94FF0000AEFF00BDFF00CCFF00CCFF00CCFF00BDFF00BDFF009EFF000085FF
00FF85FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF000005FF009EFF00FAFF00FFE600FFD700FFD700
FFB800FFA800FFA800FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFC700FFC700FFE600FAFF00
AEFF0033FF00BDFF0080FF0000C2FF9EFF0000FFF000FFA342FF0061FF0070FF0070FF00
33FF0000FFD1FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
00FF190038FF80FF00BDFF00CCFF00CCFF00CCFF00CCFF00CCFF00BDFF009EFF0042FF00
00FF66FF003DFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF000000E1FFFAFF00FFE600FFD700FFC700
FFB800FFB800FFA800FFA800FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFC700FFD700FFF50005FF00
00FF75BDFF00EBFF00EBFF00AEFF00DCFF00BDFF0000FF661400FF9EFF009EFF0080FF00
00FFC200FFF0FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
00FFC2FF000000FF38CCFF00DCFF00DCFF00DCFF00DCFF00CCFF00BDFF0005FF00FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000CC00FF70FF00EBFF00FFE600FFE600FFC700
FFC700FFB800FFA800FFA800FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00
FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00
FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFC700FFD700FFF500BDFF00
AEFF00EBFF00FFF500FAFF00FAFF00FAFF00CCFF0080FF0070FF00CCFF00BDFF009EFF00
33FF00FF000000A3FF00FF947000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF005C0028FF00FFFF
00FFFFAEFF00CCFF00DCFF00DCFF00DCFF00DCFF00DCFF00DCFF00CCFF009EFF00FF0000
00A3FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF000000FF66BDFF00EBFF00FFF500FFE600FFD700
FFC700FFC700FFB800FFA800FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF6B00
FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFC700FFD700FAFF0000FF66
EBFF00FFF500FFE600FFE600FFF500FFF500AEFF00DCFF00EBFF00DCFF00CCFF0042FF00
FF000F0094FF00FFE100FF19CC00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000047FFFA00FF05FF0000FF38
70FF00BDFF00DCFF00DCFF00EBFF00EBFF00EBFF00DCFF00DCFF00CCFF00BDFF00FF0000
00FF4700FFB3FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000500FFAEFF00CCFF0051FF00DCFF00FFF500
FAFF00FFE600FFC700FFB800FFA800FF9900FF9900FF9900FF8A00FF8A00FF8A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FFA800FF9900FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFE600FAFF00FFF500
FFF500FFE600FFE600FFE600FFE600FFE600EBFF00FAFF00FAFF00EBFF00CCFF0042FF00
AEFF00DC00FF70FF0023FF00FF003D00FFE1FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000014FF0023FF0000FF75
AEFF00DCFF00EBFF00EBFF00EBFF00EBFF00EBFF00EBFF00EBFF00DCFF00CCFF009EFF00
05FF0000FF47FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF000000FFC25100FF23FF000057FF6100FFDCFF00
61FF00AEFF00FFF500FFD700FFA800FFA800FF9900FF9900FF8A00FF8A00FF8A00FF8A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF8A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFC700FFD700FFD700
FFD700FFD700FFD700FFD700FFE600FFE600FFE600FFF500FFF500FAFF00DCFF00CCFF00
CCFF00AEFF009EFF0061FF0033FF0000FF3800FF75FF0099FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000085FFFF0000FF0000FF000070FF0000FF19
00FF47DCFF00EBFF00EBFF00FAFF00EBFF00FAFF00EBFF00EBFF00DCFF00BDFF0000FFC2
00FFFFFF00D7FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000094FFFF0000FF000000FFD170FF0051FF00
51FF0033FF0000FFD1FFF500FFB800FFA800FF9900FF9900FF8A00FF8A00FF8A00FF8A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFB800FFB800FFB800FFC700FFC700
FFC700FFC700FFC700FFD700FFD700FFD700FFE600FFE600FFF500FFF500FAFF00EBFF00
DCFF00BDFF00AEFF008FFF0061FF0033FF0000FF2800FF940028FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF000000FF85FF000000FFF0CC00FFAEFF00AEFF00
AEFF00EBFF00FAFF00FAFF00FAFF00FAFF00FAFF00FAFF00EBFF00DCFF008FFF00000AFF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF47
00FF579E00FF8FFF00DCFF00DCFF00FFA800FF9900FF9900FF8A00FF8A00FF8A00FF8A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800
FFC700FFC700FFC700FFD700FFD700FFD700FFD700FFE600FFE600FFF500FAFF00EBFF00
DCFF00BDFF009EFF0080FF0000FF3800FF0A00E1FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000BD00FFFF000014FF0014FF000085FF00FF0ACCFF00EBFF00
EBFF00FAFF00FAFF00FAFF00FAFF00FAFF00FAFF00FAFF00FAFF00EBFF00CCFF008FFF00
FF0000000AFFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00007000FF
00FF0A000AFF9EFF00DCFF00DCFF00FFB800FFA800FF9900FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFB800FFB800FFB800
FFB800FFB800FFC700FFC700FFC700FFD700FFD700FFE600FFF500FFF500FAFF00EBFF00
DCFF0000FF470028FF61FF0023FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF000000A3FFFF007A51FF0033FF000057FFAEFF00DCFF00EBFF00
FAFF00FAFF00FFF500FFF500FFF500FFF500FFF500FAFF00FAFF00EBFF00DCFF00BDFF00
7000FF00FF1900FF47FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000057FF0047FF
8FFF0000FFB39EFF00FFF500FFD700FFB800FF9900FF9900FF8A00FF8A00FF8A00FF8A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00
FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FFA800FF9900FFA800FFA800FFA800FFA800FFB800FFB800
FFB800FFC700FFC700FFC700FFC700FFC700FFD700FFE600FFE600FFF500FAFF00EBFF00
DCFF00BDFF008FFF0000FFC20075FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000038FFFF0000FF0000000AFF51FF0070FF0000FFB3FF0000CCFF00EBFF00FAFF00
FFF500FFF500FFF500FFF500FFF500FFF500FFF500FFF500FAFF00FAFF00EBFF00CCFF00
FF00D723FF0005FF000066FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00E600FFD1
BDFF00AEFF000085FFFAFF00FFD700FFB800FF9900FF9900FF9900FF8A00FF8A00FF8A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFB800
FFB800FFB800FFB800FFC700FFC700FFC700FFD700FFD700FFF500FAFF00EBFF00DCFF00
CCFF00BDFF0080FF0000FF7500B3FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000066FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF004C51FF009EFF000066FF51FF0014FF00EBFF00FFF500
FFF500FFF500FFF500FFF500FFF500FFF500FFF500FFF500FAFF00FAFF00EBFF00CCFF00
9EFF0061FF00EB00FF00FFFFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000005FF0061FF00
DCFF00AEFF0000FFC2AEFF00AEFF00FFB800FFA800FF9900FF9900FF8A00FF8A00FF8A00
FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF6B00FF6B00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFB800FFA800
FFB800FFB800FFC700FFB800FFC700FFC700FFD700FFE600FFF500DCFF0042FF00AEFF00
BDFF008FFF0080FF0014FF00FA00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF002E00FFB3FF0000FF008AFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFE1FF004C
05FF0000FF75FF000000E1FF1400FFBD00FFCCFF00AEFF000066FF00FF66FAFF00FFF500
FFF500FFF500FFE600FFE600FFE600FFE600FFF500FFF500FAFF00FAFF00EBFF00AEFF00
FF0000FF00C70075FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF000005FF00FF000000FFFF00FF7500D1FF05FF00
FAFF00FAFF00AEFF009EFF008FFF00FFD700FFA800FF9900FF8A00FF8A00FF8A00FF8A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00
FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800
FFB800FFB800FFB800FFB800FFC700FFC700FFD700FFE600FAFF0023FF0000FF578FFF00
00FF4700FF7551FF0000FFA3FF003DFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF000000FF3800FF19FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF7500FF19FF0000
61FF0005FF0033FF0000FF6600FF7533FF00DCFF00EBFF00FAFF00EBFF00FFF500FFF500
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF500FFF500FAFF00EBFF0014FF00
FF0099FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF000070FF00FF000070FF0000B3FFEBFF00
FFF500FFF500FFF500EBFF00EBFF00FFC700FFA800FF9900FF8A00FF8A00FF8A00FF8A00
FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800
FFA800FFB800FFB800FFB800FFC700FFC700FFD700FFF50061FF009EFF00CCFF00CCFF00
51FF0000FFD100FF0AFF00D7FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF000000FF8523FF0023FF0000FF66FF000000FFD100A3FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000047FFFF0000FF0000FF0000FF000033FF00DC00FF
8FFF0080FF0061FF0000FFE142FF009EFF00FAFF00FFF500FFF500FFF500FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF500FFF500DCFF0005FF00
FF008AFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000AEFF00CCFF00AEFF00DCFF00FFF500
FFE600FFE600FFE600FFF50080FF00FFB800FFA800FF9900FF8A00FF8A00FF8A00FF8A00
FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00
FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900
FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800
FFA800FFB800FFB800FFB800FFC700FFC700FFD700FFE600FFF500FAFF00FAFF00EBFF00
CCFF0070FF0000F0FF00FF4700B3FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000028FF00FF2861FF0061FF0000FF857000FF00FF0A4200FFFF0000FF000000E1FF
0066FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00F53300FF00FF47FF0000FF0000FF0000FF0000FF000051FF009EFF00
9EFF008FFF0061FF0000FF190066FFDCFF00FFF500FFF500FFE600FFE600FFE600FFE600
FFE600FFD700FFE600FFE600FFE600FFE600FFE600FFE600FFF500FFF500FAFF00DCFF00
FF002E6100FF00FF28FF000000FF75FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000028FFAEFF00DCFF00EBFF00FFF500FFE600
FFD700FFD700FFD700FFF500BDFF00FFB800FF9900FF9900FF9900FF8A00FF8A00FF8A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00
FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800
FFA800FFB800FFB800FFB800FFB800FFC700FFC700FFD700FFE600FFF500FFF500FAFF00
DCFF008FFF0000FF9433FF0000FF47FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF000033FF0080FF0070FF0061FF0070FF0051FF0000FF66FF0000FF0000FF0000
EB00FFFF0000FF000000FFB3FF0000FF0000FF0000FF0000FF000000FFE100FFF0FF0000
00FF575100FF00A3FF00FFE105FF00FF0000FF0000FF0000FF000000FF8533FF00AEFF00
BDFF0080FF0000FF6600FFD1DCFF00FAFF00FFF500FFE600FFE600FFE600FFD700FFE600
FFD700FFD700FFD700FFD700FFD700FFD700FFE600FFE600FFE600FFF500FAFF00FAFF00
BDFF00FF00E633FF0042FF008F00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF000023FF00AEFF00EBFF00FFF500FFE600FFE600
FFD700FFC700FFC700FFC700FFB800FFA800FF9900FF9900FF8A00FF8A00FF8A00FF8A00
FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF7A00FF7A00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800
FFA800FFA800FFB800FFB800FFB800FFC700FFC700FFD700FFD700FFE600FFF500FAFF00
BDFF00AEFF008FFF0070FF0005FF00EB00FFFF0000FF0000FF0000FF0000FF0000FF0000
1400FFFF00A800D1FF9EFF00AEFF009EFF009EFF0014FF00FF0000FF000000FFB323FF00
00FF3814FF0023FF0000FF75FF0000FF0000FF0000FF0000FF0000FF001E05FF0014FF00
00FFB300FFF000E1FF61FF0014FF0000FFB30019FF0047FFFF0000FF000070FF00CCFF00
CCFF0070FF0051FF009EFF00DCFF00FAFF00FFE600FFE600FFE600FFD700FFD700FFD700
FFD700FFD700FFD700FFD700FFD700FFE600FFD700FFE600FFE600FFE600FFF500FAFF00
DCFF0000FFE100F0FF61FF00FF000000F0FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFF0CCFF00FFF500FFE600FFD700
FFC700FFC700FFB800FFB800FFA800FFA800FF9900FF9900FF8A00FF8A00FF8A00FF8A00
FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF9900FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800
FFA800FFB800FFB800FFB800FFB800FFC700FFC700FFD700FFD700FFE600FFF500FFF500
EBFF00DCFF00BDFF0080FF0023FF00BD00FFFF0000FF0000FF0000FF0000FF0000FF0000
FF000000FF0A42FF00AEFF00BDFF00BDFF00AEFF0080FF0000D1FFFF001E00FF1980FF00
8000FF70FF000057FF00FF85FF0000FF0000FF0000FF0000FF0000FF000000FF0A61FF00
51FF0000FFA370FF008FFF0023FF0042FF0000FF2800FF2800FFD1FF000023FF00DCFF00
EBFF00BDFF0000FF9405FF0000FF94FFF500FFE600FFE600FFD700FFD700FFD700FFD700
FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFE600FFE600FFE600FFF500FAFF00
EBFF00CCFF009EFF0080FF0023FF0000FF66FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFFF00D1FFFAFF00FFD700FFD700
FFC700FFB800FFB800FFA800FFA800FFA800FF9900FF9900FF8A00FF8A00FF8A00FF8A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF8A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800
FFA800FFA800FFB800FFB800FFB800FFC700FFC700FFD700FFD700FFE600FFE600FFF500
FAFF00DCFF009EFF0070FF000066FF4200FFFF0000FF0000AE00FFFF0000FF000000B3FF
FF005C61FF0051FF00BDFF00DCFF00CCFF00AEFF0070FF00FF00A870FF009EFF00AEFF00
9EFF008FFF0051FF008F00FFFF0000FF0000FF0000FF0000FF0000FA00FF00FF198FFF00
42FF0061FF00AEFF00AEFF008FFF008FFF0061FF0005FF000075FF00FF943300FFEBFF00
FAFF00FAFF0014FF00AEFF0000FF94FFF500FFD700FFD700FFD700FFD700FFD700FFD700
FFD700FFC700FFD700FFD700FFD700FFD700FFD700FFD700FFE600FFE600FFF500FAFF00
EBFF00CCFF009EFF0061FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF9400FF75EBFF00FFD700FFC700
FFC700FFB800FFB800FFA800FFA800FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800
FFA800FFB800FFB800FFB800FFC700FFC700FFC700FFD700FFD700FFE600FFE600FFF500
EBFF00DCFF00CCFF009EFF0000FF3800FF66FF0000FF00000066FF00FF1923FF0000FF66
00FFE114FF00BDFF00DCFF00EBFF00DCFF0070FF0080FF00BDFF00BDFF00CCFF00CCFF00
AEFF0080FF0042FF0000FF75FF0000FF0000FF0000FF0000FF00000066FFFF00009EFF00
BDFF0080FF00CCFF00CCFF00BDFF00AEFF0000FF4700FFA300FFC20094FFCCFF00FAFF00
FFF500FFF500FFF500FAFF0033FF00FFE600FFD700FFD700FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFD700FFD700FFD700FFD700FFD700FFE600FFE600FFF500FAFF00
CCFF0000FF5700FF3800FF28CC00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF000000FFD1FF0000FF000014FF00FAFF00FFD700FFC700
FFC700FFC700FFB800FFA800FFA800FFA800FF9900FF9900FF8A00FF8A00FF8A00FF8A00
FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF9900FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800
FFA800FFB800FFB800FFB800FFB800FFC700FFC700FFD700FFD700FFE600FFF500FAFF00
EBFF00DCFF00BDFF00AEFF0070FF0000FF3800C2FF00FF6600D1FF61FF0070FF0000FF57
00FF1951FF00CCFF00EBFF00FAFF00EBFF008FFF0051FF00DCFF00EBFF00EBFF00DCFF00
AEFF0033FF0000FF3800FFB300D1FF9E00FFFF0000FF000000D1FF00FFC200FF28AEFF00
DCFF00DCFF00DCFF00CCFF00CCFF00AEFF008FFF0000FFB30094FF70FF00EBFF00FFF500
FFE600FFE600FFE600FFE600FFE600FFD700FFD700FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFD700FFC700FFD700FFD700FFD700FFE600FFE600FAFF00
00FF4700FFC26100FF0075FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF000000FF388FFF00AEFF00CCFF00FAFF00FFD700FFC700
FFC700FFB800FFB800FFA800FFA800FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00
FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800
FFA800FFB800FFB800FFB800FFB800FFC700FFC700FFD700FFD700FFE600FAFF00CCFF00
BDFF00CCFF00BDFF0080FF0070FF0000FF754200FF23FF000066FF9EFF0080FF0000A3FF
00FFFFCCFF009EFF00FAFF00FAFF00FAFF00EBFF0000FF75EBFF00FAFF00EBFF00EBFF00
AEFF008FFF008FFF0000FFE10075FF00FF281400FFFF00000094FF23FF0000FF19BDFF00
DCFF00EBFF00EBFF00DCFF00BDFF009EFF0080FF0000FF6600FF66DCFF00DCFF00FFE600
FFD700FFD700FFD700FFD700FFD700FFD700FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFE600FFF500DCFF00
61FF000066FF5100FFFF0000FF0000FF0000FF00000066FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF000000FFF0DCFF00FAFF00FFF500FFD700FFC700
FFC700FFB800FFB800FFA800FFA800FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800
FFA800FFB800FFB800FFB800FFC700FFC700FFC700FFD700FFE600FFF500FAFF009EFF00
80FF00AEFF009EFF0014FF0014FF0000C2FF23FF0080FF0051FF00BDFF00BDFF009EFF00
70FF00EBFF00FAFF00FFF500FFF500FFF500FFF500FAFF00FFF500FFF500FAFF00EBFF00
CCFF00CCFF00BDFF009EFF0070FF0014FF00FF0000FF000000FF7570FF0042FF0042FF00
EBFF00FAFF00FAFF00EBFF0023FF0023FF0042FF000019FFCCFF00FFF500FFE600FFD700
FFD700FFD700FFD700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFD700FFE600FFE60033FF00
61FF00BD00FF00FFF000FF8500FF66FF0000FF000000FF94FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF000000A3FFDCFF00FAFF00FFF500FFE600FFD700
FFC700FFB800FFB800FFA800FFA800FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00
FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800
FFB800FFB800FFB800FFC700FFC700FFC700FFD700FFD700FFE600FFF500FAFF00DCFF00
9EFF0061FF0061FF0000D1FF00FF0A00FF0A33FF009EFF00BDFF00DCFF00DCFF0080FF00
BDFF00EBFF00FFF500FFE600FFE600FFE600FFE600FFF500FFF500FFF500FFF500FAFF00
EBFF00EBFF00CCFF00BDFF008FFF0061FF0014FF0000F0FF00FF1900FF47BDFF00EBFF00
FAFF00FFF500FAFF00EBFF0005FF0080FF009EFF00DCFF00FAFF00FFE600FFD700FFD700
FFD700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFB800FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFE600FFF500
EBFF00BDFF0023FF0000FF9423FF00FF000000FF9400FF28FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF000000FF75AEFF00DCFF00FAFF00FFF500FFE600FFD700
FFC700FFC700FFB800FFB800FFA800FFA800FF9900FF9900FF9900FF8A00FF8A00FF8A00
FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800
FFB800FFB800FFB800FFC700FFC700FFD700FFD700FFE600FFE600FFF500FAFF00DCFF00
8FFF000075FF6100FF61FF008FFF0061FF0000FF199EFF00CCFF00EBFF00EBFF008FFF00
80FF00EBFF00FFF500FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF500FFF500
FAFF00EBFF00DCFF00AEFF0042FF0051FF00FF000000FF9400FF3842FF00CCFF00FAFF00
FFF500FFF500FFF500FAFF008FFF008FFF00BDFF00EBFF00FFF500FFE600FFD700FFD700
FFC700FFC700FFC700FFC700FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFE600
FFF500EBFF008FFF0000E1FF61FF0070FF0061FF00FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000DC00FF42FF009EFF00AEFF00CCFF00DCFF00CCFF00FAFF00
FFD700FFC700FFB800FFB800FFA800FFA800FF9900FF9900FF9900FF8A00FF8A00FF8A00
FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800
FFB800FFC700FFC700FFC700FFD700FFE600FFF500FFF500FFF500FAFF00DCFF00CCFF00
00FF1900FF3814FF009EFF00CCFF0080FF0000FF5700D1FFBDFF00FAFF00FFF500FAFF00
80FF00CCFF00FFE600FFD700FFD700FFD700FFD700FFD700FFE600FFE600FFF500FFF500
FAFF00EBFF00DCFF009EFF0051FF0000FF0A00FFB333FF0000FF0AAEFF0061FF00FFF500
FFE600FFE600FFE600FFF5008FFF0000FF85AEFF00CCFF00EBFF00FFE600FFD700FFC700
FFC700FFC700FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFC700FFB800FFC700FFC700FFC700FFC700FFD700FFD700FFD700FFE600
FFE600FAFF0000FF28BD00FF70FF009EFF0080FF00FF00008000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF000000FF3842FF00FF0000FF00000075FF23FF0000FF6600FF0A
FAFF00FFD700FFC700FFB800FFB800FFA800FFA800FF9900FF9900FF8A00FF8A00FF8A00
FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FFA800FFA800FFA800
FFB800FFC700FFD700FFD700FFE6009EFF00EBFF00DCFF00EBFF00DCFF0061FF009EFF00
23FF009EFF00AEFF00EBFF00EBFF0080FF00AEFF000066FFDCFF00FFF500FFE600FFE600
FFF500FAFF00FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFE600FFE600FFF500
FAFF00EBFF00DCFF00BDFF0061FF00FF000000FF3800FF4742FF00DCFF00FFF500FFE600
FFD700FFD700FFD700FFE600FAFF0080FF0080FF0033FF0000FF28FFE600FFC700FFC700
FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFC700FFD700FFD700
FFE600FFF500EBFF0000FF0A9EFF00AEFF009EFF0000A3FF00FF28FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF000000FF66FF0000FF0000FF000000D1FFFF000000FFC200FF75
9EFF00FFE600FFD700FFC700FFB800FFA800FFA800FF9900FF9900FF9900FF8A00FF8A00
FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00
FF6B00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF7A00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FFA800FFA800FFB800
FFB800FFE600FFF500FFE600FAFF008FFF0000FFA3BDFF009EFF009EFF0005FF0070FF00
8FFF00DCFF0000FF0AFAFF00FFF500FAFF00CCFF0042FF00AEFF00FFE600FFD700FFD700
FFD700FFD700FFD700FFC700FFD700FFC700FFC700FFD700FFD700FFD700FFE600FFF500
FAFF00EBFF00CCFF00BDFF0080FF0042FF0000FF57CCFF0080FF00FAFF00FFE600FFD700
FFD700FFD700FFD700FFD700FFF500FFF500FAFF00AEFF00FAFF00FFD700FFC700FFC700
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFC700FFD700FFD700
FFE600FFF500FAFF00EBFF00DCFF00BDFF009EFF0070FF0023FF0000FFA3FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000051FF008FFF00
DCFF00FFF500FFF50070FF00BDFF00FFB800FFA800FFA800FF9900FF9900FF8A00FF8A00
FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFB800
FFC700FFD700DCFF00EBFF00AEFF0033FF00EBFF00FAFF00BDFF00BDFF00DCFF00DCFF00
00FF47FAFF00FFF500FFF500FFF500FFF500DCFF0070FF00FFF500FFE600FFD700FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFD700FFE600FFE600FFF500
DCFF00AEFF00BDFF009EFF0000FF0A23FF00DCFF00EBFF0080FF00FAFF00FFD700FFD700
FFC700FFC700FFC700FFC700FFD700FFD700FFE600BDFF00FFE600FFC700FFC700FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFD700
FFD700FFF500FFF500EBFF00DCFF00BDFF0051FF0000FF66FF0000FF00000075FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF859EFF00
DCFF00EBFF00EBFF0051FF00FFF500FFD700FFB800FFA800FF9900FF9900FF8A00FF8A00
FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FFA800FFB800FFB800
FFC700FFD700FAFF0033FF009EFF0080FF00FAFF00FFF500FFF500FAFF00FFF500FFF500
DCFF00FFE600FFD700FFD700FFE600FFF50033FF00FAFF00FFE600FFD700FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFE600EBFF00
80FF0080FF0061FF0000FF0AAEFF0000FF57FFF500FFF500FFF500FFF500FFD700FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFD7009EFF00FFD700FFC700FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFA800FFB800FFA800FFB800FFA800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFD700
FFD700FFE600FFF500EBFF00DCFF00BDFF00FF00000019FFCC00FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF9451FF00
00FF0A42FF00CCFF0000FF0AFAFF00FAFF008FFF00FFB800FFA800FF9900FF8A00FF8A00
FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FFA800FFA800FFB800FFB800
FFC700FFD700FFF500DCFF00BDFF00FAFF00FFF500FFE600FFE600FFD700FFD700FFE600
8FFF00FFD700FFD700FFD700FFD700FFE600BDFF00EBFF00FFE600FFC700FFC700FFC700
FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFD700FFE600EBFF00
00FF28BDFF00CCFF00CCFF00FAFF00EBFF00FFE600FFD700FFD700FFD700FFC700FFC700
FFB800FFB800FFB800FFB800FFC700FFB800FFC700FFC700FFC700FFB800FFB800FFB800
FFB800FFA800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFA800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFD700
FFD700FFE600FAFF00CCFF0051FF0080FF00FF000000FFFFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000094FF4200FF
05FF008FFF009EFF000094FFCCFF0000FF85FFF500FFB800FFA800FF9900FF8A00FF8A00
FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FFA800FFA800FFB800FFC700
FFC700FFE600EBFF008FFF00DCFF00FFF500FFE600FFD700FFD700FFD700FFC700FFD700
FFD700FFC700FFC700FFC700FFC700FFD700FFF5009EFF00FFE600FFC700FFC700FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFD700DCFF00BDFF00
42FF00CCFF00EBFF00FAFF00FFF500FFE600FFD700FFD700FFC700FFC700FFC700FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFB800FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFD700
FFD700FFF500EBFF0000FF9423FF0000FF0AFF000000B3FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000DC00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
CC00FF00FF8542FF003300FF00FF94BDFF00FFE600FFC700FFA800FF9900FF9900FF8A00
FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FFA800FFB800FFC700FFC700
FFD700FFF500AEFF008F00FF70FF00FFF500FFD700FFD700FFC700FFC700FFC700FFC700
FFC700FFB800FFC700FFB800FFB800FFC700FFD70014FF00FFC700FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFE600BDFF00
33FF00DCFF00FAFF00FFF500FFE600FFD700FFD700FFC700FFC700FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFB800FFA800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFD700
FFE60000FF858FFF000028FF00FF6600FF4700F0FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF000000D1FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
00E1FF00FF660075FF4200FF70FF00CCFF00FFF500FFF500FFB800FF9900FF9900FF8A00
FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FFA800FFA800FFC700AEFF00FFF500
FFE600FFF5009EFF00CCFF00EBFF00FFE600FFD700FFC700FFC700FFC700FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFB800FFB800FFB800FFA800
FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFC700FFC700FFE600FAFF00
00FFE1BDFF00FAFF00FFF500FFE600FFD700FFC700FFC700FFB800FFB800FFB800FFB800
FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFD700
FFE600DCFF0051FF0000FF750094FF00C2FFFF0000FF0000FF0000FF0000FF0000FF0000
00FFB3FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF000000FF75FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF006B0094FF
14FF0080FF0080FF0000FF6680FF008FFF000075FFBDFF00FFF500FFA800FF9900FF8A00
FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FFB800DCFF009EFF00DCFF00
DCFF00CCFF00AEFF00FAFF00FFE600FFD700FFD700FFC700FFC700FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFC700FFE600EBFF00
80FF00AEFF00EBFF00FFF500FFE600FFD700FFC700FFC700FFB800FFB800FFB800FFB800
FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFB800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFC700FFD700
FFE600CCFF0070FF0000F0FFFA00FF00FFF000FF57FF0000FF0000FA00FF0019FF0028FF
00FF287000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF000005FF00FF0000FF0000FF0000FF0000FF0000FF00005100FF42FF0005FF00
05FF00BDFF009EFF001400FFCCFF00EBFF00FFF500FFE60042FF00FFA800FF9900FF8A00
FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FFA800FFB800FFC700FFE600
EBFF00DCFF0000FF19FAFF00FFE600FFD700FFC700FFC700FFB800FFB800FFB800FFB800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFC700FAFF0061FF00
9EFF009EFF0061FF00EBFF00FFE600FFD700FFC700FFC700FFB800FFB800FFB800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFC700FFC700
AEFF000047FF9EFF00FF006B00D1FF00FFC200FF4733FF0000FFE1FF000000FF8533FF00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF000042FF0023FF00FF0000FF0000FF0000FF00001400FF00FF0A8FFF0000FF75
CCFF00DCFF00AEFF000047FFBDFF00FFF500FFD700FFC700FFC700FFA800FF9900FF8A00
FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FFA800FFA800FFB800FFC700
FFE600FFF500DCFF00FAFF00FFE600FFD700FFC700FFC700FFB800FFB800FFB800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFD700FFD700
80FF00FAFF0033FF00AEFF008FFF00FFD700FFC700FFB800FFB800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFC700FFC700
FFD700FAFF0000F0FFDCFF0000FF6633FF0000FF3842FF0042FF001400FF00FF4761FF00
51FF0000FF381400FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF000000FF7580FF0061FF0000E1FF0019FFFF0000FF00000500FF61FF00AEFF00DCFF00
EBFF00EBFF00DCFF009EFF0000FF38FFF500FFC700FFB800FFA800FF9900FF9900FF8A00
FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FFA800FFA800FFB800FFB800
FFC700FFE6009EFF00FAFF00FFE600FFC700FFC700FFC700FFB800FFB800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900
FF9900FFA800FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFC700
FFD700FFE600FAFF0070FF0000FF75FFD700FFC700FFB800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FF9900FFA800FF9900FFA800FF9900FFA800FF9900
FFA800FF9900FF9900FF9900FF9900FFA800FF9900FF9900FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFA800FFB800FFB800FFB800FFC700
FFC700FFD700FFE600FFF50023FF009EFF00FF000061FF009EFF009EFF00AEFF009EFF00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00004200FF8FFF00AEFF0042FF00FF00004200FF6100FFAE00FF5100FF00FF28FAFF00
FAFF00FAFF00EBFF00AEFF0000FF38FFF500FFC700FFB800FFA800FF9900FF9900FF8A00
FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FFA800FFA800FFB800
FFC700FFF50070FF00EBFF00FFF500FFD700FFC700FFB800FFB800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FF9900FF9900FFA800FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFB800FFB800
FFC700FFE600FAFF0000FF38FAFF00FFD700FFB800FFA800FFA800FFA800FFA800FFA800
FFA800FF9900FFA800FF9900FFA800FF9900FFA800FF9900FF9900FF9900FFA800FF9900
FF9900FF9900FF9900FF9900FF9900FFA800FF9900FF9900FFA800FF9900FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800
FFC700FFD700FFD700FFE600FFF5009EFF002300FF61FF00BDFF00CCFF00CCFF009EFF00
00A3FFFF0000FF0000000AFFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
00E1FF42FF00AEFF00CCFF00BDFF00AEFF00BDFF008FFF0033FF0000D1FFCCFF00FFF500
FFE600FFF500CCFF0000FFE1FF0000AEFF00FFD700FFB800FFA800FF9900FF8A00FF8A00
FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF6B00FF6B00
FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FFA800FFA800FFB800
FFC700FFF50000FF1942FF00DCFF00FFD700FFB800FFB800FFA800FFA800FFA800FFA800
FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFB800
FFC700FFE6009EFF00EBFF00FFC700FFB800FFB800FFA800FFA800FFA800FFA800FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FFA800FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800
FFC700FFC700FFD700FFD700FFE60051FF0000FF5705FF00BDFF00DCFF00DCFF00AEFF00
FF0000FF000000FF8500FF75FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00004200FF8FFF00DCFF00EBFF00EBFF00DCFF0061FF000057FFFF004CFAFF00FFE600
FFE600FFE600FFF50080FF0051FF00DCFF00CCFF00FFC700FFA800FF9900FF8A00FF8A00
FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FFA800FFA800FFB800
FFC700FAFF00AEFF009EFF00FFF500FFD700FFB800FFB800FFA800FFA800FFA800FFA800
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800
FFB800FAFF00EBFF00FFC700FFB800FFB800FFA800FFA800FFA800FFA800FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800
FFB800FFC700FFC700FFD700FFE600EBFF00EBFF0033FF00DCFF00EBFF00DCFF00CCFF00
AEFF00FF001E33FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00003300FF00FF85EBFF00FAFF00FAFF00EBFF0061FF00DCFF00FAFF00FFE600FFD700
FFD700FFD700FFD700FFF50070FF0000FF5733FF00FAFF00FFA800FF9900FF8A00FF8A00
FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FFA800FFA800FFB800
FFC700FFD700FAFF00AEFF00FFD700FFC700FFB800FFA800FFA800FFA800FFA800FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800
FFB800FFC70061FF00FFB800FFB800FFB800FFA800FFA800FFA800FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FF9900
FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800
FFB800FFB800FFC700FFC700FFD700FFE600FFE600FFF500FAFF00FAFF00EBFF00DCFF00
CCFF00FF006B70FF0000F0FF00FF75FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000028FF
23FF0033FF00BDFF00FAFF00FFF500FFF500FFF500EBFF00FFE600FFD700FFD700FFD700
FFC700FFC700FFD700FFD700FFF500EBFF00CCFF00DCFF00FFA800FF9900FF8A00FF8A00
FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FFA800FFA800FFA800FFB800
FFC700FFD700EBFF00FAFF00FFD700FFC700FFB800FFA800FFA800FFA800FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800
FFA800FFB800FFC700FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800
FFB800FFB800FFC700FFC700FFC700FFD700FFE600FFE600FFF500FAFF00FAFF00EBFF00
CCFF00AEFF008FFF0051FF0005FF0000FFD1FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
80FF00BDFF00EBFF00FFF500FFE600FFE600FFE600FFD700FFD700FFC700FFC700FFC700
FFC700FFC700FFC700FFD700FFE60080FF00FFF500FFD700FFA800FF9900FF8A00FF8A00
FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FFA800FFA800FFB800
FFC700FFD700EBFF00FAFF00FFD700FFC700FFB800FFA800FFA800FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800
FFB800FFB800FFB800FFC700FFC700FFD700FFD700FFE600FFF500FAFF00FAFF00DCFF00
BDFF009EFF0000FFC2CC00FFFF000000D1FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFF0FF0000
51FF00BDFF00EBFF00FFF500FFE600FFD700FFD700FFC700FFC700FFC700FFB800FFC700
FFB800FFB800FFC700FFC700FFD70000FF28DCFF00FFB800FF9900FF9900FF8A00FF8A00
FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF6B00FF6B00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FFA800FFB800FFC700
FFD7009EFF00EBFF00DCFF00FFF500FFC700FFB800FFA800FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF8A00FF9900FF8A00FF8A00FF9900FF8A00FF9900FF8A00
FF8A00FF9900FF8A00FF9900FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FFA800FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFB800
FFB800FFB800FFB800FFC700FFC700FFD700FFD700FFE600FFF500FFF500FAFF00BDFF00
FF0000000AFFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00008FFF0023FF00FFF500FFE600FFD700FFD700FFC700FFC700FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFD700EBFF00FFF500FFA800FF9900FF8A00FF8A00FF8A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FFA800FFA800FFB800FFD700
FFE600DCFF00FFE600FFD700EBFF00FFD700FFB800FFA800FF9900FF9900FF9900FF9900
FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFB800FFB800FFB800FFC700FFC700FFC700FFD700FFE600FFE600FFF500EBFF0070FF00
FF00000038FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
00FF9433FF0042FF00FAFF00FFE600FFC700FFC700FFC700FFB800FFB800FFB800FFB800
FFA800FFB800FFB800FFB800FFE60000FF0AFFB800FF9900FF9900FF8A00FF8A00FF8A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF8A00FF7A00FF7A00FF8A00FF8A00FF8A00FF9900FF9900FFA800FFC700FFD700EBFF00
8FFF0061FF00FFC700FFC700FFD700FFE600FFA800FFA800FF9900FF9900FF9900FF9900
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF9900
FF9900FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FFA800FF9900FFA800FFA800FFA800FFA800FFA800
FFB800FFB800FFB800FFB800FFC700FFC700FFD700FFE600FFF500FAFF00EBFF008FFF00
00D1FF00FFB3FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF000000FF4700FF4700FF38FFD700FFC700FFC700FFB800FFB800FFB800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900FF8A00FF8A00FF8A00FF8A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF9900FFA800FFC700AEFF00FFD700
FFC700FFC700FFB800FFA800FFB800FFA800FFA800FF9900FF9900FF9900FF9900FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900
FF8A00FF9900FF9900FF8A00FF9900FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF9900
FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800
FFA800FFB800FFB800FFB800FFC700FFD700FFD700FFE600FAFF00EBFF00DCFF00EB00FF
00FF4700FF47FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFE1
00F0FF8000FF00FFFFDCFF00FFE600FFC700FFC700FFB800FFB800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF9900FFA800FFB800AEFF00FFC700
FFB800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF8A00FF9900FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900
FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFB800
FFA800FFB800FFB800FFB800FFC700FFC700FFD700FFF50000D1FFCC00FFBDFF008FFF00
51FF000066FFFF0000FF0000FF0000FF0000FF0000FF0000FF00000075FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000051FF000038FFFF0000
05FF000500FF0075FF23FF00FFD700FFC700FFB800FFB800FFB800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF9900FFA800FFC700EBFF00FFB800
FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800
FFA800FFB800FFB800FFB800FFC700FFD700FFE600FAFF0033FF0000FF198FFF008FFF00
00FF750085FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00F5FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000005FF009EFF00AEFF009EFF00
000AFF61FF009EFF00FFF500FFD700FFC700FFB800FFB800FFA800FFA800FFA800FFA800
FFA800FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF9900FFA800FFE600FFC700FFA800
FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800
FFA800FFB800FFB800FFC700FFC700FFE600FFF500EBFF009EFF00FF000061FF000038FF
0047FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF66FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF2861FF00DCFF00BDFF00
FF00E6BDFF0014FF00FFE600FFC700FFB800FFB800FFB800FFA800FFA800FFA800FFA800
FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FFA800FFA800FFA800FF9900
FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800
FFA800FFA800FFB800FFB800FFC70061FF000057FFBDFF00AEFF0000FF6614FF0023FF00
00FFA3FF0000FF0000FF004CFF0000FF0000FF0000FF00008000FF05FF000028FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFF09EFF00EBFF00FAFF00
FAFF00EBFF0000FF38FFD700FFC700FFB800FFB800FFA800FFA800FFA800FFA800FF9900
FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF9900FF9900FF9900FF9900
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800
FFA800FFA800FFB800FFC700FFC700FFF50023FF00FF000070FF0000FF2800FF3800FFD1
FF0000FF0099FF000000C2FFFF00F5FF0000FF0000FF0000FF000000FF0A42FF0000FF57
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF000000FF6600FF66EB00FF51FF00FAFF00FFF500
FFF500FFF500FAFF00FFC700FFB800FFB800FFB800FFA800FFA800FFA800FF9900FF9900
FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF8A00FF8A00FF8A00FF7A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FF9900FF9900FFA800
FFA800FFA800FFB800FFB800FFC700FFF500CCFF0080FF0000FF5700FF1900FF94FF0000
0028FF00FF47FF000000FF38FF0000FF001EFF000000FF280057FF80FF0061FF00FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF000061FF0000FF19CCFF00FAFF00FFE600
FFE600FFD700FFD700FFC700FFB800FFB800FFA800FFA800FFA800FFA800FF9900FF9900
FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00
FF7A00FF8A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00
FF8A00FF7A00FF7A00FF7A00FF8A00FF8A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF9900FF8A00FF8A00
FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800
FFA800FFA800FFB800FFB800FFD700FFE600EBFF00BDFF0070FF0000FF38FF00D700FF57
14FF0000FF28FF000014FF0023FF0000FFB3FF000014FF0080FF009EFF0080FF00FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF004CFF0000AEFF00AEFF00EBFF00FFF500FFE600
FFD700FFD700FFC700FFC700FFB800FFB800FFA800FFA800FFA800FF9900FF9900FF9900
FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF8A00FF7A00FF7A00FF8A00FF7A00
FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00
FF8A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF9900FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800
FFA800FFA800FFB800FFC700FFD70080FF00DCFF0000FF5700FF3814FF0000FFC25100FF
00FF0A61FF0080FF008FFF0000FF75FF0000FF000000FF190028FFBDFF00AEFF0070FF00
42FF0000FF28FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF000000FF389EFF00CCFF00EBFF00FAFF00FFE600FFE600
FFD700FFC700FFC700FFB800FFB800FFB800FFA800FFA800FFA800FF9900FF9900FF9900
FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF8A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF8A00FF7A00FF8A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00
FF8A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00
FF8A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800
FFA800FFA800FFB800FFC700BDFF0000FF3800FF1933FF00BDFF0000F0FF0085FF33FF00
FF000061FF009EFF00AEFF00AEFF0042FF0070FF00BDFF00CCFF00CCFF00BDFF008FFF00
51FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF000000A3FFFA00FF8FFF00BDFF00DCFF00EBFF00FFF500FFE600FFE600
FFD700FFC700FFC700FFB800FFB800FFA800FFA800FFA800FFA800FF9900FF9900FF9900
FF9900FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF8A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF8A00FF8A00FF7A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FFA800FFA800FFB800FFC70080FF0061FF00BDFF00FAFF00EBFF00AEFF0000B3FF8FFF00
00C2FF33FF0070FF00CCFF00DCFF00CCFF00DCFF00EBFF00EBFF00DCFF00CCFF00FF0000
05FF00FF0099FF0000FF00008000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF000000FF2870FF009EFF00BDFF00DCFF00EBFF00FAFF00FFE600FFE600
FFD700FFC700FFC700FFB800FFB800FFA800FFA800FFA800FF9900FF9900FF9900FF9900
FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00
FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00
FF8A00FF8A00FF8A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900
FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FFA800FFA800FFB800FFD700FFE60000FFF0FFE600FFE600FAFF0042FF00CCFF00
80FF00FF000080FF00CCFF00EBFF00EBFF00FAFF00FAFF00FAFF00EBFF00CCFF0000FF19
00FFB3FF0000FF0000FF000000F0FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF000000FF2842FF0070FF008FFF00AEFF00BDFF00DCFF00FAFF00FFF500FFE600
FFD700FFC700FFC700FFC700FFB800FFA800FFA800FFA800FFA800FF9900FF9900FF9900
FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00
FF7A00FF8A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900
FFA800FFA800FFA800FFA800FFB800FFC700FFD700FFC700FFD700FFE600FAFF00FAFF00
CCFF0051FF005100FFDCFF00EBFF00FAFF00FFF500FFF500FAFF00FAFF0070FF0000FF0A
FF0000FF00B86100FFFF000000FF0AFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF000000FF94FF000000FFB300FF660047FF00FF2800FF47BDFF0000FF19DCFF00FFF500
FFE600FFD700FFC700FFB800FFB800FFB800FFA800FFA800FF9900FF9900FF9900FF9900
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF7A00FF7A00FF7A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FFA800FFA800FFA800FFB800FFB800FFB800FFC700FFC700FFC700FFD700FFE600
05FF0023FF008FFF00CCFF00FAFF00FFF500FFF500FFF500FFF500FAFF00DCFF00FF0000
FF00007000FF0066FF42FF0051FF0000FF57FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0028FFFF0000FF0000FF0000FF0000CC00FFFF000005FF0000FFA300FFFF80FF00DCFF00
FFE600FFD700FFD700FFC700FFB800FFB800FFA800FFA800FF9900FF9900FF9900FF9900
FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF7A00FF7A00FF7A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900
FF9900FF9900FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFC700FFC700FFE600
8FFF0000FF6600FF8561FF00FAFF00FFE600FFE600FFE600FFE600FFF500CCFF0061FF00
000AFF00FFD1FA00FF80FF0070FF00FF0000FF00000075FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000500FF00FF380057FFDCFF00
FAFF00FAFF00FFE600FFC700FFB800FFB800FFA800FFA800FFA800FF9900FF9900FF9900
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF8A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00
FF8A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFC700FFD700
00FF94EBFF00FAFF00DCFF00FFE600FFE600FFE600FFE600FFE600FFE600FAFF00EBFF00
CCFF0000FFC29EFF00BDFF008FFF00FF0000FF00F500FF28FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000075FF33FF008FFF00CCFF00
DCFF0000FFB3FAFF00FFD700FFC700FFB800FFA800FFA800FF9900FF9900FF9900FF9900
FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00
FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFC700
FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFE600FFD700FFE600FFE600FFF500
FAFF00BDFF00CCFF00CCFF00BDFF00CC00FF00B3FF42FF00FF000000E1FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFB300FF570057FF
9EFF0070FF00BDFF0014FF00FFD700FFB800FFB800FFA800FF9900FF9900FF9900FF9900
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFB800FFB800
FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFD700FFD700FFD700FFE600FFF500
FFF500FAFF00EBFF00DCFF00CCFF00BDFF008FFF0080FF00FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000094FFFF0000FF004C
1400FF00FFC270FF00DCFF00FFD700FFB800FFB800FFA800FFA800FF9900FF9900FF9900
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF6B00
FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900
FF9900FF9900FF9900FF9900FFA800FF9900FFA800FFA800FFA800FFA800FFB800FFB800
FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFD700FFD700FFD700FFE600FFE600
FFF500FAFF00FAFF00EBFF00DCFF00BDFF009EFF008FFF0061FF0033FF0000FF19FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFC2
42FF00FF008A61FF00DCFF00FFE600FFC700FFB800FFA800FFA800FF9900FF9900FF9900
FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF8A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800
FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFD700FFD700FFD700FFE600
FFF500FFF500FAFF00EBFF00DCFF00BDFF009EFF0070FF0051FF005100FFFF000000FF94
00E1FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFFFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000057FF00FFFF
8FFF00FF000000FF5700FF2861FF00FFE600FFB800FFA800FFA800FFA800FF9900FF9900
FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00
FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF6B00FF6B00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800
FFA800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFD700FFD700FFD700FFE600
FFE600FFF500FAFF00EBFF00BDFF0042FF0080FF00FF00C7FF00003300FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000075FF00FF66FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFA300FFA3
AEFF0070FF00AEFF0061FF00DCFF00EBFF00FFB800FFA800FFA800FF9900FF9900FF9900
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00
FF7A00FF7A00FF7A00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800
FFA800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFD700FFD700FFE600
FFF500FFF500FAFF00DCFF0000FF1900FF5700FF9400FFA3FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF000005FF0000FF66FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000042FF00
BDFF00DCFF00EBFF00FAFF00FFE600FFD700FFB800FFB800FFA800FF9900FF9900FF9900
FF9900FF9900FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00
FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FFA800FF9900FFA800FFA800FFA800
FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFD700FFD700FFE600
FFF500FAFF00EBFF00CCFF00FF0000FF0000FF00008F00FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000057FF42FF000047FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00004200FF00FF57
AEFF00EBFF00FAFF00FFE600FFD700FFC700FFB800FFB800FFA800FFA800FFA800FF9900
FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800
FFA800FFA800FFA800FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFD700FFE600
FAFF00AEFF00CCFF00BDFF0000FF8500FF572300FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00B8FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF000000FF2861FF0061FF00FF005CFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFC261FF00
8FFF00EBFF00FFF500FFE600FFD700FFC700FFC700FFB800FFB800FFA800FFA800FF9900
FF9900FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF9900FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800
FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFC700FFC700FFD700FFD700FFF500
EBFF0000FF2851FF008FFF0051FF0000FF19FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF000000B3FFFF00008FFF0080FF000028FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF1961FF00
AEFF0000FF19FAFF00FFE600FFD700FFC700FFC700FFB800FFB800FFA800FFA800FF9900
FF9900FF9900FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00
FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFC700FFC700FFD700FFE6000057FF
CCFF0000D1FF51FF00FF00F500FF85FF008AFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF000014FF008FFF00AEFF009EFF000038FF0028FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000028FFFF00E62300FF
61FF0000FFA333FF00FFF500FFE600FFD700FFC700FFC700FFC700FFB800FFA800FF9900
FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00
FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800
FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFC700FFD700FFE60000FF85
00FF5700FFA300FF47FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF47FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
00FFC2FF00001400FF05FF00BDFF00BDFF00AEFF0061FF00FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
00A3FF00FFC28FFF00CCFF00FFE600FFE600FFD700FFE600FFE600FFE600FFC700FFA800
FF9900FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF6B00
FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF8A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFC700FFC700FFD700FAFF00
61FF0000FF6600FFE1FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0AFF00A8FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFA3
05FF0000FF85FF000005FF00CCFF00DCFF00BDFF0000FF6600FF750047FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
00FF1970FF0000FFE1DCFF00FFF500FFF500FFF5009EFF00BDFF0080FF00FFD700FFA800
FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFC700FFC700FFD700FFF500
00C2FF00E1FFCC00FF33FF00EB00FF0066FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000042FF00FF00000075FF0019FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
61FF00FF000000FFC2CCFF00DCFF00EBFF00DCFF0061FF0005FF00FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000066FFFF0000FF0000FF0000FF0000
00FF3880FF00BDFF00EBFF00FAFF00FAFF00EBFF0005FF00DCFF00DCFF00DCFF00FFB800
FF9900FF9900FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFC700FFD700FFD700FFF500
DCFF0005FF000028FF61FF0033FF0000FF94FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00D700FF1970FF0061FF0014FF008F00FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000B3FFFF0000FF00000085FF
61FF00BDFF00DCFF00EBFF00FAFF00FAFF00EBFF00CCFF008FFF00FF0000FF0099FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF38FF0000FF0000FF0000FF0000
00FF9461FF009EFF00DCFF00EBFF00EBFF00CCFF0014FF00FFF500FFD700FFD700FFA800
FF9900FF9900FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF6B00FF6B00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900
FF9900FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFC700FFC700FFD700FFF500
00FFB361FF0061FF008FFF000028FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFA380FF008FFF00FF00D7FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF28FF0000FF0000FF0000
FF0000AEFF00EBFF00FAFF00FAFF00FAFF00FAFF00CCFF0080FF000028FF14FF0000FF85
00FF75FF0000FF0000FF000000FFFF6100FF00FF1942FF000047FFFF000000FFF000A3FF
00FF6600FF2800FF8551FF00CCFF009EFF0000FF5751FF00FFE600FFC700FFB800FFA800
FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FFA800FFA800FFA800FFB800FFB800FFB800FFC700FFD700FFD700FFF500
00E1FFCCFF00BDFF00AEFF0051FF0000FF38FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF000000FF9400C2FF9EFF00AEFF000075FFFF00A8
DC00FF00FF38FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000042FF00CC00FFFF0000FF0000
00FFD1FF0000FAFF00FFF500FFF500FFF500FAFF00FF008A00FFC20057FF00FF4770FF00
00FFE1FF0000FF000000FF4714FF00FF000023FF0080FF0033FF0000FF1900FF5700FF19
61FF0000FFB300FF388FFF00AEFF0000FF669EFF00EBFF00FFE600FFC700FFB800FFA800
FF9900FF9900FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF9900FF9900FF9900FF9900
FF9900FFA800FFA800FFA800FFA800FFB800FFB800FFC700FFC700FFD700FFD700FFE600
FAFF00EBFF00CCFF00AEFF0070FF0023FF0000FF85FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF009970FF00AEFF00BDFF00BDFF00AEFF00
80FF0000FF75FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00003300FF8FFF0061FF0000FFB3FF0000
000AFFCCFF00FFF500FFF500FFE600FFE600FFF500FAFF00EBFF0000FF9423FF00AEFF00
4200FFFF000000FFD100FFC280FF0000FFE19EFF00AEFF008FFF0033FF0051FF009EFF00
8FFF0000FF1970FF000057FF61FF008FFF00DCFF00FFF500FFD700FFC700FFB800FFA800
FF9900FF9900FF9900FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900
FF9900FF9900FFA800FFA800FFB800FFB800FFB800FFC700FFD700FFD700FFE600FFF500
FFF500EBFF00CCFF009E00FF42FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000057FFFA00FFBDFF00CCFF00CCFF00BDFF00
70FF000075FFFF0000FF00F5FF000000FF47FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00002300FF00FFA305FF0051FF0061FF009EFF00BDFF00DC00FF14FF0000FF75
00FF0A00D1FFFFF500FFE600FFE600FFE600FFE600FFF500FFF500FAFF00DCFF00BDFF00
00FF4700F0FF00FFF042FF009EFF00BDFF00DCFF00CCFF0061FF0061FF0070FF00BDFF00
CCFF00CCFF00AEFF0080FF0000FF0A8FFF00DCFF00FAFF00FFE600FFC700FFB800FFA800
FFA800FF9900FF9900FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF7A00FF7A00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900
FF9900FF9900FFA800FFA800FFB800FFB800FFC700FFD700FFD700FFE600FFE600FFF500
FAFF00EBFF00AEFF0014FF0000FF1900C2FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000066FF00FF191400FF70FF00CCFF00DCFF00DCFF00BDFF00
FF00E60094FFFF002E00FF8523FF000075FFFF000000FF6600E1FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00E633FF009EFF00CCFF00DCFF00AEFF00CCFF0061FF00
DCFF00FFF500FFE600FFD700FFD700FFD700FFD700FFE600FFE600FFF500FAFF00DCFF00
00FFFF0085FF05FF0080FF00BDFF00DCFF00EBFF00EBFF0000FF19DCFF00DCFF00EBFF00
EBFF00DCFF00CCFF0070FF009EFF0061FF0042FF00BDFF00AEFF00FFF500FFD700FFC700
FFA800FF9900FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900
FF9900FF9900FFA800FFA800FFB800FFC700FFD700FFF500FFF500FFF500FFF500FAFF00
FAFF00EBFF00CCFF0000FFA300FF660500FFFF0000FF0000FF0000FF0000FF003DAE00FF
FF0000FF0000FF0000FF0000FF000042FF0005FF0000FF85DCFF00EBFF00EBFF00DCFF00
AEFF00FF0000FF000000FF94FF000080FF00FF000033FF0000FF38000AFFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000047FF80FF00CCFF00EBFF00FAFF00FAFF00AEFF00
FFF500FFE600FFD700FFD700FFD700FFD700FFD700FFD700FFE600FFE600FAFF00DCFF00
BDFF0070FF0000FF3800FFE180FF00DCFF00FAFF00FFF500FFF500FFF500FFF500FFF500
FAFF00EBFF00CCFF0000FF38BDFF00DCFF009EFF00AEFF0000FF1970FF00EBFF00BDFF00
FFB800FF9900FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900
FF9900FF9900FFA800FFA800FFB800FFF500FAFF00DCFF00DCFF00EBFF0005FF00EBFF00
EBFF00DCFF00AEFF0000FFA323FF0000FFA3FF0000FF0000FF0000FF000000FF4700FF57
FF000000FF478F00FFFF000000B3FF80FF00AEFF00DCFF00EBFF00FAFF00FAFF00EBFF00
80FF0070FF0014FF009EFF00AEFF00AEFF0080FF0000FF280066FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000047FF00FF66FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00C7CCFF00EBFF00FFF500FFF500FFF500
FFE600FFD700FFD700FFC700FFC700FFC700FFC700FFD700FFD700FFE600EBFF00BDFF00
8FFF0042FF0000FF8570FF0000FFE1DCFF00FFF500FFE600FFE600FFE600FFE600FFF500
FAFF00EBFF00BDFF0000FF75CCFF00FAFF00FFF500EBFF00EBFF00FAFF00FAFF00BDFF00
FFF500FF9900FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900
FF9900FF9900FFA800FFA800FFB800FFC700DCFF008FFF0061FF0000FF198FFF00BDFF00
DCFF00DCFF00BDFF008FFF0051FF0000FFC2FF0000FF0000FF000000FFF023FF00FF0000
AE00FF33FF000019FF00A3FF00FF198FFF00BDFF00EBFF00FAFF00FFF500FFF500FAFF00
EBFF00EBFF00AEFF00CCFF00CCFF00BDFF0000FFF0FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF28FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00009EFF00FAFF00FFF500FFE600FFD700
FFD700FFD700FFC700FFC700FFC700FFC700FFC700FFC700FFD700FFE600EBFF0000FF28
23FF009EFF00AEFF00AEFF00CCFF0070FF00FFE600FFD700FFD700FFD700FFE600FFE600
FFF500EBFF0000FFC200FFB351FF00FFF500FFE600FFF500FFD700FFD700FFD700AEFF00
FFB800FF9900FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF9900FF9900
FF9900FF9900FFA800FFA800FFB800FFC700FFE60051FF009EFF008FFF00FF000080FF00
BDFF00BDFF00AEFF008FFF0000FF5700FFA300FFF000FF753300FF00FF0A61FF0080FF00
8FFF0070FF0033FF0000FF4700FFB370FF0000FF28EBFF00FFF500FFF500FFF500FFF500
FFF500FAFF00FAFF00EBFF00DCFF00BDFF00FF005CFF0000FF0000FF0000FF0000FF0000
FF0000FF000000FF19FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF000FFF000000D1FF61FF0000FFE1FF0000
FF0000FF0000FF0000FF0000FF000000FF3800FFA300F0FFFAFF00FFF500FFE600FFD700
FFD700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFE600CCFF0000FF85
EBFF00FFF50061FF00EBFF00FFE600FFE600FFD700FFD700FFD700FFD700FFD700FFE600
FFE600FAFF0051FF0070FF0070FF00FFE600FFD700FFC700FFC700FFC700FFC700FFD700
FFD700FF9900FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00
FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00
FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900
FF9900FF9900FF9900FFA800FFB800FFB800FFD70080FF00DCFF00BDFF0000FF0A70FF00
70FF008FFF009EFF0070FF0000FFFF0047FF14FF0033FF0000FF2800FFE10094FFAEFF00
AEFF0070FF00FF0000FF000000FF195100FF00FF66DCFF00FFF500FFE600FFE600FFE600
FFE600FFF500FFF500FAFF00EBFF00BDFF008000FF00FFF0FF0000FF0000FF0000FF0000
FF0000FF000014FF0033FF002300FF8F00FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF000000E1FF00FF3800FFE1FF00000019FF8FFF0042FF0000FFB3
FF0000FF0000FF0000FF00000075FF23FF0000FFC2CCFF00EBFF00FFF500FFE600FFD700
FFC700FFC700FFC700FFC700FFB800FFB800FFB800FFC700FFC700FFD70000FF0AAEFF00
FFE600FFD700CCFF00FFE600FFD700FFC700FFC700FFC700FFC700FFD700FFD700FFD700
FFE600FFF500DCFF0042FF00DCFF00FFE600FFC700FFB800FFB800FFB800FFB800FFC700
FFA800FF9900FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900
FF9900FF9900FF9900FFA800FFA800FFB800FFD70033FF00FFF500EBFF0000D1FF33FF00
00FF190066FF80FF0051FF0000FF85FF000000D1FF70FF000066FF42FF00BDFF00CCFF00
BDFF0000A3FF33FF0000FF3833FF00DCFF00DCFF00FFF500FFE600FFE600FFE600FFE600
FFE600FFE600FFF500FAFF00EBFF00CCFF0000F0FF1400FFBD00FFFF0000FF0000FF0000
FF000000FFC251FF0061FF00FF00C7FF000014FF007000FFFF0000FF0000FF00A8FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000066FF80FF0000FF38AEFF00BDFF0070FF00FF000F
FF0000FF0000FF0000FF0000FF000000A3FF9EFF00BDFF00DCFF00EBFF00FFD700FFC700
FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFD700
FFE600FFF500EBFF00AEFF00AEFF00FFE600FFC700FFB800FFB800FFA800FFA800FFA800
FF9900FF9900FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900
FF9900FF9900FF9900FFA800FFA800FFB800FFC700FFD700FFE600FFF500EBFF009EFF00
000AFF00FFA300FF0A23FF0000FF570085FF8FFF009EFF009EFF0005FF00DCFF00EBFF00
CCFF0061FF009EFF0000FF85BDFF00FAFF00FFF500FFE600FFD700FFD700FFD700FFD700
FFE600FFE600FFF500FAFF00DCFF00BDFF008FFF0042FF0000FFB3FF0000FF00008000FF
FF0000FF00000500FF9EFF008FFF0070FF00CC00FFFF0000FF0000FF0000FF000000FF75
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
00FF0AFA00FFFF0000FF0000FF0000FF00009EFF00BDFF00CCFF00CCFF0042FF000094FF
00FF8500FF284200FFFF0000EB00FFFF004C80FF0042FF0033FF0000A3FFFFE600FFC700
FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFD700
FFE600FAFF0061FF0023FF00DCFF00FFE600FFB800FFB800FFA800FFA800FF9900FF9900
FF9900FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900
FF9900FF9900FF9900FFA800FFA800FFB800FFB800FFC700FFE600FFE600FAFF00DCFF00
BDFF0080FF0000FF3800FFA342FF0080FF009EFF00BDFF00CCFF00DCFF00EBFF00FAFF00
EBFF00AEFF00EBFF00AEFF00CCFF00FFE600FFD700FFD700FFD700FFD700FFD700FFD700
FFD700FFE600FFE600EBFF0051FF008FFF0080FF0051FF000028FFFF0000FF000000FF57
FF00F5FF0000FF0000BDFF00BDFF009EFF0033FF0000B3FFFF0000FF0000FF000023FF00
FF0000FF0000FF0000FF000000A3FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF007AFF002E00FFB3FF0000FF0000FF0000FF0000
51FF00FF0000FF0000FF000000FFC200FF199EFF00CCFF00EBFF00EBFF0000FFE100FFA3
FF000061FF0000C2FF00FF94FF00C714FF0014FF0000FF5770FF0070FF00FFD700FFC700
FFB800FFB800FFB800FFB800FFB800FFB800FFA800FFA800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFD700
FAFF00DCFF0033FF0000FF38FAFF00FFD700FFB800FFA800FFA800FF9900FF9900FF9900
FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF8A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00
FF9900FF9900FF9900FFA800FFA800FFB800FFC700FFC700FFD700FFE600FAFF00DCFF00
AEFF0000FF0A0066FF00FF3800FFFF70FF009EFF00BDFF00DCFF00EBFF00FAFF00FAFF00
FFF500FFF500FFF500FAFF00FFF500FFD700FFD700FFD700FFC700FFC700FFC700FFD700
FFD700FFD700FFE600CCFF0000FF190066FF00FF8533FF0000FF38FF000000FFFF0019FF
00FF0A61FF00CCFF00CCFF00CCFF0000FFD142FF0000FF28FF0000FF0000FF000070FF00
51FF00FF0000FF0000FF000000FF0A00FF75FF000000C2FF000AFFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000028FFFF0000FF0000FF0000FF000000FF0A8000FFFF007AFF00005100FF70FF00
8FFF0000FF6600FFB3FF0000EB00FF00FF8533FF00DCFF00FAFF00FAFF00EBFF00DCFF00
8FFF009EFF0070FF0023FF000085FF00FF38FF009970FF00DCFF00FAFF00FFD700FFC700
FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFB800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFD700
FAFF0014FF0000FF19FF0000AEFF00FFD700FFB800FFA800FFA800FF9900FF9900FF8A00
FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF7A00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900
FF9900FF9900FF9900FFA800FFA800FFB800FFB800FFC700FFD700FFF500EBFF00CCFF00
42FF0014FF0070FF0005FF00FF002E14FF0023FF00BDFF00DCFF00EBFF00FFF500FFF500
FFE600FFE600FFE600FFE600FFD700FFD700FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFD700FFE600CCFF0000FF6670FF0000F0FFFF000000FF751400FF00FF2861FF00
9EFF00CCFF00DCFF00EBFF00DCFF0014FF000075FFFF002EFF0000FF000033FF009EFF00
1400FFFF00000066FF00FFFF51FF00FF0000FF000000FF194200FFCC00FFFF00003300FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000EB00FFFF003DFF0000FF0000FF0000
FF0000FF0000FF0000AE00FF3300FFFF0000FF0000FF00C7FF0000FF0000BD00FFFF0000
FF000000FF28FF00006100FFFF00002300FFFF000051FF0000FFF000B3FF8000FF00D1FF
BDFF0070FF0000FF19FF000000FFC20500FF00E1FFEBFF00FFF500FFF500FFF500FAFF00
DCFF00AEFF0070FF0000FF0A00FF4700F0FF00FFB300FF94FFF500FFD700FFC700FFB800
FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFC700
FFE600FAFF0042FF0000FF28FAFF00FFD700FFB800FFA800FF9900FF9900FF9900FF8A00
FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF9900FF9900FF9900FFA800FFA800FFB800FFC700FFD700FFE600EBFF0080FF0042FF00
00FF57AEFF008FFF0000D1FF9EFF0000FFA300FFF09EFF00CCFF00EBFF00FFF500FFE600
FFE600FFD700FFD700FFD700FFD700FFC700FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFD700FFE60070FF00CCFF0070FF0000D1FF00FFE100FF853300FF0028FF
80FF00CCFF00FAFF00FAFF00EBFF000500FF80FF0000FF753300FF8000FF00A3FFBDFF00
23FF00FF0000FF0000FF00008FFF0080FF00FF000000FF0A70FF0000FF8561FF0000C2FF
33FF0014FF0000FF0A00FF3800FF94FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000075FF00FF9400FF3800FF0A14FF0005FF0051FF00
51FF0000FF1900FF858FFF000066FF00FFA3AEFF0080FF00FF0000FF00009EFF00CCFF00
DCFF0014FF00FF003DFF0000FF000000FF85DCFF00FFF500FFE600FFE600FFF500FAFF00
CCFF000038FF00FFFF9E00FF00FF1900FF9400FF19BDFF00FFF500FFD700FFC700FFB800
FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800
FFC700FFE600BDFF00DCFF00FFF500FFD700FFB800FFA800FF9900FF9900FF8A00FF8A00
FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900
FF9900FF9900FF9900FFA800FFA800FFC700FFD700FFE600FAFF0000FF1933FF0000FFC2
DCFF00EBFF008FFF008FFF00CCFF00BDFF000047FF8FFF009EFF00BDFF00FAFF00FFE600
FFD700FFD700FFC700FFC700FFC700FFC700FFC700FFB800FFB800FFB800FFB800FFC700
FFC700FFC700FFD700FFD700FFF500CCFF0000FF4700FFFFFF000000FFA300FF6600FF28
00FFD1BDFF00FAFF00FFF500FAFF00FAFF00CCFF00FF0000FF000000FF85FF0000DCFF00
DCFF00AEFF00FF0000FF0000BDFF00BDFF009EFF009EFF009EFF008FFF0080FF0070FF00
51FF0033FF0000FF19FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0A33FF0051FF0070FF00
8FFF008FFF00AEFF00AEFF000094FFBDFF00CCFF009EFF0014FF00FF002EDCFF00EBFF00
EBFF00AEFF00FF001E00FF6600FF948FFF00FFF500FFE600FFE600FFE600FFE600FFF500
AEFF0000FFA361FF0061FF0014FF0042FF008FFF00FF000000FF19FFC700FFB800FFB800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900FF9900FFA800FF9900FF9900
FF9900FFA800FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800
FFC700FFE600BDFF0061FF00FFF500FFE600FFC700FFA800FF9900FF9900FF8A00FF8A00
FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF9900FF9900FF9900FFA800FFB8009EFF00FFF500FAFF0000FFC200FF19CCFF00FAFF00
FAFF00FAFF0070FF008FFF00EBFF00DCFF0000FF3805FF0000FF47AEFF00FAFF00FFE600
FFD700FFC700FFC700FFC700FFB800FFB800FFC700FFB800FFB800FFB800FFB800FFB800
FFB800FFC700FFC700FFD700FFE600FAFF00AEFF00FF008A00FFA300D1FF42FF009EFF00
BDFF00FAFF00FFF500FFE600FFF500FFF500CCFF0000FF3800FF0A23FF00CCFF00EBFF00
EBFF00DCFF00DCFF00CCFF00DCFF00DCFF00CCFF00BDFF00BDFF009EFF008FFF0070FF00
42FF0000FF19FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF7551FF0080FF00
9EFF00AEFF00BDFF00CCFF00CCFF00DCFF00DCFF00DCFF0000FF0AEBFF00FAFF00FAFF00
FAFF00DCFF0061FF0000FF0A8FFF0000FF94FFE600FFD700FFD700FFD700FFD700FFE600
00FF6623FF00BDFF00BDFF0005FF00BDFF0061FF00DCFF008FFF00FFC700FFB800FFA800
FFA800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFB800
FFB800FFC700FFF500CCFF00DCFF00EBFF00CCFF00FFB800FF9900FF9900FF8A00FF8A00
FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900
FF9900FF9900FF9900FFA800FFB800EBFF0014FF00DCFF009EFF00EBFF00FAFF00FFE600
FFE600FFF5008FFF0080FF00FFF500FFF5009EFF00AEFF0000FF2851FF0061FF00FFE600
FFD700FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFC700FFC700FFC700FFE60023FF000075FF8FFF0000FF2861FF0023FF00AEFF00
FAFF00FFF500FFE600FFE600FFE600FFE600DCFF0000FFE1FAFF00CCFF00FAFF00FAFF00
FAFF00FAFF00EBFF00EBFF00EBFF00DCFF00DCFF00CCFF00BDFF009EFF008FFF0061FF00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF1900FF28
9EFF00AEFF00CCFF00DCFF00DCFF00EBFF00EBFF00FAFF00FAFF00FAFF00FFF500FFF500
FFF500FAFF00CCFF00FF0000FFF500FFE600FFD700FFD700FFD700FFD700FFD700FFD700
FFE600FFF500FAFF00CCFF000094FFFAFF00FFE600FFE600FFE600FFB800FFA800FFA800
FFA800FFA800FF9900FFA800FF9900FF9900FF9900FF9900FF9900FFA800FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800
FFB800FFC700FFD700FFF500AEFF00EBFF00FFD700FFA800FF9900FF9900FF8A00FF8A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF9900FF9900FFA800FFC700FFE600DCFF0042FF00EBFF00FFE600FFE600FFD700
FFD700FFE60070FF00CCFF00FFE600FFE600FFF500EBFF00BDFF0051FF00DCFF00FFE600
FFD700FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFC700FFC700FFE60080FF0080FF00EBFF0000FF57FAFF0080FF0000FF85
FAFF00FFE600FFE600FFD700FFD700FFE600FFE600FFE600FFF500FFF500FFF500FFF500
FFF500FFF500FAFF00FAFF00EBFF00EBFF00DCFF00CCFF00BDFF009EFF0080FF000047FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000085FF
80FF00AEFF00CCFF00DCFF00EBFF00EBFF00FAFF00FAFF00FFF500FFF500FFE600FFE600
FFE600FFE600FAFF00FFF500FFE600FFD700FFD700FFC700FFC700FFC700FFC700FFC700
FFD700FFD700FFF500DCFF0070FF00EBFF00FFD700FFC700FFB800FFB800FFA800FFA800
FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800
FFB800FFC700FFD700FFF50061FF00EBFF00FFD700FFA800FF9900FF8A00FF8A00FF8A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00
FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF6B00
FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF9900FF9900FFA8008FFF0042FF00CCFF00BDFF00EBFF00FFE600FFC700FFC700
FFC700FFC7008FFF00FFD700FFD700FFD700FFD700FFF500DCFF0023FF00EBFF00FFF500
FFD700FFC700FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFB800FFA800FFA800
FFB800FFB800FFB800FFC700FFE600CCFF0000FF38FFE600FFE600FFE600FAFF00BDFF00
FFE600FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFE600FFE600FFE600FFE600
FFF500FFF500FFF500FAFF00FAFF00EBFF00DCFF00CCFF00BDFF0000FFB300C2FF00FFA3
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
00D1FF00C2FFBDFF00DCFF00EBFF00FAFF00FAFF00FFF500FFF500FFE600FFE600FFE600
FFE600FFD700FFD700FFD700FFD700FFC700FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFD700FFE60042FF0000FFA3FAFF00FFC700FFB800FFB800FFA800FFA800FFA800
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800
FFB800FFB800FFD700EBFF00FAFF00FFD7008FFF00FFA800FF9900FF8A00FF8A00FF8A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF9900FF9900FFB800FFE600FFE600FFD700FFE60070FF00FFF500FFC700FFB800
FFB800FFB800FFB800FFB800FFB800FFC700FFD700EBFF0033FF007000FF9EFF009EFF00
FFE600FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFB800FFA800FFA800
FFA800FFB800FFB800FFB800FFC700FFD700FFD700FFD700FFC700FFD700FFD700FFD700
FFD700FFC700FFC700FFC700FFD700FFC700FFD700FFD700FFD700FFD700FFD700FFE600
FFE600FFF500FFF500FAFF00FAFF00EBFF00DCFF00CCFF00AEFF000094FF00FFC2FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0099
00FF6661FF00AEFF00CCFF00EBFF00FAFF00FFF500FFF500FFE600FFE600FFE600FFD700
FFD700FFD700FFD700FFC700FFC700FFC700FFC700FFC700FFC700FFB800FFB800FFB800
FFC700FFC700FFD700DCFF0000FF57FFD700FFB800FFB800FFA800FFA800FFA800FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800
FFB800FFB800FFE60000FF28FFC700FFB800FFF500FFA800FF8A00FF8A00FF8A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF9900FFA800FFA800FFB800FFB800FFB800FFF500FFC700FFB800FFB800
FFA800FFA800FFB800FFB800FFB800FFB800FFC700DCFF00DCFF0070FF00FAFF00DCFF00
FFC700FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFB800FFB800FFC700FFB800FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFD700FFD700FFE600
FFE600FFE600FFF500FFF500FAFF00EBFF00DCFF00000AFF80FF0014FF0000FFD1FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF000000FFFFAEFF00EBFF00FAFF00FFF500FFF500FFE600FFE600FFD700FFD700
FFD700FFC700FFC700FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFC700EBFF00FFC700FFB800FFB800FFA800FFA800FFA800FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00
FF8A00FF9900FF8A00FF9900FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FFA800
FFA800FFC700FAFF00FFE600FFB800FFA800FF9900FF9900FF8A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00
FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF8A00FF8A00FF8A00
FF8A00FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFB800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFC700FAFF00FFF500FFD700FFC700
FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFD700
FFE600FFE600FFF500FFF500FAFF00EBFF00CCFF0000FF380057FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF000000FFC2CC00FF0028FFDCFF00FAFF00FFF500FFE600FFE600FFD700FFD700FFD700
FFC700FFC700FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFA800FFA800FFA800FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF9900FF9900FF9900FF9900FF9900
FFA800FFC700FAFF00FFF500FFA800FF9900FF9900FF8A00FF8A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FFA800FFA800FF9900FF9900
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800DCFF00FFF500FFB800FFB800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFD700FFC700FFD700FFD700
FFD700FFE600FFE600FFF500FAFF00EBFF00BDFF0000FF4700FF389E00FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF000023FF008FFF00CCFF00EBFF00FAFF00FFE600FFE600FFD700FFD700FFC700
FFC700FFC700FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFA800FFB800FFB800
FFB800FFA800FFB800FFA800FFB800FFA800FFA800FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900
FFA8009EFF00FFC700FFD700FF9900FF9900FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFB800FFC700FFB800FFA800FFA800
FFA800FFA800FFA800FFA800FF9900FF9900FFA800FF9900FF9900FF9900FF9900FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFD700FFD700
FFD700FFE600FFF500FAFF00EBFF00DCFF00BDFF0070FF0005FF00FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000038FF2300FF8FFF0005FF00FAFF00FFF500FFE600FFD700FFD700FFC700
FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900
FF9900FFA800FFA800FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800
FFA800FF9900FF9900FFA800FF9900FF9900FFA800FF9900FF9900FF9900FF9900FF9900
FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFD700
FFD700FFE600FFF500FAFF008FFF00AEFF0000FFA3FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF000000FF57FF001EEBFF00FFF500FFE600FFD700FFD700FFC700
FFC700FFB800FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFD700
FFD700FFE600FFE600FAFF0061FF0061FF00FF00B80085FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF000000FF0A00FF9423FF0000FF0AFFF500FFE600FFD700FFC700FFC700
FFC700FFB800FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FF9900FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00
FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FFA800FF9900FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFD700
FFD700FFE600FFE600FAFF00AEFF00DC00FF00FF0A00FF66FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF000023FF0061FF0000FFE1DCFF00FFF500FFE600FFD700FFC700FFC700
FFC700FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FFA800FF9900FF9900FF9900FFA800FF9900FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700
FFD700FFE600FFF500FAFF0000FF0A00FF2833FF0000FF0AFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000000AFF0085FF70FF00BDFF00EBFF00FFF500FFE600FFD700FFD700FFC700
FFC700FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00
FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFC700FFC700FFD700
FFD700FFE600FFF500FAFF00CCFF0080FF0070FF0000FF19FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000075FF00FF57FF00A8BDFF00FAFF00FFF500FFE600FFD700FFC700
FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FF9900FFA800FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF7A00FF8A00FF8A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF8A00FF7A00FF7A00FF8A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF9900
FF8A00FF9900FF8A00FF9900FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800
FFA800FFA800FFA800FFA800FFB800FFA800FFB800FFB800FFB800FFC700FFC700FFD700
FFD700FFE600FFF500FAFF00DCFF00AEFF0051FF0000FF66FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00D780FF00DCFF0061FF00FAFF00FFD700FFC700
FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00
FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900
FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FF9900FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFC700FFC700FFD700
FFE600FFF500FAFF00EBFF009EFF0000A3FF00FF750019FF1400FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF000000D1FF00FF940019FF9EFF000019FFFAFF00FFD700FFC700
FFC700FFB800FFB800FFA800FFA800FFA800FFA800FFA800FF9900FFA800FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF8A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFC700FFE600
FFF50005FF00EBFF00DCFF000057FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF000000FF7533FF0033FF0000FF0A00FFA3FFF500FFD700FFC700
FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF7A00FF6B00FF6B00
FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900
FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFC700FFF500
8FFF000057FFBDFF00AEFF0000FF1900FFFFFF008AFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF000000FF19FF000080FF0023FF0000FF94BDFF00DCFF00FFD700FFC700
FFB800FFB800FFB800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFC700FFD700
51FF009EFF008FFF0000FF190085FF0085FF00F0FF5100FF0057FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00006100FF80FF009EFF0000FF4700FF4714FF008FFF00FAFF00FFC700
FFB800FFB800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF7A00FF7A00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF8A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF9900FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFC700FFD700
FFE60080FF0000FF0A00FFD142FF0061FF0014FF0000FF3800D1FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000EB00FF00FF57BDFF00BDFF0033FF0014FF00EBFF00BDFF00FFC700
FFB800FFB800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF5C00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF8A00FF7A00FF7A00FF8A00FF8A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFC700FFC700
FFD700FAFF00AEFF0000FFB300D1FF8FFF0080FF0033FF0000FF94FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF000014FF00EB00FFCCFF00DCFF00EBFF00FAFF00FFE600FFD700FFC700
FFB800FFB800FFA800FFA800FFA800FF9900FFA800FF9900FF9900FF9900FF9900FF8A00
FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00
FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFC700
FFD700FFF5008FFF0000FFF061FF00AEFF009EFF0051FF00FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF000000FF6642FF008FFF00BDFF00EBFF00FAFF00FFF500FFD700FFC700FFC700
FFB800FFB800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00
FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00
FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFC700
FFD7009EFF00BDFF0061FF00BDFF00CCFF009EFF0000FF2800FF85FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000BD00FFFF000000F0FF05FF00FF00F5DCFF00FFF500FFE600FFD700FFC700FFC700
FFB800FFB800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF8A00FF9900
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00
FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00
FF8A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFC700
FFD700FFE600FAFF00EBFF00EBFF00DCFF00BDFF0033FF0023FF000085FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000BD00FF00FF57CCFF00FAFF00FFF500FFD700FFC700FFC700
FFB800FFB800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF7A00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF6B00FF6B00FF6B00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF8A00
FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFC700
FFC700FFD700FFE600FFF500FAFF00DCFF00AEFF0080FF0005FF0000FF75FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000094FF51FF0005FF0023FF00FFF500FFD700FFD700FFC700
FFB800FFB800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00
FF7A00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900
FF9900FF9900FFA800FF9900FF9900FFA800FFA800FFA800FFA800FFB800FFC700FFC700
FFC700FFD700FFE600FFF500FAFF00DCFF0042FF0000FF1900FFC2FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0500FFFF0000FF0000FF0000FA00FF00FFFF61FF0000FF57FAFF00FFE600FFD700FFC700
FFC700FFB800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900
FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFB800FFB800FFB800FFC700
FFC700FFD700FFE600FFF500FAFF00CCFF0000FF7500F0FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
00FFA3FF0000FF000000E1FF00FF570047FF80FF00CCFF00FAFF00FFF500FFE600FFD700
FFC700FFB800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00
FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900
FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFB800FFB800FFB800FFB800FFC700
FFC700FFD700FFE600FAFF00AEFF00AEFF0070FF000085FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000000AFF
00FF0A00FF57FF000000FFC251FF0000FF3800FF288FFF00EBFF00FAFF00FAFF0023FF00
FFE600FFC700FFA800FFA800FF9900FF9900FF9900FF9900FF8A00FF9900FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF6B00FF6B00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFB800FFB800FFB800FFC700
FFC700FFD700FFE600FAFF0005FF0000FFA300FF0A00FFC2FF0000FF0000FF0000FF0000
0019FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
51FF0051FF0000FFC200FF7580FF0000FF2814FF0080FF00DCFF00DCFF009EFF0080FF00
80FF00FFC700FFA800FFA800FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFB800FFB800FFC700FFC700
FFD700FFD700FFE600FAFF0000D1FF80FF0000FF7500E1FF0057FFFF0000FF000000B3FF
00FF380085FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000023FF00
80FF0000FF3805FF009EFF00BDFF00AEFF0080FF0000FF19BDFF00BDFF0000FF28FAFF00
61FF00EBFF00FFB800FFA800FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFB800FFB800FFC700FFD700
FFD700FFE600FFF500FAFF00DCFF008FFF0000FF5700FF475100FFCC00FF00FF8500FF19
33FF00FF003D0085FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000A3FF00FF47
9EFF00AEFF00AEFF00CCFF00DCFF00BDFF008FFF0000FFF080FF0000A3FF33FF00FFE600
FFD700FFC700FFA800FFA800FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF6B00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00
FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF9900FF9900FF9900FF9900FFA800FFA800FFB800FFB800FFC700FFD700FFE600
FFE600FFE600FFF500FAFF00BDFF0000FF57FF000005FF0070FF000085FF00FFA361FF00
61FF006100FF00FF57FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF57FF004CFF000051FF00
BDFF00DCFF00EBFF00EBFF00EBFF00CCFF000075FF80FF0051FF0080FF00EBFF00FFD700
FFC700FFB800FFA800FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF9900FF9900FF9900FF9900FFA800FFA800FFB800FFB800FFD700EBFF00EBFF00
FFF500FAFF00FAFF00EBFF0070FF0000FF2800FFB333FF00AEFF008FFF0000FFC233FF00
9EFF0070FF0000FF47FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00002300FFFF000000FF4700B3FF00FF0A70FF00
BDFF00EBFF00FAFF00FAFF00EBFF00DCFF0051FF00AEFF00DCFF00FAFF00FFE600FFC700
FFB800FFB800FFA800FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF7A00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF9900FF9900FF9900FF9900FFA800FFA800FFB800FFD700FFE600DCFF008FFF00
BDFF00DCFF00EBFF00DCFF00BDFF0000FF478FFF00AEFF00CCFF00AEFF00AEFF009EFF00
BDFF0000D1FF0038FF0066FF00FF6600FFF0FF00000028FFFF0000FF0000FF0000FF0000
FF0000FF0000FF00000047FF00A3FF00FF4700FF1914FF0042FF008FFF0061FF0000B3FF
00FF85FAFF00FFF500FFF500FAFF00DCFF0070FF0051FF00DCFF00FFF500FFE600FFC700
FFB800FFA800FFA800FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF8A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF9900FF9900FF9900FF9900FFA800FFF50000FF38FAFF008FFF00CCFF00
FF0000AEFF00CCFF00CCFF00AEFF0000FF0A8FFF00BDFF00DCFF00DCFF00DCFF00DCFF00
CCFF00AEFF0023FF0000FF1900FF9400FFD10057FF00FF1900FF4700FFC200C2FFFF0000
FF0000FF0000FF0000FF000000FFB314FF0061FF0051FF009EFF00BDFF0000FFE19EFF00
EBFF00FFF500FFF500FFE600FFF500EBFF00BDFF0000FFD1AEFF00EBFF00FFF500FFD700
FFB800FFA800FFA800FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF5C00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF7A00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF8A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF9900FF9900FF9900FF9900FFA800FFC700FFF5008FFF00BDFF00FAFF00
EBFF0070FF0014FF0061FF0061FF0000FF85FF0000BDFF00EBFF00EBFF00FAFF00EBFF00
DCFF00AEFF0051FF0070FF008FFF0033FF0000FF8551FF0023FF0000FFB3FF0000FF0000
FF0000FF0000FF0000FF0000FF000000FF1933FF009EFF00BDFF00CCFF0000FF8500FF19
FAFF00FFF500FFE600FFE600FFE600FFF500FAFF00BDFF009EFF00FF0000BDFF00BDFF00
FFB800FFA800FFA800FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF9900FF9900FF9900FFA800FFB800FFC700FFE6009EFF00FFE600
FFF50080FF00DCFF0000FF5733FF00BDFF0000FF19BDFF00EBFF00FAFF00FFF500FAFF00
DCFF00FF00C780FF000094FFBDFF00AEFF008FFF0070FF0023FF00FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF000000FF199EFF00CCFF00EBFF00EBFF00DCFF00
FFF500FFE600FFD700FFD700FFD700FFE600FAFF0070FF00EBFF00EBFF00AEFF00FFF500
FFC700FFA800FFA800FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FFA800FFB800FFE600FFD700FFC700
FFD700FFF500FFF500FFF500EBFF00CCFF0000FF0A70FF00FAFF00FFF500FFF500FFF500
DCFF00DCFF00DCFF009EFF00CCFF00CCFF00AEFF008FFF0000FF38FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF000000FF280094FFCCFF00EBFF00FAFF00FFF500
FFE600FFD700FFD700FFD700FFD700FFD70000FFA3FFF500FFE600FFE600EBFF009EFF00
EBFF00FFA800FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FFA800FFA800FFB800FFB800FFB800
FFC700FFC700FFD700FFE600FAFF00BDFF0023FF00DCFF00FFF500FFF500FFE600FFE600
FFF500FFF500FAFF00EBFF00EBFF00DCFF0080FF0070FF0000FF19FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF000000FFC200FF5700A3FF9EFF00EBFF00FFF500FFE600
FFD700FFD700FFD700FFC700FFC700FFC700FFC700FFC700FFC700FFD70014FF00FFF500
FFB800FFA800FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF6B00FF6B00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF9900FF8A00FF9900FF9900FF9900FFA800FFA800FFA800FFB800
FFB800FFB800FFC700FFD700FAFF0080FF0080FF0000FF28FFF500FFE600FFD700FFE600
FFE600FFE600FFF500FFF500FAFF00EBFF009EFF000066FFEB00FF00FFFFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000000AFF42FF009EFF00CCFF00EBFF00FFF500FFE600
FFD700FFD700FFC700FFC700FFC700FFC700FFC700FFC700FFB800FFC700FFD70000FF38
FFB800FFA800FF9900FF9900FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FFA800FFA800FFA800
FFB800FFB800FFC700FFD70033FF0080FF00EBFF00FAFF00FFE600FFD700FFD700FFD700
FFD700FFE600FFE600FFF500FAFF00EBFF00CCFF0061FF0051FF0000FFC2FF0000FF0000
FF0000FF0000FF0000FF0000BD00FFFF00F533FF008FFF00CCFF00DCFF00FAFF00FFE600
FFD700FFC700FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700
FFA800FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF7A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FFA800FFA800
FFA800FFB800FFB800FFD700EBFF00EBFF00FFF500FFE600FFD700FFC700FFC700FFD700
FFD700FFD700FFE600FFF500FAFF00EBFF00DCFF00AEFF0042FF000038FFFF00D7FF0000
FF0000FF0000FF0000FF000000FFB300FF1900FF6600FF94AEFF0070FF0033FF00DCFF00
FFD700FFC700FFC700FFC700FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800
FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF9900FF9900FF9900FF9900FFA800
FFA800FFA800FFB800FFD70070FF009EFF00FFD700FFC700FFC700FFC700FFC700FFC700
FFC700FFD700FFE600FFF500FAFF00EBFF00CCFF008FFF0033FF000075FFFF007AFF0000
0047FFFF0000FF000000FFB3000AFF61FF0000FF4700FF6642FF0061FF00CCFF00DCFF00
FFD700FFC700FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FF9900
FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00
FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900
FF9900FFA800FFA800FFC700FFC700FFD700FFC700FFC700FFB800FFB800FFC700FFC700
FFC700FFD700FFD700FFF500DCFF00BDFF00BDFF008FFF0000FF5714FF0042FF0005FF00
FF00E6FF0000FF000000FF5751FF009EFF00AEFF00AEFF0051FF00DCFF00FFF500FFD700
FFC700FFC700FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FF9900FF9900
FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900
FF9900FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFC700FFD700FFE600FAFF0000FF9405FF0000E1FF00FF2880FF0080FF008FFF0061FF00
00FF570094FFFF005C00FFE151FF00AEFF00CCFF00CCFF0000FF389EFF00FFF500FFD700
FFC700FFB800FFB800FFB800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900
FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00
FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900
FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800
FFC700FFC700FFF50023FF00CCFF00BDFF00BDFF0042FF00BDFF00CCFF00AEFF0000FF75
00FF4700FF1900FF7561FF0000FF19CCFF00DCFF00EBFF00CCFF0061FF00EBFF00FFD700
FFC700FFB800FFB800FFB800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900
FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900
FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800
FFB800FFC700FFD700FFE600FFF500FFF500EBFF0000FF38CCFF00DCFF0070FF009EFF00
8FFF00FF00F500FF668FFF00AEFF00DCFF00FAFF00FAFF00EBFF00FAFF0042FF00FFD700
FFC700FFB800FFB800FFA800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900
FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800
FFB800FFB800FFC700FFD700FFD700FFE600EBFF008FFF00EBFF00FAFF00EBFF00DCFF00
BDFF0061FF0000FF9400FF66CCFF00EBFF00FAFF00FFF500FFE600FFE600FFE600FFC700
FFB800FFB800FFB800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF8A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00
FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800
FFB800FFB800FFB800FFC700FFC700FFD70051FF00FAFF00FFF500FAFF00FAFF00EBFF00
CCFF0000FF8500FF9480FF00CCFF00EBFF00FFF500FFE600FFE600FFD700FFD700FFC700
FFB800FFB800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800
FFA800FFB800FFB800FFB800FFC700FFD700FFD700FFE600FFE600FFF500FAFF00DCFF00
BDFF008FFF0000FF7542FF0005FF0005FF00FFF500FFE600FFD700FFD700FFC700FFC700
FFB800FFB800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00
FF5C00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900
FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800
FFA800FFB800FFB800FFB800FFC700FFC700FFD700FFD700FFE600FFE600FFF50070FF00
0019FF33FF00FF000005FF0080FF00EBFF00FFF500FFE600FFD700FFC700FFC700FFB800
FFB800FFB800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF8A00
FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF8A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800
FFA800FFA800FFB800FFB800FFB800FFC700FFC700FFD700FFD700FFE600FFE600FAFF00
BDFF0080FF0042FF008FFF009EFF0033FF00FFF500FFE600FFD700FFC700FFC700FFB800
FFB800FFB800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800
FFA800FFA800FFB800FFB800FFB800FFB800FFC700FFC700FFD700FFE600FFE600FFF500
AEFF00CCFF0051FF0061FF00DCFF00FAFF00FFF500FFD700FFD700FFC700FFC700FFB800
FFB800FFB800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800
FFA800FFA800FFA800FFB800FFB800FFB800FFC700FFC700FFC700FFD700FFE600FFF500
FAFF00DCFF008FFF0080FF00DCFF00FAFF00FFE600FFD700FFD700FFC700FFC700FFC700
FFB800FFB800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF6B00
FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800
FFA800FFA800FFA800FFB800FFB800FFB800FFC700FFC700FFC700FFD700FFE600FFE600
FFF500EBFF0005FF0080FF00DCFF00FAFF00FFE600FFE600FFD700FFC700FFC700FFC700
FFB800FFB800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800
FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFC700FFC700FFD700FFE600FFE600
FFF500EBFF00CCFF0033FF00DCFF00FAFF00FFF500FFE600FFD700FFD700FFC700FFC700
FFB800FFB800FFA800FFA800FFA800FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FFA800
FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFC700FFC700FFD700FFE600FFE600
FAFF00EBFF00BDFF0000FF949EFF00CCFF00FAFF00FFF500FFE600FFD700FFC700FFC700
FFB800FFB800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00
FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900
FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFC700FFD700FFD700FFE600FFF500
33FF00CCFF0033FF00CCFF009EFF0042FF00DCFF00CCFF00FAFF00FFE600FFD700FFC700
FFC700FFB800FFB800FFA800FFA800FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900
FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFC700FFD700FFE600FFE600FFF500
CCFF0061FF00DCFF00FAFF00DCFF00CCFF0070FF0051FF00CCFF00EBFF00FFE600FFD700
FFD700FFC700FFB800FFB800FFA800FFA800FF9900FF9900FF9900FF8A00FF8A00FF8A00
FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900
FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFC700FFD700FFF500FFF500FAFF00
AEFF0000FF66FAFF00FFF500FFF500FAFF0051FF0023FF0070FF00FAFF00FFF500FFE600
FFF500FFE600FFC700FFB800FFB800FFA800FF9900FF9900FF9900FF8A00FF8A00FF8A00
FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900
FFA800FFA800FFA800FFA800FFB800FFB800FFC700FFC700FFE6008FFF00CCFF00DCFF00
33FF00EBFF00FFF500FFE600FFE600FFF500EBFF009EFF00CCFF0061FF00FAFF00FAFF00
CCFF00FFF500FFD700FFC700FFB800FFA800FF9900FF9900FF9900FF8A00FF8A00FF8A00
FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900
FFA800FFA800FFA800FFA800FFB800FFB800FFC700FFC700FFE600EBFF0080FF009EFF00
9EFF00FAFF00FFE600FFD700FFD700FFD700FFE600FFE600FFF500CCFF00CCFF00CCFF00
42FF00DCFF00FFF5009EFF00FFC700FFA800FFA800FF9900FF9900FF8A00FF8A00FF8A00
FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00
FF6B00FF6B00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FFA800
FFA800FFA800FFA800FFB800FFB800FFC700FFC700FFD700FFE600EBFF0042FF0000FF0A
DCFF00EBFF00FFD700FFC700FFC700FFC700FFD700FFD700FFE600AEFF00DCFF009EFF00
FF0000BDFF00BDFF00FFF500FFC700FFB800FFA800FF9900FF9900FF8A00FF8A00FF8A00
FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900
FFA800FFA800FFA800FFB800FFB800FFC700FFC700FFD700FFF5009EFF009EFF009EFF00
FAFF00FFD700FFC700FFC700FFC700FFC700FFC700FFC700FFE60080FF00FFF500FAFF00
8FFF00FAFF008FFF00FFE600FFC700FFB800FFA800FF9900FF9900FF8A00FF8A00FF8A00
FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900
FFA800FFA800FFA800FFB800FFB800FFC700FFC700FFD700FFE600EBFF00DCFF00FAFF00
CCFF00FFD700FFC700FFB800FFB800FFB800FFB800FFC700FFD700FAFF00FFD700FFE600
FAFF00FFE600FAFF0061FF00FFF500FFC700FFC700FFB800FF9900FF8A00FF8A00FF8A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FFA800
FFA800FFB800FFB800FFB800FFC700FFC700FFD700FFD700FFF50000FFA3DCFF00FFE600
FFD700FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFC700
FFC700FFC700FFD700FFF5009EFF00FAFF00FAFF00FFC700FF9900FF8A00FF8A00FF8A00
FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF6B00FF6B00FF6B00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900
FFA800FFA800FFB800FFC700FFC700FFD700FFD700FFE600FFF5009EFF00FAFF00FFD700
FFC700FFC700FFB800FFB800FFB800FFA800FFA800FFA800FFB800FFB800FFB800FFB800
FFB800FFB800FFC700FFD700DCFF00FFE600FFB800FFA800FF9900FF8A00FF8A00FF8A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900
FFA800FFB800FFD700FFD700FFD700FFD700FFF500FFF500FAFF008FFF00FAFF00FFE600
FFC700FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFB800FFB800FFD700CCFF00FFC700FFA800FF9900FF9900FF8A00FF8A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900
FFA800FFB800EBFF00FFF500FFF500FAFF00EBFF00FAFF008FFF00EBFF00CCFF00FFF500
FFC700FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFB800FFD700EBFF00FFC700FFA800FF9900FF8A00FF8A00FF8A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900
FFA800FFB800FFF500BDFF0061FF009EFF0080FF00CCFF00CCFF00FFE600FFE600DCFF00
FFB800FFB800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FFA800FFA800FFB800FFD700FFD700FFA800FF9900FF8A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00
FF6B00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900
FFA800FFB800FFD700FFF500DCFF0014FF00FF000080FF00FAFF00FFD700FFC700FFC700
FFB800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FFA800FFC7009EFF00FF9900FF8A00FF8A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900
FFA800FFB800FFC700FFE600BDFF0000FFC2FF000000FFFFFAFF00FFC700FFB800FFB800
FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FFA800FFC700FFA800FF9900FF8A00FF8A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900
FFA800FFB800FFC700FFE600BDFF0000E1FF14FF008FFF00FFF500FFC700FFB800FFA800
FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF9900FF8A00FF8A00
FF8A00FF8A00FF9900FF9900FFA800FF9900FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900
FFA800FFB800FFC700FFE6009EFF00DCFF00EBFF00AEFF00EBFF00FFD700FFB800FFA800
FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FFA800
FFA800FFC700FFE600FAFF00EBFF00FFF500FFE600FFE600FAFF00FFC700FFA800FFA800
FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FFA800
FFA800FFC700FFF500DCFF00FFF500FFD700FFD700FFC700FFC700FFB800FFA800FFA800
FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FFA800
FFA800FFB800FFD700FFF500FFF500FFD700FFC700FFB800FFB800FFA800FFA800FF9900
FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FFA800
FFA800FFB800FFC700FFF500FAFF00FFC700FFB800FFB800FFA800FFA800FF9900FF9900
FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FFA800
FFA800FFB800FFC70051FF0000FF75FFC700FFB800FFA800FFA800FF9900FF9900FF9900
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF8A00FF7A00FF8A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FFA800
FFA800FFB800FFD70080FF00FFE600FFC700FFB800FFA800FFA800FF9900FF9900FF9900
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FFA800
FFB800FFB800FFD700AEFF00FFD700FFC700FFB800FFA800FFA800FF9900FF9900FF8A00
FF8A00FF8A00FF8A00FF8A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF9900FF9900FFA800FFA800
FFB800FFC700FFE600CCFF00FFF500FFC700FFB800FFA800FF9900FF9900FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FFA800FFB800
FFC700FFD70061FF00FFE600FFF500FFE600FFB800FFA800FF9900FF9900FF8A00FF8A00
FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF9900FF9900FFA800FFB800FFD700
FFF5008FFF00FFD700FFC700FFC700BDFF00FFC700FFA800FF9900FF9900FF8A00FF8A00
FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF9900FF9900FFA800FFD700DCFF00
FFE600FFC700FFB800FFB800FFB800FFC700FFE600FFB800FF9900FF9900FF8A00FF8A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF9900FFA800FFB800FFE600FFC700
FFB800FFA800FFA800FFA800FFA800FFB800EBFF00FFA800FF9900FF8A00FF8A00FF8A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FFA800FFB800FFD700FAFF00FFB800
FFA800FF9900FF9900FF9900FF9900FF9900FFF500FF9900FF8A00FF8A00FF8A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FFA800FFE600FFB800FFC700FFA800
FF9900FF9900FF9900FF8A00FF9900FF9900FF9900FF8A00FF8A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00
FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00
FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF9900FF9900FFA800FF9900
FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF7A00FF6B00FF7A00
FF7A00FF6B00FF7A00FF6B00FF7A00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00
FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00
FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF6B00FF6B00
FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00
FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF6B00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF5C00FF5C00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF6B00FF6B00FF6B00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00
FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF5C00FF5C00
FF5C00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF5C00
FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5C00FF5C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 234},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000jR000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQ
ooooo`006_ooool5o`0000?ooooo00?o0000ooooooooool00_ooool3o`0001gooooo1Ol0000Moooo
o`?o00001?ooool00ol0003oooooooooo`02ooooo`?o00007_ooool3o`0001oooooo0_l00004oooo
o`03o`000?oooooooooo00;ooooo0ol0000Looooo`;o00007oooool2o`0000Cooooo00?o0000oooo
ooooool00_ooool3o`0000oooooo000Kooooo`04o`000?ooooooooooo`0000Oooooo00Go0000oooo
ooooooooooooo`00000Mooooo`04o`000?ooooooooooo`0001kooooo00?o0000ooooooooool01ooo
ool01Ol0003ooooooooooooooooo000001kooooo00?o0000ooooooooool07Oooool01?l0003ooooo
ooooool00007ooooo`05o`000?ooooooooooooooool000006_ooool01?l0003oooooooooool0000M
ooooo`04o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`00000>ooooo`005?oo
ool5o`0000?ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Dooooo`Go00000ooo
ool00ol0003oooooooooo`0Fooooo`Go00000oooool00ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo01Cooooo1Ol00003ooooo`03o`000?oooooooooo01Kooooo1Ol00002ooooo`04o`000?oo
ooooooooo`0000_ooooo00?o0000ooooooooool06?ooool01?l0003oooooooooool0000Mooooo`04
o`000?ooooooooooo`0000_ooooo00?o0000ooooooooool03?ooool001gooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo01gooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01gooooo00Co0000oooooooo
oooo00002oooool00ol0003oooooooooo`0Hooooo`04o`000?ooooooooooo`0001gooooo00Co0000
oooooooooooo00002oooool00ol0003oooooooooo`0<ooooo`006_ooool01Ol0003ooooooooooooo
oooo000000Oooooo1?l0000Mooooo`05o`000?ooooooooooooooool000007_ooool00ol0003ooooo
ooooo`07ooooo`Co00007oooool00ol0003oooooooooo`0Mooooo`04o`000?ooooooooooo`0000Oo
oooo1?l0000Kooooo`04o`000?ooooooooooo`0001gooooo00Co0000oooooooooooo00001oooool4
o`0000oooooo000Jooooo`05o`000?ooooooooooooooool000001oooool00ol0003oooooooooo`0N
ooooo`05o`000?ooooooooooooooool000007Oooool2o`0000Wooooo00?o0000ooooooooool07ooo
ool2o`0001oooooo00Co0000oooooooooooo00001oooool00ol0003oooooooooo`0Looooo`04o`00
0?ooooooooooo`0001gooooo00Co0000oooooooooooo00001oooool00ol0003oooooooooo`0@oooo
o`006oooool3o`0000Sooooo1Ol0000Mooooo`?o00007oooool00ol0003oooooooooo`07ooooo`Go
00007_ooool00ol0003oooooooooo`0Nooooo`;o00002?ooool5o`0001_ooooo0_l0000Oooooo`;o
00002?ooool5o`0000kooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo003ooooo
ob7ooooo003oooooob7ooooo000Koooooooo00001Ol00001ooooo`006oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`02ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool0ooooool1ooooo`7o00000Oooool0
01_ooooo00?o0000ooooooooool0ooooool1ooooo`7o00000Oooool001_ooooo0_l0003oooooo`7o
oooo0_l00001ooooo`006oooool00ol0003oooooooooo`02oooooal0ocd000<0odD00?m<003oC000
@03oC0000`3oD000od`00?m<000=0?m<00030?m@003oE000od`000`0od`00`3oG0000`3oD000od`0
0?m<00050?m<00030?mD003oG000oe`002T0oe`000<0of000?mL003oG000703oG0000`3oE000od`0
0?m<00070?m<00030?m@003oF000od`001D0od`01Oooool1o`00007ooooo000Kooooo`03o`000?oo
oooooooo00;ooooo7`3o?@000`3oA@00od`00?m<00110?m<00030?mA003oC000od`000d0od`000<0
oeX00?m?003oC0002`3oC0001@3oE`00oe`00?mL003oFP00oe4000D0od`000<0odl00?mL003oG000
6P3oG0000`3oG`00oe`00?mL000/0?mL00030?mD003oC000od`000H0od`000<0odl00?mJ003oC`00
3@3oC0000`3oC`00od`00?m<00060?m<00Gooooo0Ol00001ooooo`006oooool00ol0003ooooooooo
o`02oooooal0ocd000<0odD00?m<003oC000D@3oC0000`3oE000oeP00?m<000;0?m<00030?mD003o
G000oe`00080oe`000D0oeP00?mD003oC000oe000?mH000Y0?mL00030?mP003oG000oe`00240oe`0
1`3oC0000`3oD000oe`00?mD000=0?m<00030?mD003oC000od`000L0od`01Oooool1o`00007ooooo
000Kooooo`03o`000?oooooooooo00;ooooo7`3o?@000`3oBP00od`00?m<000<0?m<00030?m?003o
C000od`003<0od`000<0oe400?m<003oC0003@3oC0000`3oG000oe800?m<000:0?m<00030?mG003o
G000oe`001X0oe`000<0oel00?mL003oG000303oG0001@3oG`00oe`00?mL003oG000oel00080oe`0
00D0of@00?mL003oG000oe`00?mO00020?mL00050?mO003oG000oe`00?mL003oG`00103oG0000`3o
G`00oe`00?mL000A0?mL00030?mD003oC000od`000<0od`000@0oe@00?mL003oG000odl0303oC000
0`3oD@00od`00?m<00080?m<00Gooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`02oooo
oal0ocd0AP3oC0000`3oD000od`00?m<000<0?m<00030?mH003oG000oe0000X0od`0<03oG000103o
I000oe`00?mL003oI0030?mL00030?mT003oG000oe`000P0oe`000<0of000?mL003oG0004`3oG000
103oF000oe@00?mD003oE0030?mL00030?mH003oC000od`000X0od`000<0oe000?m<003oC0002@3o
C005ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool00_ooool00`3oA`00od000?lm000K
0?lm00030?m7003oC000od`004@0od`000<0oe@00?m<003oC000303oC000103oE000oe`00?mJ003o
C`080?m<00030?m?003oG000oe`002H0oe`000H0of400?mL003oG000oe`00?mT003oG`020?mL000;
0?mY003oG`00oe`00?mY003oH@00oe`00?mQ003oIP00oe`00?mN003oI0000`3oG0001@3oG`00oe`0
0?mL003oG000oel001`0oe`000<0oe@00?m<003oC0002@3oC0000`3oDP00odl00?m<000:0?m<00Go
oooo0Ol00001ooooo`006oooool00ol0003oooooooooo`02ooooo`80od`000<0odT00?lm003o?@00
603o?@000`3o@@00od`00?m<000e0?m<00030?m@003oC000od`000h0od`000<0oe@00?m<003oC000
2`3oC0001@3oD000oe`00?mL003oG000oe0000L0od`000<0oeP00?mL003oG0008P3oG0000`3oH000
oe`00?mL00020?mL00070?mP003oG000oe`00?mT003oJ000of000?mX00080?m[00030?mT003oIP00
of@00080oe`000D0of@00?mL003oG000oe`00?mP00040?mL00030?mP003oG000oe`001H0oe`000<0
oe@00?m<003oC000203oC0020?m@00`0od`01Oooool1o`00007ooooo000Kooooo`;o00000oooool3
0?m<00030?m:003oA@00ocd001L0ocd000<0odX00?m<003oC000=@3oC0020?m?00l0od`000<0oeL0
0?m?003oC000303oC0040?mL00030?mD003oC`00od`00080od`000<0odl00?mJ003oG0006@3oG000
0`3oG`00oe`00?mL00080?mL00030?mO003oG000oe`00080oe`000@0of/00?mQ003oH@00ofT03P3o
J`000`3oI000ofH00?m[00030?mL00030?mQ003oG000oe`001/0oe`000<0oe@00?m<003oC0001`3o
C0000`3oE000oeL00?m<000<0?m<00Cooooo0_l00001ooooo`006oooool00ol0003oooooooooo`02
ooooo`H0od`000<0odD00?lm003o?@004`3o?@000`3oB@00od`00?m<000g0?m<00030?m@003oC000
od`000d0od`000<0oe000?mH003oC000303oC0060?mL00030?mH003oE000oeP00280oe`000<0of00
0?mL003oG0000`3oG000103oJ000oe`00?mL003oG00E0?m[00040?mX003oG000ofP00?mT00<0oe`0
00<0of000?mL003oG0005`3oG0000`3oE000od`00?m<00060?m<00030?m@003oG000od`000d0od`0
1Oooool1o`00007ooooo000Kooooo`03o`000?oooooooooo00;ooooo00<0od000?m<003oC000103o
C0000`3oBP00odD00?m0000@0?lm00030?m0003oBP00od`003X0od`000<0odl00?m<003oC0003@3o
C0000`3oFP00oeL00?m<000;0?m<02`0oe`000<0of400?mL003oG0000P3oG000103oIP00ofT00?mQ
003oJ@0:0?m[00030?m^003oJ`00of/000/0of/000@0ofH00?mL003oG000ofH0103oG0000`3oH@00
oe`00?mL000D0?mL00030?m?003oC000od`000<0od`000@0odl00?mG003oG000oe803P3oC005oooo
o`7o00000Oooool001_ooooo00?o0000ooooooooool00_ooool00`3o?@00od400?m<00070?m<0003
0?m9003oA@00ocd000`0ocd000<0odD00?m<003oC000>`3oC0000`3oD000od`00?m<000=0?m<0003
0?mD003oG000oe0000/0od`09P3oG0000`3oH000oe`00?mL00030?mL0080of000`3oG0000`3oI000
of/00?m[00060?m[00060?m_003oJ`00of/00?m_003oJ`00og<00P3oJ`000`3oK`00of/00?m[0009
0?m[00030?mX003oJ`00of/000<0oe`000<0of000?mL003oG0005P3oG0001@3oD000od`00?m<003o
C000oe@00080oe`000<0oeP00?m<003oC000303oC0000`3oE03oooooooooo`03ooooo`7o00000Ooo
ool001_ooooo00?o0000ooooooooool00_ooool20?lm00030?m2003oC000od`000P0od`00P3oA`02
0?m200040?m0003o?@00ocd00?m00080od8000<0odL00?m<003oC000?P3oC0000`3oD@00od`00?m<
000=0?m<0080oe`000<0oe800?m<003oC0001`3oC0000`3oE000oe`00?mL000U0?mL00030?mO003o
G000oe`000<0oe`000@0of/00?mT003oG000oel02P3oJ`00103oL`00ogP00?mh003oNP020?mh0080
ogD000<0og000?m^003oJ`002`3oJ`00103oG`00oe`00?mQ003oI00O0?mL00030?mB003oC000od`0
00d0od`01Oooool1o`00007ooooo000Kooooo`03o`000?oooooooooo00;ooooo0`3o?@000`3oA@00
od`00?m<001C0?m<00030?mD003oC000od`000`0od`000@0oeP00?mL003oG000oe00203oC00R0?mL
00030?mP003oG000oe`000<0oe`00P3oH0040?mL00030?mT003oJ`00of/000P0of/000<0ofl00?m[
003oNP002P3oNP000`3oL`00of/00?m_000<0?m[00050?mT003oG000oe`00?mL003oH0006`3oG00=
0?m<00030?mD003oC000od`000Gooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`02oooo
o`@0ocd000<0odT00?m<003oC000@@3oC0000`3oD000od`00?m<000>0?m<00030?mH003oC000od`0
00`0od`000D0oe@00?mL003oG000oe`00?m@00060?m<00030?mH003oG000oe`002L0oe`000<0of@0
0?mL003oG0000P3oG0000`3oJ000of/00?m[00040?m[00030?m_003oJ`00of/00080of/00`3oNP00
103oPP00ohX00?n:003oQP020?n200@0ogX000<0og<00?m[003oK`002`3oJ`000`3oI000oe`00?mL
00020?mP01/0oe`0303oC000103oE000od`00?m<003oC005ooooo`7o00000Oooool001_ooooo0_l0
0003ooooo`@0ocd000<0od000?m:003oC000DP3oC0000`3oC`00oeL00?m<000<0?m<00030?mD003o
G000oe`00080oe`000<0oeX00?mD003oD@000P3oD@000`3oFP00oe`00?mL000X0?mL00050?mT003o
J@00of400?mL003oH@002P3oJ`003@3oKP00ogD00?mj003oNP00ohD00?n^003na000oj<00?nD003o
TP00oj@00?n=003oPP000`3oNP00103oN000og<00?m[003oL0090?m[00040?mY003oH@00ofH00?mY
00D0oe`000<0oel00?mL003oG000503oG00:0?m<00030?m?003oE`00odl000<0od`01?ooool2o`00
007ooooo000Kooooo`03o`000?oooooooooo00;ooooo1@3o?@000`3o@@00od`00?m<00110?m<0003
0?m@003oC000od`000h0od`000<0oeP00?m@003oC0002`3oC0000`3oE000oe`00?mL000/0?mL0080
of001@3oG00=0?m[00030?m_003oL`00ogX00080ogX000X0ohX00?nM003ob000mmT00?nd003o/000
n]X00?nU003oSP00oh801@3oNP020?mc00/0of/000@0of@00?mL003oG000oe`00P3oH00G0?mL00T0
od`000<0oe000?mL003oC000103oC005ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool0
0_ooool60?lm00030?m7003oC000od`00440od`000<0oe400?m<003oC0003@3oC0000`3oC`00oe`0
0?m?000;0?m<00030?mD003oG000oe`002H0oe`000<0of400?mL003oG000103oG0000`3oIP00oel0
0?mL00020?mL00030?mO003oJ`00of/000`0of/00`3oNP00303oO@00ohX00?nG003oYP00olL00=;T
003gi@00m=400?nQ003oTP00ohX00?n100H0ogX000<0ogD00?mc003oJ`00203oJ`001@3oJ@00oe`0
0?mL003oH@00of@001P0oe`000<0oe800?m<003oC0001@3oC0000`3oE000oe`00?m?00050?m<00Go
oooo0Ol00001ooooo`006oooool00ol0003oooooooooo`02ooooo`L0ocd0A03oC0000`3oD000od`0
0?m<000=0?m<00030?mH003oG000od`000X0od`000<0oe@00?mL003oG0009`3oG0000`3oH000oe`0
0?mL00030?mL00030?mT003oJ`00of000080oe`000<0ofP00?m[003oJ`002P3oJ`000`3oL`00ogL0
0?mj00020?mj000>0?n2003oRP00ohh00?nI003o[000olP00<__003o`000ojP00?nI003oSP00ohX0
0?n6003oOP060?mj00030?mc003oJ`00ofl000X0of/01@3oG0000`3oH000oe`00?mL000B0?mL0003
0?m@003oC000od`00080od`000@0oe000?mL003oG000oe@01P3oC005ooooo`7o00000Oooool001_o
oooo00?o0000ooooooooool00_ooool70?lm00030?m2003oC000od`00440od`00P3oC`0>0?m<0004
0?mB003oG000oeX00?m?00T0od`000<0oeX00?mL003oG0009`3oG0000`3oH@00oe`00?mL00040?mL
0080of/000<0ofT00?m[003oJ`002@3oJ`00103oKP00og000?m[003oKP040?mj000;0?n5003oRP00
ohl00?nI003oZ000ol800;Oj503oa@00ok000?nQ003oU`000`3oRP00103oR000oh800?mm003oO@04
0?mj00030?m^003oJ`00of/000P0of/0103oG0000`3oH@00oe`00?mL000D0?mL00030?mJ003oE`00
oeL000<0oe`000<0oeX00?m<003oC0001@3oC005ooooo`7o00000Oooool001_ooooo00?o0000oooo
ooooool00_ooool80?lm00030?m9003oC000od`00440od`000<0oe000?m<003oC0003@3oC0030?mL
00030?m@003oC000od`000D0od`000<0oe@00?mL003oG000:@3oG0000`3oJ000oe`00?mL00030?mL
0100of/01P3oNP00303oQP00ohX00?n>003oV@00ojP00?oK003`o@00on<00?kM003o]000oj400?nB
00H0ohX000<0ohH00?mn003oNP000P3oNP0:0?m[00050?mP003oG000oe`00?mX003oH000703oG000
0`3oD000od`00?m<00050?m<00Gooooo0Ol00001ooooo`004oooool3o`0000Gooooo00?o0000oooo
ooooool00_ooool80?lm00030?m2003oC000od`00480od`000<0oe@00?m<003oC000303oC0001P3o
FP00oe`00?mL003oG000oe@00?m?00@0od`000<0oe@00?mL003oG000703oG0000`3oG`00oe`00?mL
00040?mL00030?mQ003oG000oe`000@0oe`000<0ofH00?mT003oG0000P3oG0000`3oIP00of/00?m[
000;0?m[00040?m^003oJ`00of/00?me00@0ogX000h0ogd00?n:003oRP00ohl00?nI003oX@00ol00
0=Wc001jd4/0/Oh[0?o2003oZ000oi`00?nI0080oi800P3oS`00103oU`00oj400?n=003oPP030?mj
00030?m^003oJ`00of/000L0of/000<0ofH00?m[003oIP001@3oG0000`3oG`00oe`00?mL000D0?mL
00030?mJ003oC000od`000H0od`01Oooool1o`00007ooooo000Dooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool00_ooool90?lm03<0od`000<0oe000?m<003oC0003P3oC0020?m@00d0
od`000<0oe@00?mL003oG000103oG0000`3oE000oeP00?mL000W0?mL00030?mP003oG000oe`000<0
oe`000D0of@00?m[003oJ`00of@00?mX00070?m[00030?m_003oJ`00of/000D0of/000<0ogL00?mj
003oNP00103oNP003@3oOP00ohX00?n:003oSP00oiT00?nQ003oc`00_od008g00035o`00om/00?O>
003oZ000103oV@001@3oW@00ojT00>OM003oVP00ohX000<0ogX000<0ogL00?mc003oJ`002@3oJ`00
0`3oI000oe`00?mL00020?mL00030?mT003oG000oe`001D0oe`000<0oe@00?m<003oC0001P3oC005
ooooo`7o00000Oooool000cooooo1Ol00003ooooo`03o`000?oooooooooo00Cooooo0_l00003oooo
o`T0ocd000<0odL00?m<003oC000<@3oC0000`3oC`00od`00?m<000>0?m<00030?mJ003oC`00od`0
00/0od`000<0oe@00?mL003oG0007`3oG0000`3oG`00oe`00?mL000<0?mL00030?mT003oG`00oe`0
00<0oe`000<0of@00?m[003oJ`003P3oJ`00103oKP00of/00?m[003oL`050?mj000@0?mm003oRP00
ohX00?n:003oTP00oiT00?nQ003la`00om`00?_Y003[n000col00?oG003o]000oj/00?nX0080ojd0
00H0ok000?o:003^j000ojH00?n?003oQ@030?mj00030?m`003oKP00of/000P0of/000H0ofH00?mL
003oG000oel00?mT003oG`0G0?mL00030?mD003oC000od`000H0od`01?ooool2o`00007ooooo000D
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool90?lm00030?m5003oC000
od`00380od`000<0odl00?m<003oC0003@3oC0000`3oD000oe`00?m<000;0?m<00030?mD003oG000
oe`002L0oe`000<0of000?mL003oG000103oG0000`3oH000ofP00?mL00030?mL00030?mX003oJ`00
of/000l0of/000<0ogL00?mc003oNP001@3oNP006@3oPP00ohX00?n:003oRP00oiH00?nI003oY@00
ok000?nl003ob`00on<00:Wo:@3bk`00ol800?nh003o_000o]T00?oC003ng@00eo<00>K_003ndP00
oi800?n:003oOP000`3oNP000`3oL`00of/00?m[00080?m[0080ofP000<0of/00?mT003oG000103o
G0000`3oH000oe`00?mL000@0?mL00030?mH003oC000od`000H0od`01Oooool1o`00007ooooo000D
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool90?lm00030?m0003oC000
od`003<0od`000<0odl00?m<003oC0003@3oC0000`3oE`00oeX00?m?000:0?m<00030?mG003oG000
oe`002P0oe`000<0of400?mL003oG000103oG0001@3oJ`00ofT00?mT003oH@00ofH000h0of/000D0
ofh00?m[003oJ`00of/00?mc00060?mj000J0?mm003oQ@00ohX00?n:003oS@00oiL00?nI003oX`00
ojP00?nf003oa@00oml00:?o002Mo`80o=`00?o<003oe`00e?D00=On002le@00d_P00?nm003oX@00
oi800?n:003oQ@030?mj00030?me003oL000ofh000/0of/000<0oel00?mL003oG0000P3oG0000`3o
G`00oe`00?mL000B0?mL00030?m?003oC000od`000@0od`000<0odl0ooooooooool00oooool1o`00
007ooooo000Cooooo`;o00001_ooool00ol0003oooooooooo`02ooooo`X0ocd0=@3oC0000`3oD000
od`00?m<000=0?m<00030?m@003oG000oe`000X0od`0:`3oG0000`3oI000of000?mL00040?mL01@0
of/000<0ofl00?mc003oL`001`3oNP001@3oPP00ohX00?n:003oRP00ohh00080oiT001<0oj400?nX
003o/000ok`00?oC003GnP00[_l00=7h4@3nm000P?l00:Ko003mm`00lo@00?o8003o/000oiT00?nB
003oRP00ohH000D0ogX0303oJ`001@3oH000oe`00?mL003oG000ofP001H0oe`000L0oe000?m<003o
C000od`00?m@003oE000oe`000Gooooo0Ol00001ooooo`005?ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00;ooooo2P3o?@0f0?m<00030?mA003oC000od`000d0od`000@0oeX00?mL
003oFP00oe401`3oC0000`3oE`00oe`00?mL000J0?mL00030?mO003oG000oe`000D0oe`000<0oel0
0?mL003oG0001@3oG0000`3oJ@00oel00?mL00020?mL00030?mO003oJ`00of/000l0of/000@0ofh0
0?m[003oJ`00of/0203oNP000`3oPP00ohP00?n:00020?n:000D0?nB003oV@00oiT00?nS003oZ000
ok<00?nh003oc@00on400=Ch002Qoa00ZOl00;_n003bl000om800?o2003o/000oj<00?nI003oS`02
0?n:00D0ogX00P3oL0000`3oKP00of/00?m[00070?m[00050?mY003oH@00of400?mY003oI0007@3o
G005ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool00_ooool:0?lm03L0od`000<0oe@0
0?m<003oC000303oC0001@3oE000oe`00?mL003oG000oeP000D0od`000<0oeP00?mL003oG000903o
G0000`3oH000oe`00?mL00040?mL00050?mX003oJ`00of@00?mL003oH0004`3oJ`000`3oM`00of/0
0?m_00070?mj00030?mn003oQP00ohX00080ohX000@0oi800?nI003oV@00oiT00P3oZ0003`3o]000
ok`00?o7003og`00onh008oo003[o`00onX00?oC003oa`00okP00?nX003oX@00oiT00?n>00020?n:
00030?n6003oNP00ogX000<0ogX000@0og<00?m[003oJ`00ofl02`3oJ`050?mL00030?mP003oG000
oe`001D0oe`000<0oe@0ooooooooool00oooool1o`00007ooooo000Kooooo`03o`000?oooooooooo
00;ooooo2P3o?@0V0?m<00030?m@003oC000od`000h0od`00P3oD00=0?m<00030?m@003oG000oe`0
00<0oe`000<0oeP00?mD003oE000:03oG0000`3oI000oe`00?mL00040?mL00030?mT003oJ`00of/0
01D0of/000<0og<00?mj003oNP001`3oNP000`3oQP00ohX00?n:00020?n:00<0oiT00180oid00?nX
003o[000okP00?o0003ob`00on<00>[j002Bo`00jol00?oS003oc`00ol@00?nh003oZ000oj400?nI
003oUP020?n:00030?n6003oOP00ogX000<0ogX000<0og<00?m[003oL`00303oJ`040?mL00030?mP
003oG000oe`001H0oe`000<0od`0ooooooooool00oooool1o`00007ooooo000Kooooo`03o`000?oo
oooooooo00;ooooo2@3o?@000`3o@P00od`00?m<000f0?m<00030?mD003oC`00od`000`0od`0:@3o
G0000`3oG`00oe`00?mL00050?mL00030?mY003oG`00oe`000<0oe`000<0ofH00?m[003oJ`004P3o
J`00103oL`00ofh00?m[003oM@050?mj00040?mm003oNP00ogd00?n500<0ohX000D0ohl00?nG003o
V@00oiT00?nS00020?nX000A0?nf003o_@00oll00?oO003nk`00X=T[05oS3@1Qo`00onh00?oB003o
`P00okP00?nX003oX@00oiT00?nG003oS@000P3oRP020?mo00D0ogX03@3oJ`001@3oI000oe`00?mO
003oI000of4001L0oe`000<0oeL00?m<0?ooool01?ooool1o`00007ooooo000Kooooo`;o00000ooo
ool90?lm00030?m5003oC000od`002D0od`000<0oe000?m<003oC0003`3oC0000`3oG000od`00?m<
000;0?m<02X0oe`000<0of000?mL003oG000103oG0000`3oI000ofP00?mL00020?mL00030?mP003o
J`00of/000`0of/000D0ofl00?m[003oJ`00of/00?m_00020?m[00030?mc003oNP00ogX000L0ogX0
00<0ogh00?n2003oRP000P3oRP001@3oSP00oiH00?nI003oW@00ojD00080ojP000l0ok@00?nl003o
c`00cnl00=gm003go`00eOl002KoF@3Lo`00o_@00?oS003od`00okP00?n/003oZ0000P3oV@00103o
UP00ohX00?n:003oRP060?mj0080of/000<0ofl00?m[003oJ`00303oJ`050?mL00030?mP003oG000
oe`00100oe`000<0oe@00?m<0?ooool00oooool2o`00007ooooo000Kooooo`03o`000?oooooooooo
00;ooooo2@3o?@000`3oBP00od`00?m<000W0?m<00030?m?003oC000od`000d0od`000<0oe800?mJ
003oC`002`3oC00R0?mL00030?mO003oG000oe`000D0oe`000<0of400?mL003oG000103oG0000`3o
I000of/00?m[00020?mV00l0of/000P0ofh00?m[003oJ`00of/00?m`003oKP00of/00?mc00P0ogX0
0P3oO`030?n:000H0?n=003oV@00oiT00?nS003oZ`00ojd00?nc003o^000okd00?oI002WnQT0T_T[
06;o402To`00@ol^05>jMP2>o`@0i?l009go2P3LjP00ol000?nf003oZ000ojH00P3oV@00103oS`00
ohX00?n:003oQ@070?mj00<0of/000<0ofh00?m[003oJ`002@3oJ`040?mL00030?mQ003oG000oe`0
0140oe`000<0oe@00?m<0?ooool01?ooool1o`00007ooooo000Kooooo`03o`000?oooooooooo00;o
oooo203o?@000`3oA@00od`00?m<000i0?m<00030?mH003oG000od`000T0od`000<0oe000?mL003o
G0008@3oG0000`3oH000oe`00?mL00050?mL00030?mX003oG000oe`000<0oe`000<0of@00?m[003o
J`004P3oJ`00103oK`00of/00?m[003oK`0;0?mj00050?n2003oRP00ohX00?n:003oSP000P3oV@00
103oX@00oj`00=cI003Wg@020?o4000?0?o7003of`00mOX00<go001EoaH0EYeO085BNP2ZEB`0EL90
05Oo;01eo`00j_<00?o;003o^000ok@00080ojP000<0oid00?nI003oSP000P3oRP000`3oPP00ogX0
0?mj00040?mj0080of/000<0ofl00?m[003oJ`002P3oJ`001@3oH000oe`00?mL003oJ000of0001<0
oe`000<0oeP00?m<0?ooool01?ooool1o`00007ooooo000Kooooo`03o`000?oooooooooo00;ooooo
1`3o?@000`3o@000od`00?m<000Z0?m<00030?m?003oC000od`000d0od`000@0odl00?mL003oFP00
odl0203oC0000`3oE`00oe`00?mL000J0?mL00030?mO003oG000oe`000`0oe`000<0ofH00?mT003o
G0000`3oG0000`3oIP00of/00?m[000B0?m[0080og<000<0of/00?me003oNP002@3oNP00503oQ@00
ohP00?n:003oRP00ohd00?nG003oW000ojH00?n`003o_@00fN/00;Wn003Dk`L0omD00?oL003oiP00
oOX00=Oo001]^eD0P5nJ0P3o0000401eEj00A_lZ0<3o003Fm@00om800?o7003o_@00ok/00?nf003E
aPX0oj<00?nG003oRP00ohd00?n8003oP0070?mj0100of/000<0ofH00?mL003oG0000P3oG0000`3o
G`00oe`00?mL000>0?mL00030?mD0?oooooooooo00?ooooo0Ol00001ooooo`006oooool00ol0003o
ooooooooo`02ooooo`L0ocd000<0odT00?m<003oC000:`3oC0000`3oD000od`00?m<000=0?m<0004
0?mH003oG000oe`00?mH00H0od`000<0oe@00?mL003oG0008`3oG0000`3oH000oe`00?mL00040?mL
00060?mT003oJ`00ofP00?mP003oG000of@04P3oJ`00103oK`00of/00?m[003oK`0;0?mj00030?mn
003oPP00ohH000<0ohX000l0oiH00?nI003o[000ol`00?o8003ohP00nOL006co0`3Bo@00oo800?Od
003]o@00dOl00;Ko0010oaD00`3o00003@30@3400<jP0=3o003nm000om/00?oC003oc`00`>4Y0?oK
002Xo@00n/800?nI003oTP000P3oRP000`3oPP00ogh00?mj00050?mj0080of/000@0ofl00?m[003o
J`00ofl02P3oJ`00103oI000oe`00?mL003oG0020?mP0140oe`01Oooool1o`00007ooooo000Koooo
o`03o`000?oooooooooo00;ooooo1@3o?@000`3o@000odX00?m<000^0?m<00030?mA003oC000od`0
00`0od`000<0oe800?mL003oG0000P3oG0001@3oE`00oe400?mA003oE000oeX001l0oe`000<0oel0
0?mL003oG000103oG0020?mQ00D0oe`000<0of@00?m[003oJ`004P3oJ`001`3oKP00of/00?m[003o
KP00ogP00?m`003oN0002P3oNP000`3oO`00ogd00?n:00030?n:000A0?n?003oV@00oj400=GM2P2n
n`00l/l008oo001Xo`l0H]DL0=;o003_oP00hOl008gE8@1:kDL0?^=T02co4020MVT00P3o00003@23
P280Fol40<Go001Vod00noH00?oT003lk@00YOlS0=SE003Lm@00ok<00?nQ003oU0000`3oRP020?mm
00L0ogX000<0ofh00?m[003oKP002`3oJ`001@3oJ@00of400?mO003oI000ofH00180oe`01Oooool1
o`00007ooooo000Kooooo`03o`000?oooooooooo00;ooooo103o?@000`3oA@00od`00?m<000`0?m<
00030?mD003oC000od`000`0od`0:03oG0000`3oH000oe`00?mL00050?mL00030?m[003oH000oe`0
00<0oe`000<0of@00?m[003oJ`004`3oJ`000`3oK`00of/00?m_00080?mj00030?mn003oNP00ogX0
0080ogX000<0oh800?n:003oRP000`3oRP020?nI000>0?nX003o`000l^l00<km003_o`00__l002Co
B@2Go`00Nola08co000L`Y80P5YJ0<10?0302T020?l0000?0=D<:`20JE80CX1603G/DP0ek4<0ZOlR
0?gj003Xo`00LOl00>gm003oe`00ok@00?nQ003oV@00ohh000<0ohX0203oNP000`3oM`00ofl00?mc
000?0?m[01<0oe`01Oooool1o`00007ooooo000Kooooo`03o`000?oooooooooo00;ooooo00@0ocd0
0?m2003oA@00odX0=03oC0000`3oE000od`00?m<000;0?m<0240oe`000<0oel00?mL003oG0001@3o
G0000`3oH@00oe`00?mL00040?mL00030?mT003oJ@00of400080oe`000<0oel00?mY003oJ`00403o
J`020?m^0080of/000<0ogX00?mh003oNP002@3oNP001@3oO`00ogX00?n2003oQ@00ohP000@0ohX0
00h0ohl00?nI003oV@00ojP00?nc003oa@00omX00?oY0031n2/0F=Da026dS01gJhL0:O<h06EGV0P0
o`0000d0eB/K06VK=`2Ao`X0ZOl00<[o0013j5L0N?0[0:kd1`3QfP00ojP00?nI003oU`00ohd00080
ohX000@0ohD00?n2003oNP00ogd01P3oNP00103oM@00of/00?m^003oKP0<0?m[00<0oe`000<0oel0
0?mL003oG0003@3oG005ooooo`7o00000Oooool001_ooooo0_l00003ooooobH0od`000<0oe000?m<
003oC0003`3oC0000`3oD000oeP00?m<000;0?m<00030?mD003oG000oe`002H0oe`000<0of@00?mL
003oG000103oG0001@3oI000of/00?m[003oJ`00ofP001@0of/00`3oL`0:0?mj00050?mn003oNP00
ogh00?n2003oQP001@3oRP003P3oSP00oiT00?nI003oV@00ojP00?nd003o^000olL00?oO002Zo`00
B?l/081QL@3o0000`0M02P3o00002@300d00:OlI0430O`0eoaP0BOl:0>So002?o`00h=d00?nX0002
0?nI00040?n>003oRP00ohX00?n:0080oh802P3oNP020?m[00040?m_003oJ`00of/00?m_00L0of/0
00@0of000?mL003oI000ofP01P3oG0000`3oH000oe`00?mL00060?mL00Cooooo0_l00001ooooo`00
6oooool00ol0003oooooooooo`02ooooocT0od`000<0oe800?mJ003oC`002P3oC0000`3oFP00oe`0
0?mL000H0?mL00030?mO003oG000oe`000@0oe`000<0of400?mL003oG000103oG0000`3oG`00ofH0
0?mL00040?mL00030?mT003oJ`00of/001<0of/000@0og000?m^003oJ`00ogD02@3oNP001P3oO@00
ogX00?mm003oNP00oh800?n500L0ohX000d0oi@00?nI003oW000oi`00?nX003o[P00ok/00?o7003o
g`00oOX009Co5011dTl0eB/D00`0o`0000/0Zb]60=DV:`0gY;T0Col?0?ka003oe000okd00?nX003o
W000oiT00?nD00040?n:00030?n5003oO@00ogX000P0ogX00P3oM@001@3oL`00of/00?m`003oJ`00
ofh000T0of/0403oG005ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool00_oooolj0?m<
00030?mH003oG000oe0000T0od`08`3oG0000`3oH000oe`00?mL00040?mL00030?m[003oJ000oe`0
00<0oe`000<0ofP00?m[003oJ`00303oJ`001@3oK`00of/00?m[003oJ`00ofl000<0of/02P3oNP00
1P3oOP00ogX00?mn003oNP00ohX00?n600L0ohX000<0ohh00?nB003oV@000P3oV@002P3oY@00ojP0
0?nd003o^000oll00=Ki002mo`00`Ol001Ko;0308T0<0?l000090>l0@030?400LH2C0>Wm003oh`00
olL00?nh003oZ000oj400080oiT000<0ohh00?n:003oRP000`3oRP000`3oNP00ogh00?mj00080?mj
0080ogL000<0og<00?m[003oK`00203oJ`000`3oI000oe`00?mL00020?mL00030?mP003oG000oe`0
00T0oe`01Oooool1o`00007ooooo000Kooooo`03o`000?oooooooooo00;ooooo:@3oC0000`3oD000
od`00?m<000>0?m<00040?m@003oG000oe`00?m@00L0od`000<0oe@00?mL003oG0008@3oG0000`3o
I000oe`00?mL00040?mL00030?mX003oJ`00ofP00080oe`000<0ofP00?m[003oJ`004P3oJ`000`3o
K`00of/00?m_00090?mj00<0ogh000<0ohH00?n:003oRP001`3oRP000`3oSP00oi800?nI00020?nI
000:0?nM003oZ000ojP00?nd003o_000oll00<km000Im:T0Uol006709@h0o`0000`0E/0J0<70@03/
o`00o^d00?o;003o^000ojP00?nQ003oW@00oiT00?nB003oSP040?n:00030?n6003oPP00ogX000X0
ogX00P3oM`020?m[00030?m_003oJ`00of/000D0of/00`3oG0000`3oI000oe`00?mL000:0?mL00Go
oooo0Ol00001ooooo`006oooool00ol0003oooooooooo`02ooooobX0od`000<0odl00?m<003oC000
3P3oC000103oE`00oe`00?mL003oD`050?m<00030?mD003oG000oe`001/0oe`000<0oel00?mL003o
G000103oG0000`3oI000of400?mL00040?mL00030?mV003oJ`00of/001<0of/000H0ofh00?m[003o
J`00of/00?me003oN0070?mj00030?mo003oNP00ogl00080ohP02@3oRP000`3oS@00oi@00?nG0004
0?nI000:0?nS003oZ000oj/00?nf003o`000d>`006OS;00XjeH0?[jG06=LR@h0o`0000P0]b]I08oE
3`0^oc40R_l00??M003o^000oj/00?nX00<0oiT000<0oi@00?n=003oRP000`3oRP00103oR000ohD0
0?n2003oO@0:0?mj00040?mh003oM@00of/00?m^00L0of/00P3oJ@070?mL00030?mO003oG000oe`0
00<0oe`01Oooool1o`00007ooooo000Kooooo`03o`000?oooooooooo00;ooooo?03oC0040?mL00<0
oe@000<0oeP00?mL003oG0003P3oG0000`3oH000oe`00?mL00040?mL00030?mP003oG000oe`000D0
oe`000<0of000?mL003oG000103oG0000`3oJ`00of000?mL00030?mL01<0of/000D0ofl00?m[003o
J`00of/00?mc00020?m[00P0ogX00P3oPP070?n:00040?n>003oRP00ohh00?n:0080oi801@3oV@00
303oW@00ojP00?nX003oZ000oj`00?nh003oa000onL00;_m002JeD00P6UN08D7P0l0o`0000H03OB2
03G6@`1o`fT0oll00?nl003o[0020?nX00050?nM003oV@00oiT00?nF003oSP001`3oRP000`3oNP00
ogh00?mj00090?mj00040?mg003oJ`00of/00?m_00H0of/000<0of000?mL003oG0000`3oG0000`3o
H000oe`00?mL00050?mL00Gooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`02ooooob`0
od`000<0oe400?m?003oC0003@3oC0000`3oE`00oe`00?mL000T0?mL00030?mT003oG000oe`000@0
oe`000<0of/00?mY003oI0000P3oG`000`3oIP00of/00?m[000A0?m[00050?m^003oJ`00of/00?m[
003oL`001`3oNP000`3oO@00ogl00?n800060?n:0080oi8000@0oi@00?nG003oU`00oiL0103oV@00
1@3oW000oiT00?nL003oWP00ojH00080ojP000T0ojh00?nf003o^000olL00?oE003okP00a?l205_o
1`20P1L03P3o00001`20:h00/X1?0=Gn003TkP00oll00?nk003o/`000P3oZ0001`3oX`00oi`00?nI
003oV@00oiL00?nD003oS@001P3oRP001@3oR000ohD00?n2003oQ@00oh800080ogl000L0oh800?mm
003oNP00ogd00?mj003oM@00og0000L0of/000D0oel00?mL003oG000oe`00?mQ00090?mL00Gooooo
0Ol00001ooooo`006oooool00ol0003oooooooooo`02ooooobd0od`00P3oD00=0?m<00030?mD003o
G000oe`002@0oe`000<0of000?mT003oG000103oG00J0?m[00040?mc003oJ`00of/00?mc00L0ogX0
00<0oh800?n:003oRP000P3oRP000`3oSP00oi800?nF00040?nI00030?nM003oV@00oiT000D0oiT0
0P3oY@030?nX000:0?nd003o^000okP00?o0003oa`00omL00?oV0031o`00T81a081QFPh0o`0000P0
RH0302;oGP2gnP<0oml00?o7003o`000okP00?nd00<0ojP00P3oW@030?nI00030?nB003oSP00ohX0
00d0ohX000L0ogh00?mj003oNP00ogL00?m_003oJ`00ofl000D0of/000<0of@00?mX003oJ0002P3o
G005ooooo`7o00000Oooool001_ooooo0_l00003ooooobh0od`000<0oe400?m?003oC000303oC00P
0?mL00030?mQ003oG000oe`000@0oe`000<0of/00?mQ003oG0000P3oG0000`3oH@00of/00?m[000H
0?m[00030?m^003oN000ogD000L0ogX000D0oh800?n:003oRP00ohl00?nD00030?nL0080oih000@0
oj<00?W1003o^P00oj/00`3oX`020?nN000B0?nS003oZ000ojP00?nX003o[@00ok<00?nf003o^000
ok/00?o0003obP00old00?oG003oj`00ioh00:So6`1YZQH0k`0[3@3o00002`1iGeD0SMDD0?[h003o
g`00oll00?o5003o_@00okP00?n`003oZ`00ojd00080oj/000L0ojP00?nN003oV@00oiT00?nG003o
U000ohl000L0ohX000L0ohl00?nB003_[@00oj/00?nB003oRP00oh000080ogX000<0ogD00?m`003o
J`001P3oJ`000`3oIP00oe`00?mL00090?mL00Cooooo0_l00001ooooo`006oooool00ol0003ooooo
ooooo`02ooooobl0od`000<0oe@00?m@003oC0002`3oC00J0?mL00030?mP003oG000oe`000@0oe`0
00<0of000?mL003oG0000`3oG0020?m[00030?mX003oH000of@001P0of/000@0og<00?m[003oJ`00
of/0203oNP00203oPP00ohX00?n:003oUP00oj400?n`003oa000ok@00P3o[0001P3o]000ok`00>ga
003Kl`00mm800?nd00H0ojP000<0okP00?nl003o`0000P3o`0030?o700080?o?003oe`00on<00?o^
003mnP00h?l0022HSP25P3D<0?l000090<10<@1OR/00kol00?ob003oh`00omL00?o;003oa`00ok`0
00@0okP000@0n/h00?nh003o[000oj400`3oV@020?nF000=0?n>003oRP00ohh00?n>003oTP00oiH0
0?nI003oW@00okP00?gg003oZ@00oiH00?n:00030?mj00030?mc003oK`00of/000D0of/000<0of@0
0?mL003oG0002@3oG005ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool00_ooool`0?m<
00030?mG003oE000od`000T0od`000<0oe800?mL003oG000603oG0000`3oG`00oe`00?mL00040?mL
00030?mY003oG`00oe`000<0oe`07@3oJ`00103oL000ogP00?m`003oN0070?mj000X0?mo003oR000
ohX00?n:003oV@00kLT00=7`002fn`00omh00?o7003EfP00mmH00?oL0036oP00S=D[0>oX003o_@00
okH00?n`003o[@00ok<00?n`003o^`00oll00:;b2P3Ai`l0j>h00<W^5P3oe`00omD00?oJ003oh@00
onH00?o^003nm`00n?l00>Co0032o`00<>>D0:XgAPX0o`0001@0eAI404?^IP3:o`00l?l00?gj003o
kP00on@00?oO003nh000om800?o:003oa@00ol800?o?003Dl`00S_TZ0?o2003o/000ojH00?nL00T0
oiT000P0oi`00?nX003o^`00dN`70>7S003]b`00ohl00?n800<0ogX000<0ofh00?m[003oJ`00103o
J`00103oIP00oel00?mL003oH@020?mO00H0oe`01Oooool1o`00007ooooo000Kooooo`03o`000?oo
oooooooo00;ooooo<@3oC0020?mH00030?m@003oC000od`000H0od`000<0oeP00?mL003oG0004P3o
G0000`3oH000oe`00?mL00040?mL00030?mP003oG000oe`000<0oe`000<0of@00?m[003oH0000P3o
G0000`3oI000of/00?m[000G0?m[0080ofl00`3oJ`090?mj000;0?mn003oPP00ohX00?n:003oUP00
oiT00?n`002Xo@00WOla0:go1`3ml`000P2oo@001@2Oo@h0;OlL09Oo003og`00olL00080ok`00`3o
^0004`3oa`00om/007?M@01T`5H0<_A00<7o003nm000onX00>[g000oodT0[_l00??o003Xo`00h?l0
0=So0031o`00Uol008G00030@0L0203o00006@30@1h0=OlA0:Ko003=o`00g?l00>So002ho`<0oOX0
0?Cm002<`0<0Y?LU0?oK003oe`00om/008Wg6P3Ao`00L>E00<oc003SfP00oj`00?nX003oY@00oid0
0?nI003oW@00103oV@002P3oW@00ojP00?n/003o`000lo000=So003ccP00oiT00?n:003oOP020?mj
00030?mg003oK`00of/000L0of/000<0of000?mL003oG0001P3oG005ooooo`7o00000Oooool001_o
oooo00?o0000ooooooooool00_oooola0?m<00050?m?003oG000oe`00?mD003oC`001@3oC0000`3o
E000oe`00?mL000J0?mL0080of40103oG0001@3oI000of/00?m[003oIP00ofT000h0of/000<0ofh0
0?m[003oJ`001@3oJ`000`3oKP00of/00?m[00020?m[00040?me003oL000of/00?me00T0ogX001@0
oh800?n:003oRP00ohX00?nG003oV@00ojP00?o2003nh000Uoh405go;`2:o`00P<db02WQKP2co`00
kO`00?oV003ofP00omD00?o:0080ol8001L0olL00?oD002dla40JOdg05FSSP0<ZYh0@=]D0=co003a
oP00I[iE0;<[AP1cL6/0SMD[0<Ll:`2JZR/0ch0005?E<@2:ZT40G:1E066Z1P2ZEB80o`000?`0=@02
0?l0000J0?H0702c55D0ZUE3066Z101iZR/0J=D;08fZ@@1@Oi/0YmD008=cFP2NcED0Wol00:YE9@13
ZWX0bo<[0?o[003nmP00PMi604kEE`0?oE<0H]Dk0=GU103o_@00ok000?n[003oZ0020?nV00030?nS
003oYP00oj<00080ojP000X0ojd00?nk003nh000Ool70?kZ003o/`00oiT00?n=003oR000ogd00P3o
NP000`3oL000ofh00?m[00050?m[00030?mQ003oG000oe`000L0oe`01Oooool1o`00007ooooo000K
ooooo`03o`000?oooooooooo00;ooooo<P3oC0001@3oE000oe`00?mL003oG000oeP000<0oe@07`3o
G0000`3oJ`00of000?mL00020?mL00030?mX003oJ`00of/00100of/000<0ofl00?m[003oJ`001P3o
J`001@3oL`00of/00?m[003oJ`00og<000/0ogX000<0oh800?n6003oRP000P3oSP008`3oUP00oiT0
0?nX003o_000om<00?gc0039o`008=UA017oM`2;o`00bOl00>co003ho@00i_X00=gm003of`00om<0
0?o?003oe`00on<008?o1`14fF808LY>0<10@010QYH0bh000<Go0015ocD0P6e:0?l0001i`000o`00
081Y@`30@1h0P3>000d0o`0001H0`0Y00?l0003o01l0H81k0?l07`2`@400N<0J0<10;@0k`9P0Wol0
0??o001bof80Y<0002G`I@15XH00HL0m0:ko003oc`00okP00?nd003o/000ojP00`3o/0003@3o]000
ok000?nd003o^000ol`00;Wo001=`1D0j^/00?n`003oX@00oiH00?n:003oPP000P3oNP000`3oM`00
of/00?m[00050?m[00H0oe`000@0of000?mL003oG000oe`01Oooool1o`00007ooooo000Kooooo`03
o`000?oooooooooo00;ooooo8P3oC0000`3oD@00odl00?m<000>0?m<01T0oe`000<0oel00?mL003o
G000103oG0000`3oH@00oe`00?mL00030?mL00050?mT003oJ`00of@00?mQ003oI000303oJ`000`3o
KP00of/00?m[00050?m[00050?m^003oJ`00of/00?m[003oL0000`3oJ`020?mc0080of/000<0ogP0
0?mj003oNP001`3oNP000`3oO@00ogX00?n500030?n:000P0?n=003oV@00oiT00?n[003oa@00`_<0
09Sf;018eRl0B>I702KoC`16VX00D>Ha053]D035o`00LLD[05?E902[dc`0nNd00?oQ003oi000oo00
0?3o002>dUD0FH2K0?l0003Z02/0Ih1;07^ZC02UEED0i`0[0?l0703E:a@G0?l0000Q0=@[;03o0000
P65O07[E;`2IfB/0Dl=;0:YE7@3P02/0PUV<07co8@2VkR/0omL00?o7003o_@00okP00?nk003oa@00
amD20?o:003gd@00olD00?o2003oa`00om800?k_002:o`00i_<00?nm003o/000oj/00?nI003oRP00
oh000080ogX000<0og<00?m[003oJ`00103oJ`00103oIP00of400?mQ003oH@020?mO00@0oe`01Ooo
ool1o`00007ooooo000Kooooo`;o00000ooooolS0?m<0080oe003P3oC0000`3oE000oe`00?mL000N
0?mL00030?mT003oG000oe`00080oe`000<0of@00?m[003oJ`004P3oJ`001@3oK`00of/00?m[003o
J`00ofl000<0of/000D0og<00?m[003oJ`00of/00?mc000>0?mj00@0ohX001P0ohh00?nF003oV@00
oj400?n`003gg@00N?l008S01`2fo`00`_l005co5P10`9H0SD1N027o?`2`P400=/I0003XQ@1`o`X0
m?d00?oe003inP00i?l00=So002O`5<30?l000030<101`3o0000o`0001d0o`0000<0o`0409Qe@020
P4<00P3o00001@30@0h0J;aY0?gj003og`00om<000<0olL00140om/006ko;02[o@00Zol00<oc003o
f`00omL00?oS003im`00<OmN0;3g003og`00oll00>_M003o/@00ohX00?mn00020?mj00030?m_003o
J`00of/000H0of/000<0ofP00?mL003oG0001@3oG004ooooo`;o00000Oooool001_ooooo00?o0000
ooooooooool00_oooolT0?m<0080oe003@3oC0000`3oE000oe`00?mL000G0?mL00030?mP003oG000
oe`000@0oe`000<0ofP00?mP003oG0000P3oG0000`3oJ000of/00?m[000K0?m[00040?mg003oJ`00
of/00?mc00`0ogX000<0ogh00?mj003oRP00103oRP006@3oUP00oiT00?nQ003o/000o^D00>kj002l
nP00lol00=7o0009of/0PD1Y0?l00030@240Zd1F0:A0DP30;D00G_l00:Wo8P3co`00__l00:60002C
`2D0[<0000gIF0300d008P3o00007@304T00`40J0?l0003o0000`1900<K0<P3do@00j_X00?oW003o
d`00oll00?oC003oh`00h?l0083o000LofP0S_li0?kd003okP00oo800??o001Sob`0f?l00<km002F
o`L0f?l00?nh003oRP00ohH000<0ogX000<0ofl00?m[003oJ`001@3oJ`080?mL00Gooooo0Ol00001
ooooo`006oooool00ol0003oooooooooo`02ooooobD0od`000<0odl00?mD003oC0002`3oC0000`3o
C`00oe`00?mL000A0?mL00030?mO003oG000oe`000@0oe`000<0oel00?mL003oG0000`3oG0001@3o
H@00of/00?mV003oH@00ofH001H0of/000D0ofh00?m[003oJ`00of/00?me00030?m[00030?mj003o
N000ogD000/0ogX000<0ogd00?mj003oPP00103oRP003@3oS@00oi800?nI003oV@00oj<00?n^003o
^`00oll00?oO003nmP00eol005SE;`26MT40103o00002@3E4B/0PcUc0:kE:`3<o`00[mDW081GL02`
ECl0ZShg0:Y@?00V0?l0000J0;0[AP2GP2L0VZX[0:kE:`1PeC80LLeG0?o[003oh@00o^d00=3h6@2e
o`00=Y>f02;oK02CobH0c?l006Ko102Vo`00Z?l407[S:`1[o`80b?h00?;P003o^P00oih00?n?003o
R0020?mj00030?mh003oKP00of/000D0of/000<0of@00?mL003oG0001@3oG0000`3oG`3ooooooooo
o`03ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool00_oooolV0?m<00030?m@003oF000
od`000X0od`000<0oe@00?mL003oG0006@3oG0000`3oH000oe`00?mL00030?mL01H0of/000D0ofl0
0?m[003oJ`00of/00?m_00030?m[00040?mj003oM`00of/00?mg00/0ogX000<0ogh00?mj003oNP00
0P3oPP000`3oQP00ohX00?n:00030?n:00<0oiT000T0ojD00?nX003o^000ol000?oC0020lfd0Tol0
06C:@030@0h01@3o00001@30@2D0B?1Y092MMP3g06X0`40>02`0o`0001P0Q81:0?l0002/P3D0n?d0
0?gj003``2<08:2`027o=020P5H0`40B05f0P00jo`L0CI97003XV00Ioe40>?l`08Ko6P1goaH0omL0
0?n`003oV@00ohX00?n6003oOP020?mj00030?mc003oJ`00of/00080of/000@0ofl00?m[003oJ`00
of000`3oG000103oH000oe`00?mL003oG005ooooo`7o00000Oooool001_ooooo00?o0000oooooooo
ool00_oooolW0?m<00030?m?003oFP00oe4000T0od`000<0oe@00?mL003oG0004P3oG0000`3oG`00
oe`00?mL00040?mL00030?mQ003oI000oe`00080oe`000<0of400?m[003oJ`004@3oJ`001@3oKP00
of/00?m[003oJ`00og000080of/00P3oL`000`3oJ`00ofh00?mj00060?mj00040?mm003oNP00ogX0
0?mm00D0ogX000<0ogd00?mj003oO@001P3oRP00103oU`00oiT00?nI003oW0020?nX00070?nh003o
`000om800;Cb:`0S[;H0WH0[0:Xl@`050?l000040?l0901cZR80TfT[0<84EBd0o`0000P0eAh[0:Y1
AP1[eAH0VMDQ0>Ko002Noa40KX`n0?l06P<0o`0000`0ZS`d0?l0003o0000>?lV0:_o9P3go000T_h0
0=?g003ib@00oiT00?n:003oQ@030?mj00030?mc003oL000of/000H0of/00P3oJ@000`3oG`00oe`0
0?mL00020?mL00Gooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`02ooooobP0od`000<0
oe000?mL003oF0001`3oC0000`3oD000oe`00?mL000D0?mL00030?mP003oG000oe`000@0oe`000@0
of/00?mX003oI000of@03P3oJ`00103oK`00of/00?m[003oK`020?m[00050?mc003oJ`00of/00?m[
003oNP000P3oJ`0D0?mj00030?mn003oRP00ohX000D0ohX000h0oiH00?nI003oV@00oiT00?nU003o
Z000oj`00?nh003oa000oml003?EM`0Em7/0`41O0?l08`H0o`0000<0`40B0?l0003o0000;`3o0000
1@30@340C8100:ko001/cT00`0Y000D0o`0000D0`0Y00<P0NP0Ij9X0Y?d00?oS00020?oC00050?n]
003oTP00ohX00?n6003oOP000P3oNP000`3oM`00of/00?m[00060?m[00030?mX003oG000oe`000@0
oe`01Oooool1o`00007ooooo0008ooooo`;o00001?ooool00ol0003oooooooooo`02ooooo`?o0000
1Oooool00ol0003oooooooooo`02ooooobT0od`000D0oe800?mL003oG000oeL00?mA00020?m<0003
0?m?003oE000oeX001L0oe`000<0of400?mL003oG0000`3oG0000`3oI000of/00?m[000=0?m[000<
0?m^003oJ`00of/00?m^003oJ`00og<00?m^003oJ`00og<00?mh003oL000ogD05@3oNP000`3oP000
ogl00?n200060?n:000@0?nB003oU`00oiT00?nL003oX`00ojP00?n[003o]P00ok/00?o7003oe@00
no@009go1`2BeAH0QUDm0>d0:`@0o`0000<0o`0O0?l0003o0000<@3o00000`3E7R/0OHha05^BI@07
0?l0000:02cEGP2Qo`@0o_400?o?003o_@00ojh00?nQ003oU000ohX00?n500<0ogX000<0ogD00?m`
003oKP001P3oJ`070?mL00Gooooo0Ol00001ooooo`001oooool01?l0003oooooooooool00007oooo
o`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`02oooooaP0od`000<0oe00
0?m<003oC0003`3oC0000`3oF000oe`00?mL000F0?mL00030?mP003oG000oe`000@0oe`00P3oH004
0?mL00030?mT003oJ`00of/000/0of/000X0ofl00?m[003oK`00of/00?m_003oM`00of/00?mg003o
NP00og<05`3oNP000`3oOP00ogX00?n200070?n:00050?nB003oV@00oiT00?nI003oX@000P3oZ002
0?nh00090?o0003ob`00omL00?oZ003mnP00X_l7037o>`30@5/0c01003T0o`0000<00]ec0?l0003o
00001@3o00002P1A`580[_l00;ko003bk`00ok@00?nQ003oV@00oi800?n:003oQP040?mj00030?m_
003oJ`00of/000D0of/000<0of000?mL003oG0000`3oG0000`3oH03oooooooooo`03ooooo`7o0000
0Oooool000Go00000_ooool01?l0003oooooooooool0000;ooooo`03o`000?oooooooooo00;ooooo
0_l00003oooooaX0od`000<0odl00?m<003oC0003@3oC0000`3oC`00oe`00?mL000G0?mL00030?mO
003oG000oe`000@0oe`000D0ofH00?mT003oG`00oe`00?mO00090?m[00070?m^003oJ`00of/00?m^
003oJ`00ogP00?m`00030?mh01T0ogX000H0oh000?mj003oNP00ohP00?n5003oR0050?n:000E0?n=
003oS`00oiL00?nI003oW000oj400?nX003o[P00okP00?nm003oa@00ol`00?oE003og000oo000?Wn
003Oo`00Zol008SE002FEBl0ZU1303P0o`0000<0eB/[0?l0003o0000103o00003@3E6B/0P6B207^0
HP1]oaD0iM/00?n`003oX`00oiT00?n=003oRP00ohP00?mj003oO@000P3oNP000`3oL000of/00?m^
00060?m[0080ofH000@0of400?mO003oG000oe`01?ooool2o`00007ooooo0007ooooo`04o`000?oo
ooooooooo`0000_ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02oooooa/0od`0
00<0oe000?m<003oC0003@3oC0000`3oF000oe`00?mL000G0?mL00030?mP003oG000oe`000@0oe`0
3P3oJ`00103oK`00of/00?mc003oL`0E0?mj00050?mn003oNP00ogX00?mj003oOP000P3oNP001@3o
PP00ogX00?n2003oQP00ogh000P0ohX001@0oi800?nI003oV@00oiT00?nU003oZ000ok@00?nl0030
gBD0nN/00?OU003og`00on<00?k]003/o@00R_la0;Ko002c;Kd0T80:0<0i@400o`0000H0CIe]05OE
EP1kobd0/oD00?o4003o[0020?nI00040?n>003oRP00ohX00?mn00@0ogX000<0ofl00?m[003oJ`00
1P3oJ`000`3oH000oe`00?mL00020?mL00Gooooo0Ol00001ooooo`001oooool01?l0003ooooooooo
ool00007ooooo`Co00001Oooool00ol0003oooooooooo`02oooooad0od`000<0oe400?m<003oC000
2`3oC0000`3oE000oe`00?mL000G0?mL0080oel01@3oG00>0?m[00030?mc003oM@00ogX001P0ogX0
00P0ogd00?mj003oNP00ogd00?mj003oRP00ogl00?n500T0ohX000`0ohl00?nG003oV@00oi`00?nV
003o[P00okd00?o5003nf000^OL003WEDP3Bo`020?kb00060=Sn002@Eb`0Mcc/06_E0P3E:`l0eA@[
?@3o00003@2Z<D<0eB/N0:8gIP21P1<08MEn0:kR:`3mj@00old00?nh003oZ000oi`00?nI003oS@00
0P3oRP001@3oPP00ogX00?mj003oNP00ogD000P0of/000<0of@00?mL003oG0000`3oG005ooooo`7o
00000Oooool000Oooooo00Co0000oooooooooooo00001oooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo00;ooooo7P3oC0000`3oE000od`00?m<000:0?m<00030?mD003oG000oe`00140
oe`000<0of000?mL003oG000103oG0000`3oI000of000?mL00030?mL00`0of/000<0ofl00?mc003o
M`001@3oNP020?mn00L0ogX000<0oh800?mj003oNP001`3oNP001`3oOP00ogX00?n2003oOP00ohH0
0?n:003oQP002@3oRP00103oSP00ohX00?nB003oUP020?nI000?0?nM003o[000h=H008Si?03il`00
Nna007O`@029`000f?l00>Co003co`00f?l004;0=03o02L0X3b00400o`0000`0DL0D08Co0032o`00
kol00?oZ003oc`00ol@00?n`003oZ000oid00?nI003oUP020?n:00030?n6003oNP00ogX00080ogX0
00<0ogL00?m[003oJ`001@3oJ`000`3oI000oe`00?mL00030?mL00Gooooo0Ol00001ooooo`002?oo
ool2o`0000Sooooo1Ol00004ooooo`03o`000?oooooooooo00;ooooo7`3oC0020?mD00X0od`000<0
oe@00?mL003oG0004P3oG0000`3oG`00oe`00?mL00040?mL00050?mY003oIP00of400?mQ003oJ@00
2P3oJ`020?m^00030?m[003oNP00ogX00080ogX00P3oPP00103oQ@00ohP00?n8003oQ@020?n2000>
0?mj003oP000ogd00?mj003oPP00ogX00?n2003oNP00oh800?mm003oQ@00ogl00?n8003oQ@0=0?n:
00060?n=003oRP00ohd00?n:003oTP00oiL00P3oV@003`3oW000ojP00?n`003dd`00S?/>05[o600^
_Z<0A:Xk07_E1`1Koa@0WH0N05_K;`2^o`00V:X00=D[1`110?l0000=0=DK:`31ED40b=D00>On003o
j@00om800?o2003o]P00ojP00?nQ003oV@00oiL00?n=00020?n:0080ogd00P3oNP000`3oL`00of/0
0?m^00060?m[00030?mT003oH@00of400080oel01Oooool1o`00007ooooo000Kooooo`03o`000?oo
oooooooo00;ooooo803oC0000`3oD000oe`00?m@00080?m<01`0oe`000<0of@00?m[003oJ`003@3o
J`000`3oL`00ogX00?mj00020?mj00040?n2003oSP00oi800?n>00P0ohX000<0ohH00?n:003oQP00
5`3oRP000`3oSP00oi800?nI00020?nI000?0?nM003oX@00ojP00?n`003oa000_?X007c05P00od@0
P4Ye0<10>020LH`0o`08081FBP19o`<0`40F04@0o`0000P0FL0c08?0AP3mm`00onX00?kI003o^000
oj`00?nX0080oiT000D0oiH00?n:003oRP00ohH00?mn00030?mj00030?mc003oJ`00of/000H0of/0
00@0ofP00?mP003oG000oe`01Oooool1o`00007ooooo000Kooooo`03o`000?oooooooooo00;ooooo
8@3oC000103oD000oe`00?mH003oD0050?m<00030?mH003oG000oe`001@0oe`000<0of@00?mL003o
G0000`3oG0000`3oI000of/00?m[000;0?m[00030?m_003oJ`00og<000@0ogX000L0ohX00?nM003o
`000oid00?nF003oTP00ohh001d0ohX00P3oSP000`3oTP00oiT00?nI00020?nI000>0?nM003oY@00
ojP00?nd003oa000V<e00;go001N`1X02J2Y0?l0003o01<0o`000>00@012RUY60?l00008043oAP3P
o`00jL0j08G_3P3o`000ok@00?nX003oY@020?nI00030?n>003oRP00ohX000@0ogX02@3oJ`040?mL
00Gooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`02ooooob80od`000@0oe@00?mL003o
G000oeX00`3oE`0B0?mL00030?mO003oG000oe`000<0oe`000<0oel00?mY003oG`000`3oG0000`3o
I000of/00?m[00080?m[00040?m^003oJ`00of/00?m^00D0ogX000X0ohD00?n:003oX@00hN400?o0
003o[@00oj<00?nN003oU`00oi80103oRP000`3oS@00ohX00?n:00050?n:00040?n=003oS`00ohd0
0?n=00H0ohX000@0ohd00?n:003oTP00ohX00P3oTP060?nI000:0?nS003oZ000oj/00?nh003o`000
omL00;7b:`2UeBl0IME:081BH@<0o`0000<0eAAD0?l0003o0000A03o00003P2YP000SHU@02QoZP1`
ieD0om800?nk003o[P00ojP00?nV003oX`00oi`00?nD003oRP00ohD00`3oNP000`3oM@00ofh00?m[
00050?m[00030?mT003oG000oe`00080oe`01Oooool1o`00007ooooo000Kooooo`;o00000ooooolS
0?m<00030?mH003oG000oe`001H0oe`000<0of000?mL003oG0000`3oG0001@3oI000of/00?mT003o
G000of0000`0of/000<0ofl00?m[003oJ`000`3oNP020?mn000<0?n:003oTP00oj400?o0003Nk`00
cn/00?[M003ob000oj400?nI003oUP00ohh01P3oRP000`3oSP00ohX00?nB00070?nI0080oiH000H0
oi800?n>003oUP00oi800?nI003oUP070?nI000;0?nU003oZ000ojP00?n`003o^000ol@00?o?003o
jP00m?d0082d@020CVd0C03o0000301=`3L0ColP0?oC003oa000okP00?n`003o[000ok000<3>0`3o
Y@00ohh00?n:00<0ogX000<0og<00?m[003oJ`001@3oJ`000`3oJ000oe`00?mL00020?mL00Cooooo
0_l00001ooooo`006oooool00ol0003oooooooooo`02ooooob<0od`000<0odl00?mL003oG0005`3o
G0000`3oG`00oe`00?mL00030?mL00`0of/000<0ofh00?m[003oJ`000P3oJ`060?mj000;0?n5003o
RP00ohd00?nL003oZ`00olD00>Gb003hl000ol000?nV003oW0000P3oV@030?nG0080oi@00P3oU`03
0?nI00040?nQ003oZ`00oj400?nN0100oiT000h0oj400?nX003oZ000oj/00?nh003o^`00olL00?oJ
003okP00noh00=SE001j[4/0/5D[0:Y>CTT0o`0000h0eB/X0:GE003DnP00on400?oD003oa`00ol00
0?nm003oa@00_>h70?WK003oV@00ohX00?n000<0ogX000<0ofh00?m[003oJ`001@3oJ`00103oJ@00
ofH00?mQ003oH@05ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool00_oooolT0?m<0003
0?mD003oG000oe`001H0oe`000<0of@00?mL003oG0000`3oG00A0?m[00030?mg003oNP00ogX000<0
ogX000`0ohH00?n:003oSP00oiT00?nX003o`000jOD00=?c003oa000oj`00?nX003oW@090?nI0008
0?nM003oZ000ok000=;a003o_000ok000?nX003oW@0;0?nI00030?nM003oV@00ojP000<0ojP000X0
ok@00?nh003oa000omL00?Gc0032o@00k?l00<Wo002YP2<0P7aNBP3o00003P302T00HX100:Wo8P3m
nP00c_d00?K_003of`00oll00?oO002GoAH0]_l00?nQ003oRP00oh800`3oNP090?m[00030?mT003o
G000oe`000Gooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`02oooooaD0od`00P3oC`0=
0?m<00030?mD003oG000oe`001L0oe`000D0of@00?mL003oG000oe`00?mO000;0?m[00060?m^003o
J`00of/00?m^003oN000ogD01@3oNP003P3oP000ohX00?n:003oU000oi`00?n[003o`000[OP40=Ki
003obP00okP00?n[003oZ000oj<00P3oX@020?nN000=0?nI003oW000oih00?nS003oZ000ok000?o5
003]l`00S_HM0?o5003oZ`00ojP00?nS00030?nQ00030?nL003oWP00oi`00080oiT00P3oWP00403o
X@00ojP00?nX003oZ000oj/00?n^003o^000ol800?oG003Kk@00LjXi07_o0035o`00Yi/[0=D[5P2Z
;3i;0?l0000=07I@P02`o`00`=D008NZE@1NG;L0b_T70?ga002VoRH0Y=<:0?O>003oX@00ohd00?n8
00030?mj00030?me003oJ`00of/000D0of/000@0of@00?mL003oG000oe`01Oooool1o`00007ooooo
000Kooooo`03o`000?oooooooooo00;ooooo5`3oC0020?m@00/0od`000<0oe@00?mL003oG0004@3o
G0000`3oH000oe`00?mL00030?mL00040?mV003oJ`00of@00?mT0100of/000<0og<00?mj003oNP00
103oNP003@3oQP00ohX00?n:003oV@00oj400?nh003ji@00[_d70?gc003oc`00ol000?nh003o[000
2@3oZ000203o]000o]H00:3e002;o`00b_T00?o?003o_000ok003`3oZ0002`3o/000okP00?o0003[
f@00I/j007NdM@0=oe40;_li04F0L`1i`000QD1>04`0o`0000h0`40N05;o0020?h00o`0001n0PP27
oah0h?l008[A@02_nPh0olP00?n]003oTP00ohX00?mn0080ogX000<0ofl00?m[003oJ`001@3oJ`00
103oH000oe`00?mL003oG005ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool00_oooolH
0?m<00030?m?003oD@00oe@000T0od`000<0oeL00?mL003oG0004@3oG0020?mO00@0oe`000<0of40
0?m[003oJ`003P3oJ`000`3oKP00og<00?m`00060?mj000C0?n2003oR000ohX00?n:003oV@00ojH0
0=cQ003cj@00c?`00<SA:`3og`00olX00?o0003o_@00ok/00?nh003o`000f<T00?nc00020?n]0009
0?n`003o]P00okd00?oG002?obH0g?l00?o^003odP00ol800080okP000@0ok000?n]003o[@00ojd0
0`3oZ0000`3oZ`00ojP00?nX00020?nX000=0?n]003o[P00okP00?nh003oa@00oml007oo5P0ZW<l0
:lRH0?l0003D15D0P5a?0>L0:`1=0?l0000=085h?P3o0000o`000>80:`2<KSd0>OXl03jCT@2[o`00
b]l[0>34003oTP00ohX00?mo00020?mj00030?mh003oJ`00of/000D0of/000@0ofT00?mO003oG000
oe`01Oooool1o`00007ooooo000Kooooo`03o`000?oooooooooo00;ooooo6P3oC0000`3oD000oe`0
0?mD00060?m<00030?mH003oG000oe`000`0oe`000<0of000?mL003oG000103oG0000`3oI000of00
0?mL00020?mL00030?mT003oJ`00of/000l0of/0203oNP003P3oPP00ohX00?n:003oSP00oiT00?nQ
003o/000ol@00?[]0032o`00o_@00?oO003od`00hnD00P3oc`00103_k@00h_<00?o7003o_0020?nh
000;0?nl003oa`00mnD007_o2P3Ao`00l?d00?[Y003od`00ol/00?nl003o^0000P3o_000103o`000
okP00?n`003o[0030?nX00030?n/003o/000ok@00080okP000L0ol000?o7003oe`00nOL0053o9@2P
P0<0P6f00500o`0000`0m`100?l0003o0000o`00094UP01I`680AJF006?oA`3oe`00oj400?n>003o
RP030?mj00030?mc003oJ`00of/000P0of/000<0ofP0ooooooooool00oooool1o`00007ooooo000K
ooooo`03o`000?oooooooooo00;ooooo6`3oC000103oC`00oeX00?mL003oFP030?mG00030?mJ003o
G000oe`000h0oe`000<0oel00?mL003oG000103oG0001@3oJ`00of@00?mO003oG`00ofT000h0of/0
00<0og000?m^003oKP001`3oNP00503oP000ohX00?n:003oRP00ohd00?nI003oW000oj/00?nm003i
k000^o/008Oo6`3Ho000]?h009on303>l`80o^l00<kl002jn@00omX00P3oc0004@3obP00olL00?oB
003oh@00h?`00:_o001]o`<0H?hM0<Wl003nk000oll00?o<003oe000o^<00=Kd003oa`00ok/00080
okP00`3o]P030?nh00090?nm003oa@00olX00?oJ003nm000i?l00;7E001UQ6H0ZSi605<0o`0000P0
COl_0:Kn0P2DoP80l^/00>fl003oW000ohX00?n800<0ogX000<0ogP00?m^003oJ`001P3oJ`000`3o
I000oel00?mL0005ooooo`7o00000Oooool001_ooooo0_l00003oooooad0od`000<0oeP00?mL003o
G000503oG0000`3oH000oe`00?mL00030?mL00030?mT003oJ`00of/00100of/000<0og<00?mj003o
NP001P3oNP000`3oOP00oh800?n:00020?n:000B0?n>003oV@00oid00?nX003o/000ol/00?oG003R
m`00l_X00<Go001To`L0F?l>0=7o001/oaH0Ilj00?kd003Om`00lNl00P3oe`004@3of`00onX00?gj
003To`00Q?l00430?P0NoaD0^od00?oW003og`00h_L006co8P1ko`X0om/00?o7003oa000ok`000@0
okP00P3o_000203oa`00ol/00?oC003oh`00^_d:07?0@`2Ko`00H6V:D@3o0000301A`2P0o`0004VB
P000ofX0i^l00?o8003o/000oj400?nF003oRP00ohH00?mn0080ogX000<0og<00?m[003oJ`001P3o
J`030?mL00Cooooo0_l00001ooooo`006oooool00ol0003oooooooooo`02oooooah0od`000<0oeX0
0?mL003oG000503oG0000`3oI000oe`00?mL00020?mL00030?mV003oJ`00of/000d0of/000@0og<0
0?m^003oJ`00og<0203oNP000`3oO@00ohX00?n:00020?n:000B0?nD003oV@00oiT00?nV003o[P00
okP00?o5003oc`00on400?gj002[o`00J;iE02oh;00OmC00VOl00=Oo002?o`00m?`00P3oj`007`3n
lP00o_@00>on003Go`00SOl007ZZ000[dV@0J_l<0=Sn003mnP00Uol007So0032eb/0on@00?oE003o
c000olL00?o5003o`P00ol000?o2003oa@00olL00?o:003oc`00oml00<3h0024eE<05_Y[0::06@2Z
EB00D@3o00002`2_ECh0W_0[0>ol003fj@00olL00?nf003oYP00oiT00?n?003oRP00oh8000@0ogX0
0P3oL0060?m[00<0oe`01Oooool1o`00007ooooo000Kooooo`03o`000?oooooooooo00;ooooo7P3o
C0000`3oD000oe`00?mL000D0?mL00050?mP003oJ000of000?mL003oH0004@3oJ`0:0?mj00030?n6
003oRP00ohX00080ohX000H0ohh00?nF003oV@00oiT00?nU003oZ0020?nh000L0?o7003oe`00o_00
0=co0039o`00Q?l0016`Z`09cYT0O?l0003XW02Ro`00mol00=So0027oah0kol00<Wo001Eo`h00=7U
06e0RP20FX002Om10<Wo003To`00cOl009Oo0000iJ00aOl00?oW0080oml000<0om<00?o7003oa`00
0P3oa`020?o;00070?oG003ojP00S_lB02eJl0307T00o`000<0J@01A0?l0000;0<103P27oc`0l?d0
0?o?003o`000ok000?nQ003oV@00ohh00?n:003oQP000`3oNP000`3oL`00of/00?m[00060?m[0003
0?mX003oG000oe`000Gooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`02ooooo`/0od`0
00<0odl00?m<003oC0004@3oC00A0?mL00030?mO003oG000oe`000<0oe`03@3oJ`00103oKP00of/0
0?m[003oJ`020?m^0080of/0203oNP000`3oO@00ogl00?n500030?n:00050?n=003oS`00oiT00?nI
003oW0000P3oZ000503o]P00ok/00?o7003oe`00onT00?Sj003:o`00BNHd0:X[IP374ED0/5D4081c
L@1<o`80cOl00;?o0028cDL0VMD90:7E:`1Ihb/0V5ED0P3o0000301oIU/0Nol007Oo6`2Do`00D?lC
007XT01KV6h0lOh00:;l6@1@oc80onH00?oG0080om8000T0oll00?oG003oe`00on400?o^003^o`00
NOlH07RZ<@3E:a40DP3o0000203E:b<0ZUE307kh?P3odP00ol800?n`003oYP00oiT00P3oRP001P3o
PP00ogX00?mj003oNP00ogP00?m`00T0of/000<0ofH0ooooooooool00oooool1o`00007ooooo000K
ooooo`03o`000?oooooooooo00;ooooo7`3oC00<0?mL00030?mP003oG000oe`000<0oe`000<0of@0
0?mL003oG0000P3oG00B0?m[00<0ogL0103oNP001@3oOP00ogX00?mj003oOP00ogX000H0ohX0103o
V@020?nX00090?nd003o^000olL00?oK003olP00i?l007Co9@0[oa80nP100080o`0000T0a@1008ed
JP2?o`00Q?l005[06P30@2d0Q81>08j00020P4X00P3o00003012`7`0AL1301FQo00OocT0P4M]0<0B
@01Y`280`Ol0057o6P2FocD0oOL00?oV0080om/00P3oe`001`3og`00onH00?kd003To`00CKbb08f0
@030?400D`3o00001`1d`3`0k_X00?oS003ob`00ol000?n/003oV@000P3oRP001@3oPP00ogX00?mj
003oNP00og<000P0of/000<0ofP00?mL003oG0001Oooool1o`00007ooooo000Kooooo`03o`000?oo
oooooooo00;ooooo4@3oC0020?m@00`0od`04P3oG0001@3oH000ofP00?mL003oG000of0000l0of/0
00@0ofl00?m[003oJ`00og<02@3oNP020?n200D0ohX000D0oiH00?nI003oV@00oiT00?nQ00020?nX
00080?nh003o`000oll00=Sd003Ho`00]_l001clM`20KHP40?l00006042:K012o`00G81k016Y]`3o
0000P5:01P3o00003@3o03h0SD1B0<0B@03o0000XH000:[0@01eo`004MUo0=gm003olP00onX00?oV
003oh`000P3oiP001@3okP00mOX00;R0;P2H@4X0`40N05@0o`0000X0UhY00=7o003gm000oml00?oZ
003?g000oid00?n>003oRP00ogh00`3oNP000`3oL`00of/00?m[00060?m[00030?mP003oG000oe`0
00Gooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`02oooooa<0od`000@0odl00?mA003o
D@00oe401`3oC0000`3oFP00oe`00?mL000<0?mL00030?mO003oG000oe`00080oe`0403oJ`000`3o
KP00of/00?m[00030?mc00P0ogX000<0ogd00?n2003oQ@001@3oRP00403oTP00oiL00?nI003oV@00
oi`00?nX003oZ`00ok<00?nk003o`P00oll00?k]0026o`l0Vol<073o501HWXh40?l00003081VF@3E
:a/0o`0000d0o`000100P80m0;]E3@29P1@0FG^609OE:`1kc5D0Y_hA0?oc003okP00on/00?o^003n
n@00lol00;:Z6P2g?WH0eB/[E03o00002P2nE@00TX0n03W[E@3Zo000Y_hQ0=cS003oX@00ohd00?n:
003oP0030?mj00030?mh003oL000of/000H0of/000<0oel00?mL003oG0001Oooool1o`00007ooooo
000Kooooo`03o`000?oooooooooo00;ooooo5P3oC0000`3oD000oe`00?mH00040?mD0100oe`00P3o
H0030?mL00d0of/000@0ofl00?m[003oJ`00ofl00P3oJ`000`3oL`00ogX00?mj00070?mj00030?mn
003oNP00ohX000D0ohX00140oiH00?nI003oV@00oiT00?nM003oY@00ojP00?nd003o^000ol@00?o7
003od`00onX00?gj003To`00E<YB02;ML@0F0?l000070<0>@020;800QL0O04fFK@3Ao`00n?d00?kh
00020?oe00050?cm003/o`00_h1f00_o6@306T00EP3o00001`10J>h0Ool]0:KN@03ob000oiT00?n>
003oRP00103oNP000`3oK`00of/00?m[00060?m[00030?mX003oG000oe`000Gooooo0Ol00001oooo
o`006oooool2o`0000?ooooo603oC0000`3oE000oe`00?mL000>0?mL00030?mO003oG000oe`00080
oe`00P3oIP000`3oH@00of@00?m[00090?m[00040?m^003oJ`00of/00?m`0080of/000<0og<00?mh
003oM@002@3oNP020?mm00D0ohX000<0ohl00?nG003oV@000P3oV@00403oW000ojH00?nX003o/`00
ol800?o:003oc000omX00?oO003okP00mo`00=co002^o`00E_l:00WjD02Z<EdE0?l000060?@0:`23
Jd40Pf]C09jZ;028oa00l?l00P3ho`00103co`00b_l006f1MP3E0TmE0?l000070=DI:`3E:b<0R80g
036/I@2VoR<0m<X00?nL00020?n:00060?mo003oNP00ogX00?mj003oM@00og002@3oJ`000`3oI03o
ooooooooo`02ooooo`;o00000Oooool001_ooooo00?o0000ooooooooool00_oooolI0?m<00030?m@
003oG000oe`00180oe`000<0of@00?m[003oJ`003`3oJ`000`3oM`00of/00?mg00090?mj00030?mn
003oNP00oh8000@0ohX000<0ohh00?nI003oV@000`3oV@001`3oW@00ojD00?nX003o/000ok`00?g_
002knQX00P3ojP001`3Vm`00kol00=So002=`0@0DjFh07b0EP30@3T0603o00002P304T00C/1004So
;03Io`00j?l00>_o003To`00cOl006W04P20P3mE0?l0000904:0/@1AeD00ake00<?i003od`00ojD0
0?nI003oRP00ohH000@0ogX02P3oJ`000`3oH000oe`0ooooo`04ooooo`7o00000Oooool001_ooooo
00?o0000ooooooooool00_oooolJ0?m<00030?mB003oG000oe`000d0oe`000D0oel00?mQ003oG`00
oe`00?mV000<0?m[00050?m^003oJ`00og<00?m]003oKP002P3oNP00103oO@00ogX00?mm003oQ@04
0?n:0080oiL00P3oV@000`3oW000oih00?nS00030?nX000<0?nc003o`000on4008Co5030oP00[OD[
0:[o:00geEL0VOl005Co8@20L7H0_B]36P3o00002@3E1cX0EJYj07nd=03Bo`00eol00=Co002Go`00
Rg0l0?l02P1E0?l0000;07nUIP3hm@00omL00?o0003oZ`00oiT00?n=003oRP00ohD00?mj003oO@00
0P3oNP000`3oL`00ofh00?m[00060?m[00030?mQ003oG000oe`000Gooooo0Ol00001ooooo`006ooo
ool00ol0003oooooooooo`02oooooa/0od`0403oG0000`3oI000of/00?m[000:0?m[00060?m_003o
J`00of/00?mg003oJ`00og<03@3oNP020?n600@0ohX000<0oiH00?nI003oY@001P3oZ0003@3o[000
ok@00?nh003oa000oll00?O`003Lo`00K?a004:YL02n5X00o`0001k0N`305T00703o00001`2=@5d0
`41C0:Oo0035o`00`Ol008?h@020HV80EP3o00001P24o`00oO<00?oK003o/000oj400?nI0080ohX0
00<0oh800?mj003oNP000P3oNP000`3oK`00of/00?m[00060?m[00030?mP003oG000oe`000Gooooo
0Ol00001ooooo`006oooool00ol0003oooooooooo`02oooooa/0od`000<0oeX00?mL003oG0002P3o
G000103oH@00oe`00?mL003oI00:0?m[00070?m^003oJ`00of/00?mc003oJ`00ogX00?mh000<0?mj
00030?n0003oO`00ohX000@0ohX000P0ohl00?nI003oX`00old00>;C003nc000okH00?n]0080ok00
0P3o^000203o`000olL00?oE003oiP00oOX00;Ko000WobH0i`0[803o00001P2ZEBD0J:aE0:Ko002/
o`00Lol00=D[8EH0o`0000H0Zh0A0:kn102[oP80ol800?nQ003oTP020?n:00030?mm003oNP00ogX0
0080ogX02@3oJ`000`3oJ@00oel00?mL0005ooooo`7o00000Oooool001_ooooo00?o0000oooooooo
ool00_oooolK0?m<00d0oe`000<0of000?mX003oI0001`3oJ`000`3oK`00of/00?m[00020?m[0080
ofl03P3oNP000`3oPP00ogh00?n600050?n:00090?n>003oV@00oiT00?nX003o`000j_L00?;c003o
b000ok`00080okP000/0ok`00?o7003oa`00ol/00?oG003ojP00oOX00=co0028o`00`40>0<0U@00P
0?l000050950O01io`00Tol00830@020N7P0E@3o00001`307T00f01003Wo:03?^P00ok@00?nI003o
TP000P3oRP050?mj00030?mg003oJ`00of/000P0of/000<0ofP0ooooooooool00oooool1o`00007o
oooo000Kooooo`03o`000?oooooooooo00;ooooo303oC000103oC`00od`00?m?003oC`0:0?m<0003
0?mG003oG000oe`000P0oe`000@0of400?mL003oG000oe`02P3oJ`00103oKP00of/00?mc003oL`0;
0?mj00060?mm003oNP00ogd00?mj003oPP00ohD01P3oRP002P3oS`00oiT00?nI003oX@00ojP00?o0
003_m`00Zo/?0?_W003oc0020?o7000;0?o:003oc`00om800?oJ003oh@00loH00=co002Noa@0OLD[
06j0?@3E3b/08@3o00000`3=E@00L?l008VZ001F0?l0000;0:n0302FXUD0ENZ40:;T7@3oYP00oiT0
0?n=003oRP00ohD00?mj003oO@000P3oNP000`3oL`00of/00?m[00080?m[00030?mT003oH@3ooooo
00Cooooo0Ol00001ooooo`006oooool2o`0000?ooooo403oC0000`3oD000oe@00?m@00060?mD00d0
oe`000<0of@00?mP003oI0002P3oJ`000`3oM`00og<00?mj000:0?mj00040?n2003oNP00ogh00?mj
00T0ohX000/0oi800?nI003oV@00oiT00?nU003oZ000ok`00?oG001ko`X0k_L00?oS00020?oG000:
0?oK003^nP00onh00?oZ003olP00jol009?o001A`680`35G0<10=B80o`0000<0T`?004?o001N`1X0
E@3o00001`309D00aL100?k`003ob000ok000?nM003oUP000P3oRP000`3oPP00ogh00?mj00020?mj
00030?mg003oK`00of/000L0of/000<0of@00?mL003oG0001?ooool2o`00007ooooo000Kooooo`03
o`000?oooooooooo00;ooooo503oC0000`3oD@00oeL00?mL000<0?mL00040?mO003oG000oe`00?mO
00P0of/000@0ofh00?m[003oL`00ogD0203oNP020?mm00050?mj003oP`00ohD00?n5003oR0002P3o
RP005`3oU000oiT00?nI003oV@00oj400?nX003oZ`00okP00?o=003lk@00b_l00>Kh003Vm@00on/0
0?kf002To`00lOh00?gj003go000jol00<[o001<eR/0_b^002@0o`0000<0==D?06N0D`3o0000E@3o
00001P1l[V40Pk]O0?nk003oYP00oiT00?nB0080ohX000<0oh800?mj003oNP000P3oNP000`3oM@00
og000?m`00070?m[00030?mO003oG000oe`000Gooooo0Ol00001ooooo`006oooool00ol0003ooooo
ooooo`02oooooaL0od`000<0oeP00?mL003oG0002P3oG0000`3oH000oe`00?mP00070?m[0080ofl0
1P3oNP030?mn00030?n6003oRP00ohX000d0ohX00P3oTP040?nI000D0?nM003oZ000ojP00?nd003o
^000ol/00?oO003^nP00B?l=0<Wo002ho`h0k?l007OM@02MocT0dOl00<Wo003Ho`00R?l009b09@30
?40T0?l0000304V0G020P2l0o`0005@0o`0000@0O/0003VJ`03ai000oj`00P3oV@000`3oSP00ohX0
0?n:00050?mj00X0of/000<0ofP00?mL003oG0001Oooool1o`00007ooooo000Kooooo`03o`000?oo
oooooooo00;ooooo603oC0000`3oF000oe`00?mL000:0?mL00H0of/00P3oK`000`3oJ`00ogL00?mj
00060?mj00030?n2003oRP00ohX000/0ohX00P3oSP00103oTP00ohh00?nF003oUP040?nI000D0?nQ
003oZ000ojP00?n/003o^000ol000?o;003og`00e_d003VjP01ko`L0FomJ0;go0012^800B>5709?o
002So`00^_l009oo001QQTPU0?l00003081dH@1_P7/0o`0005<0o`0000L0`4070=7o003oh`00ok`0
0?nU003oV@00oi800080ohX000<0ohH00?mn003oNP000`3oNP000`3oM`00of/00?m[00080?m[0003
0?mX003oG03ooooo00Cooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`02oooooaT0od`0
2@3oG000103oG`00oe`00?mL003oIP050?m[00030?m`003oL`00ogX000D0ogX000<0ogd00?n2003o
R0000P3oRP00203oV@00kJl00?nD003oTP00ohl00?n:003oS000ohl00P3oS@001P3oTP00oi@00?nG
003oU`00oiT00?nL00@0oiT001H0oj400?nV003oZ000ojd00?n`003o^000ok/00?o:003oe`00on@0
0?Cl002^o`00<_l_036fR@1CcF@06jb006T_UP1SZTX0/80f04co101Qo`00G7QL9@3o00000`3o02@0
P7]^0?l0001C0?l000070=aE001VkeD0ol000?n[003oW000oiT00?n=00020?n:00030?n5003oNP00
ogX000<0ogX000@0og<00?m`003oL000og00203oJ`000`3oIP3oooooooooo`03ooooo`7o00000Ooo
ool001_ooooo00?o0000ooooooooool00_oooolI0?m<00030?mD003oG000oe`000L0oe`000<0of00
0?m[003oJ`00103oJ`000`3oL`00ogX00?mj00050?mj000:0?n6003oRP00ohX00?n:003oSP00oiT0
0?nQ003od000ojD00?nM00L0oiT000<0oid00?nI003oV@000`3oV@004`3oW@00ojD00?nU003oZ000
oj`00?nl003o`000ok`00?o0003oa`00mnD00?[a003nm000h?l00<;o0012o`<0`41S0<0a@03j0400
0`3o00000`2h08008ol>05Y0QP0V0?l00003080cP03o0000o`000580o`0000H0_?L00?o8003o/000
ojD00?nI003oUP030?n:00H0ogX02P3oJ`000`3oJ000oe`00?mL0005ooooo`7o00000Oooool001Co
oooo0_l00005ooooo`03o`000?oooooooooo00;ooooo6@3oC0000`3oFP00oe`00?mL00080?mL00@0
of/000T0og000?mh003oNP00ogX00?mm003oNP00ogl00?n5003oR0000`3oRP00203oS@00oi800?nI
003oW000ok000?oJ003o^000oj/00P3oX`002`3oW000oiT00?nL003oWP00oj<00?nj003o[@00ojH0
0?nS003oZ000ojH00080ojP000l0oj/00?nc003o^`00jnH00?_U003oc`00ol`00?oE003nk@00^ol0
0<oo0038o`00FOlN02cEF`35:ch01P3o00000`20P2h0P81O0?l0000U0?l000030>00:`3o0000o`00
0500o`0000P0^44[0=O:003dd`00okH00?nX003oWP00oiT00?nD00<0ohX000<0oh000?mj003oNP00
0`3oNP001@3oM@00og000?m^003oJ`00ofh000D0of/000<0oel00?mL003oG0001Oooool1o`00007o
oooo000Cooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool00_oooolH0?m<0003
0?m@003oG000oe`000H0oe`000<0of000?mL003oJ0000P3oJ`020?m_00040?mj003oOP00ogX00?n2
00D0ohX000<0ohh00?nB003oUP000P3oV@001`3oX@00oj`00?nl003bj`00omL00?o@003o/000103o
Z0001P3o[000okP00?kM003oc000okP00?n`0080ok@000L0ok000?nd003o^000ol000?o;003nk@00
`_d00080onH000L0onX00?kh003Ho`00?_Q006Wo0012o`X0`40m00P0o`0000<0P3n00?l0003o0000
MP3o00001P3[@000do<00?o?003o^000ok000?nU0080oiT000D0ohh00?n:003oRP00ohX00?mn0005
0?mj00030?m_003oJ`00of/000L0of/000<0of000?mL003oG0001Oooool1o`00007ooooo000Coooo
o`04o`000?ooooooooooo`0000Cooooo0_l00003oooooaH0od`000<0oe400?mG003oG0002P3oG000
2P3oI000of/00?m[003oM@00ogd00?n2003oRP00ohl00?nG003oU0020?nG0080oih001H0oj<00?nX
003oX`00ojP00?n]003o/000olX00?3`0034d@00iX000>_^003oa`00okd00?nj003o_@00nLL00?o2
003obP00i_<00?kZ003obP00olL00P3odP020?o7000=0?oB003lf`00o^D00?;e0035o`00h?`00=on
003ZoP00b_l00:ko000aoc/0DhB405FCGP090?l000030?80:`3o0000o`0007@0o`0000P0eB/F0?20
003RaB/0om@00?o2003o]P00ojP00?nV0080oiT000L0ohd00?n:003oRP00ohP00?mm003oNP00ogd0
0080ogX000<0ogP00?m[003oJ`00203oJ`000`3oJ@00oel00?mL0004ooooo`;o00000Oooool001?o
oooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`02oooooa@0oe`0203oI0000`3o
J000of/00?m[00040?m[000c0?m_003oM`00og/00?n30030Zd00P:Z0082mP020Wh00P8^0082RP020
Q800RGZ0085ZP029IX00[gZ00<m/P02MH800`6B00:eTP03SJ4`0oGI00:n0:@30@3T0o`000>MnC@3L
Ld00mg1^0<E/P03jL5L0h7XS0?mc?P3oLa<0_8000>:05`3oLe40og/f0?Yn7`3jOQ/0og]90?mc4`3n
OP00lX000>Z0003VP000V80R0=N00038P000ah000<n00025Ad00P6e30800o`0000`0V41>07FF@035
o`00m?d00?k]003of`00ol`00?nl003o^000ojd00?nY003oX@020?nI00030?nF003oTP00ohX000<0
ohX00P3oPP000`3oO`00og/00?mk00040?mk00030?mg003oL`00og<000<0og<01Oooool1o`00007o
oooo000Cooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool00_oooolD0?m<0080
oe4000<0oeL00?mL003oG0002P3oG0002@3oI000of/00?m[003oM@00oh800?n=003oU000oiT00?nV
00020?nQ000I0?nV003oZ000ojP00?n`003o_@00ok000?ne003o^000okd00?kF002joQ/0WJXV0?8[
003Ql`00om@00?o:003oa`00olX00>CJ003odP00omL00<_i003[l`00omL00?oL00020?cU000?0?oL
003oe`00o^<00?;^003`l`00h_/008ko5P35o`00_Ol00<Go002^o`00KMT[01KcI`2W;h00ZSi@07l0
o`0000T0e@l[0<B05P3_d`00onH00?o?003o`000ok<00?nX003oX`000P3oV@00103oS@00ohX00?n:
003oR0060?mj00030?m^003oJ`00of/000P0of/000<0of@00?mQ0?ooool01?ooool1o`00007ooooo
000Cooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool00_oooolH0?m<00030?mH
003oG000oe`000P0oe`000P0ofP00?m[003oJ`00og<00?mg003oNP00ogh00?n200@0ohX00P3oTP00
3P3oUP00oiT00?nI003oW@00oj400?nU003o_000ol`00?;_003^k`00mnD00?nl003o/000oj/00P3o
/0001P3o]000ok`00>;W003og`00ok`00?nh0080ok`00P3o^0003@3o`000olL00?oC003okP00_Ol0
0?o^003jl@00o_@00?Sm003Ao`00A_l002Oo1`0Eoal02@3o00000`2[4X00o`000?l0001f0?l00006
0<1m@03ni@00ol/00?nh003o[000ojD00P3oV@040?n:00030?n2003oNP00ogh00080ogX000<0ogL0
0?m[003oJ`00203oJ`000`3oI000oe`00?mL0005ooooo`7o00000Oooool001Cooooo0_l00005oooo
o`03o`000?oooooooooo00;ooooo6@3oC0080?mL00030?mO003oG000oel000@0of/000P0ogD00?mm
003oNP00ogX00?n2003oO`00ohD00?n800<0ohX000T0ohd00?nB003oU`00oi`00?nQ003o/`00o>D0
0?o2003o]P000P3oZ0002@3oX@00oih00?nQ003oX`00ojd00?o:003o]P00ojd00?nX00020?n[000@
0?nX003oZ`00ok000?nh003o`000jnT00?3c003ofP00omL00?oL003ol000cOl009Cj:`2`o`00E_lN
05JZH@L0o`0000<0eB/F081cL`3o0000N03o00002035OP00inD00?o5003o/`00ojP00?nL003oV@00
oi@00`3oRP000`3oO@00ogX00?mj00030?mj00050?mh003oL000ofh00?m[003oKP001@3oJ`030?mL
00Gooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`02oooooaT0od`000<0oe@00?mL003o
G000203oG0050?m[00030?m_003oM`00ogX000<0ogX00P3oOP000`3oPP00ohX00?n:00020?n:0006
0?nF003oV@00ojT00?o;003o[000oj401`3oV@001`3oY@00oj400?nM003oV@00oj400?nM003oY@00
0`3oZ0003@3o]000o]800?o;003oa000olL00?o;003ej`00c_d00?Sm003=o`00S?l0023o=P1XP8X0
1@3o00000`3_04001Olb09A0H@0V0?l00003090>P03o0000o`000500o`0000P0`2900>M0002lj`00
ok`00?n/003oX@00oiT00?nB00<0ohX000<0ogh00?mj003oNP000`3oNP0:0?m[00030?mT003oG000
oe`000Gooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`02oooooaT0od`000<0oeX00?mL
003oG0001P3oG0020?mO00030?mQ003oJ@00of/000<0of/000<0ofh00?me003oN0001@3oNP000`3o
O@00oh800?n800020?n:00090?n?003oWP00kL400?nL003oU`00oi@00?n?003oT@00oi@00080oi80
00<0oiL00?nI003oV@000P3oV@000`3oW000oiT00?nI00020?nL000F0?nS003oZ000ojd00?nc003o
]P00okP00?o0003odP00oml00?oY003go000`ol004Oo0020IX<0F9V>05UGZP2[15D0ZUDO0=d[=P1R
ZR/0Eol003:SH2H0o`0000<0P6Uk0?l0003o0000DP3o0000103AZ@00SMiE0?nh003oZ0020?nI0004
0?n=003oRP00ohX00?n200D0ogX000<0ofh00?m[003oJ`00203oJ`000`3oIP00of40ooooo`04oooo
o`7o00000Oooool001_ooooo00?o0000ooooooooool00_oooolH0?m<00030?m@003oG000oe`000X0
oe`000<0ofP00?m[003oJ`000`3oJ`000`3oK`00of/00?mc00070?mj00050?mn003oRP00ohX00?n>
003oTP002P3oRP020?nB0080oiH0103oV@020?nM00<0ojP00140ok@00?nh003oa000oll00?oO003A
o`00EMe002SoC@0an6d0T?l002[h@00LXJL0DOm008So001oo`L0O?l005I7P00U0?l000030<0eMP20
P4h0o`0005@0o`0000H0Zol00?o@003o]000oj400?nI003oSP020?n:00030?n2003oNP00ogX000@0
ogX00`3oL`080?m[00030?mT0?oooooooooo00?ooooo0Ol00001ooooo`006oooool2o`0000?ooooo
5`3oC0000`3oD000oe`00?mL000:0?mL00030?mP003oI000ofP000D0of/000@0ofl00?m[003oL`00
ogL01P3oNP000`3oOP00ohH00?n6000=0?n:00040?n>003oRP00ohh00?nB00D0oiT001<0ojD00?nX
003oZ000ok@00?nl003oa`00oml00?Gj001KgD<0/_l006ko>`3Ho`00N<1007_o>@2fo`00/_l00<go
002Co`00T80]02D0o`0000<0P80c06n0K03o0000D`3o00001`30@0L0Yol008WH@03ncP00ojP00?nI
003oUP000`3oRP000`3oOP00ogX00?mj00020?mj00030?m_003oJ`00of/000P0of/000<0of000?mL
0?ooool00oooool2o`00007ooooo000Kooooo`03o`000?oooooooooo00;ooooo5@3oC0000`3oD@00
oeL00?mL000;0?mL00040?mO003oG000oe`00?mL00P0of/000<0ofh00?m`003oM@001`3oNP001P3o
O@00ogl00?n2003oPP00ogl00?n70080ohP0203oRP000`3oS@00ohX00?n?00040?nI000C0?nV003o
Z000ok000?nh003oc@00on@00=Sn002QoPL0f?h00?gc003io000TNP[0>Co003doP00jol00>Co002c
o`00PMD00;lXP00T0?l0000303BZ>P1QP5l0o`0005@0o`0000L0eR/007IoZP2YcS@0okD00?nQ003o
V@00oi800080ohX000<0ogl00?mj003oNP000P3oNP000`3oL000of/00?m[00070?m[00030?mQ003o
G000oe`000Gooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`02oooooa80od`000<0oe00
0?mD003oG0004@3oG0000`3oI000ofP00?m[00080?m[00030?m_003oJ`00ogX000X0ogX000H0ogd0
0?mn003oPP00ogh00?n6003oPP090?n:00@0oiT00P3oZ0001@3o^000oll00;Km2P3>o@00onX00080
oml000T0onL00;ko003nn000oo800?oe003co`00aOl005j2H`30@4008`3o00000`3P04009ol:09F0
301F0?l0000609[o4P2jdd00ol000?n/003oV@00oiH00P3oRP000`3oOP00ogX00?mj00030?mj0003
0?mg003oL`00of/000H0of/000<0of000?mL003oG0001Oooool1o`00007ooooo000Kooooo`03o`00
0?oooooooooo00;ooooo303oC0000`3oC`00od`00?m?00020?m?00030?mA003oC000od`000D0od`0
00<0oe400?mJ003oG0002@3oG000103oH@00oel00?mL003oG00:0?m[00040?m`003oJ`00ogP00?mh
00T0ogX000H0ogd00?mj003oO@00ogX00?n2003oO`020?n800H0ohX000X0oi@00?nI003oV@00oj<0
0?nX003o`000l_<008co3`3jl000omD00P3oc0002P3oc`00oml00?oL003og`00onH00>[l002[o`00
Eolm07FAI@2=EETR0?l000030;8/E@1Oo`00EmDA05D0o`0000/0eAT[09bZ=`3[c`00Z^a40?O9003o
X@00oiL00?n=003oRP00ohD00?mm00030?mj00030?mc003oJ`00of/000L0of/000<0ofT00?mO003o
G0001Oooool1o`00007ooooo000Kooooo`03o`000?oooooooooo00;ooooo6P3oC0000`3oD000oe`0
0?mL000<0?mL00h0of/00P3oM`0>0?mj00030?n2003oQP00ohX000D0ohX000T0oi800?nI003oV@00
ojP00?o0003ek`00j_<00?oC003oa0000P3o`0002`3oa000olL00?o7003od`00om/00?o^003lo@00
f?l0093o001A`1P0P3^00200o`0000D0d01009C00028o`00RL000<0i@01E0?l000070<0N@020=800
0>F907?i;03o/000oiT00?n>00020?n:00060?mj003oOP00ogX00?mj003oM`00ofl02`3oJ`05oooo
o`7o00000Oooool001_ooooo00?o0000ooooooooool00_oooolK0?m<00030?mJ003oG000oe`000X0
oe`000@0of@00?mO003oG000ofH01P3oJ`001@3oKP00of/00?m[003oJ`00ofh00080of/000<0ogP0
0?m`003oNP002`3oNP00103oO@00ogX00?n2003oQ@040?n:00090?n=003oU000oiT00?nS003obP00
enT00?SO003o_@00ok<00080okH000X0okP00?nm003oa@00olL00?oG003oiP00oOX00<3o001Do``0
i`0[803o00001P3E:a/0NjEC09Co002Qo`00R]D[0:YEAUH0o`0000H0^R/l08;o102Le@80ol800?nN
003oTP020?n:00030?mm003oNP00ogX00080ogX000<0og000?m[003oJ`001`3oJ`000`3oI000oel0
ooooo`04ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool00_oooolK0?m<0100oe`000<0
of@00?m[003oJ`002P3oJ`001P3oK`00of/00?m[003oNP00ofl00?mg00d0ogX01P3oRP000`3oV@00
oj400?nh00020?n`00@0ojP000`0ok@00?nh003o^000olL00?o?003ojP00n?d00:[o0002j6P0oP10
0?l00020P3/M0?l000030<`0@030@3`0L<Y00080^_l000<0G?Q00?l0003o0000E@3o00001P2Ko`00
nOL00??]003o]000oj400?nF0080ohX000<0ogh00?mj003oNP000P3oNP090?m[00030?mT003oG000
oe`000Gooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`02oooooaX0od`000<0odl00?mL
003oG0003P3oG0020?mT00030?mQ003oJ@00of/000/0of/000D0og000?m[003oL`00og800?mc000:
0?mj00<0ogd0103oRP000`3oS@00oiT00?nL00020?nN00030?nQ003oX`00ojP00080ojP000`0oj/0
0?nf003o`000omT009Ok502`o`00Ko=E08WEB00iSX40[JX004CEB`20I7HL0?l000080820>01[RDd0
aOl00=7o003<o`00U?l0062FDP3o00YE0?l0000607^UE@3jl`00om@00?nh003oYP00oiT00P3oRP00
0`3oPP00ogX00?mm00020?mj00030?me003oKP00of/000H0of/000<0oel00?mL003oG0001Oooool1
o`00007ooooo000Kooooo`;o00000ooooolJ0?m<00030?mH003oG000oe`000d0oe`000D0of000?mL
003oG000oe`00?mT000>0?m[00050?m_003oJ`00of/00?mj003oL`002P3oNP000`3oOP00ogX00?n6
00030?n:00030?n>003oTP00oiT000@0oiT000l0oj400?nX003oZ000ok000?o0003nj@00U_lJ0?[d
003mm`00gOd00:ko003=o`00QL04042>^01?P:/06@3o00002P304T00P4ZG01coSP35o`00h?l00>Co
003Lo`00_Ol0081YDP30@2eE0?l0000905g0FP32o@00mnd00?kM003o^000oid00?nF003oRP00ohH0
00@0ogX02@3oJ`000`3oJ000oe`00?mL0004ooooo`;o00000Oooool001_ooooo00?o0000oooooooo
ool00_oooolH0?m<00030?m?003oFP00oe`000h0oe`000<0oel00?mL003oG0000P3oG000103oI000
of/00?mV003oJ@0=0?m[00040?m`003oKP00of/00?mc00T0ogX000@0ogd00?mj003oO`00oh80103o
RP000`3oS`00oi@00?nI00020?nI000A0?nL003oWP00ojH00?n[003o^000o]H00?oL003oe`00oml0
0?cX003mmP00k?h00;So002[eB/0LMD:03?EB@2Z<Ed05P3o00001@2Z@D40eB/X08JZ:`1Gob@0jOl0
0080lol000@0k_l00<So0016[7H0eB/`E@3o00001`2=@gH0QVA>082Z=`1NeCT0_?DS0?Vi003oV@00
0P3oRP040?mj00030?mc003oL000of/000L0of/000<0ofT00?mT0?ooool01?ooool1o`00007ooooo
000Kooooo`03o`000?oooooooooo00;ooooo5`3oC0000`3oE000oe`00?mL000D0?mL00040?mX003o
G000oe`00?mL00X0of/000@0ofl00?m[003oJ`00ofl00P3oJ`00103oL`00ofl00?m[003oM`090?mj
00030?mn003oPP00ohX000@0ohX000<0ohh00?nI003oV@000P3oV@003P3oX@00ojP00?nX003o^000
ok`00?o4003oc`00omL00?oZ003mnP00i?l005O:DP12o`h0P7U35P3o00001P2_:H00VH0O01:gP02F
o`<0kol00?cm0080oOX000@0n_l00>3o002_P400@8=HE`3o00001@1L:<009<9_0<Km003gdP00oid0
0080ohX000D0oh800?mj003oNP00ogX00?mc00090?m[00030?mT003oG03ooooo00Cooooo0Ol00001
ooooo`006oooool00ol0003oooooooooo`02oooooa@0od`000D0odl00?mA003oE000oe400?m?0004
0?m<00030?mA003oG000oe`000d0oe`000<0of400?mL003oG0000P3oG00@0?m[00040?m^003oJ`00
of/00?mc0080ogP02@3oNP020?n800@0ohX00140ohd00?nG003oV@00oiT00?nL003oWP00ojP00?n^
003o]P00ol000?o5003oc`00onT00=Gn003?o`00V_l002fa]0040?l000030:XlD03o01L0o`0000d0
o`000100eB/V0=H[3@2Z=3h0PbN<08[E:`1EXW<0W_lA0?kg003ol`00oo000?oc003mnP00lol00=6Z
901YTgH0ZSaEE03o00002P3F:`00ZUDn03g=M03Bo`00O^];0=oJ003oWP00ohl00?n:003oO@030?mj
00030?mc003oJ`00of/000H0of/000<0of400?mL003oG0001Oooool1o`00007ooooo000Kooooo`03
o`000?oooooooooo00;ooooo4P3oC0030?m@00T0od`000<0oe000?mL003oG0004@3oG000103oJ`00
of@00?mT003oJ00?0?m[00040?mc003oJ`00of/00?mg00L0ogX000<0ogh00?mj003oPP001P3oRP00
3`3oUP00oiT00?nI003oV@00ojD00?nX003o[000okP00?o0003oc`00eoL006Co5P1/oa805OmD0<10
KP040?l000040820<01B`0L0`40J081YM@X0o`0000X0`1900?l0001=`2@0/h1004Oo000Aog00Z_l0
0?Wj003jm000onX00`3oiP000`3olP00lOd008J0B@1F0?l000070<N0002k`000/^Y00?o^003jm000
fn000?nQ00020?n:00060?n2003oNP00ogX00?mj003oM`00og<01`3oJ`030?mL00Gooooo0Ol00001
ooooo`006oooool00ol0003oooooooooo`02oooooa40od`000<0oe000?m<003oC0002`3oC00B0?mL
00030?mT003oH000oe`00080oe`04P3oJ`000`3oL`00ogX00?mj00040?mj00050?mn003oNP00ogX0
0?n2003oNP001@3oRP001@3oSP00oiT00?nI003oV@00oid00080ojP000P0okP00?nl003ob`00onL0
0?gj003To`00@?aU00g/I0@0o`0000P0CHY:06go001A`6809L1L0?l0001kD/00o`000<10;@80o`00
00@0P81e0<105P2D:Kd03l2:0P3o00001P1Q`280Z_l005go6P0gfG/0mOX00?oZ0080on<000P0om/0
0?oO003oh`00onX00?gj003U`0`0IH2407F0GE@0o`0000X0H<Y00>gm003ojP00om<00?oG003_aP00
oiT00?n>003oRP00ogh00`3oNP000`3oL`00of/00?m[00060?m[00030?mT003oG000oe`000Gooooo
0Ol00001ooooo`006oooool00ol0003oooooooooo`02oooooal0od`0303oG0000`3oG`00oe`00?mL
00020?mL0080oel0103oG00B0?m[00030?mc003oKP00ofh000P0ogX000<0ogd00?n5003oR0000`3o
RP001@3oS@00oi800?nI003oV@00oi`00080ojP001@0ok<00?nh003oa`00omL00?o[003_o000^?l0
047V:`3A0800lP0[0?l0002^7VD0Dle80;So002ao`00PJ=708:Z9`1XeC@0@^<[09QEE080o`0000`0
P80f04Co7P10nVh0I_l003?IC`0/Wgl0MX130>7o001]oaT0GOlb0?k]003og`020?oG00090?oE003o
e`00omX00?oT003okP00l?l007WmD02AZP00ZU<l05<0o`0000L0P81[09kf?P3oe`00ol800?nc003o
YP00oiT00080ohX000H0oh800?mj003oNP00ogX00?mh003oL0080?m[00030?mV003oH@3ooooo00Co
oooo0Ol00001ooooo`006oooool00ol0003oooooooooo`02ooooo`/0od`000<0oe000?m<003oC000
4@3oC00G0?mL00040?m[003oJ000of@00?mX00T0of/000D0ofl00?m[003oJ`00of/00?m_00030?m[
00X0ogX000<0oh800?n:003oRP000P3oRP00:03oTP00oiT00?nI003oV@00ojD00?nX003o^000ok`0
0?o7003oe`00onX00?Cm003Ao`00Kol>042`J010SYT0?_l7003oKP1lo`00k?l00;;o002Ko`00f?l0
0<7o000no`h0@;B:0>L0@030=D00@9Yk0;[o0031o`00bOl007_o4P00iLH0R^E00?kd003okP00bo<0
0?oK003ob`030?o70080om<000D0om/00?oZ002`oa806L2E07=MRP1C0?l0000;0820@`3?P000]Ol0
0?o?003oa000ok000?nU003oV@00ohh00?n:003oPP000`3oNP000`3oL`00of/00?m[00070?m[0080
of@01Oooool1o`00007ooooo000Kooooo`;o00000ooooolN0?m<00030?mG003oG000oe`001@0oe`0
00<0of@00?mO003oG0000P3oG0000`3oJ@00of/00?m[000=0?m[00040?m`003oL`00og000?me00L0
ogX00P3oO`040?n:000X0?nD003oV@00oiT00?nV003oZ`00okP00?o0003obP00om`00?gh002`o`00
VOl002oh;00JbfX0HnH[0;So001Rl5D0goh00?gc003kl`00d?XD0?[j003No`00^ol006GXD015ZS40
EII]04?o4037o`00m_h009Wo001`o`00L=U=0??^003ofP00om800?o<003obP00olL00?o500<0olL0
00P0olX00?oE003oiP00Woh005>AZ01KZT00eB/I081VBU40o`0000/0eB/D08_`D`3mnP00omX00?o2
003o/`00oj<00?nI003oS@00ohX00?n500030?mj00030?mh003oL000og0000H0of/000<0oel00?mL
003oG0001?ooool2o`00007ooooo000Kooooo`03o`000?oooooooooo00;ooooo7@3oC0000`3oD000
oe`00?mL000D0?mL0080of00103oG0000`3oI000of/00?m[000=0?m[00040?m_003oJ`00of/00?mc
00P0ogX000<0oh800?n:003oRP000P3oRP004P3oTP00oiT00?nM003oZ000ok000?o0003ob`00on<0
0?o^003do@00S_l701jMSP2Go`00>OlL08[d@03do@00Xol00>kg0080oml00180on<00?o^003mnP00
i?l007So001E`3003Olf08So003nm000onh00<Km001oob80jOd00?oO003ob`00olL00?o4003o_003
0?nh000:0?o0003oa000olL00?o;003oe`00onX009ko2P1T^800O?l00>00@540o`0000/0F<1>0=>0
001cgD00L_lL0?kM003o_000oj`00?nM003oTP00ohX00?n200030?mj00030?mg003oJ`00of/000H0
of/00`3oG005ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool00_oooolL0?m<00030?mD
003oG000oe`001@0oe`000<0oel00?mL003oG000103oG0020?mY0080of@03`3oJ`030?mc00L0ogX0
02P0ogd00?n:003oRP00ohX00?n=003oV@00oi`00?nX003o^000nN<00>g`0029oa/0col009Co001_
o``0/?h20?Sj003=oP00R^@[0?oT003ofP00o]T00?o?003oc000omD00?oT003hnP00d_l007oo0P1P
eAP0Ool<0?Sc003oe`00om800?kS003Dl`00VO/70?o?003o`000ok/01`3o^0002@3o`P00olL00?o=
003og000noT00;;o0P2No`00@lE20:XnAP1@0?l0000<0=D[4@3o0000eB<[043oBP3Pn@00and00?CA
003oZ000oiT00?n:003oR000ogd00P3oNP000`3oM@00ofh00?m[00060?m[00030?mO003oG000oe`0
00Gooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`02oooooa/0od`000@0oeP00?mL003o
E000oe000`3oC0000`3oD000oe`00?mL000D0?mL00030?mP003oJ000oe`00080oe`000<0ofH00?m[
003oJ`003`3oJ`070?mj000?0?mn003oQP00ohX00?n:003oSP00oiT00?nM003o/000ol000?kY002K
o`00gOd00?o^003nj@00foL00080om/000@0_?L00?Wc003ob`00ol@00P3o`0004P3oa000ol/00?oO
002Fo`X0Vol009go0`2kmaH0onH00?oK003oa000ol000?o4003ob000imT00?nl003o^000ok@00?n`
0080oj`000<0ok000?nd003o^0000P3o^0001`3o`000olL00?oG003nl000^_l00<n0001cA/00E03o
00001P0UYJD0=_l305_U@`2`ob80hmT00?nQ0080ohX00`3oNP000`3oM`00of/00?m[00070?m[0003
0?mX003oH03ooooo00Cooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`02oooooaT0od`0
00<0odl00?mG003oD@001`3oC0000`3oC`00oeX00?mL000<0?mL00030?mO003oG000oe`000@0oe`0
00<0of400?mL003oG0000P3oG0000`3oH@00of/00?m[000>0?m[00030?m^003oN000ogD000H0ogX0
00`0ohD00?n:003oRP00ohX00?nI003oX`00l/L00?oG003Nn000/=D[0?oV003oc`020?o700050?o0
003o_@00oll00<SL003o_@000P3o/`00303o]P00okP00?o2003ig@00O?lV0>7o003nlP00omL00?o7
003o_@00okP00?nf00<0ok<000@0ojd00?nX003oZ000oj/00`3oZ0003@3oZ`00ojh00?nc003o^000
ok/00?o7003og000W?hF00K9TP1EWV<0eAh[0?l0003E:ah0CP3o00003@2TCVT0o`000?l0003o0000
eATm03_@O00dTi40P_lI0<[G:`3o/`00oi800?n:003oO`000P3oNP000`3oM@00of/00?m[00060?m[
00030?mT003oH@00of4000Gooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`02oooooaP0
od`000<0oe@00?m@003oC0002@3oC0000`3oE000oe`00?mL000A0?mL00030?mT003oG000oe`000<0
oe`000<0of@00?m[003oJ`004@3oJ`000`3oM`00ogX00?mj00040?mj000=0?n2003oRP00ohX00?nI
003oY@00gn000>Wi002Fo`L0oO<00?oC003oa000okP00?nd00040?n`00@0ojP000X0oj`00?nh003n
g@00Vol00:Ko003jl000oll00?o0003o^000ok00303oZ0003@3o[000ojP00?nh003o^000ol000>_Q
001gdD00Og7J003oU02=P3T0OdJQ04f:BP3L0400C@3o00003@1K`000o`000?l0001J@8<0=_lN09_o
001HTX00gOd00?oO003@aP00oi800?n:003oOP000P3oNP000`3oM`00of/00?m[00050?m[00040?mT
003oG000oe`00?mL00Gooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`02oooooaH0od`0
0P3oC`0<0?m<00030?mD003oG000oe`001L0oe`000D0ofH00?mQ003oG000oe`00?mT000;0?m[0005
0?m^003oJ`00of/00?m[003oN0001P3oNP00303oPP00ohX00?n:003oU000oih00?n^003oa`00dOP0
0?[e003oc@00okd00?n`0080ojP00P3oYP020?nS000;0?nN003oX@00oj<00?nX003oZ`00ok/00>[C
003Km`00LOlM0?o=003o/0000P3oZ0020?nV00040?nS003oX@00oj<00?nQ0080oih00P3oX`00403o
YP00ojP00?nX003oZ000oj/00?nc003o^`00olL00=CT:`2Zn140KZXd077o001oeCL0OLD[0:h[=03E
0R];0?l0000=06]kJ@2Io`00LZUE0:QEE@14N:X0^?h70?Oj002VobH0WM4C0?o2003oX@00ohl00?n8
00030?mj00030?mc003oJ`00of/000D0of/000@0of400?mL003oG000oe`01Oooool1o`00007ooooo
000Kooooo`;o00000ooooolE0?m<00030?m@003oC000od`000`0od`000<0oe@00?mL003oG0005P3o
G0000`3oH000oel00?mL00030?mL00h0of/00P3oK`000`3oJ`00ogX00?mj00030?mj000=0?mn003o
RP00ohX00?nF003oV@00ojP00?o0002Zo@L0[od00?o8003o/000ojP00?nU00090?nI00080?nU003o
Z000okP00>7i003jdP00ok@00?nX003oY@030?nI00030?nM003oV@00oiT000H0oiT000<0oj400?nX
003oZ0000P3oZ0002P3o^000ok`00?o;003og`00R_lF07Go003Po`00b/0008f0:@30@1i;0?l0000=
09d0P02Fob80lol00:?o002fUU<0o^T00?oO003Pl000J?lF0;oa003oX@00ohX00?n600030?mj0003
0?m_003oJ`00of/000D0of/000@0ofP00?mL003oG000oe`01?ooool2o`00007ooooo000Kooooo`03
o`000?oooooooooo00;ooooo903oC0000`3oFP00oe`00?mL000F0?mL00030?mQ003oG000oe`000<0
oe`04@3oJ`000`3oN000ogX00?mj00030?mj000;0?n5003oRP00ohd00?nL003oZ000ol000?S[003`
j`00ol000?nX003oX@001@3oV@000`3oU`00oiT00?nI00030?nI00060?nN003oZ000iL@00?n[003o
YP00oih0303oV@00103oW000oiT00?nN003oX`020?nX000;0?n^003o^000okd00?o:003og`00o_80
0?So003Do`00SMDc05^XJ@2ZCTh0B@3o00003P2Z<E<0L?l00>gl003oj@00o><00?oB003obP00ol80
0?o?002ll`L0jn/00?nN003oRP00oh800`3oNP000`3oKP00of/00?m[00070?m[0080of401Oooool1
o`00007ooooo000Kooooo`03o`000?oooooooooo00;ooooo8`3oC0000`3oE000oe`00?mL000F0?mL
00030?mP003oG000oe`000<0oe`000D0of000?m[003oJ`00of@00?mX00080?m[00050?m_003oJ`00
of/00?m[003oK`000P3oL`040?mj000:0?n2003oRP00ohh00?nM003o/000omL00=Wi003bl`00ol@0
0?nQ0080oiT000<0oiH00?n>003oSP000P3oSP00103oRP00ohh00?nB003oTP0;0?nI00030?nF003o
V@00oiT000P0oiT000`0oid00?nX003oZ000ojP00?nd003o^000olL00?oC003ojP00nOX00<^00020
4H1<0?l0000<07709@2Ho@00om/00?o;003o_000okP00?nd003o^000^nl30?nl003oTP00ohX00`3o
NP000`3oM`00of/00?m[00060?m[00040?mP003oG000oe`00?mL00Gooooo0Ol00001ooooo`006ooo
ool00ol0003oooooooooo`02ooooob80od`000<0odl00?mL003oG0005P3oG0000`3oG`00oe`00?mL
00040?mL00030?mY003oI000oe`00080oe`000<0ofH00?m[003oJ`00203oJ`00103oKP00of/00?m[
003oJ`030?mj000=0?mm003oNP00ohP00?n=003oX@00i=X00>WJ003Ua000okD00?n^003oW000oiL0
0?n=00030?n:00030?n=003oRP00ohX000@0ohX000<0ohl00?nB003oU0000P3oTP020?n?0080ohd0
0P3oRP00103oS`00ohX00?nD003oS@020?nG00D0oiT000/0oi`00?nX003oZ000ojd00?nh003o`000
om800=C/:`3OeB/0ILeQ081VE0030?l000030=DD:`3o0000o`0004@0o`0000L0hR/00:XdD012OH`0
:nQ[0?oB003o_@00ok<000<0ojP000@0oj400?nL003oRP00ohP00`3oNP000`3oM@00ofh00?m[0005
0?m[00030?mT003oG000oe`00080oe`01Oooool1o`00007ooooo000Kooooo`03o`000?oooooooooo
00;ooooo8P3oC0020?mL00030?mH003oD000od`00080od`000<0oe@00?mL003oG0005@3oG0000`3o
I000of000?mL00030?mL00030?mT003oJ`00of/000/0of/00P3oL`003@3oM`00ogX00?mj003oNP00
ogh00?n:003oX@00n]d00?nY003oW@00oiT00?nF003oSP006@3oRP00103oSP00ohX00?n:003oRP02
0?nF00@0oiT000X0oid00?nX003oZ000okP00?o4003oi`00[_l007c01`0TX9d0`2900`3o00000`30
@5L0o`000?l000140?l0000604;o2P2jo`00R89j0:cg003ob000okP00P3oZ0000`3oW@00oiT00?nF
00020?n:00050?mn003oNP00ogX00?mj003oK`001`3oJ`000`3oJ000oe`00?mL00020?mL00Gooooo
0Ol00001ooooo`006oooool00ol0003oooooooooo`02ooooob40od`00P3oF0000`3oD000od`00?m<
00040?m<00030?m@003oG000oe`001@0oe`000<0of000?mL003oG0000`3oG0000`3oI000of/00?m[
000=0?m[00030?mc003oNP00ogX00080ogX000D0ohH00?nF003oX@00oiH00?n>000O0?n:00030?n>
003oRP00oi8000D0oiT000h0ojD00?nX003o/000ol@0067C@02g`0001Olb04W0GP3o02L0`36A0?l0
003P04004/Y30<105T@0o`0000T0P80c07O0O03ho@00nOX00;kW3P3o_000ok000?nX003oW@000P3o
V@030?n:00040?mn003oNP00ogX00?mj00T0of/000@0of000?mL003oG000oe`01Oooool1o`00007o
oooo0008ooooo`;o00001?ooool00ol0003oooooooooo`02ooooo`?o00001Oooool00ol0003ooooo
ooooo`02oooooal0od`000<0odl00?mG003oD@002@3oC0000`3oE`00oe`00?mL000B0?mL00030?mO
003oG000oe`000@0oe`000@0ofH00?m[003oIP00ofH02`3oJ`000`3oKP00og000?m`00030?mj0003
0?mm003oR000ohP000<0ohX00`3oR000303oO`00ohD00?n2003oO@00ohD00?mm003oQ@00ogl00?n5
003oPP00ohP00?n500l0ohX000D0ohd00?n:003oS@00ohX00?nG00020?nI0080oi`000h0ojP00?n`
003ob000fOT004So9`0^eF/0?8IU07^Z4`1<eAd0eB/S01VoH02Bo`00b5D00=D[1d80o`0000T0eB/F
0;nZ002go`@0o^d00?oG003oa`00okP00?nX003oX`000P3oV@001@3oS@00ohX00?n:003oP000ogd0
0080ogX000<0ogD00?m`003oKP001P3oJ`000`3oJ@00ofH00?mT00020?mO00Gooooo0Ol00001oooo
o`001oooool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool000001?ooool0
0ol0003oooooooooo`02oooooah0od`000<0oe000?mD003oC0002P3oC0000`3oE000oe`00?mL000A
0?mL00030?mP003oG000oe`000@0oe`000<0of000?mX003oG0000P3oG0000`3oH000of/00?m[000;
0?m[00L0ogX00P3oPP000`3oOP00ogX00?mj00040?mj000<0?n2003oNP00ogh00?mj003oOP00ogX0
0?mn003oNP00ogh00?mj003oQP00oh800P3oQP0>0?n:000C0?nB003oV@00oiT00?nI003oY@00ok00
0<oS0018oaD0]_l002c:`01a/400JOl00<7o002Go`00f?l00<go001i`000o`0W0>00@0100?l0000=
081YBP2V`400cOl00?Cm003oiP00oll00?o0003o/000ojP00?nM003oV@00oi800?n>00020?n:00@0
ogX000<0og<00?m[003oJ`001@3oJ`000`3oJ000oe`00?mL00030?mL00Gooooo0Ol00001ooooo`00
1oooool01?l0003oooooooooool0000;ooooo`03o`000?oooooooooo00;ooooo0_l00003oooooad0
od`000<0oe400?m?003oC0002`3oC0000`3oE000oe`00?mL000H0?mL00030?mQ003oG000oe`000<0
oe`0303oJ`000`3oKP00of/00?mc000>0?mj00030?mm003oNP00ogX000T0ogX000P0oh000?mj003o
O@00oh800?mm003oRP00ohD00?n800H0ohX000@0ohd00?n:003oS@00oi800P3oV@00403oW000ojP0
0?nh003EdbP0om@00=k[002^n`00NJX[0>7o003jnP00oOX00=Co0020P2@0XQ6N06jX;03E:`ln0?l0
000=0:Xa@`2;P2D0MhaV06SE4`1^odX0g_P00?oJ003oa`00okH00?nX003oW000oiT00?nB00020?n:
00060?n5003oNP00ogX00?mj003oN000og001`3oJ`000`3oI000oe`00?mL00030?mL00Cooooo0_l0
0001ooooo`001oooool01?l0003oooooooooool0000;ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool00_ooool[0?m<00030?mD003oG000oe`001L0oe`000<0of@00?mL003oG000103o
G00>0?m[00030?mc003oJ`00ogL001H0ogX000D0ogh00?mj003oNP00ogX00?mn00020?mj00050?n6
003oNP00oh800?n:003oQP00203oRP002`3oTP00oiT00?nI003oW@00ojP00?n/003o^000ol@00:C_
9@1joc/0c_T00080onH000H0lOL008K2@01V`:D0T?l00?l0?P20GDY10?l0000900nMSP2>eD00]?l]
0?kQ003o_000ojP00?nM003oV@00ohh00080ohX0103oNP000`3oM`00of/00?m[00060?m[00030?mX
003oG000oe`000<0oe`01Oooool1o`00007ooooo0007ooooo`04o`000?ooooooooooo`0000Oooooo
1?l00005ooooo`03o`000?oooooooooo00;ooooo6P3oC0020?m?00l0od`06@3oG0000`3oG`00oe`0
0?mL00040?mL00050?mQ003oJ@00of@00?mQ003oI0002@3oJ`001`3oKP00of/00?m[003oL000of/0
0?mj003oM@006P3oNP001P3oO@00ogX00?n2003oO@00ogX00?n800L0ohX001@0ohl00?nD003oV@00
oiT00?nN003oYP00oj/00?nc003o`P00olL00?o<003odP00omX00?oQ003nm000i_l00=Co002Cb5D0
WJX008Qk;d00o`0000P0ZT=9081TIP1VZV80Sol00?o=003o/000oih00?nI0080ohX000<0ohP00?mm
003oO@000P3oNP000`3oM@00ofh00?m^00070?m[00030?mY003oH@00oe`00080oe`01Oooool1o`00
007ooooo0007ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`02ooooobX0od`000<0oe@00?mL003oG0007P3oG0000`3oJ000oe`00?mL00020?mL
00030?mX003oJ`00of/000/0of/000L0og<00?m[003oL`00ofl00?mc003oNP00og<001X0ogX000<0
ohH00?mj003oPP001`3oRP004`3oTP00oiT00?nI003oV@00ojD00?nX003o[000okP00?nl003oa000
oll00?oG003ojP00oOX00=co0028o`00/80b0:40P020NFD0>03o00000`10WIX0o`000?l000050?l0
0008003Ed@2/`000A?lP0<[i003o/000ojD00?nI003oSP020?n:00@0ogX0203oJ`001`3oJ000oe`0
0?mL003oG000of000?mL003oH0001Oooool1o`00007ooooo0008ooooo`;o00002?ooool5o`0000Co
oooo00?o0000ooooooooool00_oooolH0?m<00030?m?003oC000od`000h0od`000D0odl00?mL003o
G000oe`00?mG00020?mA00030?mD003oFP00oe`00100oe`000<0oel00?mL003oG000103oG0000`3o
I000oe`00?mL00030?mL00030?mT003oJ`00of/000d0of/000D0ofh00?m[003oJ`00og000?m[0002
0?mc00050?m[003oM@00ogX00?me003oN0005@3oNP000`3oPP00ohD00?n800050?n:000A0?n=003o
U000oiT00?nI003oWP00ojH00?nX003o/000okP00?nm003oa`00omD00?k_003ToP00TMDK05^0H032
:dH0103o00000`3o01l0o`000?l0000b0?l00003091T<@17]T/0o`0000H0o`0000X0DJYJ0<So003j
m@00om@00?nk003oZ000oih00?nD003oRP00ohD00`3oNP000`3oN000og<00?m^00060?m[00L0oe`0
1Oooool1o`00007ooooo000Kooooo`03o`000?oooooooooo00;ooooo:@3oC0000`3oF000oe`00?mD
00060?m<00030?mD003oG000oe`001/0oe`000<0ofP00?m[003oJ`003`3oJ`00103oK`00of/00?m[
003oL`020?m[00050?mc003oK`00of/00?m_003oNP000P3oL`0E0?mj00H0ohX000l0ohh00?nB003o
V@00oiT00?nM003oY@00ojP00?n/003o^000olL00?oK002^dd00:OA:07S0G`30@2T0>@3o00001025
KD00/l0004RHP0302T050?l0000<0<0:@01QP800A?l_0<_g003oe`00ol@00?nh003oX@00oiH00?n:
003oQP00ogh00P3oNP000`3oL`00of/00?m[00060?m[00030?mP003oG000oe`000@0oe`01Oooool1
o`00007ooooo000Kooooo`03o`000?oooooooooo00;ooooo:03oC0000`3oFP00oeL00?m?00080?m<
00030?mG003oG000oe`001<0oe`000<0oel00?mL003oG0000`3oG0000`3oG`00ofT00?mO00020?mL
00030?mV003oJ`00of/00140of/000D0og000?m[003oJ`00of/00?me00020?m[00040?me003oN000
og000?mc00X0ogX000<0ogd00?mj003oNP000`3oNP000`3oP000ogl00?n200050?n:000>0?n?003o
U`00oiT00?nI003oX@00ojP00?n[003o^000ol000?oD001Tm4l08]2c0=X[:`3E4B/60?l0000308^0
:P3E52/0e@@[02h0o`0000H0eB/K06JZ=`1BZT/0d_l008;o4@21HCh40?l0000<0=DA:`3o0000o`00
02S`F@2VobH0oO<00<;c003Cm`00nLH00?nG003oRP00ohD00`3oNP000`3oN000og000?m[00070?m[
00030?mT003oG000oe`000<0oe`01Oooool1o`00007ooooo000Kooooo`03o`000?oooooooooo00;o
oooo9`3oC0000`3oF000oe000?m<00090?m<00030?mD003oG000oe`00180oe`000<0of000?mL003o
G000103oG0000`3oI000oe`00?mL00030?mL01X0of/000@0og<00?m[003oJ`00of/00P3oNP000`3o
L`00ogX00?mj00020?mj00030?mn003oNP00ogX000D0ogX000@0ogh00?mj003oNP00ogh01P3oRP00
103oTP00oiT00?nI003oV@020?nX00070?nh003o`000om<00;Oj;@0bbT00BLY00<109@050?l00004
0?l0=P0lobl0PL0f0><0@2d0o`0001P0P6e:0<0R@02c`000k?l00?[o003Po`00Q8Y008F0B030@1h0
o`0009Q0P01A`1D0`190081YO00IodT0LolR0=7o001=oaH0oml00?nh003oV@00ohX00?n6003oOP02
0?mj00030?m_003oJ`00of/00080of/000H0ofl00?m[003oJ`00ofP00?mP003oI0020?mP00<0oe`0
1Oooool1o`00007ooooo000Kooooo`;o00000ooooolV0?m<00030?mG003oC`00od`000X0od`000<0
odl00?mL003oG0004@3oG0000`3oG`00oe`00?mL00040?mL00030?mO003oG000oe`000<0oe`000@0
oel00?m[003oJ`00ofH04`3oJ`001@3oKP00of/00?m[003oJ`00ofh000<0of/000@0ogP00?m^003o
J`00ofh03P3oNP000`3oO`00ogX00?n200040?n:000=0?n=003oU000oiT00?nI003oX`00oj/00?nh
003oa`00omX00=Ca:`3Do`00P=D[08J080050?l000070:XiG@2DbeD0X>P[0;BZA`20JDP0o`0Y0=D[
300W0?l0000J0;0[AP2iE@00/eD[09ZZE@23P380CJAj0?kd003oj`00oLdG07_RI01jo``0H7f703KE
M`1meBH0V_l004Wo101Joa<0K?lR05gS=01Moa<0goh00?oD003o/000oi`00?n?003oQ@030?mj0003
0?m`003oJ`00of/000@0of/000<0ofH00?mL003oG0001@3oG0000`3oG`3oooooooooo`02ooooo`;o
00000Oooool001_ooooo00?o0000ooooooooool00_oooolU0?m<00030?mD003oC000od`000/0od`0
00<0oe@00?mL003oG0005`3oG0000`3oH000oe`00?mL00040?mL00030?mT003oJ000oe`00080oe`0
6P3oJ`00203oK`00of/00?m[003oJ`00ogX00?m_003oJ`00ogL0303oNP020?n200@0ohX001X0ohh0
0?nI003oV@00oj400?n`003ob000onH00?o^003lo@00e?l000GoB@21<H00o`000?l0403[0400o`00
0<0J@00G`4L0Q_lR0>Co003B`3X0`2E<04W0A`2PGD003OQX0<03@2H0o`0001T0SE9j0:ko003Lo`00
]_l00?Od003of`00omL00?oK003ojP00jol004cQP00RodL0__l00?Cm002gnPL0l_X00>co0022o`h0
Yol009?o0028o@L0j^L00?nU003oRP00ohH00080ogX000<0ogL00?m[003oJ`001@3oJ`000`3oJ000
oe`00?mL00060?mL00Gooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`02ooooob@0od`0
00<0oe@00?m<003oC000303oC0000`3oE000oe`00?mL000N0?mL00030?mX003oG000oe`00080oe`0
00<0of@00?m[003oJ`004P3oJ`001@3oK`00of/00?m[003oJ`00ofl000<0of/00P3oK`020?m[0003
0?mc003oNP00ogX000`0ogX01@3oRP00603oUP00oiT00?nQ003o/000mNl00:_o001Po`L0g?l00<Wo
0011obT0P81J0?l00019`4h0[41F0366TP10UXH0Wol00>co003mnP00eOl008So002io`00Noll081J
BR<0o`0000<0`1900820903o00000P3o0000603JP380nOX00?oZ003of`00ol/00?o7003ob`00oml0
0:Go2P1Uo`00LolR08Ko>@3oi`00oml00?oZ003do@00<?mk0<Km003jm000nN/00=[e003o^000ohX0
0?n60080ogX000<0ogL00?m_003oJ`001P3oJ`000`3oH000oe`00?mL00050?mL00Gooooo0Ol00001
ooooo`006oooool00ol0003oooooooooo`02ooooob80od`000<0odl00?mA003oC0003P3oC0000`3o
FP00oe`00?mL000F0?mL00030?mO003oG000oe`000@0oe`00P3oG`040?mL00050?mT003oJ`00ofT0
0?mV003oJ@00303oJ`000`3oKP00of/00?m[00050?m[00050?m^003oJ`00of/00?m[003oL0000`3o
J`00103oL`00ogP00?m`003oL00:0?mj00030?mm003oO`00ohP00080ohX001<0ohd00?n?003oV@00
oi`00?n^003oc@00UOh008W=;01So`@0Q>H[03SoC`0^[iP09;]_03_]DP2Yo`00HLD[03?E=`1ZeD80
m_H00080on/000@0oOH00>ko002QZ6D0Xb]m0P3o00001@1VZRD0WUE<0<H[:`3W02/0o`0L01X0o`00
00@0P65O09F0<P1UdED0LjY60P3o00006@1KQ5l0G?eV0?;l003ofP00olX00?o2003o_@00ol000?o?
002Dk1P0o>000=WX003oe000ol`00?o?003oe`00o^l009Co003Dl`00olD00?nk003o_@00ojH00?n:
003oO@000P3oNP000`3oL`00of/00?m[00040?m[00050?mY003oIP00ofH00?mQ003oG`001@3oG005
ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool00_oooolR0?m<00030?m@003oC000od`0
00d0od`000<0oe000?mL003oG0007P3oG0000`3oH000oe`00?mL00030?mL0080ofP00`3oG00H0?m[
00050?m_003oJ`00of/00?m[003oL`000`3oJ`000`3oL`00ogX00?mj00090?mj00050?n2003oRP00
ohX00?n:003oSP000P3oV@007`3oZ000ok`00?oK003im`00S/90023o>P0Jocl0K>500;;o002[o`00
j?l00:Oo002>ob80o^d00?oK003oe`00om/00?oZ0035o`00Uol002G:K@3o0000X42C0<40@02Zo`00
Q<100<0]@03o0000RH0N0?l00030:D004@3o00004@3o01l0`40i0?l0003o0000Th130?l00020P3L0
/_l00=co000AiJ40FL0/055aY@30@8D0=_lF04GX@03od`00ol000080okP000<0ok000?nh003o^000
103o^0003@3o_000oll00?Ci000^o`h0mNl00?nd003oY@00oiT00?n>003oQP00ogh00?mj003oM`00
1`3oJ`000`3oH000oe`00?mL00020?mL0080of000`3oG005ooooo`7o00000Oooool001_ooooo00?o
0000ooooooooool00_oooolb0?m<00050?mJ003oG000oeX00?mD003oC`000`3oC0000`3oD@00oeX0
0?mL000K0?mL00030?mO003oIP00oe`000<0oe`000<0of@00?m[003oJ`00403oJ`000`3oKP00of/0
0?m[00060?m[00040?m^003oJ`00of/00?m[0080ogD000<0og000?mh003oNP001`3oNP00;P3oO@00
oh800?n:003oS@00ohX00?nD003oV@00ojP00?nm003oe000h_T007[o3`1;iR`0A/eV03Ko@`35o`00
m?`00?k_003oiP00o^D00?o?003obP00olL00?o<003ofP00PO/E04OSJ`0ccFd0=h2L042eE`35o`00
hOl002FnN028EDd0WTIE06?E:`3E4B/0NjX/0<1E500NXXH0/UE1095;E@2^E@80ZUDR0?l0003l03D2
0?l0000I0?H0702c55D0ZUE30:iE0P2^EB/0HhHf0:QE@@26?700P:X/0:Y9I`1bXh00L_lA0:YE;01C
P:80Y?T[0?gc003do000U]h[04KEE`00j8L0GMED0?S^003oa@00okH00?n^00050?nX000=0?n[003o
Z000oj/00?nc003o`000e^h007[E2`3ajP00ok000?nL003oS`00ohX00?n000020?mj00030?me003o
KP00of/000D0of/000<0oel00?mL003oG0001`3oG005ooooo`7o00000Oooool001_ooooo00?o0000
ooooooooool00_oooola0?m<00030?mD003oG000oeP000P0od`0703oG0000`3oH000oe`00?mL0003
0?mL00060?mT003oJ`00ofP00?mL003oH000ofP03@3oJ`000`3oK`00of/00?m[00050?m[00030?m_
003oJ`00of/00080of/000@0og<00?m[003oJ`00ofl02@3oNP004P3oPP00ohH00?n:003oRP00oiH0
0?nI003o[000inD00;gi<@10o`d0]?la0;[o002fo`00Im5>04go4P3Ho`00oml00?o;0080ol@00P3o
^0003@3o`000ol/00?oS002Moa80P82<017dPP1Gocl0kOd00?kd003Uo@00P80A07c08P3To`000P3J
`0001@31o`00[_l0093o001Mo`00CL0=00P0o`0001@0CL0P06Go002Ko`00^_l009[U@039o`00P<0>
0>oo003Lo`00F<0T04SoBP3oi`00oml00?oW000eod<0Sol004Oo002c`000Y><70?nd0080ojP00140
ojD00?nM003oW@00oiT00?nM003oV@00oj400?nU003oZ000ok@00?o<002ko@00l_L00??:003oV@00
ohX00?n200030?mj00P0of/000<0ofP00?mL003oG0001`3oG005ooooo`7o00000Oooool001_ooooo
00?o0000ooooooooool00_ooool`0?m<00030?mB003oFP00odl000T0od`000<0oe@00?mL003oG000
4P3oG0000`3oG`00oe`00?mL00030?mL0080oel01@3oG0000`3oIP00of@00?mL00020?mL00030?mO
003oJ`00of/001L0of/000L0ofh00?m[003oJ`00of/00?m^003oNP00ogD000P0ogX001@0oh800?n:
003oRP00ohl00?nI003]_`00Yo/00;So003kj@00omL00<;`003Rk000knX00;?n1`1mo`00on400?o2
003o^000okH00?nc0080okH00180ol000?oG001Cj3@0U?LE0:[k002knaH0on@00?oL003ii@00e>hV
0?Kc003mmP00n_X00??o003Qo`00aOl006;eB@2@HDH:0?l0000;081[=@1ZkUD0d_l00>_o003ioP00
oOH00?o[003njP00m/H00?oO003oc`000P3oc000203og000d?T008g]AP3odP00okd00?nX003oX@00
oi`00P3oV@000`3oW000oiT00?nI00030?nI00080?nQ003oZ000okd00?cX003@n@00kLH00?nD003o
RP030?mj0080ofh01@3oJ`001@3oJ@00of@00?mQ003oI000oel000L0oe`01Oooool1o`00007ooooo
000Kooooo`;o00000oooool_0?m<00030?m@003oF000od`000/0od`06P3oG0000`3oH000oe`00?mL
00040?mL00030?mX003oG000oe`000<0oe`00`3oJ`000`3oJ000of/00?m[000G0?m[00040?mc003o
K`00of/00?m_00P0ogX000P0oh800?n:003oRP00oiH00?nl003oc000g>D00?o?0080ok@000L0okP0
0?o8002fo`00W/100=k[003o^000oj`00080ojP000H0oj`00?nX003o/000ok`00?o<003ob`020?o?
00030?o7003ob`00ol/00080omL000H0onH00?ob003lo@00i?l007o2@005iJD;0?l0000C0?l09`2H
P1X0R_m00??o003om@00onH00?oK003od`00ol/00?o4003o`000ok`00?nh003o`000l^L00<3F5P3o
]000ojP00?nM00040?nI00030?nF003oTP00oiH00080oiH00P3oV@001`3oY@00okP00;oc2P3o^000
ok@00?n:003oOP000P3oNP000`3oM`00og<00?m[00050?m[00030?mT003oG000oe`00080oe`000<0
of000?mL003oG000103oG004ooooo`;o00000Oooool001_ooooo00?o0000ooooooooool00_ooool^
0?m<00030?m?003oD@00od`000`0od`0803oG0000`3oG`00oe`00?mL00040?mL00030?m[003oIP00
oel00080oe`000<0ofH00?m[003oJ`005@3oJ`00103oKP00of/00?m[003oJ`080?mj00070?mm003o
R000ohX00?n?003oU000oih00?nS00020?nQ00070?nS003oYP00ojd00?WE003oc`00ok<00?n[0002
0?nV0080oj<00P3oZ0020?n]000>0?nc003o^000okP00?nm003o`000olD00?o:003odP00omX00?o[
003io000e?l001CSB@3_02/<0?l0000<0=D[8@16IJX0/?l00?kd003og`00om800?o7003o`P00okP0
0?nf003o/000ok<00P3o/0000`3o[P00oj<00?nI00020?nI00030?nG003oTP00ohd000@0ohX00P3o
S@001`3oU000oiL00>ni003ncP00oiT00?n=003oQ@000P3oNP000`3oN000og<00?m[00060?m[0003
0?mT003oG000oe`000T0oe`01Oooool1o`00007ooooo000Kooooo`03o`000?oooooooooo00;ooooo
;P3oC0000`3oE000od`00?m<000;0?m<00030?m@003oG000oe`001h0oe`000<0of000?mL003oG000
103oG0000`3oJ000oe`00?mL00030?mL01X0of/000@0og<00?m_003oJ`00ogL01`3oNP040?n:0003
0?nB003oUP00oiT000<0oiT00P3oX@00103oY@00oiT00?nM003oW@030?nI00030?nQ003oZ000ojP0
0080ojP000/0oj`00?nh003o^000okP00?o4003oa`00omL00?oZ002io`00Q<1G0<0R@00>0?l00006
0<100`19`4<0^oX30?oO003ob`00ol000P3o^0030?nX0080ojD000H0oid00?nI003oV@00oiH00?nB
003oSP0:0?n:0080ohh000<0ohX00?n6003oNP000P3oNP000`3oL`00of/00?m_00070?m[00030?mP
003oG000oe`000P0oe`01Oooool1o`00007ooooo000Kooooo`03o`000?oooooooooo00;ooooo;03o
C0000`3oC`00oe400?m<000=0?m<00030?mD003oG000oe`002@0oe`000<0of@00?mO003oG000103o
G0020?m[00040?mY003oI000of@00?mY01<0of/00P3oKP020?m[00030?mc003oNP00ogX000H0ogX0
00<0ohD00?n:003oRP000`3oRP00103oS@00ohl00?nD003oU`080?nI0080oi`000h0oih00?nS003o
Z000ojP00?n[003o/000okP00?nk003oa`00omD00?o[002lo`80EMDc08205`h0o`0000/0FeJ006gE
D03Zo000on@00?o=003o_@00okH00?n[003oZ000ojH00?nQ00030?nI00030?nG003oTP00ohd000L0
ohX000<0ohP00?n:003oR0000P3oQ@00103oR000oh800?mo003oO@020?mj00030?mc003oJ`00of/0
00D0of/000<0of@00?mL003oG`000P3oH@090?mL00Gooooo0Ol00001ooooo`006oooool00ol0003o
ooooooooo`02ooooob`0od`000<0oe000?m<003oC0003@3oC00H0?mL00030?mP003oG000oe`000`0
oe`000<0of@00?mL003oG000103oG0000`3oJ`00of@00?mL00020?mL00030?mP003oJ`00of/00140
of/000@0ofl00?m[003oJ`00of/00`3oL`050?mj00030?mn003oNP00ogh00080ohH0103oRP001@3o
SP00ohX00?n:003oTP00ohh00080oi8000<0oiH00?nI003oV@00103oV@00303oX@00ojP00?nX003o
[000ok000?nh003oa`00om/00?kd003Ho`00@>QN04E6VPl0o`0000H0P7FK07o6@02FaT00oll00?nl
003o/0020?nX00060?nQ003oV@00oiT00?nI003oTP00ohh01P3oRP020?n200/0ogX02@3oJ`0>0?mL
00Gooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`02oooooc/0od`000D0oe800?mL003o
G000oeT00?mA00030?m<00030?m?003oFP00oe`001D0oe`000<0oel00?mL003oG000103oG0000`3o
G`00oe`00?mL00040?mL00030?mQ003oIP00oe`000@0oe`000<0ofT00?m[003oJ`004`3oJ`020?m^
0080of/000<0ogD00?mj003oNP001@3oNP00103oO@00oh000?mo003oQ@090?n:00040?n=003oRP00
oi800?nG00@0oiT000/0oih00?nV003oZ000oj/00?nh003o`000d?4007[S:`12ced0P6VG0;P?E@0>
0?l000090;X[;`1heA@03olb08[n6`3neP00okP00?n[003oZ000oih00080oiT000<0oiL00?n?003o
RP001@3oRP000`3oQ@00oh800?mj000:0?mj00050?mh003oKP00ofh00?m[003oKP001P3oJ`000`3o
IP00oe`00?mL00030?mL00030?mO003oG000oe`000D0oe`01Oooool1o`00007ooooo000Kooooo`03
o`000?oooooooooo00;ooooo:@3oC0020?m@0100od`00P3oG0000`3oF000od`00?m<00050?m<0003
0?mH003oG000oe`00240oe`000<0of@00?mL003oG000103oG0000`3oI000of/00?m[00020?mT01D0
of/000<0ogL00?m_003oM`001P3oNP000`3oOP00ogX00?mj00020?n200030?n6003oRP00ohX000L0
ohX000<0ohh00?nB003oV@000`3oV@002P3oX@00ojP00?nX003o]000ol000?oG002:o`<04OBQ067o
000=m7<>0?l0000<0<10@02N`5H0[_l00;ki003_f@00okP00?nX003oY@00oid00?nI003oUP00oi80
1@3oRP000`3oPP00ogX00?mn000;0?mj0080ofl0203oJ`00103oI000of000?mT003oH0060?mL0003
0?mP003oG000oe`000<0oe`01Oooool1o`00007ooooo000Kooooo`03o`000?oooooooooo00;ooooo
>P3oC0000`3oE000oe`00?mH00080?m<00030?m@003oG000oe`00240oe`000<0of@00?mL003oG000
103oG0020?m[00040?mP003oG000oe`00?mP01<0of/000@0ofl00?m[003oJ`00of/02P3oNP00103o
OP00ogX00?n2003oPP0:0?n:00@0oiT00P3oZ0001`3o/000okP00?o?002ko@00H?ll0:ko001E`2`0
3@3o00002@3_0400DKaJ09C0?P3ao@00on<00?o7003o^000ojP00?nQ00020?nI00030?nB003oRP00
ohX000<0ohX000<0ogh00?n2003oNP002P3oNP001@3oL`00ofl00?m_003oJ`00ofl000H0of/000@0
ofP00?mL003oG000oe`00P3oH00;0?mL00Gooooo0Ol00001ooooo`006oooool2o`0000?ooooo>@3o
C0000`3oC`00oe`00?mD000:0?m<01/0oe`000<0oel00?mL003oG000103oG0000`3oG`00oe`00?mL
00050?mL00030?mY003oG`00oe`000<0oe`000<0of@00?m[003oJ`00303oJ`000`3oKP00of/00?m[
00040?m[00040?m`003oL`00og000?mh00T0ogX000@0ogd00?mj003oPP00ogd00P3oR0050?n:000?
0?n=003oRP00oiT00?nI003oW000oih00?nX003o/000ok/00?o:003ni@00mo`00;Ko000UobD0ZT4n
00`0o`0000/0eP0[0?l0001GV;T0Hol?0?kZ003oc@00ok/00?nX003oW000oiT00?nG00040?n:0003
0?n8003oPP00ogX000X0ogX000D0og<00?m^003oL000of/00?m^00080?m[00030?mY003oG000oe`0
00h0oe`01?ooool2o`00007ooooo000Kooooo`03o`000?oooooooooo00;ooooo9P3oC0000`3oD000
od`00?m<000@0?m<00030?mH003oD000od`000X0od`000<0oe@00?mL003oG0007`3oG0000`3oH000
oe`00?mL00040?mL00030?mT003oH000oe`000@0oe`000<0of@00?m[003oJ`005P3oJ`000`3oL`00
ogX00?mj000:0?mj00030?mn003oNP00ogh000P0ohX00`3oV@00203oZ000ok@00?nh003oa`00oml0
0>Wm001koah0P5j0303o000030300d00@<12081hL@0EdF@0Mol:0?Sm0037k`00ol`00?nX003oW@00
oiT00?nB00<0ohX00P3oQP0:0?mj0080of/000<0og<00?m[003oK`00203oJ`00103oJ000of@00?m[
003oH00?0?mL00Gooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`02ooooo`030?m2003o
A`00odX003D0od`000<0oe@00?m?003oC0002`3oC0000`3oFP00oe`00?mL000V0?mL00030?mT003o
G000oe`000@0oe`000H0of@00?m[003oIP00of400?mO003oI00C0?m[00030?m`003oJ`00of/000`0
ogX000<0oh000?mj003oPP001@3oRP003`3oS@00oi@00?nI003oV@00ojP00?n`003o_@00oll00?oT
002Sn2/0;Olo03R9[03<:d40<j9S0:X/G`090?l0000<08I`=`1Xo`X0Fold09Ko1`16ob`0W_0[08gk
1`3<iP00oj/00?nI003oU`00ohd00`3oRP000`3oPP00ogX00?mm00060?mj00040?mh003oL000og<0
0?m^00@0of/000<0ofh00?m[003oJ`001@3oJ`030?mL00030?mT003oG000oe`000@0oe`000<0oel0
0?mL003oG0001P3oG005ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool00_ooool30?lm
00030?m1003oC000od`00340od`00P3oD00=0?m<0240oe`000<0of000?mL003oG000103oG0000`3o
H000oe`00?mL00050?mL00030?mX003oI000oe`000<0oe`000<0of@00?m[003oJ`003`3oJ`001`3o
K`00of/00?m[003oJ`00ogL00?m_003oM`002@3oNP001@3oOP00ogX00?mn003oNP00oh8000D0ohX0
0P3oV@002`3oZ000okP00?[M003jl@00oOL00<Go0010`4d0E_l002CQVP1Uo`00=L1X00L0o`0000d0
b010042]N`1a`0<0dOl00??o003Po`00H=e00:[o003jh@00ok`00?nQ003oV@00oi8000<0ohX000<0
ogX00?mn003oNP001P3oNP000`3oM`00og<00?m[000>0?m[01<0oe`01Oooool1o`00007ooooo000K
ooooo`03o`000?oooooooooo00;ooooo1@3o?@000`3oA@00od`00?m<000^0?m<0080odl03@3oC000
0`3oC`00oe`00?mL00030?mL0080oeL000<0oeX00?mL003oG0007P3oG0000`3oG`00oe`00?mL0004
0?mL00030?mO003oIP00oe`000@0oe`000<0of@00?m[003oJ`004P3oJ`001P3oKP00of/00?m[003o
J`00ogX00?me00H0ogX000<0ogd00?mj003oNP000P3oNP020?n200@0ohX00240oi@00?nI003oX`00
eN0:0<Sk003Ee@00XOl00:Co001JeB@0b_l00=Go003<o`00C]ME02_VF00c^H`0?[4k081fJ@3o0000
h`PL02k5F@14o`@0Wol002_cJP3@o1H0onh00?Gh0029ob<0f=<00>WY003o/000oj400?nG003oS@00
0P3oRP000`3oPP00ogd00?mj00060?mj00030?m^003oJ`00og0000`0of/000@0ofH00?mT003oJ@00
of404P3oG005ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool00_ooool60?lm00030?m1
003oC000od`002`0od`00P3oD00>0?m<00050?mD003oG000oe`00?mL003oE000103oC0000`3oD000
oeP00?mL000T0?mL00030?mP003oG000oe`000@0oe`000D0of@00?m[003oJ`00ofP00?mT000C0?m[
00040?mc003oK`00of/00?mc00`0ogX01@3oRP003`3oV@00oid00?nh003Wj@00oml00=Oj0028oAH0
Hol90<Go003nn000kOd00<k0<P2:iD00[_l004Wo3P040?l0000<02SUD@3Lo`00lOd00?oW003oe`00
om/009_m:@3el`00c_d00?[6003oW@00oi800`3oRP000`3oOP00ogX00?mj00040?mj00<0og<00P3o
J`000`3oK`00of/00?m[00080?m[00050?mT003oG000oe`00?mL003oJ0004P3oG005ooooo`7o0000
0Oooool001_ooooo00?o0000ooooooooool00_ooool70?lm00030?m2003oC000od`002X0od`000<0
odl00?m<003oC0003P3oC0020?mL00030?mD003oC`00od`000D0od`000<0odl00?mJ003oG0006`3o
G0000`3oG`00oe`00?mL00050?mL00030?mO003oG000oe`000@0oe`000<0of@00?mY003oG`000`3o
G0000`3oJ@00of/00?m[000B0?m[00040?m`003oN000og000?mh00P0ogX000<0ogd00?mj003oPP00
0`3oRP00403oS`00oiT00?nQ003o[@00okP00?o5003LkP00SOl00<kh1`3oh@00on@00?k_003go000
aOl005RkF@2ZED/20?l0000609l/WP16l3T0d_l00?k_003oe@00olX00`3o`P000`2^hPX0oj/00?nI
00020?n=00030?n:003oP000ogX000H0ogX0403oJ`000`3oI000oe`00?mL00020?mL00030?mQ003o
G000oe`000h0oe`000<0oeX0ooooooooool00oooool1o`00007ooooo000Kooooo`;o00000oooool8
0?lm00030?m9003oC000od`003T0od`000<0oe@00?mL003oD0002@3oC0000`3oE000oe`00?mL000Y
0?mL00030?m[003oG000oe`000<0oe`000<0of@00?m[003oJ`004P3oJ`00103oK`00of/00?m[003o
K`0:0?mj0080oh800`3oRP007@3oTP00oiT00?nM003oZ000ok@00=O[003Rl`00om<00?o7003oc`00
oml00?gj003Po`00KOl0080/e0304T00eB/N01W2L`00ofX0LOl00:ko003oc`00ol000?nh003o[000
ojP00?nU003oV@00oi800080ohX000<0oh800?mj003oNP00103oNP020?mc00030?m_003oJ`00of/0
00X0of/000@0ofP00?mT003oI000of/05@3oG0000`3oC03oooooooooo`02ooooo`;o00000Oooool0
01_ooooo00?o0000ooooooooool00_ooool80?lm00030?m0003oC000od`002P0od`000<0odl00?m<
003oC0003@3oC0000`3oC`00oe`00?mD000;0?m<0280oe`00P3oG`060?mL00030?mQ003oG`00oe`0
00@0oe`000<0of@00?m[003oJ`004@3oJ`020?m^0080of/00P3oL`000`3oL000ogD00?mj00070?mj
00030?n2003oQ@00ohX00080ohX000D0oi800?nI003oV@00ojH00?ne00030?nk000C0?o2003og000
XOhI07oj:`1HoaD0Nol003cEE01PWUT0MOl40<[o001oo`X0o>P00?o2003o^000oj/00?nV003oWP00
oiT00?nD00020?n:00030?n5003oO@00ogX000D0ogX00`3oJ`000`3oKP00of/00?m[00090?m[00<0
oe`000<0oel00?mT003oG0004P3oG0000`3oE000od`0ooooo`04ooooo`7o00000Oooool001_ooooo
00?o0000ooooooooool00_ooool90?lm00030?m5003oC000od`003L0od`000<0oeP00?m@003oC000
2`3oC00Z0?mL00030?mP003oG000oe`000@0oe`000<0of@00?m[003oI0000P3oG0000`3oJ000of/0
0?m[000<0?m[00050?m_003oJ`00of/00?m[003oK`000P3oJ`000`3oL`00ogX00?mj00080?mj00@0
ohX000@0oi800?nI003oW@00ojD00P3oZ0004`3o/000okP00?o8003oh`00mOL009;o3P3=o`00/_l0
05?EI03Ao`00o?d00?Wc003@h@00ok`00?n`003oZ000oj400?nI003oUP000`3oRP000`3oPP00ogX0
0?mj00030?mj0080og<000<0ofl00?m[003oJ`00303oJ`0H0?mL00030?mD003oC03ooooo00Cooooo
0Ol00001ooooo`006oooool00ol0003oooooooooo`02ooooo`T0ocd000<0odD00?m<003oC0009@3o
C0000`3oC`00od`00?m<000>0?m<00030?mB003oE000od`000`0od`0:@3oG0000`3oG`00oe`00?mL
00050?mL00030?mY003oH@00oe`000<0oe`000<0ofT00?m[003oJ`004P3oJ`020?mc00030?m`003o
N000ogX000@0ogX00P3oO@006P3oNP00ohX00?n:003oRP00ohd00?nB003oU`00oiT00?nL003oYP00
ojP00?n[003o^000ol800>;K003njP00oOP00:3I:`18hb`0Qol00?o^003oe`00olL00?nh003oZ000
oj<00P3oV@001@3oTP00ohX00?n:003oQ@00ogl000D0ogX03@3oJ`001@3oJ@00of400?mT003oJ@00
oel000@0oe`000<0oel00?mL003oG000403oG0000`3oE000od`0ooooo`04ooooo`7o00000Oooool0
01_ooooo00?o0000ooooooooool00_ooool:0?lm02H0od`000<0oe000?m<003oC0003`3oC0000`3o
E000od`00?m<000<0?m<0300oe`00P3oH0050?mL00030?mT003oJ`00of/00180of/000@0ofl00?m[
003oJ`00og<01`3oNP000`3oOP00ogX00?n600030?n:000F0?nB003oV@00oiT00?nM003oY@00ojP0
0?n`003o^000ol@00?oC003oiP00f_d007So002Zo`00onX00?o?003o`000okP00?nX003oX@00oiT0
0?nF00<0ohX000<0ogh00?mj003oNP000P3oNP000`3oM`00og<00?m_000<0?m[00@0oe`000<0of@0
0?mL003oG0005P3oG0000`3oC03oooooooooo`03ooooo`7o00000Oooool001_ooooo00?o0000oooo
ooooool00_ooool:0?lm03L0od`000<0oe@00?m<003oC000303oC0000`3oE000oe`00?mL00020?mL
00050?mD003oD000od`00?m<003oE0009`3oG0000`3oH000oe`00?mL00040?mL00050?mT003oJ`00
of/00?mT003oJ0004`3oJ`000`3oM`00og<00?mg00070?mj00030?n6003oRP00ohX00080ohX000@0
oiH00?nI003oV@00oiT00P3oZ0003`3o^000ol000?o7003og`00o_@008oo003[o`00on<00?o?003o
a`00okP00?nX003oX@00oiT00?nB00020?n:00030?n2003oNP00ogX000<0ogX000@0og<00?m[003o
K`00ofl02`3oJ`0M0?mL00030?m@0?oooooooooo00?ooooo0Ol00001ooooo`004oooool3o`0000Go
oooo00?o0000ooooooooool00_ooool:0?lm03H0od`00P3oC`0>0?m<00050?mG003oG000oe`00?mG
003oC`001@3oC0000`3oC`00oeX00?mL000S0?mL0080oel01P3oG0000`3oJ`00of@00?mL00020?mL
00030?mT003oJ`00of/00100of/000<0ofh00?m[003oJ`00203oNP001P3oQ@00ohX00?n:003oRP00
ohd00?nD0080oiT00140ojH00?nX003o/`00okP00?o:003og`00g?@009Wo402`o`00l?P00?kS003o
bP00ok/00?n[003oX@00oiT00?n=00020?n:00030?mo003oNP00ogX00080ogX000<0ogD00?mc003o
J`002P3oJ`020?mV00030?m[003oH@00oe`000<0oe`000<0oel00?mL003oG0005@3oG0000`3oFP3o
ooooooooo`03ooooo`7o00000Oooool001Cooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`02ooooo`X0ocd0=@3oC0020?m@00l0od`00P3oG0000`3oD000od`00?m<00060?m<00030?m@
003oG000oe`001X0oe`000<0of000?mL003oG000303oG0000`3oH000of@00?mL00040?mL0140of/0
00@0ofl00?m[003oJ`00of/02@3oNP001@3oPP00ohX00?n:003oRP00ohh00080oiT001<0oj400?nX
003o/000okP00?o?003okP00gOd00;?m4@3Yo@00C_l00<Wo003oi`00oml00?nl003o[000oiT00?nB
003oRP00ohH000D0ogX00P3oJ`000`3oK`00of/00?m[00070?m[00050?mT003oG000oe`00?mP003o
J0005P3oG0001@3oF000oe@00?mD003oE000oeP00080oe`01Oooool1o`00007ooooo000Dooooo`03
o`000?oooooooooo00Cooooo0_l00003ooooo`X0ocd0=@3oC0000`3oC`00od`00?m<000=0?m<0003
0?mD003oG000oe@000X0od`000<0oeX00?mL003oG000:03oG0000`3oI000oe`00?mL00040?mL0080
of/000<0ofT00?mV003oJ`003`3oJ`00103oKP00of/00?m[003oM@060?mj000J0?mo003oR000ohX0
0?n:003oS@00oiL00?nI003oX`00ojP00?nc003o`P00omT00:Wo0027o`80n^T00?oJ003/j@00a_T0
0=Oo0036d`00i>`00?nh003oWP00oi800?n:003oQ@030?mj00030?mh003oM@00ofh000/0of/0103o
G0020?mO01@0oe`000<0oe@00?m<003oC000103oC0000`3oE03oooooooooo`02ooooo`;o00000Ooo
ool001Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`T0ocd000<0odD0
0?m<003oC000<P3oC0000`3oC`00od`00?m<000>0?m<00030?mL003oD000od`000X0od`000<0oe@0
0?mL003oG0009`3oG0000`3oH000oe`00?mL00050?mL00030?m[003oH000oe`00080oe`03P3oJ`00
1@3oK`00of/00?m[003oJ`00ogL000L0ogX001T0ohH00?n:003oRP00ohh00?nF003oV@00oj400?nX
003o^000olL00?oS0031o`00f?l00?o:003o`000ol@00=k_003nk@00hOT00;_i003oc`00ok400?nB
003oRP00oh8000<0ogX000<0og<00?m[003oJ`002`3oJ`000`3oI000oe`00?mL00030?mL00030?mP
003oG000oe`00140oe`0203oC005ooooo`7o00000Oooool001Cooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`02ooooo`T0ocd000<0odD00?m<003oC000<@3oC0000`3oC`00od`00?m<
000>0?m<00030?mG003oE000od`000/0od`000<0oe@00?mL003oG0007`3oG0000`3oG`00oe`00?mL
000<0?mL00030?mT003oH@00oe`000<0oe`000<0of@00?m[003oJ`003P3oJ`020?m^00030?m[003o
M@00ogX000D0ogX00`3oRP00303oU000oiT00?nS003o^`00olX00?oJ003nk`00Z_lK0?oG003o^P00
ok000?n]0080okP000L0ok/00?oD003PlP00o[`00?nB003oR000ogd00080ogX000<0og<00?m`003o
J`00203oJ`001@3oJ@00oel00?mO003oI000ofH001P0oe`000<0oe@00?m<003oC0001P3oC005oooo
o`7o00000Oooool001?ooooo0_l00006ooooo`03o`000?oooooooooo00;ooooo2@3o?@150?m<0003
0?mH003oC000od`000/0od`000<0oe@00?mL003oG000;P3oG0000`3oI000oe`00?mL00030?mL0003
0?mT003oJ`00of/000T0of/000<0ofl00?m[003oJ`001@3oJ`000`3oL`00ogX00?mj00030?mj000>
0?mn003oPP00ohX00?n:003oTP00oiT00?nQ003jf@00aoX00<7o0039o`00k_<00?OM003o[@040?nQ
00060?nU003o_000n]d00?nQ003oRP00ogh00`3oNP000`3oL`00of/00?m[00080?m[00030?mT003o
G000oe`00080oe`000<0of@00?mL003oG0005@3oG0000`3oE000od`00?m<00060?m<00Gooooo0Ol0
0001ooooo`005?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo203o?@00
0`3o@000od`00?m<000a0?m<00030?m?003oC000od`000h0od`000<0oe@00?m<003oC000303oC000
2`3oE`00oe`00?mL003oG000oeX00?mD003oD@00od`00?m?003oD@00oeX001h0oe`000<0oel00?mL
003oG000103oG0000`3oG`00oe`00?mL00040?mL00060?mT003oJ@00of400?mL003oG`00ofT03@3o
J`00103oKP00og000?m`003oN0040?mj000>0?n0003oRP00ohX00?n=003oV@00oj400?o2003Sm@00
G:E;0:_n:`3oa@00ok<00?nP003oV@020?nG0080oi@000@0oih00>no003oS`00ohP00`3oNP020?m^
00X0of/000<0of@00?mL003oG0000P3oG0000`3oG`00oe`00?mL000E0?mL00030?mG003oC000od`0
00H0od`01Oooool1o`00007ooooo000Kooooo`03o`000?oooooooooo00;ooooo203o?@000`3oA@00
od`00?m<00110?m<0080oe003P3oC0030?mL00030?mH003oC000od`000D0od`000<0oeP00?mL003o
G0008P3oG0000`3oH000oe`00?mL00040?mL00030?m[003oG000oe`00080oe`000<0of000?m[003o
J`003P3oJ`000`3oM`00ogX00?mj00030?mj0080ohX000/0ohh00?nI003oY@00ol`00>7i003bm`00
iOT00?o0003oX@00oiL00?nB00060?n:00060?n6003oNP00ogX00?mj003oL`00ofl0203oJ`00103o
J000oe`00?mT003oJ`050?mL00030?mP003oG000oe`001D0oe`0203oC005ooooo`7o00000Oooool0
01_ooooo00?o0000ooooooooool00_ooool70?lm00030?m0003oC000od`00480od`000<0odl00?m<
003oC000303oC000103oC`00oe`00?mL003oE0080?m<00030?m?003oG000oe`002P0oe`000<0of40
0?mO003oG000103oG00?0?m[0080og0000<0og<00?mj003oNP000P3oNP00303oQ@00ohX00?n?003o
V@00ojP00?o=003hn000old00?nk003oZ000oi`00?n<00<0ohX000@0ohD00?n2003oPP00ogd00`3o
NP000`3oL`00of/00?m[00080?m[00<0oe`000<0oel00?mT003oG0006`3oG0000`3oE`00od`00?m<
00050?m<00Gooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`02ooooo`L0ocd000<0odT0
0?m<003oC000@@3oC0000`3oE000od`00?m<000=0?m<00030?mD003oG000oe0000X0od`000<0oe@0
0?mL003oG0009`3oG0000`3oH000oe`00?mL00030?mL00050?mP003oJ`00ofP00?mP003oI0002P3o
J`00103oK`00of/00?m[003oK`040?mj000;0?n2003oRP00ohh00?nI003oZ000ol@007Gi7P3o`000
ojP00?nI003oTP000P3oRP000`3oQP00ogh00?mn00040?mj00030?mg003oL`00of/000X0of/06P3o
G0001P3oF000oe000?m<003oC000oe@00?mH0080oe`000<0oe000?m<003oC000103oC005ooooo`7o
00000Oooool001_ooooo0_l00003ooooo`H0ocd000<0od800?m<003oC000@@3oC0000`3oC`00od`0
0?m<000>0?m<00030?mL003oE000od`000X0od`000<0oe@00?mL003oG0009P3oG0000`3oG`00oe`0
0?mL00040?mL00030?mV003oI000oe`00080oe`000<0of400?m[003oJ`002P3oJ`020?m^00<0ogX0
00d0oh000?n:003oU000oih00?ne003Uf000jO400?o5003oX`00oi@00?n:003oQ`00ogd000H0ogX0
00@0ogD00?m^003oJ`00ofh01`3oJ`020?mQ00030?mV003oH@00oe`000<0oe`000<0oel00?mL003o
G0004@3oG0000`3oE`00od`00?m<00040?m<00030?mA003oFP00oeX000H0od`01?ooool2o`00007o
oooo000Kooooo`03o`000?oooooooooo00;ooooo1P3o?@140?m<00030?m@003oC000od`000d0od`0
00<0oe@00?mH003oC0002`3oC0000`3oE000oe`00?mL000V0?mL00030?mP003oG000oe`000@0oe`0
00<0of@00?mL003oG0000`3oG00=0?m[00030?m_003oNP00ogX00080ogX000X0ohX00?nI003o^000
mnd00>?F003o`000kmd00?nU003oTP00ohH01@3oNP020?mg00030?m[003oK`00of/000P0of/000D0
of@00?mL003oG000oe`00?mT000H0?mL00T0od`00P3oF0050?m<00Gooooo0Ol00001ooooo`006ooo
ool00ol0003oooooooooo`02ooooo`D0ocd000<0odL00?m<003oC000@@3oC0000`3oC`00od`00?m<
000>0?m<00030?mJ003oC000od`000/0od`000<0oe@00?mL003oG0000`3oG000103oFP00oeL00?mG
003oE`0U0?mL00030?mO003oG000oe`000<0oe`000D0of400?m[003oIP00of400?mV000;0?m[00<0
ogX000X0ohP00?nc003nd`00ok000?nN003oW000o;l00?nD003oR000ogd00`3oNP00103oN000og00
0?mc003oKP090?m[00030?mV003oJ`00ofH000@0oe`000<0oel00?mL003oG0005@3oG00:0?m<0080
oe@0103oC005ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool00_ooool40?lm00030?m5
003oC000od`00580od`000<0oe@00?m@003oC000303oC0001P3oE000oe`00?mL003oG000oeP00?m@
00@0od`000<0oe000?mL003oG000:03oG0000`3oI000of000?mL00020?mL00L0of/000D0ofl00?m[
003oJ`00ofl00?m[00020?mj00040?mn003oSP00oiH00?nB00<0ohX000<0oh800?mj003oNP000P3o
NP020?m_00/0of/000@0of@00?mL003oG000ofP01@3oG0000`3oH000oe`00?mL000D0?mL00/0od`0
00<0oe000?mD003oC0000P3oC005ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool00_oo
ool30?lm00030?m1003oC000od`00480od`000<0oe000?m<003oC0003P3oC0000`3oF000od`00?m<
000<0?m<00040?mD003oG000oe`00?mH00L0od`000<0oe000?mL003oG0009`3oG0000`3oI000oe`0
0?mL00020?mL00030?mT003oJ`00of/000P0of/000<0ofl00?mc003oNP000P3oNP020?n200030?mn
003oNP00ogX000<0ogX000<0ogP00?m[003oK`00303oJ`001@3oI000oe`00?mL003oG000of0001/0
oe`0303oC0020?m@0080od`01Oooool1o`00007ooooo000Kooooo`03o`000?oooooooooo00;ooooo
0P3o?@000`3o@000odX00?m<000:0?m<0080odL000@0odD00?m2003o@P00odD00P3oA`110?m<0080
odl03P3oC0020?mL00030?mG003oC000od`000L0od`000<0oeL00?mL003oG0007`3oG0000`3oG`00
oe`00?mL00030?mL00030?mQ003oG000oe`000<0oe`00P3oJ@000`3oH@00of@00?m[00080?m[0003
0?m`003oN000ogX000D0ogX000@0ogP00?me003oL`00ofd02`3oJ`00103oI000of400?mV003oI003
0?mL00030?mO003oG000oe`001T0oe`000<0odl00?m<003oC0002P3oC0000`3oC`00od`00?m<0005
ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool00_ooool20?lm00030?m9003oC000od`0
00L0od`000<0odD00?lm003o?@002@3o?@000`3oA@00od`00?m<000m0?m<00030?m@003oC000od`0
00`0od`000<0oe000?mL003oF0002P3oC0000`3oD000oe`00?mL000[0?mL00050?mX003oG000oe`0
0?mL003oJ000203oJ`00103oK`00of/00?m_003oK`020?mc00030?m_003oJ`00og<000h0of/00`3o
G0000`3oI000oe`00?mL000F0?mL00040?mH003oE000oe@00?mD00<0oe`000<0oe@00?m<003oC000
303oC0000`3oD03oooooooooo`03ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool00_oo
ool00`3o?@00odX00?m<00050?m<00030?m:003oA@00od0000l0ocd000<0odD00?m<003oC000>P3o
C0000`3oD@00od`00?m<000=0?m<00030?mG003oFP00od`000/0od`09P3oG0000`3oG`00oe`00?mL
00030?mL00030?mQ003oG000oe`00080oe`000<0of@00?m[003oIP002@3oJ`000`3oKP00of/00?m`
000=0?m[00040?mY003oG`00of400?mY00@0oe`000<0oel00?mL003oG000503oG0000`3oE000od`0
0?m<00030?m<00040?mD003oG000oe`00?m?00d0od`000<0odl0ooooooooool00oooool1o`00007o
oooo000Kooooo`;o00000oooool00`3oB@00od`00?m<00040?m<00030?m1003o?@00ocd00140ocd0
00<0od400?m<003oC000>03oC0000`3oD000od`00?m<000>0?m<00030?mL003oD000od`000/0od`0
;03oG0000`3oH000oe`00?mL00020?mL00040?m[003oH000oe`00?mP01H0of/000<0of@00?m[003o
I0000P3oG0020?mP00<0oe`000<0of000?mL003oG0004`3oG0000`3oF000od`00?m<00060?m<0080
oeP03P3oC004ooooo`;o00000Oooool001_ooooo00?o0000ooooooooool00_ooool40?m<00030?m:
003o@P00ocd001D0ocd000<0od000?m<003oC000=`3oC0000`3oC`00od`00?m<000=0?m<00030?mD
003oDP00od`000`0od`0103oG0001P3oFP00oe@00?m?003oC000odl00?mD01/0oe`000<0oel00?mL
003oG0000`3oG0000`3oG`00oe`00?mL00020?mL0080oel00`3oG0000`3oJ`00ofH00?mV000?0?m[
00070?mY003oJ`00of/00?mO003oG000oel00?mT000M0?mL00030?mD003oC000od`000L0od`000<0
oeX00?mB003oC000303oC005ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool00_ooool3
0?m<00030?m1003o?@00ocd001L0ocd000<0odD00?m<003oC000=@3oC0000`3oD000od`00?m<000>
0?m<00030?mH003oC000od`000`0od`00`3oG0000`3oF000od`00?m<00040?m<00030?m@003oG000
oe`002P0oe`000H0ofP00?mL003oG000of@00?m[003oJ00;0?m[00040?mX003oG000oe`00?mX00<0
oe`000<0of000?mL003oG0000P3oG0000`3oH000oe`00?mL000F0?mL00030?mD003oC000od`000P0
od`000<0oeP00?m<003oC0002`3oC005ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool0
0_ooool00`3oC000odD00?m0000K0?lm00030?m:003oC000od`003@0od`000<0odl00?m<003oC000
3@3oC0000`3oDP00odl00?m<000<0?m<00040?mD003oG000oe`00?mD00P0od`000<0oe800?mL003o
G0008P3oG0001@3oG`00oe`00?mL003oG000of4000<0oe`000l0of@00?mQ003oG000oel00?m[003o
I000of400?m[003oIP00of400?mV003oJ@00oe`00?mO003oI0000P3oG0000`3oG`00oe`00?mL0002
0?mL00030?mO003oG000oe`001X0oe`000<0oe@00?m<003oC0002@3oC0000`3oE000od`00?m<000:
0?m<00Gooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`02oooooah0ocd000<0od400?m<
003oC000A03oC0000`3oE000od`00?m<000<0?m<00030?mD003oG000oe@000X0od`0;03oG0001@3o
H000oe`00?mL003oG000of@00080oe`000D0of@00?mL003oG000oe`00?mT00020?mL00050?mP003o
G000oe`00?mL003oH000803oG0000`3oE000od`00?m<000:0?m<00030?mD003oC000od`000T0od`0
1Oooool1o`00007ooooo000Kooooo`03o`000?oooooooooo00;ooooo7`3o?@0?0?m<00030?m?003o
C000od`003<0od`000<0odl00?m<003oC0003@3oC0000`3oG000oeL00?m<000:0?m<00030?mJ003o
G000oe`002T0oe`000D0oel00?mL003oG000oe`00?mQ00020?mL00050?mT003oG000oe`00?mL003o
H@001P3oG0001@3oG`00oe`00?mL003oG000oel001@0oe`000<0oeX00?m?003oC0000P3oC000103o
D@00oeX00?mL003oG00=0?m<00030?mA003oC000od`000P0od`01Oooool1o`00007ooooo000Koooo
o`03o`000?oooooooooo00;ooooo7`3o?@000`3oA@00od`00?m<00120?m<00030?m@003oC000od`0
00`0od`000<0oe000?mL003oC0002`3oC0000`3oE000oe`00?mL00040?mL00030?mD003oF000oe`0
01<0oe`000<0of000?mL003oG0004`3oG0000`3oI000oe`00?mL00040?mL00030?mP003oG000oe`0
00H0oe`000<0of000?mL003oG0004@3oG0070?m<00030?mH003oG000oe@000d0od`000<0oe000?m<
003oC0001`3oC005ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool00_oooolO0?lm0003
0?m5003oC000od`00440od`000<0odl00?m<003oC0003@3oC0000`3oE`00oe800?m<000;0?m<0006
0?mD003oG000oe`00?mL003oE`00odl00`3oC0000`3oC`00oe@00?mL000K0?mL00030?mO003oG000
oe`002`0oe`000<0oeL00?m<003oC0001P3oC0000`3oE000oeX00?m<000<0?m<00030?m?003oC000
od`000L0od`01Oooool1o`00007ooooo000Kooooo`;o00000ooooolO0?lm00030?m5003oC000od`0
0440od`000<0oe000?m<003oC0003@3oC0000`3oF000od`00?m<000;0?m<00<0oe`000<0oe@00?m<
003oC0001@3oC0000`3oF000oe`00?mL000Y0?mL00030?mP003oG000oe`001`0oe`000<0oe@00?m<
003oC0001`3oC0020?mD00d0od`000<0oe000?m<003oC0001P3oC004ooooo`;o00000Oooool001_o
oooo00?o0000ooooooooool0ooooool1ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0
9?ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0
9?ooool00ol0003oooooooooo`0Aooooo`7o00000Oooool001_ooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_oo
ool1o`00007ooooo000Koooooooo00001Ol00001ooooo`00oooooolQooooo`00oooooolQooooo`00
oooooolQooooo`00oooooolQooooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {233, 0}} -> {-2.91326, -1.57182, 0.0128184, \
0.0128184}}]
}, Open  ]],

Cell["\<\
\[CapitalEGrave] naturalmente possibile aumentare ancora di pi\
\[UGrave] il numero di punti e quindi la qualit\[AGrave] del grafico, ma ci\
\[OGrave] richieder\[AGrave] un tempo di esecuzione via via maggiore. Nei \
grafici seguenti provvediamo a ingrandire via via alcune parti del grafico \
per evidenziare la natura frattale dell'insieme di Mandelbrot, i cui bordi \
contengono copie \"in miniatura\" dell'insieme stesso, che a loro volta \
contengono altre copie dell'insieme e cos\[IGrave] via:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(mandelbrotSet[{{\(-0.5\), 0.1}, {0.9, 1.2}}, 500, {0, 100}, 
        ColorFunction \[Rule] Hue];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .5 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.820513 1.60256 -1.43269 1.60256 [
[.01923 -0.0125 -12 -9 ]
[.01923 -0.0125 12 0 ]
[.17949 -0.0125 -12 -9 ]
[.17949 -0.0125 12 0 ]
[.33974 -0.0125 -12 -9 ]
[.33974 -0.0125 12 0 ]
[.5 -0.0125 -12 -9 ]
[.5 -0.0125 12 0 ]
[.66026 -0.0125 -12 -9 ]
[.66026 -0.0125 12 0 ]
[.82051 -0.0125 -3 -9 ]
[.82051 -0.0125 3 0 ]
[.98077 -0.0125 -9 -9 ]
[.98077 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .00962 -18 -4.5 ]
[-0.0125 .00962 0 4.5 ]
[-0.0125 .08974 -24 -4.5 ]
[-0.0125 .08974 0 4.5 ]
[-0.0125 .16987 -6 -4.5 ]
[-0.0125 .16987 0 4.5 ]
[-0.0125 .25 -24 -4.5 ]
[-0.0125 .25 0 4.5 ]
[-0.0125 .33013 -18 -4.5 ]
[-0.0125 .33013 0 4.5 ]
[-0.0125 .41026 -24 -4.5 ]
[-0.0125 .41026 0 4.5 ]
[-0.0125 .49038 -18 -4.5 ]
[-0.0125 .49038 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .5 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.01923 0 m
.01923 .00625 L
s
[(-0.5)] .01923 -0.0125 0 1 Mshowa
.17949 0 m
.17949 .00625 L
s
[(-0.4)] .17949 -0.0125 0 1 Mshowa
.33974 0 m
.33974 .00625 L
s
[(-0.3)] .33974 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(-0.2)] .5 -0.0125 0 1 Mshowa
.66026 0 m
.66026 .00625 L
s
[(-0.1)] .66026 -0.0125 0 1 Mshowa
.82051 0 m
.82051 .00625 L
s
[(0)] .82051 -0.0125 0 1 Mshowa
.98077 0 m
.98077 .00625 L
s
[(0.1)] .98077 -0.0125 0 1 Mshowa
.125 Mabswid
.05128 0 m
.05128 .00375 L
s
.08333 0 m
.08333 .00375 L
s
.11538 0 m
.11538 .00375 L
s
.14744 0 m
.14744 .00375 L
s
.21154 0 m
.21154 .00375 L
s
.24359 0 m
.24359 .00375 L
s
.27564 0 m
.27564 .00375 L
s
.30769 0 m
.30769 .00375 L
s
.37179 0 m
.37179 .00375 L
s
.40385 0 m
.40385 .00375 L
s
.4359 0 m
.4359 .00375 L
s
.46795 0 m
.46795 .00375 L
s
.53205 0 m
.53205 .00375 L
s
.5641 0 m
.5641 .00375 L
s
.59615 0 m
.59615 .00375 L
s
.62821 0 m
.62821 .00375 L
s
.69231 0 m
.69231 .00375 L
s
.72436 0 m
.72436 .00375 L
s
.75641 0 m
.75641 .00375 L
s
.78846 0 m
.78846 .00375 L
s
.85256 0 m
.85256 .00375 L
s
.88462 0 m
.88462 .00375 L
s
.91667 0 m
.91667 .00375 L
s
.94872 0 m
.94872 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .00962 m
.00625 .00962 L
s
[(0.9)] -0.0125 .00962 1 0 Mshowa
0 .08974 m
.00625 .08974 L
s
[(0.95)] -0.0125 .08974 1 0 Mshowa
0 .16987 m
.00625 .16987 L
s
[(1)] -0.0125 .16987 1 0 Mshowa
0 .25 m
.00625 .25 L
s
[(1.05)] -0.0125 .25 1 0 Mshowa
0 .33013 m
.00625 .33013 L
s
[(1.1)] -0.0125 .33013 1 0 Mshowa
0 .41026 m
.00625 .41026 L
s
[(1.15)] -0.0125 .41026 1 0 Mshowa
0 .49038 m
.00625 .49038 L
s
[(1.2)] -0.0125 .49038 1 0 Mshowa
.125 Mabswid
0 .02564 m
.00375 .02564 L
s
0 .04167 m
.00375 .04167 L
s
0 .05769 m
.00375 .05769 L
s
0 .07372 m
.00375 .07372 L
s
0 .10577 m
.00375 .10577 L
s
0 .12179 m
.00375 .12179 L
s
0 .13782 m
.00375 .13782 L
s
0 .15385 m
.00375 .15385 L
s
0 .1859 m
.00375 .1859 L
s
0 .20192 m
.00375 .20192 L
s
0 .21795 m
.00375 .21795 L
s
0 .23397 m
.00375 .23397 L
s
0 .26603 m
.00375 .26603 L
s
0 .28205 m
.00375 .28205 L
s
0 .29808 m
.00375 .29808 L
s
0 .3141 m
.00375 .3141 L
s
0 .34615 m
.00375 .34615 L
s
0 .36218 m
.00375 .36218 L
s
0 .37821 m
.00375 .37821 L
s
0 .39423 m
.00375 .39423 L
s
0 .42628 m
.00375 .42628 L
s
0 .44231 m
.00375 .44231 L
s
0 .45833 m
.00375 .45833 L
s
0 .47436 m
.00375 .47436 L
s
.25 Mabswid
0 0 m
0 .5 L
s
.01923 .49375 m
.01923 .5 L
s
.17949 .49375 m
.17949 .5 L
s
.33974 .49375 m
.33974 .5 L
s
.5 .49375 m
.5 .5 L
s
.66026 .49375 m
.66026 .5 L
s
.82051 .49375 m
.82051 .5 L
s
.98077 .49375 m
.98077 .5 L
s
.125 Mabswid
.05128 .49625 m
.05128 .5 L
s
.08333 .49625 m
.08333 .5 L
s
.11538 .49625 m
.11538 .5 L
s
.14744 .49625 m
.14744 .5 L
s
.21154 .49625 m
.21154 .5 L
s
.24359 .49625 m
.24359 .5 L
s
.27564 .49625 m
.27564 .5 L
s
.30769 .49625 m
.30769 .5 L
s
.37179 .49625 m
.37179 .5 L
s
.40385 .49625 m
.40385 .5 L
s
.4359 .49625 m
.4359 .5 L
s
.46795 .49625 m
.46795 .5 L
s
.53205 .49625 m
.53205 .5 L
s
.5641 .49625 m
.5641 .5 L
s
.59615 .49625 m
.59615 .5 L
s
.62821 .49625 m
.62821 .5 L
s
.69231 .49625 m
.69231 .5 L
s
.72436 .49625 m
.72436 .5 L
s
.75641 .49625 m
.75641 .5 L
s
.78846 .49625 m
.78846 .5 L
s
.85256 .49625 m
.85256 .5 L
s
.88462 .49625 m
.88462 .5 L
s
.91667 .49625 m
.91667 .5 L
s
.94872 .49625 m
.94872 .5 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
.99375 .00962 m
1 .00962 L
s
.99375 .08974 m
1 .08974 L
s
.99375 .16987 m
1 .16987 L
s
.99375 .25 m
1 .25 L
s
.99375 .33013 m
1 .33013 L
s
.99375 .41026 m
1 .41026 L
s
.99375 .49038 m
1 .49038 L
s
.125 Mabswid
.99625 .02564 m
1 .02564 L
s
.99625 .04167 m
1 .04167 L
s
.99625 .05769 m
1 .05769 L
s
.99625 .07372 m
1 .07372 L
s
.99625 .10577 m
1 .10577 L
s
.99625 .12179 m
1 .12179 L
s
.99625 .13782 m
1 .13782 L
s
.99625 .15385 m
1 .15385 L
s
.99625 .1859 m
1 .1859 L
s
.99625 .20192 m
1 .20192 L
s
.99625 .21795 m
1 .21795 L
s
.99625 .23397 m
1 .23397 L
s
.99625 .26603 m
1 .26603 L
s
.99625 .28205 m
1 .28205 L
s
.99625 .29808 m
1 .29808 L
s
.99625 .3141 m
1 .3141 L
s
.99625 .34615 m
1 .34615 L
s
.99625 .36218 m
1 .36218 L
s
.99625 .37821 m
1 .37821 L
s
.99625 .39423 m
1 .39423 L
s
.99625 .42628 m
1 .42628 L
s
.99625 .44231 m
1 .44231 L
s
.99625 .45833 m
1 .45833 L
s
.99625 .47436 m
1 .47436 L
s
.25 Mabswid
1 0 m
1 .5 L
s
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.01923 .00962 translate
.96154 .48076 scale
1500 string
500 500 8 [500 0 0 500 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FFA800FF9900FF9900FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFB800FFA800FFA800FFB800FFB800FFA800FFA800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFD700
FFE600DCFF0023FF00BDFF0033FF0070FF0051FF008FFF00BDFF00CCFF00DCFF00DCFF00
BDFF0005FF0005FF0051FF00BDFF00CCFF00CCFF00CCFF00CCFF00CCFF00BDFF00BDFF00
AEFF009EFF0000FF5700FF0A00FF1933FF009EFF00AEFF00BDFF00BDFF00CCFF00CCFF00
CCFF00BDFF00CCFF00CCFF00BDFF00BDFF00AEFF009EFF008FFF0080FF0014FF0042FF00
00FF8500FF0A00FFFF00FF9423FF0000FF9414FF0042FF0033FF0023FF0005FF0000FF19
00FF7500FFD1FF006B00F0FF00FF7500FF3805FF0033FF0042FF0061FF0070FF0070FF00
70FF0051FF0000FF1900FF1961FF008FFF00AEFF00BDFF00CCFF00CCFF00DCFF00DCFF00
DCFF00EBFF00EBFF00EBFF00EBFF00EBFF00EBFF00EBFF00EBFF00EBFF00DCFF00DCFF00
CCFF00BDFF009EFF0070FF0000FF0A80FF0000FF0A42FF0023FF0080FF00BDFF00EBFF00
FAFF00FFF500FFE600FFE600FFD700FFD700FFC700FFC700FFC700FFC700FFC700FFC700
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFA800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FFA800FF9900FF9900FF9900FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFA800FFA800FFA800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFD700FFD700
FFE600FFF5009EFF00DCFF009EFF00BDFF00AEFF0042FF00CCFF00DCFF00EBFF00DCFF00
BDFF0051FF009EFF0000FFF0CCFF00DCFF00DCFF00DCFF00CCFF00CCFF00CCFF00BDFF00
AEFF009EFF0051FF0000FF7523FF0070FF009EFF00AEFF00BDFF00BDFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00BDFF00BDFF00AEFF009EFF0070FF0070FF00CC00FF00FF0A
00FF9400FFA300FF5723FF0042FF0000FF9442FF0042FF0042FF0033FF0014FF0000FF28
00FF57FF001EAE00FF00A3FF00FFC200FFA300FF0A23FF0042FF0061FF0070FF0070FF00
70FF0061FF0000FF0A00FFA351FF008FFF00AEFF00BDFF00CCFF00DCFF00DCFF00DCFF00
EBFF00EBFF00EBFF00EBFF00EBFF00EBFF00EBFF00EBFF00EBFF00EBFF00EBFF00DCFF00
CCFF00BDFF008FFF0061FF0051FF009EFF009EFF009EFF0000FF2870FF0080FF00DCFF00
EBFF00FAFF00FFF500FFE600FFD700FFD700FFD700FFC700FFC700FFC700FFC700FFC700
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFA800FFA800FFA800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900FF9900
FF9900FF9900FF9900FF9900FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FFA800FF9900FF9900FF9900FF9900FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFA800FFA800FFA800FFB800
FFB800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700
FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFD700FFD700
FFE600FFF500FAFF00FAFF00EBFF00DCFF00AEFF0080FF00DCFF00EBFF00EBFF00EBFF00
CCFF0070FF00BDFF0042FF00DCFF00DCFF00DCFF00DCFF00DCFF00DCFF00CCFF00CCFF00
BDFF009EFF0061FF0000C2FF00FF0A70FF009EFF00AEFF00BDFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00BDFF00AEFF009EFF0005FF0051FF0000FF1900E1FF
00FF3800FF0A00FFC233FF0051FF0051FF0061FF0051FF0042FF0033FF0014FF0000FFE1
00FFC200FFFFFF00000500FF000AFF0028FF00FF1900FF6614FF0070FF0080FF0080FF00
80FF0061FF0000FF0A00FF5742FF0000FF0AAEFF00BDFF00CCFF00DCFF00DCFF00EBFF00
EBFF00EBFF00EBFF00EBFF00EBFF00EBFF00EBFF00EBFF00EBFF00EBFF00EBFF00DCFF00
DCFF00BDFF0061FF0014FF0061FF009EFF00BDFF00AEFF0061FF0000FF5770FF00CCFF00
CCFF00DCFF00FFF500FFE600FFD700FFD700FFC700FFC700FFD700FFC700FFC700FFC700
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFA800
FFA800FFA800FFA800FFA800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFA800FFA800FFA800FFB800
FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFD700
FFE600FFE600FFF500FFF500FAFF00EBFF00AEFF0000FF66DCFF00EBFF00FAFF00EBFF00
CCFF00AEFF00DCFF008FFF00DCFF00EBFF00EBFF00EBFF00DCFF00DCFF00CCFF00CCFF00
AEFF009EFF0070FF0033FF0000FF2870FF008FFF00AEFF00BDFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00BDFF00BDFF009EFF0000FF0A00FF380500FF00FFE1
23FF0042FF0000FF9433FF0051FF0061FF0061FF0061FF0051FF0033FF0014FF0000B3FF
FF001E00E1FF000AFF00A3FF3300FF00FFB300FFC200FFC205FF0070FF0080FF0080FF00
80FF0080FF0051FF0000FF7500FF0A33FF00AEFF00CCFF00CCFF00DCFF00DCFF00EBFF00
EBFF00EBFF00EBFF00EBFF00EBFF00EBFF00EBFF00EBFF00EBFF00EBFF00EBFF00EBFF00
DCFF0070FF0014FF0080FF0000FF0AAEFF00BDFF00BDFF0042FF0080FF0042FF00AEFF00
9EFF0023FF00FAFF00FFE600FFD700FFD700FFC700FFC700FFC700FFC700FFC700FFC700
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFA800
FFA800FFA800FFA800FFA800FFA800FFB800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FFA800FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00
FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFA800FFA800FFA800FFB800
FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFD700
FFD700FFE600FFE600FFE600FFF500FAFF0042FF009EFF00EBFF00FAFF00FAFF00FAFF00
DCFF00DCFF00EBFF00EBFF00EBFF00EBFF00EBFF00EBFF00EBFF00DCFF00CCFF00CCFF00
AEFF008FFF0070FF0000C2FF00FF5742FF0014FF00AEFF00CCFF00CCFF00CCFF00DCFF00
DCFF00DCFF00DCFF00CCFF00CCFF00BDFF00AEFF009EFF0033FF0000FFA300FFF000C2FF
61FF0051FF0000A3FF33FF0061FF0070FF0061FF0061FF0051FF0023FF0000FF0A00FF66
5100FF00FF850057FF00FFC200FF574200FF00FF7514FF0051FF0070FF0080FF008FFF00
8FFF008FFF0070FF0033FF0000C2FF51FF00AEFF00CCFF00CCFF00DCFF00DCFF00EBFF00
EBFF00EBFF00EBFF00EBFF00FAFF00FAFF00FAFF00FAFF00FAFF00EBFF00EBFF00EBFF00
DCFF00AEFF0000FF0AAEFF0014FF00AEFF00CCFF00CCFF00AEFF00AEFF0070FF0080FF00
00FF85DCFF00FAFF00FFE600FFD700FFD700FFD700FFC700FFC700FFC700FFC700FFC700
FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800
FFA800FFA800FFA800FFA800FFB800FFB800FFA800FFA800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFD700FFD700
FFD700FFD700FFE600FFE600FFF500FAFF00CCFF00CCFF00FAFF00FAFF00FAFF00FAFF00
FAFF00FAFF00FAFF00FAFF00FAFF00FAFF00FAFF00EBFF00EBFF00DCFF00DCFF00CCFF00
00FF2861FF0061FF0000FF2800FF1900F0FF80FF00BDFF00CCFF00CCFF00DCFF00DCFF00
DCFF00DCFF00DCFF00CCFF00CCFF00BDFF00BDFF009EFF0042FF0005FF0042FF0070FF00
70FF0051FF0000FF4733FF0070FF0070FF0070FF0070FF0042FF0000FF1900F0FF00FFA3
0047FF00FF570028FF0075FF00FF2800FF0A00FF2805FF0061FF0080FF008FFF008FFF00
8FFF008FFF0080FF0000FF0A23FF0014FF009EFF00CCFF00DCFF00DCFF00EBFF00EBFF00
EBFF00EBFF00EBFF00FAFF00FAFF00FAFF00FAFF00FAFF00FAFF00FAFF00EBFF00EBFF00
DCFF00BDFF0000D1FFBDFF00AEFF00BDFF00DCFF00DCFF00CCFF00BDFF009EFF0051FF00
AEFF00EBFF00FFF500FFE600FFD700FFD700FFC700FFC700FFC700FFC700FFC700FFC700
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FF9900FF9900
FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800
FFA800FFA800FFA800FFA800FFB800FFA800FFA800FFA800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFC700FFB800FFB800FFC700FFC700FFC700FFC700FFC700FFC700FFD700
FFD700FFD700FFD700FFE600FFE600FFF5008FFF00CCFF00FAFF00FFF500FFF500FFF500
FFF500FAFF00FAFF00FAFF00FAFF00FAFF00FAFF00FAFF00EBFF00DCFF00DCFF00CCFF00
9EFF0000FFD142FF000038FF42FF0014FF008FFF00BDFF00CCFF00CCFF00CCFF00DCFF00
DCFF00DCFF00DCFF00DCFF00CCFF00CCFF00BDFF008FFF0000B3FF61FF0000C2FF8FFF00
80FF0061FF0000FF7505FF0070FF0080FF0080FF0070FF0042FF0000FF6600FF0A00FF28
00FF1900FF2800FFC200FFC200FF1914FF0000FF0A00FFD161FF0080FF008FFF009EFF00
9EFF009EFF008FFF0023FF0070FF0023FF0000FF28CCFF00CCFF00DCFF00EBFF00EBFF00
EBFF00EBFF00EBFF00FAFF00FAFF00EBFF00FAFF00FAFF00FAFF00FAFF00EBFF00EBFF00
DCFF009EFF00AEFF00DCFF00CCFF00CCFF00EBFF00EBFF00DCFF00CCFF009EFF009EFF00
DCFF00FAFF00FFF500FFE600FFD700FFD700FFC700FFC700FFC700FFC700FFC700FFB800
FFB800FFB800FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFB800FFA800FFA800FFA800FFA800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFC700FFC700FFC700
FFD700FFD700FFD700FFD700FFE600FFF5009EFF00FAFF00FFF500FFF500FFF500FFF500
FFF500FFF500FFF500FFF500FAFF00FAFF00FAFF00FAFF00EBFF00EBFF00DCFF00CCFF00
AEFF0042FF0000FF1900FF7561FF0061FF0080FF00BDFF00CCFF00DCFF00DCFF00DCFF00
DCFF00DCFF00DCFF00DCFF00DCFF00CCFF00AEFF0033FF0051FF0080FF008FFF009EFF00
8FFF0061FF000094FF33FF0080FF0080FF0080FF0080FF0000FF0A33FF0023FF0000FF19
14FF0000FF2800FFB300A3FF00FF8523FF0033FF0000FF5714FF0080FF008FFF008FFF00
9EFF009EFF009EFF008FFF008FFF0070FF009EFF00CCFF00DCFF00DCFF00EBFF00EBFF00
EBFF00EBFF00FAFF00FAFF00FAFF00FAFF00FAFF00FAFF00FAFF00FAFF00FAFF00EBFF00
EBFF0023FF00CCFF00EBFF00EBFF00EBFF00EBFF00EBFF00EBFF00DCFF0042FF0080FF00
DCFF00FAFF00FFE600FFD700FFD700FFD700FFC700FFC700FFC700FFC700FFC700FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FF9900FF9900FF9900
FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFC700FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFC700FFC700FFC700
FFD700FFD700FFD700FFD700FFE600FFE600FFF500FFF500FFF500FFF500FFE600FFF500
FFF500FFF500FFF500FFF500FFF500FAFF00FAFF00FAFF00EBFF00EBFF00DCFF00CCFF00
AEFF0000FF3805FF0005FF0070FF0080FF0000FF19BDFF00CCFF00DCFF00DCFF00DCFF00
DCFF00DCFF00DCFF00DCFF00DCFF00CCFF009EFF0061FF0000FF19AEFF00AEFF00AEFF00
9EFF0061FF0000FF9451FF0080FF008FFF008FFF0080FF0070FF0061FF0000FF4714FF00
23FF00FF00000028FF00FFB300FF6633FF0042FF0051FF0051FF008FFF009EFF009EFF00
9EFF00AEFF00AEFF00AEFF00AEFF0080FF009EFF00CCFF00DCFF00EBFF00EBFF00EBFF00
EBFF00EBFF00FAFF00FAFF00FAFF00FAFF00FAFF00FAFF00FAFF00FAFF00FAFF00FAFF00
EBFF00DCFF00EBFF00EBFF00EBFF00FAFF00FAFF00FAFF00EBFF00DCFF00BDFF0061FF00
DCFF00FAFF00FFE600FFD700FFD700FFD700FFC700FFC700FFC700FFC700FFC700FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FFA800FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF8A00FF8A00FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFD700FFD700FFD700FFD700FFE600FFE600FFE600FFE600FFE600FFE600FFF500
FFE600FFF500FFF500FFF500FFF500FFF500FAFF00FAFF00FAFF00EBFF00DCFF00CCFF00
AEFF0080FF000094FF14FF0070FF009EFF00AEFF00CCFF00CCFF00DCFF00DCFF00DCFF00
DCFF00DCFF00DCFF00DCFF00DCFF00DCFF00CCFF00BDFF008FFF00BDFF00BDFF00AEFF00
9EFF0000FF2800FF7500FFD18FFF008FFF008FFF008FFF0080FF0070FF0014FF0033FF00
33FF0005FF0000FF4700FFE100FF1933FF0051FF0061FF0070FF008FFF009EFF009EFF00
AEFF00AEFF00AEFF00AEFF00BDFF00AEFF00AEFF00CCFF00DCFF00EBFF00EBFF00EBFF00
EBFF00FAFF00FAFF00FAFF00FAFF00FAFF00FAFF00FAFF00FAFF00FAFF00FAFF00FAFF00
FAFF00EBFF00FAFF00FAFF00FAFF00FAFF00FAFF00FAFF00FAFF00EBFF00BDFF0014FF00
61FF00FFF500FFE600FFE600FFD700FFD700FFC700FFC700FFC700FFC700FFC700FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FFA800
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFB800FFA800FFA800FFA800FFA800FFA800FFB800FFA800FFA800
FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFC700FFC700FFD700
FFC700FFD700FFD700FFD700FFD700FFD700FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFF500FFF500FFF500FFF500FFF500FAFF00FAFF00EBFF00DCFF00CCFF00
AEFF008FFF0042FF0000F0FF00FF199EFF00BDFF00CCFF00DCFF00DCFF00DCFF00DCFF00
DCFF00DCFF00DCFF00DCFF00DCFF00DCFF00CCFF00CCFF00BDFF00BDFF00BDFF00BDFF00
AEFF0061FF0000FFC261FF008FFF009EFF009EFF008FFF008FFF0080FF0061FF0051FF00
42FF0023FF0000FF2800FFB305FF0042FF0051FF0070FF0080FF008FFF009EFF009EFF00
AEFF00AEFF00BDFF00BDFF00BDFF00BDFF00CCFF00DCFF00DCFF00EBFF00EBFF00EBFF00
FAFF00FAFF00FAFF00FAFF00FAFF00FAFF00FAFF00FAFF00FAFF00FAFF00FAFF00FAFF00
FAFF00FAFF00FAFF00FAFF00FAFF00FAFF00FAFF00FAFF00FAFF00EBFF0000FF758FFF00
8FFF00FAFF00FFE600FFD700FFD700FFC700FFC700FFC700FFC700FFC700FFC700FFC700
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFA800FFA800
FFA800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FFA800
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FFA800FFA800FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFA800FFA800
FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFC700FFB800FFB800FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFD700FFD700FFD700FFD700FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFF500FFF500FFF500FFF500FAFF00FAFF00EBFF00CCFF00BDFF00
AEFF0080FF0051FF0000FF2800FF28AEFF00BDFF00CCFF00DCFF00DCFF00DCFF00EBFF00
EBFF00DCFF00EBFF00DCFF00DCFF00DCFF00DCFF00CCFF00CCFF00CCFF00CCFF00BDFF00
AEFF0070FF0051FF0080FF009EFF009EFF009EFF009EFF008FFF0080FF0070FF0061FF00
51FF0023FF0000FF940066FF05FF0023FF0061FF0070FF0080FF008FFF009EFF00AEFF00
AEFF00BDFF00BDFF00BDFF00CCFF00CCFF00CCFF00DCFF00DCFF00EBFF00EBFF00EBFF00
FAFF00FAFF00FAFF00FAFF00FAFF00FAFF00FFF500FFF500FAFF00FFF500FFF500FFF500
FAFF00FFF500FFF500FAFF00FFF500FFF500FFF500FFF500FFF500FAFF00DCFF00BDFF00
61FF00FAFF00FFE600FFD700FFD700FFD700FFC700FFC700FFC700FFC700FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FFA800FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFA800FFA800FFA800
FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFF500FFF500FFF500FFF500FAFF00EBFF00BDFF00AEFF00
AEFF0070FF0023FF0000FF1970FF00AEFF00BDFF00DCFF00DCFF00EBFF00EBFF00EBFF00
EBFF00EBFF00EBFF00EBFF00EBFF00EBFF00DCFF00DCFF00CCFF00CCFF00CCFF00CCFF00
AEFF0000FF5780FF009EFF009EFF00AEFF009EFF009EFF008FFF0080FF0080FF0061FF00
42FF0014FF0000FF280066FF00FF1900FF0A51FF0070FF0080FF008FFF009EFF00AEFF00
AEFF00BDFF00BDFF00CCFF00CCFF00CCFF00DCFF00DCFF00EBFF00EBFF00EBFF00FAFF00
FAFF00FAFF00FAFF00FAFF00FAFF00FAFF00FFF500FFF500FFF500FFF500FFF500FFF500
FAFF00FFF500FFF500FFF500FFF500FFF500FFF500FFF500FFF500FAFF00FAFF00EBFF00
80FF0061FF00FFE600FFD700FFD700FFC700FFC700FFC700FFC700FFC700FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00
FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FFA800FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFA800FFA800FFA800
FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFE600
FFE600FFE600FFE600FFE600FFE600FFF500FFF500FFF500FAFF00EBFF0051FF008FFF00
9EFF0070FF0000FFE100FF7570FF009EFF00BDFF00CCFF00DCFF00EBFF00EBFF00EBFF00
EBFF00EBFF00EBFF00EBFF00EBFF00EBFF00DCFF00DCFF00DCFF00DCFF00CCFF00CCFF00
BDFF008FFF008FFF00AEFF00AEFF00AEFF00AEFF009EFF008FFF008FFF0080FF0070FF00
42FF0000C2FF00FF7500C2FF00FF9405FF0051FF0070FF0080FF008FFF009EFF00AEFF00
BDFF00BDFF00BDFF00CCFF00CCFF00CCFF00DCFF00DCFF00EBFF00EBFF00EBFF00FAFF00
FAFF00FAFF00FAFF00FAFF00FFF500FFF500FFF500FFF500FFF500FFF500FFF500FFF500
FFF500FFF500FFF500FFF500FFF500FFF500FFF500FFF500FFF500FFF500FAFF00EBFF00
00FF57FAFF00FFE600FFD700FFD700FFC700FFC700FFC700FFC700FFC700FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00
FF8A00FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FFA800FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700
FFE600FFE600FFE600FFE600FFE600FFE600FFF500FAFF00FAFF00EBFF00AEFF0023FF00
80FF0000E1FF14FF0014FF0061FF0070FF00BDFF00DCFF00EBFF00EBFF00EBFF00EBFF00
EBFF00EBFF00EBFF00EBFF00EBFF00EBFF00EBFF00DCFF00DCFF00DCFF00DCFF00CCFF00
BDFF00AEFF00AEFF00AEFF00AEFF00AEFF00AEFF009EFF009EFF008FFF0080FF0070FF00
51FF0000FF0A00FFE10500FF00FF9400FF4742FF0070FF0080FF008FFF009EFF00AEFF00
AEFF00BDFF00CCFF00CCFF00CCFF00DCFF00DCFF00EBFF00EBFF00EBFF00EBFF00FAFF00
FAFF00FAFF00FAFF00FAFF00FFF500FFF500FFF500FFF500FFF500FFF500FFF500FFF500
FFF500FFF500FFF500FFF500FFF500FFF500FFF500FFF500FFF500FFF500FFF500FAFF00
9EFF00FFF500FFE600FFD700FFD700FFC700FFC700FFC700FFC700FFC700FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700
FFD700FFE600FFE600FFE600FFE600FFF500FFF500FFF500FAFF00EBFF00CCFF0000FF85
23FF005100FF42FF0042FF0000FFA300FF0A23FF00DCFF00EBFF00EBFF00EBFF00EBFF00
EBFF00EBFF00EBFF00EBFF00EBFF00EBFF00EBFF00EBFF00DCFF00DCFF00DCFF00DCFF00
CCFF00BDFF00BDFF00BDFF00BDFF00AEFF00AEFF009EFF009EFF008FFF0080FF0070FF00
51FF000047FF00FF380066FF00FF2814FF0042FF0061FF0070FF0080FF009EFF00AEFF00
BDFF00BDFF00CCFF00CCFF00CCFF00DCFF00DCFF00EBFF00EBFF00EBFF00FAFF00FAFF00
FAFF00FAFF00FAFF00FFF500FAFF00FFF500FFF500FFF500FFF500FFF500FFF500FFF500
FFF500FFF500FFF500FFE600FFE600FFE600FFE600FFE600FFF500FFE600FFF500FFF500
23FF00FFE600FFD700FFD700FFD700FFC700FFC700FFC700FFC700FFC700FFC700FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFA800FFA800FFA800FFA800
FFA800FFB800FFB800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFD700FFD700FFD700FFD700
FFD700FFD700FFE600FFE600FFE600FFE600FFF500FFF500FAFF00EBFF00CCFF0000FFFF
00FF9400FF0A70FF0080FF0000FF288FFF0033FF00DCFF00EBFF00EBFF00EBFF00EBFF00
FAFF00FAFF00FAFF00EBFF00EBFF00EBFF00EBFF00DCFF00DCFF00DCFF00DCFF00CCFF00
CCFF00CCFF00CCFF00BDFF00BDFF00BDFF00AEFF00AEFF009EFF008FFF0080FF0061FF00
51FF0023FF0000FF2800E1FF00FF6614FF0042FF0051FF0000FF4723FF008FFF00AEFF00
BDFF00BDFF00CCFF00CCFF00DCFF00DCFF00DCFF00EBFF00EBFF00EBFF00EBFF00FAFF00
FAFF00FAFF00FAFF00FFF500FFF500FFF500FFF500FFF500FFF500FFF500FFF500FFF500
FFF500FFF500FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF500
FAFF00FFE600FFD700FFD700FFC700FFC700FFC700FFC700FFC700FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800
FF9900FF9900FF9900FF9900FF9900FFA800FFA800FF9900FF9900FF9900FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFB800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFD700FFD700FFD700
FFD700FFD700FFE600FFE600FFE600FFE600FFF500FFF500FAFF00FAFF00CCFF009EFF00
42FF0023FF008FFF008FFF0000FF85BDFF00CCFF00EBFF00EBFF00EBFF00EBFF00EBFF00
FAFF00FAFF00FAFF00FAFF00EBFF00EBFF00EBFF00EBFF00EBFF00EBFF00DCFF00DCFF00
CCFF00CCFF00CCFF00CCFF00BDFF00BDFF00AEFF00AEFF009EFF0080FF0070FF0061FF00
51FF0023FF0000FF1900D1FF00FF4705FF0033FF0042FF0000FF4751FF008FFF00AEFF00
BDFF00BDFF00CCFF00CCFF00DCFF00DCFF00DCFF00EBFF00EBFF00EBFF00FAFF00FAFF00
FAFF00FAFF00FAFF00FFF500FFF500FFF500FFF500FFF500FFF500FFF500FFF500FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF500
FFE600FFE600FFD700FFD700FFC700FFC700FFC700FFC700FFC700FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FFA800FF9900FF9900FF9900FF9900FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFB800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFD700FFC700FFD700FFD700FFD700FFD700FFD700
FFD700FFD700FFD700FFE600FFE600FFE600FFF500FFF500FAFF00FAFF00DCFF00BDFF00
05FF0070FF009EFF00AEFF0000FF38CCFF00DCFF00EBFF00EBFF00FAFF00FAFF00FAFF00
FAFF00FAFF00FAFF00FAFF00EBFF00EBFF00EBFF00EBFF00EBFF00EBFF00DCFF00DCFF00
DCFF00DCFF00CCFF00CCFF00BDFF00BDFF00AEFF00AEFF008FFF0070FF0051FF0051FF00
42FF0005FF0000FF1900FFA300FF5700FF4705FF0014FF0000FF1970FF009EFF00AEFF00
BDFF00BDFF00CCFF00CCFF00DCFF00DCFF00DCFF00EBFF00EBFF00EBFF00FAFF00FAFF00
FAFF00FAFF00FFF500FFF500FFF500FFF500FFF500FFF500FFF500FFF500FFF500FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFD700FFD700FFD700FFD700FFC700FFC700FFC700FFC700FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FFA800FF9900FF9900FF9900FF9900FF9900FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFB800FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFD700FFD700
FFD700FFD700FFD700FFE600FFE600FFE600FFE600FFF500FAFF00FAFF00DCFF00AEFF00
00FF2870FF00BDFF00BDFF0000D1FFCCFF00EBFF00EBFF00FAFF00FAFF00FAFF00FAFF00
FAFF00FAFF00FAFF00FAFF00FAFF00FAFF00EBFF00EBFF00EBFF00EBFF00EBFF00DCFF00
DCFF00DCFF00CCFF00CCFF00CCFF00BDFF00BDFF00AEFF0080FF0042FF0033FF0023FF00
33FF0000FF0A00FF3800FFC200E1FF00D1FF00FF1900FF2814FF0070FF009EFF00AEFF00
BDFF00BDFF00CCFF00CCFF00DCFF00DCFF00DCFF00EBFF00EBFF00EBFF00FAFF00FAFF00
FAFF00FAFF00FFF500FFF500FFF500FFF500FFF500FFF500FFF500FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFD700FFD700FFD700FFC700FFC700FFC700FFC700FFC700FFC700FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFB800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFB800FFB800FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFD700
FFD700FFD700FFD700FFD700FFE600FFE600FFF500FFF500FAFF00FAFF00DCFF00AEFF00
00FF0A42FF00BDFF00CCFF00AEFF00DCFF00EBFF00FAFF00FAFF00FAFF00FAFF00FAFF00
FAFF00FAFF00FAFF00FAFF00FAFF00FAFF00FAFF00EBFF00EBFF00EBFF00EBFF00DCFF00
DCFF00DCFF00DCFF00CCFF00CCFF00BDFF00BDFF00AEFF0051FF000066FF00FFB300FF0A
23FF0000FF3800FF757000FF00B3FFFF007A00FFE10094FF33FF0070FF008FFF009EFF00
AEFF00BDFF00CCFF00CCFF00CCFF00DCFF00EBFF00EBFF00EBFF00FAFF00FAFF00FAFF00
FAFF00FAFF00FFF500FFF500FFF500FFF500FFF500FFF500FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD700FFD700FFD700
FFD700FFD700FFD700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FF9900FF9900FFA800FFA800FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFD700FFC700FFC700FFC700FFD700FFD700
FFD700FFD700FFD700FFD700FFE600FFE600FFE600FFF500FAFF00EBFF00DCFF00AEFF00
33FF0061FF00CCFF00DCFF00CCFF00EBFF00FAFF00FAFF00FAFF00FAFF00FAFF00FAFF00
FAFF00FAFF00FAFF00FAFF00FAFF00FAFF00FAFF00FAFF00EBFF00EBFF00EBFF00DCFF00
DCFF00DCFF00CCFF00CCFF00CCFF00CCFF00AEFF00AEFF008FFF0061FF0033FF0000FF38
00FF0A00FFF000E1FF0500FF0085FF00FFF000FF1900FF0A00FF0A42FF0080FF009EFF00
BDFF00BDFF00CCFF00CCFF00DCFF00DCFF00DCFF00EBFF00EBFF00EBFF00FAFF00FAFF00
FAFF00FFF500FFF500FFF500FFF500FFF500FFF500FFF500FFE600FFF500FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFD700FFE600FFD700FFD700FFD700FFD700
FFD700FFD700FFD700FFC700FFC700FFC700FFC700FFC700FFB800FFB800FFC700FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FF9900FF9900FF9900FF9900FF9900FFA800FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FFA800FF9900FF9900FF9900FF9900FF9900FF9900FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFD700FFD700
FFD700FFD700FFD700FFE600FFD700FFE600FFE600FFF500FAFF00EBFF00CCFF00AEFF00
42FF00BDFF00DCFF00EBFF00EBFF00EBFF00FAFF00FAFF00FAFF00FAFF00FAFF00FAFF00
FAFF00FAFF00FAFF00FAFF00FAFF00FAFF00FAFF00FAFF00EBFF00EBFF00EBFF00EBFF00
DCFF00DCFF00DCFF00CCFF00CCFF00CCFF00BDFF00AEFF009EFF0080FF0061FF0023FF00
00FF665100FF00FFD10500FF00F0FF00FF4700FF4723FF002300FF00FF5733FF009EFF00
BDFF00BDFF00CCFF00CCFF00DCFF00DCFF00DCFF00EBFF00EBFF00FAFF00FAFF00FAFF00
FAFF00FFF500FFF500FFF500FFF500FFF500FFF500FFF500FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFD700FFD700FFD700FFD700FFD700FFD700FFD700
FFD700FFD700FFC700FFC700FFC700FFC700FFC700FFC700FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900
FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800
FFA800FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700
FFB800FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFD700FFD700
FFD700FFD700FFD700FFD700FFD700FFE600FFE600FFF500FAFF00DCFF00BDFF0080FF00
80FF00CCFF00DCFF00EBFF00EBFF00FAFF00FAFF00FAFF00FAFF00FAFF00FFF500FFF500
FAFF00FAFF00FAFF00FAFF00FAFF00FAFF00FAFF00EBFF00FAFF00EBFF00EBFF00EBFF00
DCFF00DCFF00DCFF00CCFF00CCFF00CCFF00BDFF00AEFF00AEFF008FFF0070FF0023FF00
00FF0A00FF0A00FF4700FF8500FF7500FF1923FF0042FF0023FF0000FF0A51FF008FFF00
AEFF00BDFF00BDFF00CCFF00DCFF00DCFF00DCFF00EBFF00EBFF00EBFF00FAFF00FAFF00
FAFF00FFF500FFF500FFF500FFF500FFF500FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700
FFD700FFD700FFC700FFC700FFC700FFC700FFC700FFC700FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900
FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800
FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFA800FFA800FFA800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700
FFD700FFD700FFD700FFD700FFD700FFE600FFE600FFF500FAFF00BDFF0080FF0014FF00
14FF00BDFF00EBFF00EBFF00FAFF00FAFF00FAFF00FAFF00FAFF00FFF500FFF500FFF500
FFF500FFF500FAFF00FAFF00FAFF00FAFF00FAFF00FAFF00FAFF00EBFF00EBFF00EBFF00
EBFF00DCFF00DCFF00CCFF00CCFF00CCFF00BDFF00AEFF00AEFF009EFF0070FF0000FF28
23FF0014FF0000FF0A00FF4700FF8505FF0033FF0051FF0051FF0000FF5780FF009EFF00
AEFF00BDFF00CCFF00CCFF00CCFF00DCFF00DCFF00EBFF00EBFF00FAFF00FAFF00FAFF00
FAFF00FFF500FFF500FFF500FFF500FFF500FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFD700FFE600FFD700FFD700FFD700FFD700FFD700FFD700FFD700
FFD700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FF9900
FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFB800FFA800FFA800FFA800FFA800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFB800
FFB800FFB800FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700
FFD700FFD700FFD700FFD700FFD700FFE600FFE600FFF500EBFF0080FF0080FF00BDFF00
05FF00AEFF00EBFF00FAFF00FAFF00FAFF00FFF500FFF500FFF500FFF500FFF500FFF500
FFF500FFF500FFF500FAFF00FAFF00FAFF00FAFF00FAFF00EBFF00EBFF00EBFF00EBFF00
EBFF00DCFF00DCFF00DCFF00CCFF00CCFF00BDFF00AEFF00AEFF008FFF0061FF0000FF57
42FF0042FF0014FF0000FF6600F0FF05FF0033FF0061FF0061FF0070FF008FFF009EFF00
AEFF00BDFF00CCFF00CCFF00CCFF00DCFF00DCFF00EBFF00EBFF00EBFF00FAFF00FAFF00
FAFF00FFF500FFF500FFF500FFF500FFF500FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700
FFD700FFC700FFD700FFC700FFC700FFC700FFC700FFC700FFC700FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FF9900
FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFB800FFA800FFA800FFA800FFA800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFC700FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFD700FFD700FFD700FFD700FFD700FFE600FFF500AEFF0000FF479EFF00DCFF00
61FF00BDFF00EBFF00FAFF00FAFF00FFF500FFF500FFF500FFF500FFF500FFF500FFF500
FFF500FFF500FFF500FAFF00FAFF00FAFF00FAFF00FAFF00FAFF00EBFF00EBFF00EBFF00
EBFF00DCFF00DCFF00DCFF00CCFF00CCFF00BDFF00AEFF00AEFF009EFF0000FFC200FFA3
51FF0042FF0014FF0000FF2800FFD100FF0A23FF0061FF0070FF0080FF008FFF009EFF00
AEFF00BDFF00BDFF00CCFF00CCFF00DCFF00DCFF00DCFF00EBFF00EBFF00FAFF00FAFF00
FAFF00FFF500FFF500FFF500FFF500FFE600FFF500FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFC700
FFD700FFC700FFC700FFC700FFC700FFC700FFC700FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFD700
FFC700FFD700FFD700FFD700FFD700FFE600FFE600FFE600FAFF0000FF47EBFF00EBFF00
DCFF00AEFF00FAFF00FAFF00FFF500FFF500FFF500FFF500FFF500FFF500FFF500FFF500
FFF500FFF500FFF500FFF500FFF500FAFF00FAFF00FAFF00FAFF00EBFF00EBFF00EBFF00
DCFF00DCFF00DCFF00DCFF00CCFF00CCFF00BDFF00BDFF00AEFF009EFF0070FF0070FF00
61FF0051FF0000FF2800FF4700E1FF00FF5733FF0061FF0070FF0080FF009EFF009EFF00
AEFF00BDFF00BDFF00CCFF00CCFF00CCFF00DCFF00DCFF00EBFF00EBFF00FAFF00FAFF00
FFF500FFF500FFF500FFF500FFF500FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00
FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FF9900FF9900
FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFC700FFB800FFB800FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFD700FFD700FFD700FFD700FFD700FFE600FFE600FFF500FAFF00FAFF00FAFF00
EBFF00DCFF00FAFF00FFF500FFF500FFF500FFF500FFF500FFF500FFF500FFF500FFF500
FFF500FFF500FFF500FFF500FFF500FAFF00FAFF00FAFF00FAFF00FAFF00EBFF00EBFF00
EBFF00DCFF00DCFF00DCFF00CCFF00CCFF00BDFF00BDFF00AEFF009EFF008FFF0080FF00
70FF0051FF0000FF19BD00FF0094FF00FF3805FF0061FF0070FF008FFF009EFF009EFF00
AEFF00AEFF00BDFF00BDFF00CCFF00CCFF00CCFF00DCFF00EBFF00EBFF00EBFF00FAFF00
FAFF00FFF500FFF500FFF500FFF500FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FF9900FF9900
FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFD700FFD700FFD700FFD700FFD700FFD700FFE600FFE600FFF500FFF500FFF500
FAFF00FAFF00FFF500FFF500FFF500FFF500FFF500FFF500FFF500FFF500FFF500FFF500
FFF500FFF500FFF500FFF500FFF500FFF500FAFF00FAFF00FAFF00FAFF00EBFF00EBFF00
DCFF00DCFF00DCFF00DCFF00CCFF00CCFF00BDFF00BDFF00AEFF009EFF008FFF0080FF00
70FF0061FF0023FF0000FF19FF000000FF0A23FF0061FF0070FF0080FF008FFF009EFF00
AEFF00AEFF00BDFF00BDFF00BDFF00BDFF00CCFF00DCFF00DCFF00EBFF00FAFF00FAFF00
FFF500FFF500FFF500FFF500FFF500FFF500FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFC700FFC700FFD700
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFA800FFA800FFB800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFD700FFD700FFD700FFE600FFE600FFE600FFE600FFE600FFF500
FFF500FFF500FFF500FFF500FFF500FFF500FFF500FFF500FFF500FFF500FFF500FFF500
FFF500FFF500FFF500FFF500FFF500FFF500FAFF00FAFF00FAFF00FAFF00EBFF00EBFF00
EBFF00DCFF00DCFF00CCFF00CCFF00CCFF00BDFF00BDFF00AEFF00AEFF009EFF008FFF00
70FF0061FF0042FF0005FF0000C2FF05FF0042FF0061FF0070FF0080FF008FFF009EFF00
AEFF00AEFF00AEFF00AEFF00AEFF00AEFF00AEFF00BDFF00CCFF00EBFF00FAFF00FAFF00
FAFF00FFF500FFF500FFF500FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD700
FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FFA800FFA800FF9900FF9900FF9900FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFD700FFD700FFD700FFD700FFD700FFE600FFE600FFE600FFE600
FFF500FFF500FFE600FFE600FFF500FFE600FFE600FFE600FFF500FFE600FFF500FFF500
FFF500FFF500FFF500FFF500FFF500FAFF00FAFF00FAFF00FAFF00FAFF00EBFF00EBFF00
EBFF00DCFF00CCFF00CCFF00CCFF00BDFF00BDFF00BDFF00AEFF00AEFF008FFF008FFF00
70FF0061FF0042FF0014FF0000FF9400FF0A33FF0051FF0061FF0080FF008FFF009EFF00
9EFF009EFF00AEFF00AEFF009EFF0080FF009EFF00BDFF0033FF00DCFF00FAFF00FAFF00
FFF500FFF500FFF500FFF500FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD700
FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FFA800FF9900FF9900FF9900FF9900FF9900FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFA800
FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFD700FFC700FFD700FFD700FFD700FFD700FFD700FFE600FFE600FFE600
FFF500FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF500
FFF500FFF500FFF500FFF500FFF500FFF500FFF500FAFF00FAFF00EBFF00EBFF00EBFF00
EBFF00DCFF00DCFF00CCFF00CCFF00BDFF00BDFF00AEFF00AEFF009EFF009EFF008FFF00
70FF0061FF0042FF0000FFC200FF9400FFF033FF0042FF0000C2FF70FF0080FF008FFF00
9EFF009EFF009EFF009EFF0080FF0014FF0080FF008FFF0080FF00DCFF00FAFF00FAFF00
FFF500FFF500FFF500FFF500FFF500FFE600FFE600FFE600FFE600FFE600FFE600FFD700
FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFC700FFD700FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFB800FFB800FFB800FFC700FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FFA800FF9900FF9900FF9900FF9900FF9900FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFA800FFA800
FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFC700FFB800FFB800FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFD700FFD700FFD700FFD700FFD700FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFF500FFF500FFF500FFF500FFF500FFF500FAFF00FAFF00FAFF00FAFF00EBFF00EBFF00
DCFF00DCFF00CCFF00CCFF00CCFF00BDFF00BDFF00AEFF00AEFF009EFF009EFF0080FF00
61FF0042FF0042FF0000FF0A0500FF00FF5714FF0023FF0000FF3861FF0080FF008FFF00
9EFF009EFF008FFF0080FF0080FF0023FF0000FFA300FF478FFF00DCFF00EBFF00FAFF00
FFF500FFF500FFF500FFF500FFE600FFF500FFE600FFE600FFE600FFE600FFE600FFE600
FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FFA800FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFD700FFD700FFD700FFD700FFD700FFD700FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF500
FFE600FFF500FFF500FFF500FFF500FFF500FFF500FAFF00FAFF00EBFF00EBFF00EBFF00
DCFF00DCFF00CCFF00CCFF00BDFF00BDFF00BDFF00AEFF00AEFF009EFF009EFF0080FF00
00FF6614FF0033FF0005FF0000FF7500FF3805FF0005FF0014FF0042FF0051FF0080FF00
8FFF008FFF0080FF0014FF0051FF0000FF3800FF0A80FF0005FF0005FF00EBFF00FAFF00
FFF500FFF500FFF500FFF500FFE600FFE600FFE600FFE600FFE600FFE600FFD700FFD700
FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FF9900FF9900FF9900FF9900FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FFA800FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFA800FFA800FFA800
FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFC700FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFD700FFD700FFD700FFD700FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFF500FFF500FFF500FFF500FFF500FFF500FAFF00FAFF00FAFF00EBFF00EBFF00
DCFF00DCFF00CCFF00BDFF00BDFF00BDFF00AEFF00AEFF00AEFF009EFF008FFF0080FF00
42FF0000FF8514FF0000FF0A00FF6600FF4700FF1900FF1900FF0A00FF7561FF0080FF00
8FFF0080FF0033FF0014FF0005FF0000FF5770FF00AEFF00AEFF0033FF00EBFF00FAFF00
FFF500FFF500FFF500FFF500FFE600FFE600FFE600FFE600FFE600FFE600FFD700FFD700
FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900
FF9900FF9900FF9900FF9900FF9900FFA800FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFD700FFC700FFC700FFD700FFD700FFD700FFD700FFD700FFD700
FFE600FFD700FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFF500FFF500FFF500FFF500FFF500FFF500FAFF00FAFF00FAFF00EBFF00EBFF00
DCFF00CCFF00BDFF00BDFF00BDFF00AEFF00AEFF00AEFF009EFF009EFF008FFF0080FF00
51FF0000FF3800FF0A00FF3800FF7500FF8500FFE100FFA300FFFF14FF0061FF0080FF00
80FF0080FF0051FF0000A3FF05FF0042FF00FF000FBDFF00CCFF00DCFF00EBFF00FAFF00
FAFF00FFF500FFF500FFF500FFF500FFE600FFE600FFE600FFE600FFE600FFD700FFD700
FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF8A00FF8A00
FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFA800FFA800FFA800FFA800
FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFD700FFD700FFD700FFD700FFD700
FFD700FFD700FFD700FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFF500FFF500FFF500FFF500FAFF00FAFF00FAFF00EBFF00DCFF00
DCFF00BDFF009EFF00AEFF00AEFF00AEFF009EFF009EFF009EFF008FFF008FFF0080FF00
42FF0000FF0A00FF288000FF00F0FF00FFFF00FFA300FFE100FF0A33FF0061FF0070FF00
70FF0061FF0033FF001400FF61FF0070FF009EFF00CCFF00DCFF00EBFF00EBFF00FAFF00
FFF500FFF500FFF500FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD700FFD700
FFD700FFD700FFD700FFD700FFD700FFD700FFC700FFC700FFD700FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF8A00FF8A00FF8A00
FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFD700FFC700FFD700FFD700FFD700FFD700FFD700
FFD700FFE600FFD700FFD700FFD700FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFF500FFF500FFF500FFF500FAFF00FAFF00FAFF00EBFF00DCFF00
CCFF00BDFF0000FF579EFF00AEFF009EFF0000FFA38FFF008FFF008FFF0080FF0070FF00
0085FF00FFC2FF000000FF940028FF5100FF1400FF00FF8505FF0033FF0051FF0061FF00
61FF0000FF3800FFF005FF0070FF008FFF009EFF00CCFF00DCFF00EBFF00FAFF00FAFF00
FFF500FFF500FFF500FFE600FFE600FFE600FFE600FFE600FFE600FFD700FFE600FFD700
FFD700FFD700FFD700FFD700FFD700FFD700FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00
FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFC700FFB800FFB800FFB800FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFD700FFD700FFD700
FFD700FFD700FFD700FFD700FFD700FFD700FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFF500FFF500FFF500FAFF00FAFF00EBFF00EBFF00DCFF00
CCFF00AEFF0033FF008FFF009EFF0080FF0042FF008FFF008FFF008FFF0080FF0070FF00
33FF0005FF0000FF4700B3FFFF0000FF0000FF000000FFD100FF7514FF0033FF0005FF00
51FF0023FF0005FF0051FF008FFF00AEFF00BDFF00DCFF00DCFF00EBFF00FAFF00FAFF00
FFF500FFF500FFF500FFF500FFE600FFE600FFE600FFE600FFE600FFD700FFD700FFD700
FFD700FFD700FFD700FFD700FFD700FFD700FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFD700FFD700FFD700
FFD700FFD700FFD700FFD700FFD700FFD700FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFF500FFF500FFF500FAFF00FAFF00EBFF00DCFF00DCFF00
BDFF0014FF0023FF0080FF0080FF0033FF0042FF0080FF0080FF0080FF0080FF0061FF00
42FF0014FF000085FF0075FFFF0000FF0000FF00000066FF00FF3800FF8505FF0000FF19
33FF0000FFFF00FF2880FF009EFF00AEFF00CCFF00DCFF00EBFF00EBFF00FAFF00FAFF00
FFF500FFF500FFF500FFE600FFE600FFE600FFE600FFE600FFE600FFD700FFD700FFD700
FFD700FFD700FFD700FFD700FFD700FFD700FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFB800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800
FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFB800FFB800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFD700
FFD700FFD700FFD700FFD700FFD700FFD700FFE600FFD700FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFF500FFF500FFF500FFF500FAFF00EBFF00DCFF00CCFF00
BDFF0061FF0042FF0070FF0061FF0005FF0042FF0061FF0051FF0070FF0070FF0051FF00
42FF0005FF008000FFFF0000FF0000FF0000FF000000E1FF0038FF0075FF00FF940047FF
00FF2814FF0061FF008FFF009EFF00BDFF00CCFF00DCFF00EBFF00EBFF00FAFF00FAFF00
FFF500FFF500FFF500FFE600FFE600FFE600FFE600FFE600FFE600FFD700FFD700FFD700
FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FF9900
FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFB800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFD700
FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFF500FFF500FFF500FAFF00DCFF00CCFF00BDFF00
9EFF0061FF0000FF1933FF0023FF00000AFF23FF0042FF0000FF3861FF0061FF0023FF00
23FF0000FF3800FF940047FFFF0000FF0000FF00000094FF00FF4700FFE100FF1905FF00
14FF0033FF0070FF008FFF00AEFF00BDFF00CCFF00DCFF00EBFF00EBFF00FAFF00FAFF00
FFF500FFF500FFF500FFF500FFE600FFE600FFE600FFE600FFE600FFE600FFD700FFD700
FFD700FFD700FFD700FFD700FFD700FFC700FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FF9900FF9900
FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFB800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFB800FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFD700FFD700
FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFF500FFF500FAFF00FAFF008FFF0000FF479EFF00
42FF001400FF00FF8500FF4700FF1914FF0000F0FF00FFF014FF0042FF0051FF0000FF0A
05FF0000B3FF00FFA30057FFDC00FFFF00000019FF0085FF00FF1905FF0014FF0023FF00
42FF0000FF2861FF008FFF009EFF00BDFF00CCFF00DCFF00EBFF00EBFF00FAFF00FAFF00
FFF500FFF500FFF500FFE600FFE600FFE600FFE600FFE600FFD700FFD700FFE600FFD700
FFD700FFD700FFD700FFD700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFB800FFB800FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFD700FFC700FFC700FFD700
FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFE600FFD700FFE600FFE600
FFE600FFE600FFE600FFE600FFF500FFF500FFF500FFF500FAFF00CCFF0061FF0042FF00
00FF3861FF0051FF0000FF0A23FF0042FF0023FF0023FF0000FF6600FF0A33FF0000FF47
0057FF00FFA300FF2800FFD10075FFFF00000057FF00FF7505FF0033FF0042FF0061FF00
51FF0000FF3800FF2880FF009EFF00AEFF00BDFF00DCFF00EBFF00EBFF00FAFF00FAFF00
FFF500FFF500FFF500FFE600FFE600FFE600FFE600FFE600FFD700FFD700FFD700FFD700
FFD700FFD700FFD700FFD700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00
FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFD700
FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFF500FFF500FFF500FAFF00EBFF00BDFF008FFF00
8FFF008FFF0051FF0051FF008FFF0000FF2851FF0033FF0033FF0000FF2800FF2800FF66
00FF0A00FF1900FF0A0066FF00F0FFFF000000B3FF00FF7505FF0042FF0061FF0070FF00
61FF0023FF0000FF8561FF0070FF00AEFF00BDFF00CCFF00DCFF00EBFF00FAFF00FAFF00
FFF500FFF500FFF500FFF500FFE600FFE600FFE600FFE600FFD700FFD700FFD700FFD700
FFD700FFD700FFD700FFD700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFB800FFB800FFB800FFC700FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFD700
FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFF500FFF500FFF500FAFF00EBFF00DCFF0070FF00
AEFF00AEFF0000FF6600FFD19EFF008FFF0080FF0080FF0061FF0033FF0005FF0023FF00
00FF1933FF0014FF0000FF382300FFDC00FF00F0FF00FFC200FF5705FF0061FF0080FF00
70FF0000FF2800FF5723FF0042FF008FFF00AEFF00BDFF00DCFF00EBFF00FAFF00FAFF00
FFF500FFF500FFF500FFE600FFE600FFE600FFE600FFE600FFD700FFD700FFD700FFD700
FFD700FFD700FFD700FFD700FFD700FFC700FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFD700FFC700
FFC700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFE600FFD700
FFE600FFE600FFE600FFE600FFE600FFE600FFF500FFF500FAFF00FAFF00EBFF0070FF00
CCFF00BDFF009EFF0000FF28AEFF00AEFF009EFF008FFF0070FF0023FF0033FF0051FF00
51FF0042FF0014FF0000FF4700FF6600F0FF00E1FF00FF2800FF0A14FF0070FF0080FF00
80FF0070FF0023FF0000FF2814FF0080FF008FFF00AEFF00CCFF00EBFF00FAFF00FAFF00
FFF500FFF500FFF500FFE600FFE600FFE600FFE600FFE600FFE600FFD700FFD700FFD700
FFD700FFD700FFD700FFD700FFD700FFC700FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700
FFE600FFE600FFE600FFE600FFE600FFE600FFF500FFF500FFF500FAFF00EBFF00CCFF00
DCFF00DCFF00CCFF00CCFF00BDFF00BDFF00AEFF009EFF0070FF0023FF0042FF0061FF00
61FF0051FF0000FFC200FF9400FF2800FF6600FF5705FF0000FF3861FF0080FF008FFF00
80FF0080FF0061FF0000FF6600F0FF61FF0061FF0042FF00BDFF00DCFF00EBFF00FAFF00
FFF500FFF500FFF500FFE600FFE600FFE600FFE600FFE600FFD700FFD700FFD700FFD700
FFD700FFD700FFD700FFD700FFD700FFC700FFD700FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900
FF9900FF9900FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700
FFB800FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700
FFE600FFE600FFE600FFE600FFE600FFE600FFF500FFF500FFF500FAFF00FAFF00EBFF00
EBFF00DCFF00DCFF00CCFF00CCFF00BDFF00AEFF009EFF0070FF0000FF8542FF0070FF00
70FF0051FF0000FF0A00FF4714FF0000FF3800FF1923FF000057FF70FF008FFF008FFF00
8FFF008FFF0023FF0000FFA323FF0000FF2842FF0061FF00BDFF00CCFF00EBFF00FAFF00
FAFF00FFF500FFE600FFE600FFE600FFE600FFE600FFD700FFD700FFD700FFD700FFD700
FFD700FFD700FFD700FFD700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFA800FFA800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFB800
FFB800FFB800FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF500FFF500FAFF00FAFF00FAFF00
EBFF00EBFF00DCFF00DCFF00CCFF00CCFF00AEFF008FFF0061FF0000FF7561FF0080FF00
80FF0042FF0051FF0000D1FF23FF0000FF6600FFB333FF0014FF0070FF008FFF009EFF00
9EFF009EFF0023FF0042FF0061FF0014FF000057FF33FF008FFF008FFF00CCFF00FAFF00
FFF500FFF500FFF500FFE600FFE600FFE600FFE600FFD700FFD700FFD700FFD700FFD700
FFD700FFD700FFD700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700
FFD700FFC700FFC700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFE600
FFD700FFE600FFE600FFE600FFE600FFE600FFF500FFF500FFF500FFF500FAFF00FAFF00
FAFF00EBFF00EBFF00DCFF00DCFF00CCFF00AEFF008FFF0014FF0000FF1970FF008FFF00
8FFF0080FF0070FF0014FF0042FF0000FF7500FF1942FF0061FF0080FF008FFF009EFF00
9EFF009EFF008FFF009EFF008FFF0051FF0042FF0000FF3800FF2823FF00DCFF00FAFF00
FFF500FFF500FFF500FFE600FFE600FFE600FFE600FFE600FFD700FFD700FFD700FFD700
FFD700FFD700FFD700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF9900FF9900FF9900FF9900FF8A00FF8A00FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFB800FFA800FFA800FFA800FFA800FFA800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700
FFD700FFD700FFE600FFE600FFE600FFE600FFE600FFF500FFF500FFF500FAFF00FAFF00
FAFF00FAFF00EBFF00EBFF00DCFF00CCFF00AEFF008FFF0000FF2800FF0A80FF008FFF00
8FFF008FFF0080FF0061FF0051FF0014FF0000FFB342FF0070FF0080FF009EFF009EFF00
AEFF00AEFF00AEFF00AEFF009EFF0000FFD100E1FF8FFF008FFF008FFF00DCFF00FAFF00
FFF500FFF500FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD700FFD700FFD700
FFD700FFD700FFD700FFD700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FFA800FFA800FFA800FF9900FF9900FF9900FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700
FFD700FFD700FFE600FFE600FFE600FFE600FFE600FFF500FFF500FFF500FFF500FAFF00
FAFF00FAFF00EBFF00EBFF00DCFF00CCFF009EFF0080FF0000FF7500C2FF8FFF009EFF00
9EFF008FFF0080FF0070FF0061FF0000FFC200FF6642FF0070FF0080FF009EFF00AEFF00
AEFF00AEFF00AEFF00AEFF00AEFF0000FFFF61FF00AEFF00AEFF0000FF19DCFF00FAFF00
FFF500FFF500FFF500FFE600FFE600FFE600FFE600FFD700FFD700FFD700FFD700FFD700
FFD700FFD700FFD700FFD700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FFA800FFA800FF9900FF9900FF9900FF9900FF9900FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700
FFD700FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF500FFF500FFF500FFF500
FAFF00FAFF00FAFF00EBFF00DCFF00CCFF0000FF0A61FF0000FF1961FF009EFF009EFF00
9EFF009EFF008FFF0080FF0061FF0000FF2800FFE100FF0A70FF008FFF009EFF00AEFF00
AEFF00BDFF00BDFF00BDFF00AEFF0000D1FFAEFF00CCFF00CCFF0070FF0033FF00FAFF00
FFF500FFF500FFE600FFE600FFE600FFE600FFE600FFD700FFD700FFD700FFD700FFD700
FFD700FFD700FFD700FFD700FFD700FFC700FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FFA800FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700
FFD700FFE600FFD700FFE600FFE600FFE600FFE600FFE600FFF500FFF500FFF500FFF500
FAFF00FAFF00FAFF00EBFF00DCFF00CCFF0070FF0033FF0042FF008FFF009EFF00AEFF00
AEFF009EFF008FFF0080FF0061FF0023FF0000C2FF42FF0061FF0080FF009EFF00AEFF00
BDFF00BDFF00BDFF00BDFF00BDFF00AEFF00CCFF00DCFF00DCFF00CCFF0000D1FFFAFF00
FFF500FFF500FFE600FFE600FFE600FFE600FFE600FFD700FFD700FFD700FFD700FFD700
FFD700FFD700FFD700FFD700FFC700FFC700FFC700FFC700FFD700FFC700FFC700FFC700
FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFB800FFB800FFB800FFB800FFB800
FFB800FFC700FFB800FFB800FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFD700FFC700FFC700FFD700FFD700FFD700FFD700FFD700FFD700FFD700
FFD700FFD700FFD700FFE600FFE600FFE600FFE600FFE600FFE600FFF500FFF500FFF500
FFF500FAFF00EBFF00EBFF00DCFF00BDFF0070FF0000FF7551FF009EFF00AEFF00AEFF00
AEFF00AEFF008FFF0080FF0061FF0033FF0000FF9433FF0042FF0051FF009EFF00AEFF00
BDFF00BDFF00CCFF00CCFF00CCFF00CCFF00DCFF00DCFF00DCFF00DCFF00CCFF00FAFF00
FFF500FFF500FFE600FFE600FFE600FFE600FFE600FFE600FFD700FFD700FFD700FFD700
FFD700FFD700FFD700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFD700FFD700FFD700FFD700FFD700
FFD700FFD700FFD700FFE600FFE600FFE600FFE600FFE600FFE600FFF500FFF500FFF500
FFF500FAFF00FAFF00EBFF00DCFF00BDFF0070FF0051FF0051FF009EFF00BDFF00BDFF00
AEFF00AEFF008FFF0051FF0042FF0023FF00FF00A814FF0000FF6651FF009EFF00AEFF00
BDFF00CCFF00CCFF00CCFF00CCFF00DCFF00DCFF00EBFF00EBFF00EBFF00EBFF00FAFF00
FFF500FFF500FFE600FFE600FFE600FFE600FFE600FFE600FFD700FFD700FFD700FFD700
FFD700FFD700FFD700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFD700FFD700FFD700FFD700FFD700
FFD700FFD700FFD700FFE600FFE600FFE600FFE600FFE600FFE600FFF500FFF500FFF500
FFF500FAFF00FAFF00EBFF00CCFF009EFF0000FF948FFF008FFF00AEFF00BDFF00BDFF00
BDFF00AEFF0080FF0000FF6600FF0A14FF000075FF00FF7514FF0070FF009EFF00BDFF00
BDFF00CCFF00CCFF00CCFF00DCFF00DCFF00EBFF00EBFF00EBFF00EBFF00FAFF00FFF500
FFF500FFF500FFF500FFE600FFE600FFE600FFE600FFD700FFD700FFD700FFD700FFD700
FFD700FFD700FFD700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFD700FFD700FFD700FFD700FFD700
FFD700FFD700FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF500FFF500
FFF500FFF500FAFF00EBFF0023FF0005FF0080FF00AEFF00AEFF00BDFF00CCFF00BDFF00
BDFF00AEFF0070FF0000FF5714FF0000FFFF00B3FF00FF3800FF8570FF009EFF00BDFF00
CCFF00CCFF00CCFF00DCFF00DCFF00EBFF00EBFF00EBFF00EBFF00FAFF00FAFF00FAFF00
FFF500FFF500FFE600FFE600FFE600FFE600FFE600FFD700FFD700FFD700FFD700FFD700
FFD700FFD700FFD700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFB800
FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFD700FFD700FFD700FFD700FFD700
FFD700FFD700FFD700FFD700FFE600FFE600FFE600FFE600FFE600FFE600FFF500FFF500
FFF500FFF500FAFF00EBFF00DCFF00BDFF0061FF00BDFF00CCFF00CCFF00CCFF00CCFF00
BDFF00BDFF009EFF0080FF0051FF0014FF0000FF6614FF0000FF0A00FF669EFF00BDFF00
CCFF00CCFF00DCFF00DCFF00DCFF00EBFF00EBFF00EBFF00FAFF00FAFF00FAFF00FFF500
FFF500FFF500FFE600FFE600FFE600FFE600FFE600FFD700FFD700FFD700FFD700FFD700
FFD700FFD700FFD700FFD700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFA800FFA800FFA800
FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFD700FFC700FFD700FFD700FFD700FFD700FFD700FFD700
FFD700FFD700FFD700FFD700FFE600FFE600FFE600FFE600FFE600FFF500FFF500FFF500
FFF500FFF500FAFF00FAFF00EBFF00DCFF009EFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00BDFF00AEFF008FFF0005FF0042FF0000FF2833FF0051FF0005FF009EFF00BDFF00
CCFF00CCFF00DCFF00DCFF00EBFF00EBFF00EBFF00EBFF00FAFF00FAFF00FAFF00FFF500
FFF500FFF500FFE600FFE600FFE600FFE600FFE600FFE600FFD700FFD700FFD700FFD700
FFD700FFD700FFD700FFD700FFD700FFD700FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFA800FFA800FFA800FFA800
FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFD700FFD700FFD700
FFD700FFD700FFD700FFD700FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF500
FFF500FFF500FFF500FAFF00EBFF00EBFF00DCFF00DCFF00DCFF00DCFF00DCFF00CCFF00
CCFF00BDFF00BDFF009EFF0033FF0061FF0005FF0000FF2870FF008FFF00AEFF00BDFF00
CCFF00CCFF00DCFF00DCFF00EBFF00EBFF00EBFF00FAFF00FAFF00FAFF00FFF500FFF500
FFF500FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD700FFD700FFD700FFD700
FFD700FFD700FFD700FFD700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FF9900FF9900FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00
FF8A00FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFD700FFD700FFD700
FFD700FFD700FFD700FFD700FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF500
FFF500FFF500FAFF00FAFF00FAFF00EBFF00EBFF00DCFF00DCFF00DCFF00DCFF00CCFF00
CCFF00BDFF00AEFF00AEFF0080FF0070FF0000FF5700FFB380FF008FFF00AEFF00BDFF00
CCFF00CCFF00DCFF00EBFF00EBFF00EBFF00FAFF00FAFF00FAFF00FAFF00FFF500FFF500
FFF500FFF500FFE600FFE600FFE600FFE600FFE600FFD700FFD700FFD700FFD700FFD700
FFD700FFD700FFD700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFC700FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFD700FFD700FFD700
FFD700FFD700FFD700FFE600FFD700FFE600FFE600FFE600FFE600FFE600FFE600FFF500
FFF500FFF500FFF500FAFF00FAFF00EBFF00EBFF00EBFF00EBFF00DCFF00DCFF00DCFF00
CCFF00CCFF00BDFF00AEFF008FFF0070FF0033FF0033FF0080FF009EFF00AEFF00BDFF00
CCFF00DCFF00DCFF00DCFF00EBFF00EBFF00FAFF00FAFF00FAFF00FFF500FFF500FFF500
FFF500FFF500FFE600FFE600FFE600FFE600FFE600FFD700FFD700FFD700FFD700FFD700
FFD700FFD700FFD700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFC700FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFD700FFD700FFD700
FFD700FFD700FFD700FFD700FFD700FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFF500FFF500FFF500FFF500FAFF00FAFF00EBFF00EBFF00EBFF00DCFF00DCFF00DCFF00
CCFF00CCFF00BDFF00AEFF009EFF0070FF0023FF0014FF0070FF009EFF00AEFF00BDFF00
CCFF00DCFF00DCFF00EBFF00EBFF00EBFF00FAFF00FAFF00FAFF00FAFF00FFF500FFF500
FFF500FFE600FFE600FFE600FFE600FFE600FFE600FFD700FFD700FFD700FFD700FFD700
FFD700FFD700FFD700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFD700FFD700FFD700
FFD700FFD700FFD700FFD700FFD700FFE600FFE600FFE600FFE600FFE600FFE600FFF500
FFF500FFF500FFF500FFF500FAFF00FAFF00FAFF00EBFF00EBFF00EBFF00DCFF00DCFF00
CCFF00CCFF00BDFF00AEFF008FFF0070FF0000FF3800FF7551FF008FFF009EFF00BDFF00
CCFF00DCFF00DCFF00EBFF00EBFF00EBFF00FAFF00FAFF00FAFF00FFF500FFF500FFF500
FFF500FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD700FFD700FFD700FFD700
FFD700FFD700FFD700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FF9900
FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFD700FFD700FFD700FFD700
FFD700FFD700FFD700FFD700FFD700FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFF500FFF500FFF500FFF500FAFF00FAFF00FAFF00FAFF00EBFF00EBFF00DCFF00DCFF00
DCFF00CCFF00BDFF00AEFF009EFF0080FF0005FF0005FF0051FF008FFF009EFF00AEFF00
BDFF00DCFF00DCFF00EBFF00EBFF00FAFF00FAFF00FAFF00FAFF00FFF500FFF500FFF500
FFF500FFF500FFE600FFE600FFE600FFE600FFE600FFE600FFD700FFD700FFD700FFD700
FFD700FFD700FFD700FFD700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FF9900FF9900FF9900
FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFD700FFC700FFC700FFD700FFD700FFD700FFD700
FFD700FFD700FFD700FFD700FFD700FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFF500FFF500FFF500FFF500FAFF00FAFF00FAFF00FAFF00EBFF00EBFF00EBFF00DCFF00
DCFF00CCFF00BDFF00AEFF009EFF0080FF0051FF0000FF5761FF0080FF008FFF009EFF00
BDFF00CCFF00DCFF00EBFF00EBFF00EBFF00FAFF00FAFF00FAFF00FFF500FFF500FFF500
FFF500FFE600FFE600FFE600FFE600FFE600FFE600FFD700FFD700FFD700FFD700FFD700
FFD700FFD700FFD700FFD700FFD700FFC700FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFD700FFC700FFC700FFC700FFC700FFD700FFD700FFD700
FFD700FFD700FFD700FFD700FFE600FFD700FFE600FFE600FFE600FFE600FFE600FFE600
FFF500FFF500FFF500FFF500FFF500FAFF00FAFF00FAFF00EBFF00EBFF00EBFF00DCFF00
DCFF00CCFF00AEFF009EFF008FFF0080FF0023FF0000FF2861FF0070FF0070FF0051FF00
8FFF00CCFF00DCFF00EBFF00EBFF00FAFF00FAFF00FAFF00FAFF00FFF500FFF500FFF500
FFF500FFE600FFE600FFE600FFE600FFE600FFE600FFD700FFD700FFD700FFD700FFD700
FFD700FFD700FFD700FFD700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900
FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFD700
FFD700FFD700FFD700FFD700FFD700FFD700FFE600FFE600FFE600FFE600FFE600FFE600
FFF500FFF500FFF500FFF500FFF500FAFF00FAFF00FAFF00FAFF00EBFF00EBFF00DCFF00
CCFF00BDFF009EFF0080FF0080FF0070FF0042FF0000FF8542FF0061FF0033FF0033FF00
AEFF00CCFF00DCFF00DCFF00EBFF00FAFF00FAFF00FAFF00FAFF00FFF500FFF500FFF500
FFF500FFE600FFE600FFE600FFE600FFE600FFE600FFD700FFD700FFD700FFD700FFD700
FFD700FFD700FFD700FFD700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FFA800FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFD700
FFD700FFD700FFD700FFD700FFD700FFD700FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFF500FFF500FFF500FFF500FFF500FAFF00FAFF00EBFF00EBFF00EBFF00DCFF00
CCFF00AEFF0080FF0061FF0051FF0061FF0042FF007000FF33FF0042FF0000FF1914FF00
BDFF00CCFF00DCFF00EBFF00EBFF00FAFF00FAFF00FAFF00FAFF00FAFF00FFF500FFF500
FFF500FFF500FFE600FFE600FFE600FFE600FFE600FFE600FFD700FFE600FFD700FFD700
FFD700FFD700FFD700FFD700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FFA800FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800
FFB800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFD700
FFD700FFD700FFD700FFD700FFD700FFD700FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFF500FFF500FFF500FFF500FAFF00FAFF00FAFF00FAFF00EBFF00EBFF00DCFF00
CCFF0023FF0042FF0005FF0000FF2814FF0033FF0000FF8500FF8500FF1933FF008FFF00
BDFF00CCFF00DCFF00EBFF00EBFF00FAFF00FAFF00FAFF00FFF500FFF500FFF500FFF500
FFF500FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD700FFD700FFD700FFD700
FFD700FFD700FFD700FFD700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFA800
FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFC700FFB800FFB800FFB800FFB800FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFD700FFD700
FFD700FFD700FFD700FFD700FFD700FFD700FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFF500FFF500FFF500FFF500FFF500FAFF00FAFF00FAFF00FAFF00EBFF00DCFF00
DCFF00AEFF0080FF0051FF0000FF190066FF14FF000028FF00FF7500FF0A61FF009EFF00
AEFF00CCFF00DCFF00EBFF00EBFF00FAFF00FAFF00FAFF00FAFF00FFF500FFF500FFF500
FFF500FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD700FFD700FFD700FFD700
FFD700FFD700FFD700FFD700FFC700FFC700FFC700FFD700FFC700FFC700FFC700FFC700
FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFA800FFA800
FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFC700FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFD700FFD700FFD700
FFD700FFD700FFD700FFD700FFD700FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFF500FFF500FFF500FFF500FFF500FAFF00FAFF00FAFF00FAFF00EBFF00EBFF00
DCFF00BDFF00AEFF008FFF0070FF0033FF0000FFFF0085FF00FF2800FF8542FF0080FF00
AEFF00CCFF00DCFF00EBFF00EBFF00FAFF00FAFF00FAFF00FAFF00FFF500FFF500FFF500
FFF500FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD700FFD700FFD700FFD700
FFD700FFD700FFD700FFD700FFD700FFD700FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFD700FFC700FFC700FFD700FFD700FFD700
FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFF500FFF500FFF500FFF500FAFF00FAFF00FAFF00FAFF00EBFF00EBFF00
DCFF00CCFF00BDFF009EFF0080FF0000FF0A23FF0000FF4705FF0033FF0000F0FF51FF00
51FF00AEFF00DCFF00EBFF00EBFF00FAFF00FAFF00FAFF00FAFF00FFF500FFF500FFF500
FFF500FFF500FFE600FFE600FFE600FFE600FFE600FFE600FFD700FFD700FFD700FFD700
FFD700FFD700FFD700FFD700FFD700FFC700FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFD700FFD700
FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFF500FFF500FFF500FFF500FFF500FAFF00FAFF00FAFF00EBFF00EBFF00
DCFF00CCFF00CCFF00AEFF0070FF0000FFF042FF0005FF0033FF0061FF0000FFA314FF00
00FF389EFF00DCFF00EBFF00EBFF00FAFF00FAFF00FAFF00FAFF00FFF500FFF500FFF500
FFF500FFF500FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD700FFD700
FFD700FFD700FFD700FFD700FFD700FFC700FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFB800FFB800FFB800FFC700FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFD700FFD700
FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFE600FFE600FFE600FFE600FFE600
FFE600FFF500FFF500FFF500FFF500FFF500FFF500FAFF00FAFF00FAFF00EBFF00EBFF00
DCFF00DCFF00CCFF00AEFF0042FF0023FF0061FF0000E1FF14FF0070FF0080FF0061FF00
8FFF0051FF00DCFF00EBFF00EBFF00FAFF00FAFF00FAFF00FAFF00FAFF00FFF500FFF500
FFF500FFF500FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD700FFD700FFD700
FFD700FFD700FFD700FFD700FFD700FFC700FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFD700FFD700
FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFE600FFE600FFE600FFE600FFF500
FFE600FFF500FFF500FFF500FFF500FFF500FAFF00FAFF00FAFF00FAFF00EBFF00EBFF00
EBFF00DCFF00CCFF009EFF0000FF2870FF0070FF0023FF0033FF0080FF008FFF008FFF00
AEFF00BDFF00DCFF00EBFF00EBFF00FAFF00FAFF00FAFF00FAFF00FFF500FFF500FFF500
FFF500FFF500FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD700FFD700FFD700
FFD700FFD700FFD700FFD700FFD700FFC700FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFD700FFD700
FFD700FFD700FFD700FFD700FFD700FFD700FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFF500FFF500FFF500FFF500FFF500FAFF00FAFF00FAFF00FAFF00EBFF00
EBFF00DCFF00CCFF0080FF0070FF008FFF0080FF0042FF0033FF0080FF009EFF009EFF00
BDFF00CCFF00DCFF00DCFF00EBFF00EBFF00FAFF00FAFF00FAFF00FFF500FFF500FFF500
FFF500FFF500FFF500FFE600FFE600FFE600FFE600FFE600FFE600FFD700FFD700FFD700
FFD700FFD700FFD700FFD700FFD700FFC700FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFB800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFD700FFD700
FFD700FFD700FFD700FFE600FFD700FFD700FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFF500FFF500FFF500FFF500FFF500FAFF00FAFF00FAFF00FAFF00EBFF00
EBFF00DCFF00CCFF00BDFF00AEFF009EFF008FFF0000FFC200FF7580FF009EFF00AEFF00
BDFF00CCFF00DCFF00EBFF00EBFF00FAFF00FAFF00FAFF00FAFF00FAFF00FFF500FFF500
FFF500FFF500FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD700FFD700FFD700
FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00
FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFD700
FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFF500FFF500FFF500FFF500FAFF00FAFF00FAFF00FAFF00FAFF00EBFF00
EBFF00DCFF00DCFF00CCFF00AEFF00AEFF008FFF0000FF3814FF0080FF00AEFF00BDFF00
CCFF00CCFF00DCFF00EBFF00EBFF00EBFF00FAFF00FAFF00FAFF00FFF500FFF500FFF500
FFF500FFF500FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD700FFD700
FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFD700FFD700FFD700
FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFE600FFE600FFE600FFE600
FFE600FFF500FFF500FFF500FFF500FFF500FFF500FAFF00FAFF00FAFF00FAFF00EBFF00
EBFF00DCFF00DCFF00CCFF00BDFF00AEFF008FFF0061FF0023FF0080FF00AEFF00BDFF00
CCFF00DCFF00DCFF00EBFF00EBFF00EBFF00FAFF00FAFF00FAFF00FAFF00FFF500FFF500
FFF500FFF500FFF500FFF500FFE600FFE600FFE600FFE600FFE600FFE600FFD700FFD700
FFD700FFD700FFD700FFD700FFD700FFD700FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FFA800FFA800FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFD700FFD700
FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFF500FFF500FFF500FFF500FFF500FAFF00FAFF00FAFF00FAFF00EBFF00
EBFF00DCFF00DCFF00CCFF00BDFF00AEFF008FFF0070FF0000FF0A70FF009EFF00BDFF00
CCFF00DCFF00DCFF00EBFF00EBFF00EBFF00FAFF00FAFF00FAFF00FAFF00FFF500FFF500
FFF500FFF500FFF500FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD700FFD700
FFD700FFD700FFD700FFD700FFD700FFD700FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FFA800FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFD700FFD700
FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFF500FFF500FFF500FFF500FFF500FAFF00FAFF00FAFF00FAFF00EBFF00
EBFF00DCFF00DCFF00CCFF00CCFF00AEFF0080FF0051FF0000FF6614FF009EFF00BDFF00
CCFF00CCFF00DCFF00EBFF00EBFF00EBFF00FAFF00FAFF00FAFF00FAFF00FFF500FFF500
FFF500FFF500FFF500FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD700FFD700
FFD700FFD700FFD700FFD700FFD700FFD700FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFB800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800
FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFD700
FFD700FFD700FFD700FFD700FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFF500FFF500FFF500FFF500FFF500FAFF00FAFF00FAFF00EBFF00EBFF00
EBFF00DCFF00DCFF00CCFF00CCFF00BDFF0042FF0000FFB38000FF33FF009EFF00BDFF00
CCFF00CCFF00DCFF00DCFF00EBFF00EBFF00EBFF00FAFF00FAFF00FAFF00FAFF00FFF500
FFF500FFF500FFF500FFF500FFF500FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFC700FFD700FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFD700
FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFE600FFE600FFE600FFE600FFE600
FFE600FFF500FFF500FFF500FFF500FFF500FFF500FAFF00FAFF00FAFF00FAFF00EBFF00
EBFF00EBFF00DCFF00CCFF00CCFF00BDFF009EFF0042FF00FF008A00FF0A80FF00BDFF00
CCFF00CCFF00DCFF00DCFF00DCFF00EBFF00EBFF00FAFF00FAFF00FAFF00FAFF00FFF500
FFF500FFF500FFF500FFF500FFF500FFE600FFE600FFE600FFE600FFE600FFE600FFD700
FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FFA800FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFD700FFD700
FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFF500FFF500FFF500FFF500FFF500FAFF00FAFF00FAFF00FAFF00EBFF00
EBFF00DCFF00DCFF00DCFF00CCFF00BDFF009EFF0000FFFF00FF4751FF0070FF00BDFF00
CCFF00CCFF00DCFF00DCFF00EBFF00EBFF00EBFF00FAFF00FAFF00FAFF00FAFF00FFF500
FFF500FFF500FFF500FFF500FFF500FFE600FFE600FFE600FFE600FFE600FFE600FFD700
FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFD700FFD700
FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFF500FFF500FFF500FFF500FAFF00FAFF00FAFF00FAFF00EBFF00EBFF00
EBFF00DCFF00DCFF00CCFF00CCFF00BDFF009EFF0070FF0000FF1970FF009EFF00AEFF00
BDFF00CCFF00DCFF00DCFF00DCFF00EBFF00EBFF00EBFF00FAFF00FAFF00FAFF00FAFF00
FFF500FFF500FFF500FFF500FFF500FFF500FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFB800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF8A00FF8A00FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFD700FFD700FFD700
FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFF500FFF500FFF500FFF500FFF500FAFF00FAFF00FAFF00EBFF00EBFF00
EBFF00DCFF00DCFF00CCFF00CCFF00BDFF00AEFF008FFF0023FF0070FF009EFF00BDFF00
BDFF00CCFF00DCFF00DCFF00DCFF00EBFF00EBFF00EBFF00FAFF00FAFF00FAFF00FAFF00
FAFF00FFF500FFF500FFF500FFF500FFF500FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFB800FFB800FFB800FFC700FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFD700
FFD700FFD700FFD700FFE600FFD700FFD700FFD700FFE600FFE600FFE600FFE600FFE600
FFE600FFF500FFF500FFF500FFF500FAFF00FAFF00FAFF00FAFF00FAFF00EBFF00EBFF00
EBFF00DCFF00DCFF00CCFF00CCFF00BDFF00AEFF008FFF0000FF1961FF009EFF00AEFF00
BDFF00CCFF00CCFF00DCFF00DCFF00DCFF00EBFF00EBFF00EBFF00EBFF00FAFF00FAFF00
FAFF00FFF500FFF500FFF500FFF500FFF500FFF500FFE600FFE600FFE600FFE600FFE600
FFE600FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFB800FFB800FFC700FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFD700FFD700
FFD700FFD700FFD700FFD700FFD700FFD700FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFF500FFF500FFF500FFF500FFF500FAFF00FAFF00FAFF00FAFF00EBFF00EBFF00
EBFF00DCFF00DCFF00CCFF00CCFF00BDFF00AEFF008FFF0005FF0042FF009EFF00AEFF00
BDFF00BDFF00CCFF00DCFF00DCFF00DCFF00EBFF00EBFF00EBFF00EBFF00FAFF00FAFF00
FAFF00FAFF00FFF500FFF500FFF500FFF500FFF500FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFD700FFD700
FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFE600FFE600FFE600FFE600FFE600
FFE600FFF500FFF500FFF500FFF500FFF500FAFF00FAFF00FAFF00EBFF00EBFF00EBFF00
DCFF00DCFF00DCFF00CCFF00BDFF00BDFF009EFF008FFF0042FF0070FF008FFF00AEFF00
AEFF00BDFF00CCFF00CCFF00CCFF00DCFF00DCFF00EBFF00EBFF00EBFF00FAFF00FAFF00
FAFF00FAFF00FAFF00FFF500FFF500FFF500FFF500FFF500FFE600FFE600FFE600FFE600
FFE600FFE600FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFD700FFD700
FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFE600FFE600FFE600FFE600FFF500
FFE600FFF500FFF500FFF500FFF500FAFF00FAFF00FAFF00EBFF00FAFF00EBFF00EBFF00
DCFF00DCFF00CCFF00CCFF00BDFF00AEFF009EFF008FFF0051FF0061FF0080FF009EFF00
AEFF00AEFF00BDFF00CCFF00CCFF00DCFF00CCFF00DCFF00DCFF00EBFF00EBFF00FAFF00
FAFF00FAFF00FAFF00FFF500FFF500FFF500FFF500FFF500FFE600FFE600FFE600FFE600
FFE600FFE600FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFC700FFC700FFD700
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFD700FFD700
FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFE600FFE600FFE600FFE600FFE600
FFF500FFF500FFF500FFF500FFF500FAFF00FAFF00FAFF00FAFF00EBFF00EBFF00EBFF00
DCFF00DCFF00CCFF00BDFF00BDFF00AEFF008FFF0070FF0005FF0023FF0070FF0080FF00
9EFF008FFF00AEFF00BDFF00CCFF00CCFF00CCFF00CCFF00DCFF00EBFF00EBFF00EBFF00
FAFF00FAFF00FAFF00FFF500FFF500FFF500FFF500FFF500FFF500FFE600FFE600FFE600
FFE600FFE600FFE600FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFB800FFB800FFB800FFC700
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFD700FFD700
FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFE600FFE600FFE600FFE600FFE600
FFE600FFF500FFF500FFF500FFF500FAFF00FAFF00FAFF00FAFF00EBFF00EBFF00EBFF00
DCFF00CCFF00BDFF00BDFF00AEFF009EFF0061FF0000FFF033FF0000FF1923FF0014FF00
8FFF0000FF479EFF0061FF00BDFF00CCFF00CCFF00BDFF00CCFF00DCFF00EBFF00EBFF00
EBFF00FAFF00FAFF00FAFF00FFF500FFF500FFF500FFF500FFF500FFF500FFE600FFE600
FFE600FFE600FFE600FFD700FFE600FFD700FFD700FFD700FFD700FFD700FFD700FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFD700FFD700
FFD700FFD700FFD700FFD700FFD700FFE600FFE600FFE600FFE600FFE600FFF500FFE600
FFE600FFF500FFF500FFF500FFF500FAFF00FAFF00FAFF00EBFF00EBFF00EBFF00DCFF00
DCFF00CCFF009EFF00AEFF00AEFF008FFF0000FF8500FF5770FF0070FF0000FF0A05FF00
61FF0000FF0A70FF008FFF00BDFF00BDFF00BDFF0000FFC2BDFF00DCFF00DCFF00DCFF00
EBFF00EBFF00FAFF00FAFF00FAFF00FFF500FFF500FFF500FFF500FFF500FFF500FFF500
FFE600FFE600FFE600FFE600FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFA800FFB800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFD700
FFD700FFD700FFD700FFD700FFD700FFD700FFE600FFE600FFE600FFE600FFE600FFE600
FFF500FFF500FFF500FFF500FAFF00FAFF00FAFF00FAFF00EBFF00EBFF00EBFF00DCFF00
DCFF00BDFF0070FF009EFF009EFF0061FF0000B3FF51FF008FFF008FFF0051FF0042FF00
14FF0000FF3800FF858FFF009EFF00AEFF00AEFF0000FF57BDFF00CCFF00CCFF00CCFF00
EBFF00EBFF00FAFF00FAFF00FAFF00FAFF00FAFF00FAFF00FFF500FFF500FFF500FFF500
FFE600FFE600FFE600FFE600FFE600FFE600FFD700FFD700FFD700FFD700FFD700FFC700
FFD700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900
FF9900FF9900FF9900FF9900FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00
FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFD700FFD700
FFD700FFD700FFD700FFD700FFD700FFD700FFE600FFE600FFE600FFE600FFE600FFE600
FFF500FFF500FFF500FFF500FAFF00FAFF00FAFF00EBFF00EBFF00EBFF00DCFF00DCFF00
CCFF00BDFF0051FF0070FF008FFF0061FF0000FF0A00FF579EFF009EFF008FFF0080FF00
23FF0000FFF042FF008FFF009EFF00AEFF008FFF0000FF75AEFF00BDFF00BDFF009EFF00
DCFF00EBFF00FAFF00FAFF00FAFF00FAFF00FAFF00FAFF00FAFF00FAFF00FFF500FFF500
FFE600FFE600FFE600FFE600FFE600FFD700FFD700FFD700FFD700FFD700FFD700FFD700
FFD700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFB800FFB800
FFB800FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFD700FFD700
FFD700FFD700FFD700FFD700FFD700FFD700FFE600FFE600FFE600FFE600FFE600FFE600
FFF500FFF500FFF500FFF500FAFF00FAFF00EBFF00EBFF00EBFF00EBFF00DCFF00DCFF00
CCFF00BDFF0042FF0061FF0080FF0014FF0051FF0080FF009EFF00AEFF009EFF008FFF00
14FF0000FF7500FF8570FF008FFF009EFF008FFF0023FF009EFF00AEFF0000FF758FFF00
CCFF00EBFF00EBFF00EBFF00FAFF00FAFF00FAFF00FAFF00FAFF00FAFF00FAFF00FFF500
FFF500FFE600FFE600FFE600FFE600FFE600FFE600FFD700FFD700FFD700FFD700FFD700
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FFA800FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFD700FFD700
FFD700FFD700FFD700FFD700FFD700FFD700FFE600FFE600FFE600FFE600FFE600FFF500
FFF500FFF500FFF500FAFF00FAFF00EBFF00EBFF00EBFF00EBFF00DCFF00DCFF00CCFF00
CCFF00AEFF0080FF0005FF0061FF000075FF80FF009EFF00AEFF00AEFF00AEFF008FFF00
00FF3800FF8523FF0033FF0000FF758FFF0070FF0033FF008FFF009EFF0000FF19AEFF00
DCFF00DCFF00EBFF00EBFF00FAFF00EBFF00FAFF00EBFF00EBFF00EBFF00FAFF00FFF500
FFF500FFF500FFE600FFE600FFE600FFE600FFD700FFE600FFD700FFD700FFD700FFD700
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFB800FFB800
FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700
FFC700FFC700FFC700FFC700FFD700FFC700FFC700FFC700FFC700FFD700FFD700FFD700
FFD700FFD700FFD700FFD700FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF500
FFF500FFF500FFF500FAFF00FAFF00EBFF00DCFF00DCFF00DCFF00DCFF00DCFF00CCFF00
BDFF0080FF0070FF0000FFA323FF0061FF009EFF00AEFF00BDFF00BDFF00BDFF008FFF00
80FF0000FFA380FF0000FF4742FF0070FF0061FF0000FF4780FF0070FF0033FF00AEFF00
CCFF00DCFF00EBFF00EBFF00EBFF00EBFF00EBFF00EBFF008FFF00DCFF00DCFF00FAFF00
FFF500FFF500FFE600FFE600FFE600FFE600FFE600FFD700FFD700FFD700FFD700FFD700
FFD700FFD700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFD700FFD700FFD700
FFD700FFD700FFD700FFD700FFD700FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFF500FFF500FFF500FAFF00EBFF00CCFF00DCFF00DCFF00DCFF00DCFF00CCFF00CCFF00
BDFF0051FF0000FF1900FF4700FFA370FF009EFF00BDFF00BDFF00BDFF00BDFF009EFF00
AEFF0033FF008FFF0061FF0014FF0051FF0051FF0014FF0070FF0023FF0080FF00AEFF00
CCFF00DCFF00EBFF00EBFF00EBFF00EBFF00EBFF00DCFF0080FF009EFF00CCFF00FAFF00
FAFF00FFF500FFF500FFE600FFE600FFE600FFE600FFE600FFD700FFD700FFD700FFD700
FFD700FFD700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFD700FFD700
FFD700FFD700FFD700FFD700FFD700FFE600FFE600FFE600FFE600FFE600FFF500FFF500
FFF500FFF500FAFF00FAFF00EBFF00AEFF00BDFF00CCFF00CCFF00CCFF00CCFF00CCFF00
BDFF008FFF0042FF0000FF4723FF0023FF009EFF00BDFF00CCFF00CCFF00CCFF00BDFF00
BDFF00AEFF00AEFF008FFF0061FF0000FF5700FF0A00FFB351FF0033FF008FFF00BDFF00
CCFF00DCFF00DCFF00EBFF00EBFF00EBFF00DCFF00CCFF009EFF008FFF00DCFF00FAFF00
FAFF00FFF500FFF500FFF500FFF500FFE600FFE600FFE600FFD700FFD700FFD700FFD700
FFD700FFD700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700
FFB800FFB800FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFD700
FFD700FFD700FFD700FFD700FFD700FFE600FFE600FFE600FFE600FFE600FFE600FFF500
FFF500FAFF00FFF500FAFF00EBFF00BDFF00AEFF00BDFF00BDFF00CCFF00CCFF00BDFF00
AEFF008FFF0051FF0033FF0042FF0051FF008FFF00BDFF00CCFF00CCFF00CCFF00CCFF00
CCFF00BDFF00AEFF009EFF0080FF0005FF0000FFE100F0FF05FF0061FF009EFF00BDFF00
CCFF00DCFF00DCFF00DCFF00DCFF00DCFF00DCFF00AEFF0042FF00BDFF00DCFF00FAFF00
FAFF00FFF500FFF500FFF500FFF500FFF500FFE600FFE600FFE600FFD700FFD700FFD700
FFD700FFD700FFD700FFD700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFD700
FFD700FFD700FFD700FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF500
FFF500FFF500FAFF00FAFF00EBFF0042FF0061FF0080FF009EFF00BDFF00BDFF00BDFF00
AEFF008FFF0005FF0061FF0005FF008FFF00AEFF00CCFF00CCFF00DCFF00DCFF00CCFF00
CCFF00CCFF00BDFF009EFF0070FF0014FF0000FF0A00FF3823FF0061FF009EFF00AEFF00
BDFF00CCFF00CCFF00DCFF00DCFF00DCFF00CCFF0000FF2800FF75BDFF00DCFF00EBFF00
FAFF00FAFF00FFF500FFF500FFF500FFF500FFE600FFF500FFE600FFD700FFD700FFD700
FFD700FFD700FFD700FFD700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFD700
FFD700FFD700FFD700FFD700FFE600FFE600FFE600FFE600FFE600FFE600FFF500FFF500
FFF500FAFF00FAFF00FAFF00EBFF00BDFF0051FF0051FF008FFF00AEFF00BDFF00AEFF00
8FFF0070FF000094FF80FF0000FF38AEFF00CCFF00CCFF00DCFF00DCFF00DCFF00DCFF00
DCFF00CCFF00BDFF009EFF0000FF3861FF0051FF0023FF0061FF0000FFC280FF00AEFF00
BDFF00CCFF00CCFF00DCFF00CCFF00CCFF00BDFF0080FF0051FF00AEFF00DCFF00EBFF00
EBFF00FAFF00FAFF00FAFF00FAFF00FAFF00FFF500FFE600FFE600FFE600FFD700FFD700
FFD700FFD700FFD700FFD700FFC700FFD700FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFD700FFD700
FFD700FFD700FFD700FFD700FFE600FFE600FFE600FFE600FFE600FFE600FFF500FFF500
FFF500FFF500FAFF00FAFF00EBFF00CCFF0080FF0000FF0A8FFF00AEFF00AEFF00AEFF00
80FF0033FF0070FF008FFF0051FF00AEFF00CCFF00DCFF00DCFF00DCFF00DCFF00DCFF00
DCFF00CCFF00BDFF008FFF0000FF5780FF0023FF0005FF0070FF0033FF0042FF009EFF00
9EFF00BDFF00CCFF00CCFF00CCFF00CCFF00AEFF0005FF0014FF008FFF00DCFF00EBFF00
EBFF00FAFF00EBFF00EBFF00DCFF00EBFF00FAFF00FFF500FFE600FFE600FFE600FFD700
FFD700FFD700FFD700FFD700FFD700FFC700FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFB800FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FF9900FF9900FF9900FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFD700FFD700FFD700
FFD700FFD700FFD700FFD700FFE600FFE600FFE600FFE600FFE600FFE600FFF500FFF500
FFF500FAFF00FAFF00FAFF00EBFF00CCFF0070FF0000FF0A80FF009EFF009EFF009EFF00
00FF0A0075FF61FF009EFF009EFF00BDFF00CCFF00DCFF00DCFF00EBFF00DCFF00EBFF00
DCFF00DCFF00CCFF0070FF0061FF009EFF0070FF0000FF388FFF0000FFA300FF2880FF00
70FF009EFF00BDFF00CCFF00CCFF00CCFF00AEFF0070FF0005FF008FFF00CCFF00DCFF00
EBFF00EBFF00EBFF00DCFF00CCFF00CCFF00DCFF00FFF500FFE600FFE600FFD700FFD700
FFD700FFD700FFD700FFD700FFD700FFC700FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFA800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFD700FFD700FFD700
FFD700FFD700FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF500FFF500FFF500
FFF500FFF500FAFF00FAFF00EBFF00CCFF009EFF0061FF0051FF0080FF009EFF008FFF00
61FF0023FF008FFF00AEFF00BDFF00CCFF00DCFF00DCFF00DCFF00EBFF00EBFF00EBFF00
EBFF00DCFF00CCFF0070FF0042FF00AEFF0061FF0070FF009EFF008FFF0061FF0051FF00
51FF0000FF85AEFF00BDFF00BDFF00BDFF00AEFF0080FF0005FF0033FF009EFF00DCFF00
EBFF00EBFF00DCFF00BDFF009EFF0080FF008FFF00FFF500FFE600FFE600FFE600FFD700
FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFD700FFD700
FFD700FFD700FFD700FFE600FFE600FFE600FFE600FFE600FFE600FFF500FFF500FFF500
FFF500FAFF00FAFF00EBFF00DCFF00CCFF00BDFF0080FF0000FF1900FF0A8FFF0080FF00
23FF0070FF009EFF00BDFF00CCFF00CCFF00DCFF00EBFF00EBFF00EBFF00EBFF00EBFF00
EBFF00DCFF00CCFF0033FF00AEFF00BDFF008FFF0070FF00AEFF00AEFF0080FF0000FF94
23FF0061FF00AEFF00AEFF00BDFF00AEFF009EFF0080FF0014FF0080FF00BDFF00DCFF00
DCFF00DCFF00CCFF0023FF0000FF38BDFF00EBFF00FFF500FFE600FFE600FFE600FFD700
FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFC700FFD700FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900
FF9900FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFD700FFD700
FFD700FFD700FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF500FFF500FFF500
FFF500FAFF00FAFF00EBFF00DCFF00CCFF00BDFF008FFF0000FF7551FF0080FF0070FF00
00FF3880FF00AEFF00BDFF00CCFF00DCFF00DCFF00EBFF00EBFF00EBFF00EBFF00EBFF00
EBFF00EBFF00BDFF0061FF00CCFF00CCFF00AEFF009EFF00BDFF00BDFF0023FF0042FF00
23FF0070FF009EFF00AEFF00AEFF00AEFF0080FF0070FF0042FF009EFF00BDFF00CCFF00
DCFF00CCFF0070FF0014FF00AEFF00DCFF00FAFF00FFF500FFE600FFE600FFE600FFD700
FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFC700FFD700FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700
FFC700FFC700FFC700FFC700FFC700FFD700FFC700FFD700FFD700FFD700FFD700FFD700
FFD700FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF500FFF500FFF500FFF500
FFF500FAFF00FAFF00EBFF00DCFF00CCFF00BDFF009EFF0014FF0033FF0061FF0061FF00
23FF008FFF00AEFF00CCFF00DCFF00DCFF00EBFF00EBFF00EBFF00EBFF00EBFF00EBFF00
EBFF00EBFF00DCFF00CCFF00DCFF00DCFF0033FF00BDFF00CCFF00BDFF0051FF0051FF00
61FF0033FF008FFF00AEFF00AEFF009EFF0000FF1951FF0061FF009EFF00BDFF00CCFF00
CCFF00BDFF009EFF0000FF57BDFF00EBFF00FAFF00FFF500FFF500FFE600FFE600FFE600
FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFA800FFA800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00
FF7A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFD700FFD700FFD700FFD700
FFD700FFE600FFE600FFE600FFE600FFE600FFF500FFE600FFF500FFF500FFF500FFF500
FAFF00FAFF00EBFF00DCFF00CCFF00BDFF00AEFF008FFF0061FF0000FF3800FF5733FF00
42FF008FFF00AEFF00CCFF00DCFF00EBFF00EBFF00EBFF00FAFF00FAFF00FAFF00FAFF00
FAFF00EBFF00EBFF00EBFF00DCFF00DCFF00DCFF00CCFF00CCFF00CCFF00BDFF0070FF00
80FF0000FF4733FF009EFF009EFF008FFF0061FF0005FF0061FF008FFF00AEFF00BDFF00
BDFF00AEFF008FFF0000FF0ABDFF00EBFF00FAFF00FFF500FFF500FFE600FFE600FFE600
FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFC700FFC700
FFD700FFC700FFC700FFC700FFC700FFC700FFC700FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFD700FFD700FFD700
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF500FFF500FFF500FFF500FFF500
FAFF00FAFF00EBFF00DCFF00AEFF008FFF009EFF008FFF0051FF0000FF2800FF4700FF28
00FF8542FF009EFF00CCFF00DCFF00EBFF00EBFF00FAFF00FAFF00FAFF00FAFF00FAFF00
FAFF00FAFF00EBFF00EBFF00EBFF00EBFF00EBFF00DCFF00DCFF00CCFF00CCFF00AEFF00
9EFF0051FF0051FF008FFF008FFF0000FF2842FF0000FF2842FF0070FF009EFF00AEFF00
AEFF0080FF0000FF1942FF00CCFF00EBFF00FAFF00FFF500FFF500FFE600FFE600FFE600
FFE600FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700
FFD700FFD700FFC700FFC700FFC700FFC700FFC700FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFD700FFD700FFD700
FFE600FFE600FFE600FFE600FFE600FFF500FFE600FFF500FFF500FFF500FFF500FAFF00
FAFF00FAFF00EBFF00DCFF0061FF0000FF3880FF0080FF0051FF0000FFF000FFFF42FF00
61FF0000FF8500FF19BDFF00DCFF00EBFF00EBFF00FAFF00FAFF00FAFF00FAFF00FAFF00
FAFF00FAFF00FAFF00FAFF00EBFF00EBFF00EBFF00EBFF00DCFF00DCFF00CCFF00BDFF00
AEFF0080FF0000FFC280FF0080FF0051FF0000FF0A00FF3800FF1961FF0042FF00AEFF00
9EFF0005FF0080FF0070FF00CCFF00EBFF00FAFF00FFF500FFF500FFF500FFE600FFE600
FFE600FFD700FFE600FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700
FFD700FFD700FFC700FFC700FFC700FFC700FFC700FFC700FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFD700FFD700FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFF500FFF500FFF500FFF500FFF500FFF500
FAFF00FAFF00EBFF00DCFF009EFF0000FFD100FF1961FF0033FF0000FFA300E1FF51FF00
80FF0070FF0000FF57AEFF00DCFF00EBFF00FAFF00FAFF00FAFF00FAFF00FAFF00FAFF00
FAFF00FAFF00FAFF00FAFF00FAFF00FAFF00EBFF00EBFF00DCFF00DCFF00CCFF00BDFF00
AEFF008FFF0051FF0051FF0033FF0042FF0000FFFF0047FF00FF8533FF0070FF009EFF00
8FFF0023FF009EFF00BDFF00DCFF00EBFF00FAFF00FFF500FFF500FFE600FFE600FFE600
FFE600FFE600FFE600FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700
FFD700FFD700FFC700FFC700FFC700FFC700FFC700FFC700FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FFA800FF9900FF9900FF9900FF9900FF9900FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFD700FFD700FFD700FFD700FFE600
FFE600FFE600FFE600FFE600FFF500FFF500FFF500FFF500FFF500FFF500FFF500FAFF00
FAFF00FAFF00EBFF00DCFF00BDFF0000FF2842FF0000FFB30057FF00FF7500FF3861FF00
8FFF009EFF0080FF0023FF00DCFF00EBFF00FAFF00FAFF00FAFF00FAFF00FAFF00FAFF00
FAFF00FAFF00FAFF00FAFF00FAFF00FAFF00EBFF00EBFF00EBFF00DCFF00DCFF00CCFF00
BDFF008FFF0000FF7533FF0005FF0014FF0000E1FFFF00000047FF00FFA361FF0080FF00
42FF0051FF00AEFF00CCFF00DCFF00EBFF00FAFF00FFF500FFF500FFF500FFE600FFF500
FFE600FFE600FFE600FFE600FFD700FFD700FFE600FFD700FFD700FFD700FFD700FFD700
FFD700FFD700FFD700FFC700FFC700FFC700FFC700FFC700FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFA800FFB800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFD700FFD700FFE600FFE600
FFE600FFE600FFE600FFF500FFF500FFF500FFF500FFF500FFF500FFF500FFF500FAFF00
FAFF00FAFF00EBFF00DCFF00CCFF00AEFF008FFF0061FF0042FF0023FF0014FF0061FF00
9EFF00AEFF00BDFF008FFF00EBFF00FAFF00FAFF00FAFF00FAFF00FAFF00FFF500FFF500
FFF500FFF500FFF500FAFF00FAFF00FAFF00FAFF00FAFF00EBFF00EBFF00DCFF00CCFF00
AEFF0080FF0033FF0070FF0061FF0000FF3800FFD1FF00000075FF33FF0014FF0051FF00
00FF198FFF00BDFF00CCFF00DCFF00EBFF00FAFF00FFF500FFF500FFF500FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFD700FFE600FFE600FFE600FFE600FFD700FFE600
FFD700FFD700FFD700FFD700FFD700FFC700FFC700FFC700FFC700FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFD700FFD700FFE600FFE600
FFE600FFE600FFF500FFF500FFF500FFF500FFF500FFF500FFF500FFF500FAFF00FAFF00
FAFF00EBFF00EBFF00DCFF00CCFF00BDFF009EFF0051FF0061FF0070FF0051FF0023FF00
9EFF00BDFF00CCFF00CCFF00EBFF00FAFF00FAFF00FAFF00FAFF00FFF500FFF500FFF500
FFF500FFF500FFF500FFF500FAFF00FAFF00FAFF00FAFF00EBFF00EBFF00DCFF00CCFF00
9EFF0070FF0061FF008FFF0080FF0042FF0000FF57DC00FF00F0FF51FF0000C2FF33FF00
70FF009EFF00BDFF00DCFF00EBFF00EBFF00FAFF00FFF500FFF500FFF500FFF500FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFD700FFD700FFD700FFC700FFC700FFC700FFC700FFB800FFC700FFB800
FFB800FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFD700FFD700FFE600FFE600
FFE600FFF500FFF500FFF500FFF500FFF500FFF500FFF500FFF500FAFF00FAFF00FAFF00
FAFF00EBFF00EBFF00DCFF00CCFF00BDFF009EFF0023FF0070FF008FFF0000FF2800FF0A
9EFF00BDFF00DCFF00EBFF00EBFF00FAFF00FAFF00FAFF00FFF500FFF500FFF500FFF500
FFF500FFF500FFF500FFF500FAFF00FAFF00FAFF00FAFF00EBFF00DCFF00DCFF00CCFF00
9EFF0005FF008FFF009EFF0080FF0070FF0000FF2800FF4723FF0061FF0080FF0061FF00
70FF00AEFF00BDFF00DCFF00EBFF00EBFF00FAFF00FAFF00FFF500FFF500FFF500FFF500
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF500
FFF500FFE600FFE600FFE600FFD700FFD700FFC700FFC700FFC700FFC700FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFA800FFA800FFB800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFD700FFD700FFE600FFE600FFF500
FFF500FFF500FFF500FFF500FFF500FFF500FFF500FFF500FAFF00FAFF00FAFF00FAFF00
FAFF00EBFF00EBFF00DCFF00CCFF00BDFF0080FF0000FF3880FF009EFF0080FF0023FF00
80FF00CCFF00DCFF00EBFF00FAFF00FAFF00FAFF00FFF500FFF500FFF500FFF500FFF500
FFF500FFF500FFF500FFF500FFF500FFF500FAFF00FAFF00FAFF00EBFF00DCFF00CCFF00
8FFF0000FF389EFF00AEFF00AEFF008FFF0051FF0000FF1961FF0080FF009EFF0080FF00
51FF009EFF00BDFF00DCFF00DCFF00EBFF00FAFF00FAFF00FFF500FFF500FFF500FFF500
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF500EBFF00
FFF500FFF500FFE600FFE600FFD700FFD700FFC700FFC700FFC700FFC700FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFD700FFD700FFE600FFF500FAFF00
FFF500FFF500FFF500FFF500FFF500FAFF00FAFF00FAFF00FAFF00FAFF00FAFF00FAFF00
EBFF00EBFF00EBFF00CCFF00CCFF00AEFF0061FF0000FF478FFF00AEFF009EFF0070FF00
42FF00CCFF00DCFF00EBFF00FAFF00FAFF00FFF500FFF500FFF500FFF500FFF500FFF500
FFF500FFF500FFF500FFF500FFF500FFF500FFF500FAFF00FAFF00EBFF00DCFF00BDFF00
8FFF0023FF00AEFF00BDFF00AEFF009EFF0070FF0033FF0042FF009EFF009EFF008FFF00
00FF669EFF00BDFF00CCFF00DCFF00EBFF00FAFF00FAFF00FFF500FFF500FFF500FFF500
FFF500FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF500FFF500FFF5008FFF00
FAFF00FFF500FAFF00EBFF00FFE600FFD700FFD700FFC700FFC700FFC700FFC700FFC700
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFD700FFE600FFE600FFF500DCFF00
FAFF00FAFF00FFF500FAFF00FFF500FAFF00FAFF00FAFF00FAFF00FAFF00FAFF00FAFF00
EBFF00EBFF00DCFF00CCFF00BDFF00AEFF0000FF4700FF199EFF00AEFF00AEFF0070FF00
000AFFBDFF00EBFF00EBFF00FAFF00FAFF00FFF500FFF500FFF500FFF500FFF500FFF500
FFF500FFF500FFF500FFF500FFF500FFF500FFF500FAFF00FAFF00EBFF00CCFF0000FF0A
42FF008FFF00BDFF00BDFF00BDFF00AEFF0070FF0061FF0061FF00AEFF00AEFF009EFF00
61FF0080FF00AEFF00CCFF00DCFF00EBFF00EBFF00FAFF00FAFF00FFF500FFF500FFF500
FFF500FFF500FFE600FFE600FFE600FFE600FFF500FFE600FFF500FFF500FAFF008FFF00
DCFF00FAFF009EFF008FFF00FAFF00FFD700FFD700FFC700FFC700FFC700FFC700FFC700
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FF9900FF9900FF9900FFA800FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700
FFC700FFC700FFC700FFD700FFC700FFD700FFD700FFD700FFD700FFE600FAFF00AEFF00
EBFF00FAFF00FAFF00FAFF00FAFF00FAFF00FAFF00FAFF00FAFF00FAFF00FAFF00EBFF00
EBFF00EBFF00DCFF00CCFF00AEFF009EFF0061FF0061FF00AEFF00BDFF00BDFF0051FF00
61FF00BDFF00EBFF00FAFF00FAFF00FFF500FFF500FFF500FFF500FFF500FFF500FFF500
FFF500FFE600FFF500FFF500FFF500FFF500FFF500FAFF00FAFF00EBFF00DCFF0080FF00
33FF00AEFF00CCFF00CCFF00CCFF00AEFF0070FF0070FF009EFF00BDFF00BDFF00AEFF00
70FF0051FF009EFF00BDFF00DCFF00EBFF00EBFF00FAFF00FAFF00FFF500FFF500FFF500
FFF500FFF500FFF500FFE600FFE600FFE600FFF500FFF500FFF500FFF500FAFF00CCFF00
BDFF00DCFF0080FF00EBFF00FFF500FFD700FFD700FFC700FFC700FFC700FFC700FFC700
FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFD700FFE600FFE600FAFF0080FF00
DCFF00EBFF00FAFF00FAFF00FAFF00FAFF00FAFF00EBFF00FAFF00EBFF00EBFF00EBFF00
EBFF00EBFF00DCFF00BDFF0080FF008FFF0014FF008FFF00AEFF00CCFF00CCFF00BDFF00
AEFF0061FF00EBFF00FAFF00FFF500FFF500FFF500FFF500FFF500FFF500FFE600FFE600
FFE600FFE600FFE600FFF500FFF500FFF500FFF500FFF500FAFF00EBFF00DCFF008FFF00
00FF66BDFF00CCFF00DCFF00CCFF008FFF0023FF0080FF00AEFF00BDFF00CCFF00BDFF00
05FF0000FF1942FF00BDFF00CCFF00DCFF00EBFF00FAFF00FAFF00FAFF00FAFF00FFF500
FFF500FFF500FFF500FFF500FFF500FFF500FFF500FFF500FFF500FAFF00EBFF00CCFF00
70FF009EFF0005FF00FAFF00FFF500FFE600FFD700FFD700FFC700FFC700FFC700FFC700
FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFD700FFE600FFE600FAFF00BDFF00
61FF00EBFF00EBFF00EBFF00EBFF00EBFF00EBFF00EBFF00EBFF00EBFF00EBFF00EBFF00
EBFF00DCFF00DCFF00BDFF0000FF1961FF0000FF198FFF00BDFF00CCFF00CCFF00CCFF00
CCFF00BDFF00EBFF00FAFF00FFF500FFF500FFF500FFF500FFF500FFE600FFE600FFE600
FFE600FFE600FFE600FFF500FFE600FFF500FFF500FFF500FAFF00FAFF00DCFF0051FF00
70FF00BDFF00DCFF00DCFF00CCFF0070FF0070FF0042FF00AEFF00CCFF00CCFF00BDFF00
9EFF0000FF1961FF00AEFF00CCFF00CCFF00DCFF00EBFF00EBFF00FAFF00FFF500FFF500
FFF500FFF500FFF500FFF500FFF500FFF500FFF500FFF500FAFF00FAFF00EBFF00CCFF00
00FF9400FF199EFF00FAFF00FFE600FFE600FFD700FFD700FFC700FFC700FFC700FFC700
FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFD700FFE600FFE600FFF500CCFF00
AEFF00DCFF00EBFF00EBFF00EBFF00EBFF00DCFF00EBFF00EBFF00EBFF00EBFF00EBFF00
EBFF00DCFF00CCFF00BDFF0080FF0000FF7500FF3842FF00BDFF00CCFF00DCFF00DCFF00
DCFF00DCFF00FAFF00FAFF00FFF500FFF500FFF500FFE600FFF500FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFF500FFE600FFF500FFF500FAFF00EBFF00DCFF008FFF00
70FF00DCFF00EBFF00EBFF00DCFF00CCFF0000FF4761FF00BDFF00CCFF00DCFF00CCFF00
BDFF009EFF0000FF199EFF00AEFF0005FF00CCFF00EBFF00EBFF00FAFF00FAFF00FFF500
FFF500FFF500FFF500FFF500FFF500FFF500FFF500FAFF00EBFF00EBFF00DCFF008FFF00
9EFF00CCFF00DCFF00FAFF00FFE600FFE600FFD700FFD700FFD700FFC700FFC700FFC700
FFC700FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFA800FFB800FFA800FFA800
FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700
FFC700FFC700FFC700FFD700FFD700FFD700FFD700FFD700FFE600FFE600FAFF00DCFF00
42FF00CCFF00DCFF00CCFF00DCFF00CCFF0051FF00DCFF00EBFF00EBFF00EBFF00EBFF00
DCFF00DCFF00CCFF00AEFF0080FF0000FF7551FF008FFF00CCFF00CCFF00DCFF00EBFF00
EBFF00EBFF00FAFF00FFF500FFF500FFF500FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFF500FFF500FFF500FAFF00DCFF0033FF00
AEFF00EBFF00EBFF00EBFF00EBFF00DCFF008FFF0042FF00CCFF00DCFF00DCFF00DCFF00
CCFF00AEFF0000FF288FFF008FFF0080FF00CCFF00DCFF00DCFF00FAFF00FAFF00FAFF00
FAFF00FFF500FFF500FFF500FFF500FFF500FAFF00EBFF00BDFF00DCFF00CCFF0051FF00
BDFF00DCFF00EBFF00FFF500FFE600FFE600FFD700FFD700FFD700FFD700FFC700FFC700
FFC700FFC700FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFD700FFD700FFD700FFD700FFE600FFF500FAFF00DCFF00
14FF009EFF00BDFF008FFF00BDFF00AEFF009EFF00DCFF00DCFF00EBFF00DCFF00DCFF00
DCFF00DCFF00CCFF008FFF0014FF0000FFE100FFB3AEFF00CCFF00DCFF00EBFF00EBFF00
EBFF00FAFF00FAFF00FFF500FFF500FFF500FFE600FFF500FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFF500FFF500FFF500EBFF00BDFF008FFF00
DCFF00EBFF00FAFF00FAFF00EBFF00DCFF009EFF00AEFF00CCFF00DCFF00EBFF00DCFF00
CCFF00BDFF008FFF0070FF0070FF0070FF00BDFF00BDFF00BDFF00EBFF00FAFF00FAFF00
FAFF00FFF500FFF500FFF500FAFF00FAFF00FAFF00EBFF009EFF00CCFF00CCFF0000FF66
BDFF00EBFF00FAFF00FFF500FFE600FFE600FFD700FFD700FFD700FFD700FFD700FFD700
FFC700FFC700FFC700FFC700FFC700FFB800FFB800FFB800FFB800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFD700FFE600FFE600EBFF0061FF00
80FF0051FF009EFF0061FF00AEFF0042FF00AEFF00CCFF00DCFF00DCFF00DCFF00DCFF00
DCFF00CCFF00CCFF009EFF0070FF0051FF0042FF00AEFF00CCFF00DCFF00EBFF00EBFF00
FAFF00FAFF00FFF500FFF500FFF500FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF500FFF500EBFF0000FF4733FF00
EBFF00FAFF00FAFF00FAFF00FAFF00DCFF009EFF00CCFF00DCFF00EBFF00EBFF00DCFF00
DCFF00BDFF0000FF6600FF0A33FF0061FF00AEFF0042FF00BDFF00EBFF00FAFF00FAFF00
FAFF00FAFF00FAFF00FAFF00FAFF00FAFF00EBFF00DCFF0000FF38AEFF00AEFF0051FF00
CCFF00EBFF00FAFF00FFF500FFE600FFE600FFE600FFD700FFD700FFD700FFD700FFD700
FFC700FFC700FFC700FFC700FFC700FFB800FFB800FFB800FFB800FFA800FFB800FFA800
FFA800FFA800FFA800FFA800FFA800FF9900FF9900FFA800FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFC700FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFD700FFE600FFE600DCFF008FFF00
BDFF0000FF9423FF0000FF1970FF0033FF00AEFF00CCFF00DCFF00DCFF00DCFF00DCFF00
DCFF00CCFF00BDFF00AEFF0070FF0070FF0080FF0080FF00DCFF00EBFF00EBFF00FAFF00
FAFF00FFF500FFF500FFF500FFF500FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF500BDFF00DCFF00CCFF00
FAFF00FAFF00FFF500FAFF00FAFF00DCFF009EFF00CCFF00EBFF00EBFF00EBFF00EBFF00
DCFF00BDFF0000FF4780FF0000FF7551FF0080FF0042FF00CCFF00EBFF00EBFF00FAFF00
FAFF00FAFF00FAFF00FAFF00FAFF00FAFF00EBFF00DCFF00AEFF0061FF008FFF008FFF00
CCFF00EBFF00FAFF00FFF500FFF500FFE600FFE600FFE600FFD700FFD700FFD700FFD700
FFD700FFD700FFD700FFD700FFC700FFC700FFB800FFB800FFB800FFB800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00
FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFD700FFD700FFD700FFD700FFD700FFE600FFE600FAFF00DCFF00
DCFF00BDFF008FFF0070FF0000FFD170FF00AEFF00CCFF00CCFF00DCFF00DCFF00DCFF00
CCFF00CCFF00BDFF00AEFF0070FF0080FF00AEFF00BDFF00DCFF00EBFF00EBFF00FAFF00
FAFF00FAFF00FFF500FFF500FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF500FFF500FAFF00FAFF00
FAFF00FFF500FFF500FFF500FAFF00DCFF00DCFF00DCFF00FAFF00FAFF00FAFF00EBFF00
DCFF009EFF009EFF008FFF0000FF4723FF0014FF009EFF00CCFF00EBFF00EBFF00EBFF00
FAFF00FAFF00FAFF00FAFF00FAFF00EBFF00DCFF00DCFF00BDFF0061FF0000FF94AEFF00
CCFF00EBFF00FAFF00FFF500FFF500FFE600FFE600FFE600FFD700FFD700FFD700FFD700
FFD700FFD700FFD700FFE600FFD700FFC700FFB800FFB800FFB800FFB800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00
FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FFA800FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFD700FFD700FFD700FFD700FFE600FFF500FFF500FAFF00
EBFF00CCFF00AEFF0070FF0000FF388FFF00AEFF00BDFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00BDFF009EFF0033FF0080FF00BDFF00CCFF00DCFF00EBFF00EBFF00FAFF00
FAFF00FFF500FFF500FFF500FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFD700FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF500FFF500FFF500
FFF500FFF500FFF500FFF500FFF500FAFF00FAFF00FAFF00FAFF00FAFF00FAFF00FAFF00
EBFF009EFF00CCFF00AEFF0005FF008FFF0005FF00AEFF00CCFF00DCFF00EBFF00EBFF00
EBFF00FAFF00FAFF00FAFF00EBFF00DCFF00CCFF00CCFF00AEFF0070FF008FFF00BDFF00
DCFF00EBFF00EBFF00FFF500FFF500FFE600FFE600FFE600FFE600FFD700FFE600FFD700
FFD700FFE600FFE600CCFF00FFD700FFC700FFC700FFB800FFB800FFB800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00
FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFD700FFD700FFD700FFD700FFE600FFF500FFF500FAFF00
EBFF00DCFF00AEFF0070FF0000FF478FFF00AEFF00BDFF00CCFF00CCFF00CCFF00CCFF00
CCFF00BDFF00BDFF009EFF0000FF578FFF00BDFF00CCFF00DCFF00EBFF00FAFF00FAFF00
FAFF00FFF500FFF500FFF500FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD700
FFD700FFD700FFE600FFD700FFE600FFE600FFE600FFE600FFE600FFE600FFF500FFF500
FFF500FFF500FFF500FFF500FFF500FFF500FFF500FAFF00FFF500FAFF00FAFF00FAFF00
EBFF00DCFF00DCFF00BDFF0033FF009EFF0000FF57AEFF00CCFF00DCFF00EBFF00EBFF00
EBFF00EBFF00EBFF00EBFF00EBFF00CCFF00BDFF00BDFF009EFF0000FF389EFF00BDFF00
CCFF00EBFF00FAFF00FAFF00FFF500FFF500FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFF500EBFF00FFE600FFD700FFC700FFB800FFB800FFB800FFB800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFD700FFD700FFD700FFD700FFE600FFE600FFF500FAFF00
FAFF00DCFF0061FF0014FF0033FF008FFF00AEFF00AEFF00BDFF00BDFF00BDFF00BDFF00
BDFF00BDFF00AEFF008FFF0014FF0080FF00BDFF00CCFF00DCFF00EBFF00FAFF00FAFF00
FFF500FFF500FFF500FFE600FFE600FFE600FFE600FFE600FFE600FFD700FFD700FFD700
FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFF500FFF500FFF500FFF500FFF500FFF500FAFF00FAFF00
FAFF00EBFF00DCFF00BDFF00BDFF00AEFF0070FF009EFF00BDFF00CCFF00DCFF00EBFF00
EBFF00EBFF00EBFF00EBFF00DCFF00AEFF00AEFF00AEFF0000FF5714FF009EFF00BDFF00
CCFF00DCFF00EBFF00FAFF00FFF500FFF500FFE600FFF500FFE600FFE600FFE600FFE600
FFF500FAFF00FAFF00CCFF00FFF500FFE600FFC700FFC700FFB800FFB800FFB800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFD700FFD700FFD700FFD700FFD700FFE600FFE600FFF500FFF500
FAFF00CCFF0061FF0061FF0033FF0080FF009EFF00AEFF00AEFF00BDFF00AEFF009EFF00
AEFF00AEFF009EFF008FFF0000FF0A8FFF00BDFF00CCFF00DCFF00EBFF00FAFF00FAFF00
FFF500FFF500FFE600FFE600FFE600FFE600FFE600FFE600FFD700FFD700FFD700FFD700
FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFF500FFF500FFF500FFF500FFF500FFF500FFF500
FAFF00FAFF00EBFF00DCFF00CCFF00BDFF0080FF0033FF00AEFF00CCFF00DCFF00DCFF00
EBFF00EBFF00DCFF00DCFF00DCFF008FFF008FFF008FFF0061FF0061FF008FFF00AEFF00
BDFF00CCFF00DCFF00FAFF00FAFF00FFF500FFF500FFE600FFE600FFE600FFE600FFF500
FAFF00EBFF0070FF00BDFF00CCFF0070FF00FFD700FFC700FFB800FFB800FFB800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00
FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFD700FFE600FFD700FFD700FFE600FFE600FFF500FFF500
FAFF00EBFF00BDFF009EFF0033FF0061FF0080FF009EFF008FFF00AEFF009EFF0070FF00
AEFF00AEFF009EFF0080FF0051FF009EFF00BDFF00CCFF00DCFF00EBFF00FAFF00FAFF00
FFF500FFF500FFE600FFE600FFE600FFE600FFE600FFE600FFD700FFE600FFD700FFD700
FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF500FFF500FFF500FFF500FFF500
FAFF00FAFF00EBFF00EBFF00DCFF00CCFF0080FF0000FF6600FF57BDFF00DCFF00DCFF00
DCFF00DCFF00DCFF00DCFF00CCFF009EFF0061FF0051FF0014FF0061FF0080FF009EFF00
70FF0070FF00BDFF00EBFF00FAFF00FAFF00FFF500FFF500FFF500FFE600FFF500FFF500
EBFF00BDFF008FFF0070FF0080FF00AEFF00FFD700FFC700FFB800FFB800FFB800FFB800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFD700FFD700FFD700FFD700FFE600FFE600FFF500FFF500
FAFF00EBFF00DCFF00AEFF0033FF0000FF0A23FF008FFF0014FF008FFF0080FF0051FF00
9EFF009EFF0061FF0061FF0023FF008FFF00AEFF00BDFF00DCFF00EBFF00FAFF00FAFF00
FFF500FFF500FFE600FFE600FFE600FFE600FFD700FFD700FFD700FFD700FFD700FFD700
FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF500FFF500FFF500
FFF500FAFF00FAFF00EBFF00DCFF00CCFF00BDFF0070FF0080FF00BDFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF0080FF0033FF0023FF0000FF6600FF0A42FF0080FF00
00FF0A61FF00BDFF00EBFF00EBFF00EBFF00FFF500FFF500FFF500FFF500FFF500FAFF00
CCFF008FFF00CCFF00EBFF00FAFF00FFE600FFD700FFC700FFB800FFB800FFB800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFC700FFB800FFB800FFB800FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFD700FFD700FFD700FFD700FFE600FFE600FFF500FFF500
FAFF00EBFF00DCFF009EFF0051FF0080FF0000FF1970FF0033FF0080FF0042FF0000FF47
8FFF008FFF0033FF0000FF0A61FF0042FF0080FF00BDFF00CCFF00EBFF00FAFF00FAFF00
FFF500FFF500FFE600FFE600FFE600FFE600FFD700FFD700FFD700FFD700FFD700FFD700
FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700
FFD700FFD700FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF500FFF500
FFF500FAFF00FAFF00EBFF00EBFF00DCFF00BDFF009EFF0000FF47AEFF00BDFF00BDFF00
BDFF0042FF00CCFF00CCFF00BDFF008FFF0023FF0000FF94FF000000FF2805FF0061FF00
00FF388FFF00BDFF00DCFF00DCFF0061FF00FAFF00FFF500FFF500FFF500FAFF00EBFF00
23FF00CCFF00EBFF00FFF500FFE600FFE600FFD700FFC700FFB800FFB800FFB800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFD700FFD700FFD700FFD700FFD700FFE600FFE600FFE600FFE600FFF500
FAFF00FAFF00DCFF0014FF009EFF008FFF0000FF4700FF0A00FF6661FF0042FF0051FF00
80FF0070FF0000FF8551FF008FFF0061FF0033FF009EFF0000FF47DCFF00EBFF00FAFF00
FFF500FFE600FFE600FFE600FFE600FFD700FFE600FFD700FFD700FFD700FFD700FFD700
FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700
FFD700FFD700FFD700FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF500
FFF500FFF500FAFF00EBFF00EBFF00DCFF00CCFF00AEFF0000FF389EFF00AEFF00AEFF00
AEFF008FFF00BDFF00BDFF00BDFF008FFF0033FF0000FFFFFF0000FF000000FF4705FF00
33FF008FFF00BDFF00CCFF009EFF00CCFF00FAFF00FAFF00FAFF00FAFF00FAFF00EBFF00
8FFF00CCFF00FAFF00FFF500FFE600FFE600FFD700FFC700FFB800FFB800FFB800FFB800
FFB800FFA800FFA800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFD700FFD700FFD700FFD700FFD700FFE600FFE600FFF500FFF500
FAFF00FAFF00EBFF00BDFF00BDFF00AEFF0080FF0042FF0000FF1914FF0023FF0042FF00
70FF0042FF0061FF008FFF009EFF008FFF0033FF0061FF0061FF00BDFF00EBFF00FAFF00
FFF500FFF500FFE600FFE600FFE600FFD700FFD700FFD700FFD700FFD700FFD700FFD700
FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700
FFD700FFD700FFD700FFD700FFD700FFD700FFE600FFE600FFE600FFE600FFE600FFF500
FFF500FFF500FAFF00FAFF00EBFF00DCFF00CCFF00AEFF0051FF0080FF0070FF0080FF00
61FF0080FF00AEFF00AEFF00AEFF0070FF0000FF28FF0000FF0000FF000000F0FF00A3FF
00FF1933FF008FFF00BDFF0080FF00CCFF00EBFF00FAFF00FAFF00FAFF00EBFF00DCFF00
9EFF009EFF00FAFF00FFF500FFE600FFD700FFC700FFC700FFB800FFB800FFB800FFB800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFD700FFD700FFD700FFD700FFE600FFE600FFE600FFF500FFF500
FAFF00FAFF00EBFF00DCFF00BDFF00AEFF008FFF0070FF0033FF0000FF2800FF6614FF00
51FF0000C2FF80FF009EFF00AEFF009EFF0070FF0042FF0070FF0000FFA3EBFF00FAFF00
FFF500FFE600FFE600FFE600FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700
FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700
FFD700FFD700FFD700FFD700FFE600FFD700FFD700FFE600FFE600FFE600FFE600FFF500
FFF500FFF500FAFF00FAFF00EBFF00DCFF00CCFF009EFF0051FF0042FF0023FF0042FF00
00FF2851FF008FFF00AEFF009EFF0080FF0000FF66FF0000FF0000FF0000BD00FFFF0000
00FF8500FFA305FF009EFF0070FF00CCFF00EBFF00EBFF00FAFF00EBFF00EBFF00DCFF00
8FFF00CCFF00FFF500FFE600FFD700FFD700FFC700FFC700FFB800FFB800FFB800FFB800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFB800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFD700FFD700FFD700FFD700FFE600FFE600FFE600FFF500FFF500
FAFF00FAFF00EBFF00DCFF00CCFF00AEFF008FFF0070FF0014FF0000FF660075FF00FF66
23FF0023FF008FFF00AEFF00BDFF00BDFF00AEFF008FFF0000FFA39EFF00DCFF00FAFF00
FFF500FFE600FFE600FFE600FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700
FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700
FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFE600FFE600FFE600FFE600FFE600
FFF500FFF500FAFF00FAFF00EBFF00DCFF00CCFF0042FF008FFF008FFF008FFF0070FF00
51FF0080FF0005FF008FFF008FFF0070FF0000FF28FF0000FF0000FF0000FF0000FF0000
00E1FF00FF0A00FF2851FF008FFF00CCFF00DCFF00EBFF00EBFF00EBFF009EFF00BDFF00
23FF00EBFF00FFF500FFE600FFD700FFD700FFC700FFC700FFB800FFB800FFB800FFB800
FFA800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFC700
FFC700FFD700FFD700FFD700FFD700FFD700FFD700FFE600FFE600FFE600FFF500FFF500
FAFF00EBFF00EBFF00DCFF00CCFF00AEFF0070FF0061FF0000FF9400FFFFFF000000D1FF
00FF5733FF0070FF00BDFF00BDFF00CCFF00CCFF008FFF0080FF0005FF00BDFF00DCFF00
FFF500FFE600FFE600FFE600FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700
FFD700FFD700FFC700FFD700FFD700FFC700FFD700FFD700FFD700FFD700FFD700FFD700
FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFE600FFE600FFE600FFE600
FFF500FFF500FFF500FAFF00EBFF00CCFF00BDFF0005FF00AEFF00BDFF00AEFF009EFF00
80FF009EFF0080FF0061FF0051FF0061FF0005FF00FF0000FF0000FF0000FF0000FF0000
00FF9405FF0080FF0080FF008FFF00BDFF00DCFF00DCFF00EBFF00DCFF00AEFF0033FF00
70FF00EBFF00FFF500FFE600FFD700FFD700FFC700FFC700FFB800FFB800FFB800FFB800
FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFD700FFD700FFD700FFD700FFD700FFE600FFE600FFE600FFF500FFF500
FAFF00EBFF00EBFF00DCFF00CCFF009EFF0000FF7533FF0000FF380028FFFF00000500FF
00FF0A70FF0080FF00BDFF00CCFF00CCFF00CCFF00AEFF00BDFF00AEFF0080FF00EBFF00
FFF500FFE600FFE600FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700
FFC700FFD700FFC700FFC700FFC700FFC700FFD700FFC700FFD700FFC700FFD700FFD700
FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFE600FFE600FFE600
FFF500FFF500FFF500FAFF00EBFF0061FF009EFF0023FF00BDFF00CCFF00BDFF00BDFF00
BDFF00BDFF009EFF0033FF0033FF0000FF1900F0FFFF0000FF0000FF0000FF00000094FF
05FF0000FFD19EFF009EFF0000FF19AEFF00BDFF00CCFF00DCFF00CCFF0023FF00BDFF00
BDFF00AEFF00FFF500FFE600FFD700FFD700FFC700FFC700FFB800FFB800FFB800FFB800
FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFC700FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFD700FFD700FFD700FFD700FFE600FFE600FFE600FFF500FFF500
FAFF00EBFF00EBFF00DCFF00CCFF00AEFF0042FF0000FF1900E1FFFF006BFF0000FF0000
00FF4770FF009EFF00BDFF00CCFF00DCFF00DCFF00CCFF00DCFF00DCFF0051FF00FAFF00
FFF500FFE600FFE600FFE600FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700
FFC700FFD700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFD700FFC700
FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFE600FFE600FFE600
FFE600FFF500FFF500FAFF00EBFF00BDFF0000FF198FFF00BDFF00DCFF00DCFF00DCFF00
DCFF00CCFF009EFF0080FF008FFF0042FF0042FF00FF0000FF0000FF0000FF000000FF38
14FF008FFF00AEFF00AEFF0080FF008FFF008FFF00AEFF00CCFF00BDFF0042FF00DCFF00
EBFF00CCFF00FFF500FFE600FFD700FFC700FFC700FFC700FFB800FFB800FFB800FFB800
FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFD700FFD700FFD700FFD700FFE600FFE600FFF500FFF500FAFF00
FAFF00EBFF00DCFF00DCFF00CCFF00AEFF0080FF0023FF000085FFFF0000FF0000FF0000
05FF0000FF0AAEFF00CCFF00DCFF00DCFF00EBFF00EBFF00EBFF00EBFF00AEFF00FAFF00
FFE600FFE600FFE600FFD700FFD700FFD700FFD700FFD700FFD700FFC700FFC700FFD700
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700
FFD700FFC700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFE600FFE600
FFE600FFF500FFF500FAFF00EBFF00CCFF0080FF009EFF00CCFF00DCFF00DCFF00DCFF00
DCFF00CCFF009EFF009EFF00AEFF0080FF0061FF00DC00FFFF0000FF000000FFB300FF66
14FF009EFF00BDFF00BDFF00AEFF0000F0FF70FF009EFF00AEFF0000FF199EFF00DCFF00
FAFF00FAFF00FFE600FFE600FFD700FFC700FFC700FFC700FFC700FFB800FFB800FFB800
FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FFA800
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFD700FFD700FFD700FFD700FFD700FFE600FFE600FFF500FAFF00FAFF00
EBFF00EBFF00DCFF00DCFF00CCFF00AEFF0080FF0023FF000019FFFF001EFF00000038FF
00FF2800FFA38FFF00CCFF00DCFF00EBFF00EBFF00EBFF00FAFF00EBFF00EBFF00FFF500
FFE600FFE600FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFC700FFC700FFD700
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFE600FFE600
FFE600FFF500FFF500FAFF00EBFF00BDFF0000FF8561FF00DCFF00EBFF00EBFF00EBFF00
EBFF00DCFF0080FF00AEFF00BDFF00AEFF0033FF0000FFA3FF0000FF000000FF1961FF00
00FF6670FF00CCFF00CCFF00AEFF00AEFF009EFF0000FF198FFF0080FF008FFF00EBFF00
FAFF00FFF500FFE600FFD700FFD700FFD700FFC700FFC700FFC700FFB800FFB800FFB800
FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFD700FFD700FFD700FFD700FFE600FFE600FFF500FFF500FAFF00FAFF00
EBFF00DCFF00DCFF00CCFF00CCFF009EFF0051FF0005FF0000FFF000FFE100FFC200FFE1
33FF0000FF4761FF00CCFF00DCFF00EBFF00EBFF00EBFF00FAFF00FAFF00FAFF00FFF500
FFE600FFE600FFD700FFD700FFD700FFD700FFD700FFD700FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFD700FFD700FFD700FFD700FFD700FFE600FFD700FFE600
FFE600FFF500FAFF00FAFF00EBFF00BDFF0000FF0AAEFF00DCFF00EBFF00EBFF00EBFF00
EBFF00DCFF009EFF00BDFF00CCFF00BDFF008FFF0033FF0000FF280085FF33FF0080FF00
00FF19AEFF00CCFF00DCFF00CCFF00CCFF00BDFF00AEFF0070FF00BDFF00CCFF00FAFF00
FAFF00FFF500FFE600FFD700FFD700FFC700FFC700FFC700FFC700FFB800FFB800FFB800
FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFD700FFD700FFD700FFD700FFD700FFE600FFF500EBFF00EBFF00EBFF00
DCFF00DCFF00DCFF00CCFF00BDFF009EFF0051FF0023FF0005FF0000FF3800FFE100FF19
61FF008FFF00AEFF00CCFF00DCFF00EBFF00FAFF00FAFF00FAFF00FFF500FFF500FFE600
FFE600FFD700FFD700FFD700FFD700FFD700FFD700FFC700FFC700FFD700FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFD700FFD700FFD700FFD700FFE600
FFE600FFF500FAFF00EBFF00DCFF00BDFF0033FF00BDFF00DCFF00EBFF00FAFF00FAFF00
EBFF00EBFF008FFF00CCFF00DCFF00CCFF008FFF0000FF0A42FF000094FF70FF009EFF00
8FFF008FFF00DCFF00DCFF00DCFF00DCFF00CCFF00AEFF008FFF00CCFF00EBFF00EBFF00
FFF500FFF500FFE600FFD700FFD700FFD700FFC700FFC700FFC700FFB800FFB800FFB800
FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFD700FFD700FFD700FFD700FFE600FFE600FFF500AEFF00DCFF00DCFF00
AEFF00CCFF00CCFF00BDFF00BDFF009EFF0061FF0051FF0051FF0000E1FF00FF0A05FF00
51FF008FFF00AEFF00CCFF00DCFF00EBFF00FAFF00FAFF00FFF500FFF500FFF500FFE600
FFE600FFD700FFD700FFD700FFD700FFD700FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFD700FFD700FFD700FFD700FFE600
FFE600FFF500FAFF00EBFF00CCFF00AEFF008FFF0033FF00EBFF00FAFF00FAFF00FAFF00
FAFF00EBFF00CCFF00EBFF00EBFF00CCFF0042FF0000FF5700FF4751FF0080FF00AEFF00
9EFF00BDFF00DCFF00EBFF00EBFF00EBFF00DCFF00BDFF008FFF00CCFF00EBFF00FAFF00
FFF500FFF500FFE600FFE600FFD700FFD700FFC700FFC700FFC700FFB800FFB800FFB800
FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800
FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFD700FFD700FFD700FFD700FFE600FFF500FFF500CCFF00BDFF00AEFF00
61FF00AEFF00BDFF00BDFF00AEFF008FFF0033FF0070FF0070FF0000FF4761FF0033FF00
14FF0080FF00AEFF00CCFF00DCFF00EBFF00FAFF00FFF500FFF500FFF500FFE600FFE600
FFE600FFD700FFD700FFD700FFD700FFD700FFC700FFD700FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFD700FFC700FFD700FFD700FFD700FFD700FFE600
FFE600FFF500DCFF00CCFF00BDFF008FFF00BDFF00CCFF00EBFF00FAFF00FAFF00FAFF00
FAFF00FAFF00EBFF00EBFF00EBFF00CCFF0051FF00AEFF009EFF0070FF0061FF00BDFF00
CCFF00DCFF00EBFF00EBFF00EBFF00EBFF00DCFF00BDFF0000FF57CCFF00EBFF00FAFF00
FFF500FFF500FFE600FFD700FFD700FFD700FFC700FFC700FFC700FFC700FFB800FFB800
FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFB800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFD700FFD700FFD700FFD700FFD700FFE600FFE600FFF500EBFF0051FF0000FF85
23FF009EFF009EFF009EFF009EFF0070FF0000FFFF80FF0070FF000094FF80FF0023FF00
33FF0042FF009EFF00AEFF00DCFF00EBFF00FAFF00FFF500FFF500FFE600FFE600FFE600
FFD700FFD700FFD700FFD700FFD700FFD700FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFD700FFD700FFE600
FFE600FFF500CCFF0000FF0A51FF0000FF28CCFF00DCFF00FAFF00FAFF00FAFF00FFF500
FFF500FAFF00FAFF00FAFF00FAFF00EBFF00DCFF00CCFF00AEFF0061FF009EFF00CCFF00
DCFF00EBFF00FAFF00FAFF00FAFF00EBFF00DCFF00CCFF0080FF00CCFF00DCFF00FAFF00
FFF500FFE600FFE600FFD700FFD700FFD700FFC700FFC700FFC700FFC700FFB800FFB800
FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFD700FFD700FFD700FFD700FFE600FFE600FFF500EBFF00AEFF00AEFF00
23FF0070FF0023FF0080FF008FFF0042FF0061FF009EFF008FFF0051FF009EFF0033FF00
8FFF0000FF3880FF0033FF00CCFF00EBFF00FAFF00FFF500FFF500FFE600FFE600FFE600
FFD700FFD700FFD700FFD700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFD700FFD700FFE600
FFE600FFF500DCFF00BDFF009EFF0080FF00CCFF00EBFF00FAFF00FAFF00FFF500FFF500
FFF500FFF500FFF500FFF500FAFF00EBFF00EBFF00DCFF00BDFF0070FF009EFF00CCFF00
EBFF00FAFF00FAFF00FAFF00FAFF00FAFF00EBFF00CCFF0080FF00BDFF00DCFF00FAFF00
FFF500FFF500FFE600FFE600FFD700FFD700FFD700FFC700FFC700FFC700FFB800FFB800
FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFD700FFD700FFD700FFD700FFE600FFE600FFF500EBFF00DCFF00CCFF00
14FF0080FF0061FF0000FF5751FF0000FF0A80FF009EFF00AEFF0070FF00AEFF009EFF00
9EFF0000FF0A51FF0080FF00CCFF00EBFF00FAFF00FFF500FFE600FFE600FFE600FFD700
FFD700FFD700FFD700FFD700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFD700FFC700FFD700FFD700FFD700FFD700
FFE600FFF500FAFF00DCFF00BDFF0033FF00BDFF00EBFF00FAFF00FFF500FFF500FFF500
FFF500FFF500FFF500FFF500FAFF00FAFF00EBFF00DCFF00AEFF0070FF0061FF00CCFF00
EBFF00FAFF00FAFF00FAFF00FAFF00FAFF00EBFF00CCFF0080FF009EFF00CCFF00FAFF00
FFF500FFF500FFE600FFE600FFE600FFD700FFC700FFC700FFC700FFC700FFC700FFB800
FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFD700FFD700FFD700FFD700FFE600FFE600FFF500FAFF00EBFF00DCFF00
BDFF00AEFF0080FF008FFF0070FF0070FF009EFF00AEFF00BDFF00BDFF00BDFF00AEFF00
AEFF008FFF0005FF009EFF00CCFF00EBFF00FAFF00FFF500FFE600FFE600FFE600FFD700
FFD700FFD700FFD700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFD700FFD700
FFE600FFE600FAFF00EBFF00BDFF0061FF0070FF00EBFF00FAFF00FFF500FFF500FFE600
FFE600FFF500FFF500FFF500FFF500FAFF00EBFF00DCFF009EFF00AEFF0023FF00BDFF00
FAFF00FAFF00FFF500FFF500FFF500FAFF00FAFF00BDFF00BDFF0000FF28BDFF00EBFF00
FAFF00FFF500FFE600FFE600FFD700FFD700FFD700FFC700FFC700FFC700FFC700FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700
FFD700FFD700FFD700FFD700FFD700FFE600FFE600FFE600FFF500FFF500FAFF00EBFF00
DCFF00CCFF00BDFF00AEFF008FFF0051FF00AEFF00BDFF00BDFF00CCFF00CCFF00CCFF00
BDFF009EFF0023FF008FFF009EFF00EBFF00FAFF00FFF500FFE600FFE600FFD700FFD700
FFD700FFD700FFD700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFD700
FFE600FFE600FFF500EBFF00AEFF0000FF47AEFF00EBFF00FFF500FFF500FFE600FFE600
FFE600FFE600FFE600FFF500FFF500FAFF00FAFF00DCFF0080FF00BDFF00CCFF00CCFF00
FAFF00FFF500FFF500FFF500FFF500FFF500FAFF00EBFF00CCFF0070FF008FFF00BDFF00
FAFF00FFF500FFE600FFE600FFE600FFD700FFD700FFC700FFC700FFC700FFC700FFC700
FFB800FFB800FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFD700FFD700FFD700FFD700FFD700FFE600FFE600FFF500FFF500FAFF00FAFF00
EBFF00DCFF00CCFF00BDFF008FFF0033FF00AEFF00BDFF00CCFF00CCFF00CCFF00CCFF00
BDFF009EFF0000FF8542FF0042FF00DCFF00FAFF00FFF500FFE600FFE600FFE600FFD700
FFD700FFD700FFD700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFB800FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFD700
FFE600FFE600FFF50061FF0080FF0070FF00CCFF00FAFF00FFF500FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFF500FFF500FAFF00DCFF0033FF00CCFF00EBFF00EBFF00
FFF500FFF500FFF500FFF500FFF500FFF500FAFF00FAFF00DCFF00BDFF0000FF38CCFF00
FAFF00FFF500FFF500FFE600FFE600FFD700FFD700FFD700FFC700FFC700FFC700FFC700
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFD700FFD700FFD700FFD700FFD700FFE600FFE600FFE600FFF500FAFF00FAFF00
EBFF00DCFF00CCFF00BDFF0080FF0005FF00AEFF00CCFF00CCFF00DCFF00DCFF00CCFF00
CCFF0070FF0061FF0014FF00AEFF00EBFF00FAFF00FFF500FFE600FFE600FFD700FFD700
FFD700FFD700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFB800FFB800FFC700FFB800FFB800FFC700FFB800FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFD700FFD700
FFD700FFE600FFF500EBFF0061FF00AEFF00DCFF00FAFF00FFF500FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFF500FFF500FAFF00DCFF0080FF00DCFF00FAFF00FAFF00
FFF500FFF500FFE600FFF500FFF500FFF500FFF500FAFF00EBFF00CCFF0005FF00DCFF00
FAFF00FAFF00FFF500FFE600FFE600FFD700FFD700FFD700FFC700FFC700FFC700FFC700
FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFC700FFB800FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFD700FFD700FFD700FFD700FFE600FFE600FFE600FFE600FFF500FFF500FAFF00
EBFF00EBFF00DCFF00BDFF009EFF0070FF00AEFF00CCFF00DCFF00DCFF00DCFF00DCFF00
CCFF0061FF008FFF0061FF00AEFF00DCFF00FAFF00FFF500FFE600FFD700FFD700FFD700
FFD700FFD700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFB800FFC700FFC700FFB800FFB800FFC700FFB800FFB800FFC700FFB800FFB800
FFC700FFB800FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFD700FFD700
FFE600FFE600FFF500EBFF00BDFF009EFF00DCFF00FFF500FFF500FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFF500FAFF00CCFF0014FF00DCFF00FAFF00FFF500
FFF500FFE600FFE600FFE600FFE600FFF500FFF500FAFF00FAFF00DCFF0061FF00CCFF00
EBFF00FAFF00FFF500FFF500FFE600FFE600FFD700FFD700FFD700FFC700FFC700FFC700
FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800
FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800
FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFD700FFD700FFD700FFD700FFD700FFE600FFE600FFE600FFF500FFF500FAFF00
FAFF00EBFF00DCFF00BDFF009EFF0042FF00BDFF00CCFF00DCFF00DCFF00EBFF00DCFF00
DCFF0042FF00BDFF0000FFD100FF57CCFF00EBFF00FFF500FFE600FFE600FFD700FFD700
FFD700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFD700
FFD700FFE600FFF500EBFF00BDFF009EFF009EFF00FFF500FFE600FFE600FFD700FFD700
FFD700FFE600FFE600FFE600FFE600FFF500EBFF008FFF0080FF00DCFF00FFF500FFF500
FFE600FFE600FFE600FFE600FFE600FFE600FFF500FFF500FAFF00DCFF009EFF00CCFF00
DCFF00EBFF00EBFF00FAFF00FFF500FFE600FFE600FFD700FFD700FFD700FFC700FFC700
FFC700FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFA800FFA800
FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFD700
FFD700FFD700FFD700FFD700FFD700FFD700FFE600FFE600FFE600FFF500FFF500FAFF00
FAFF00EBFF00DCFF00BDFF008FFF0000FF759EFF00DCFF00DCFF00EBFF00EBFF00EBFF00
DCFF00CCFF00CCFF00AEFF0023FF00AEFF00AEFF00FFF500FFE600FFD700FFD700FFD700
FFD700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFB800FFC700
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFC700FFB800FFC700FFC700FFC700FFC700FFC700FFC700FFD700FFD700
FFD700FFE600FFF500EBFF0080FF00DCFF00DCFF00FFF500FFE600FFE600FFD700FFD700
FFD700FFD700FFD700FFD700FFE600FFF500DCFF00AEFF00CCFF00BDFF00FFF500FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFF500FFF500FAFF00DCFF009EFF00AEFF00
CCFF00DCFF00CCFF00DCFF00FFF500FFF500FFE600FFD700FFD700FFD700FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFB800FFB800FFB800FFB800FFA800FFA800FFA800
FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700
FFD700FFD700FFD700FFD700FFD700FFE600FFE600FFE600FFE600FFF500FFF500FAFF00
FAFF00EBFF00DCFF008FFF0051FF0061FF00BDFF00DCFF00EBFF00DCFF00EBFF00EBFF00
EBFF00EBFF00EBFF00DCFF00CCFF0042FF00DCFF00FFF500FFE600FFD700FFD700FFD700
FFD700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFC700FFB800FFB800FFC700FFC700FFC700FFC700FFC700FFD700FFD700
FFD700FFE600FFF500EBFF0042FF00EBFF00FAFF00FFE600FFE600FFD700FFD700FFD700
FFD700FFD700FFD700FFD700FFE600FFF500DCFF00DCFF00EBFF008FFF00FFF500FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF500FAFF00BDFF008FFF0014FF00
8FFF00BDFF0061FF00DCFF00FAFF00FFF500FFF500FFE600FFD700FFD700FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFA800FFA800
FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700
FFD700FFD700FFD700FFD700FFD700FFD700FFE600FFE600FFE600FFF500FFF500FAFF00
FAFF00EBFF00DCFF00BDFF0042FF0033FF00BDFF00DCFF00EBFF00EBFF00FAFF00FAFF00
FAFF00FAFF00FAFF00EBFF00DCFF0061FF00FAFF00FFE600FFE600FFD700FFD700FFD700
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFB800FFB800
FFC700FFB800FFB800FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFC700FFB800FFB800FFC700FFC700FFC700FFC700FFC700FFC700FFD700
FFD700FFE600FFF500EBFF0051FF00FAFF00FFF500FFE600FFD700FFD700FFD700FFD700
FFD700FFD700FFD700FFD700FFE600FFF500CCFF00FAFF00FFF50000FF57FFE600FFE600
FFD700FFE600FFD700FFD700FFE600FFE600FFE600FFF500FAFF00AEFF00BDFF008FFF00
70FF0080FF008FFF00DCFF00FAFF00EBFF00EBFF00FFE600FFD700FFD700FFD700FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFB800FFB800FFB800FFA800FFA800
FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700
FFB800FFB800FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFD700FFC700FFC700
FFD700FFD700FFD700FFD700FFD700FFD700FFE600FFE600FFE600FFF500FFF500FAFF00
FAFF00EBFF00DCFF00BDFF0000FFC251FF00AEFF00DCFF00EBFF00EBFF00FAFF00FAFF00
FAFF00FAFF00FAFF00FAFF00EBFF0042FF00FAFF00FFE600FFD700FFD700FFD700FFD700
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFB800FFB800FFC700FFB800FFB800
FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFC700FFD700
FFD700FFE600EBFF00AEFF00AEFF00FAFF00FFE600FFE600FFD700FFD700FFD700FFD700
FFD700FFD700FFD700FFD700FFD700FFF500EBFF00FFF500FFE600FFE600FFE600FFE600
FFD700FFD700FFD700FFD700FFD700FFE600FFE600FFF500FAFF0061FF00DCFF00CCFF00
BDFF0033FF0080FF00CCFF00DCFF00CCFF00DCFF00FFE600FFE600FFD700FFD700FFD700
FFD700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFB800FFA800
FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00
FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFD700FFD700
FFD700FFD700FFD700FFD700FFD700FFE600FFE600FFE600FFE600FFF500FFF500FAFF00
FAFF00EBFF00DCFF00BDFF0033FF009EFF00CCFF00DCFF00EBFF00FAFF00FAFF00FAFF00
FAFF00FAFF00FFF500FAFF00FAFF00BDFF00FAFF00FFE600FFE600FFD700FFD700FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFB800FFB800FFC700FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFC700FFB800FFB800FFC700FFC700FFC700FFC700FFD700
FFD700FFF500CCFF008FFF0023FF00FAFF00FFE600FFD700FFD700FFD700FFD700FFD700
FFD700FFC700FFD700FFD700FFD700FFE600FFE600FFE600FFE600FFE600FFD700FFD700
FFD700FFD700FFD700FFD700FFD700FFE600FFE600FFE600CCFF00BDFF00EBFF00EBFF00
CCFF0070FF0014FF0000FF47CCFF009EFF00EBFF00FFF500FFE600FFD700FFD700FFD700
FFD700FFD700FFD700FFD700FFD700FFD700FFC700FFC700FFC700FFC700FFB800FFA800
FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFD700FFD700
FFD700FFD700FFD700FFD700FFD700FFE600FFE600FFE600FFE600FFF500FFF500FAFF00
EBFF00DCFF00DCFF00BDFF0070FF00AEFF00CCFF00EBFF00EBFF00FAFF00FAFF00FFF500
FAFF00FFF500FFF500FFF500FFF500DCFF00FFF500FFE600FFD700FFD700FFD700FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFB800FFC700FFC700FFC700FFD700
FFD700FFF500AEFF00EBFF00CCFF00EBFF00FFE600FFD700FFD700FFD700FFD700FFC700
FFC700FFC700FFC700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700
FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFE600FAFF00FAFF00FAFF00FAFF00
CCFF008FFF00AEFF009EFF0051FF00AEFF00FAFF00FFF500FFE600FFE600FFD700FFD700
FFD700FFD700FFD700FFD700FFE600DCFF00FFD700FFD700FFD700FFF500FFC700FFA800
FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFA800FFA800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFD700
FFD700FFD700FFD700FFD700FFD700FFE600FFE600FFE600FFE600FFF500FAFF00FAFF00
EBFF00DCFF00DCFF00BDFF0000FF85AEFF00CCFF00EBFF00FAFF00FAFF00FAFF00FFF500
FFF500FFF500FFF500FFF500FFF500FAFF00FFE600FFD700FFD700FFD700FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFB800FFC700FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFC700
FFD700FAFF009EFF00FFF500FAFF008FFF00FFE600FFD700FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFD700FFD700FFD700FFD700FFD700
FFD700FFD700FFD700FFD700FFD700FFD700FFE600FFE600FFF500FFF500FFF500FAFF00
00FF0A80FF00DCFF00CCFF0080FF00CCFF00FAFF00FFF500FFE600FFE600FFE600FFD700
FFD700FFD700FFE600FFE600FFF500EBFF00FFE600FFE600FFF500FAFF00FFC700FFB800
FFA800FFA800FF9900FF9900FFA800FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFD700
FFD700FFD700FFD700FFD700FFE600FFE600FFE600FFE600FFF500FFF500FFF500FAFF00
EBFF00DCFF00CCFF00BDFF0061FF00AEFF00CCFF00EBFF00FAFF00FAFF00FFF500FFF500
FFF500FFF500FFF500FFE600FFE600FFE600FFE600FFD700FFD700FFD700FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700
FFE60070FF00FAFF00FFE600FFE600FAFF00FFD700FFD700FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFD700FFC700FFC700FFC700
FFC700FFC700FFC700FFD700FFD700FFD700FFD700FFE600FFE600FFF500FFF500FFF500
FAFF00EBFF00EBFF00DCFF0080FF00CCFF00FAFF00FFF500FFF500FFE600FFE600FFE600
FFE600FFE600FFE600FFF500FAFF0080FF00FFF500FFF500FAFF00FFE600FFC700FFB800
FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00
FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFB800FFB800
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFD700FFD700
FFD700FFD700FFD700FFD700FFD700FFE600FFE600FFE600FFE600FFF500FAFF00EBFF00
DCFF00CCFF00BDFF00AEFF0080FF008FFF00BDFF00EBFF00FAFF00FAFF00FFF500FFF500
FFF500FFE600FFE600FFE600FFE600FFE600FFD700FFD700FFD700FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFB800FFB800FFC700FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700
FFD700FFF500FFF500FFD700FFD700FFD700FFD700FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFD700FFD700FFD700FFD700FFE600FFE600FFE600FFE600
FFF500FAFF00FAFF00EBFF00BDFF00CCFF00EBFF00FAFF00FFF500FFE600FFE600FFE600
FFE600FFE600FFF5008FFF00EBFF00BDFF00FAFF00EBFF0061FF00FFE600FFC700FFB800
FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00
FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFB800FFA800FFA800FFA800FFA800FFA800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFD700
FFD700FFD700FFD700FFD700FFD700FFE600FFE600FFE600FFF500FFF500FAFF00EBFF00
9EFF00AEFF00AEFF009EFF0051FF0051FF0070FF00EBFF00FAFF00FFF500FFF500FFF500
FFF500FFE600FFE600FFE600FFE600FFE600FFD700FFD700FFD700FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700
FFC700FFD700FFD700FFD700FFD700FFD700FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFE600FFD700FFE600FFE600FFE600
FFF500FFF500FAFF00EBFF00BDFF00AEFF00DCFF00FAFF00FFF500FFF500FFE600FFE600
FFF500FFF500FAFF00CCFF008FFF0061FF00AEFF0051FF00AEFF00FFE600FFC700FFB800
FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFD700
FFD700FFD700FFD700FFE600FFE600FFE600FFE600FFE600FFF500FFF500FAFF00EBFF00
00FF0A61FF0080FF0080FF0023FF00AEFF00AEFF00EBFF00FAFF00FAFF00FFF500FFF500
FFE600FFE600FFE600FFE600FFE600FFD700FFD700FFD700FFC700FFD700FFC700FFC700
FFC700FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFD700FFD700FFE600FFE600
FFE600FFF500FFF500FAFF00BDFF0080FF00BDFF00EBFF00FAFF00FFF500FFF500FFF500
FFF500FFF500EBFF0061FF00DCFF00EBFF00EBFF00EBFF00EBFF00FFE600FFC700FFB800
FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF9900FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFA800FFA800FFA800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFD700
FFD700FFD700FFD700FFD700FFE600FFE600FFE600FFE600FFF500FFF500FAFF00EBFF00
BDFF0042FF0070FF0061FF0051FF00BDFF00CCFF00EBFF00FAFF00FFF500FFF500FFE600
FFE600FFE600FFE600FFE600FFD700FFD700FFD700FFD700FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFB800FFB800
FFC700FFB800FFB800FFC700FFB800FFC700FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFD700FFD700FFE600
FFE600FFE600FFF500FAFF00EBFF00BDFF0014FF00DCFF00FAFF00FAFF00FAFF00FAFF00
FAFF00FAFF00DCFF0080FF00FAFF00FFF500FFF500FFF500AEFF00FFF500FFD700FFC700
FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFA800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFB800FFB800FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFD700FFC700FFD700FFD700FFD700
FFD700FFD700FFD700FFD700FFE600FFE600FFE600FFE600FFF500FFF500FAFF00EBFF00
CCFF008FFF0023FF0000FF0A80FF00BDFF00DCFF00EBFF00FAFF00FFF500FFF500FFE600
FFF500FFE600FFE600FFD700FFD700FFD700FFD700FFD700FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFC700FFC700FFC700FFC700FFC700FFC700FFB800FFC700FFB800FFB800FFB800
FFC700FFB800FFB800FFC700FFB800FFB800FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFD700FFD700
FFE600FFE600FFF500FFF500FAFF00DCFF009EFF00CCFF00EBFF00FAFF00EBFF00BDFF00
EBFF00EBFF008FFF00DCFF00FFF500FFE600FFE600FFE600DCFF00BDFF00FAFF00FFC700
FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFD700FFD700FFD700
FFD700FFD700FFE600FFE600FFE600FFE600FFE600FFE600FFF500FFF500FAFF00EBFF00
DCFF00AEFF0061FF00FF000061FF00BDFF00DCFF00EBFF00FAFF00FFF500FFF500FFE600
FFE600FFE600FFD700FFD700FFD700FFD700FFD700FFD700FFC700FFC700FFC700FFC700
FFC700FFB800FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFC700FFC700FFB800FFB800FFB800FFB800FFC700FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFB800
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFD700FFD700
FFE600FFE600FFF500FFF500FAFF00EBFF00BDFF00AEFF00DCFF00EBFF00CCFF0070FF00
BDFF00CCFF00DCFF00DCFF00FFE600FFE600FFD700FFE600BDFF00FFF50080FF00FFF500
FFB800FFA800FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFD700FFD700FFD700
FFD700FFD700FFD700FFE600FFE600FFE600FFE600FFE600FFF500FFF500FAFF00EBFF00
DCFF00BDFF0080FF0000FFA323FF008FFF00DCFF00FAFF00FAFF00FFF500FFE600FFE600
FFE600FFE600FFD700FFD700FFD700FFD700FFD700FFC700FFC700FFC700FFC700FFC700
FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFB800
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFD700
FFD700FFE600FFE600FFF500FAFF00EBFF00CCFF009EFF00BDFF00CCFF0070FF00CCFF00
BDFF0061FF00EBFF00FFF500FFE600FFD700FFD700FFD700FFD700FFE600FAFF00FFC700
FFB800FFA800FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFC700FFB800FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFD700FFC700FFD700FFD700FFD700FFD700FFD700
FFD700FFD700FFD700FFE600FFE600FFE600FFE600FFE600FFF500FFF500FAFF00EBFF00
DCFF00AEFF0033FF0070FF0061FF0070FF00CCFF00FAFF00FFF500FFF500FFE600FFE600
FFE600FFD700FFD700FFD700FFD700FFD700FFD700FFC700FFC700FFC700FFC700FFC700
FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFA800FFA800FFB800FFB800
FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFB800FFB800FFC700FFB800
FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFD700FFD700
FFD700FFE600FFE600FFF500FAFF00EBFF00CCFF0070FF0061FF0042FF00BDFF00EBFF00
DCFF00BDFF00FFF500FFE600FFD700FFD700FFC700FFD700FFD700FFD700FFE600FFD700
FFB800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00
FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFA800FFA800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFC700FFB800FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFD700FFD700FFD700FFD700FFD700
FFD700FFE600FFD700FFE600FFE600FFE600FFE600FFF500FFF500FAFF00FAFF00EBFF00
BDFF00AEFF0000FF0A8FFF0080FF0042FF00AEFF00FAFF00FFF500FFF500FFE600FFE600
FFE600FFD700FFD700FFD700FFD700FFD700FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFA800FFA800FFB800FFB800FFA800FFA800FFB800FFB800
FFA800FFA800FFB800FFB800FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFD700FFD700
FFD700FFE600FFE600FFF500FFF500EBFF00AEFF00BDFF00CCFF00AEFF00EBFF00FAFF00
FAFF0070FF00FFF500FFD700FFD700FFC700FFC700FFC700FFC700FFC700FFD700FFC700
FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00
FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFC700FFB800FFC700FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFD700FFC700FFC700FFD700FFD700FFD700FFD700FFD700FFD700
FFD700FFD700FFE600FFE600FFE600FFE600FFE600FFF500FFF500FFF500FAFF00EBFF00
51FF0051FF0070FF00AEFF00AEFF00BDFF0080FF00FAFF00FAFF00FFF500FFE600FFE600
FFE600FFE600FFD700FFD700FFD700FFD700FFC700FFC700FFC700FFC700FFC700FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFB800FFA800FFA800FFA800FFB800
FFA800FFA800FFB800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFC700FFB800FFC700FFC700FFC700FFC700FFC700FFC700FFD700
FFD700FFD700FFE600FFF500FAFF00EBFF0033FF00DCFF00EBFF00EBFF00FAFF00FFF500
FFF500EBFF00FFF500FFD700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFB800
FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFC700FFB800FFC700FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFD700FFD700FFD700FFD700FFD700
FFD700FFD700FFE600FFE600FFE600FFE600FFF500FFF500FFF500FFF500FAFF00EBFF00
BDFF008FFF0070FF00BDFF00CCFF00DCFF00DCFF00FAFF00FFF500FFF500FFE600FFE600
FFE600FFD700FFD700FFD700FFD700FFC700FFC700FFC700FFC700FFC700FFC700FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFB800FFA800FFA800FFA800FFA800
FFA800FFA800FFB800FFA800FFA800FFB800FFA800FFA800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFC700FFD700FFD700
FFD700FFD700FFE600FFF500FAFF00EBFF001400FFEBFF00FAFF00FAFF00FFF500FFF500
FFF500FFF500FFE600FFD700FFC700FFC700FFC700FFB800FFB800FFB800FFB800FFB800
FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF500FFF500FAFF00FAFF00EBFF00
CCFF00AEFF0033FF00BDFF00CCFF00DCFF00EBFF00FAFF00FFF500FFF500FFE600FFE600
FFE600FFD700FFD700FFD700FFD700FFC700FFC700FFC700FFC700FFC700FFC700FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFA800FFA800FFA800FFB800FFA800FFA800FFA800FFB800FFA800FFA800FFA800FFA800
FFA800FFA800FFB800FFA800FFA800FFA800FFA800FFA800FFB800FFA800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFC700FFD700
FFD700FFD700FFE600FFF500FAFF00DCFF0023FF00EBFF00FAFF00FFF500FFE600FFE600
FFE600FFE600FFD700FFC700FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFA800
FFA800FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700
FFE600FFE600FFE600FFE600FFE600FFE600FFF500FFF500FFF500FAFF00FAFF00EBFF00
DCFF00BDFF0051FF00BDFF00DCFF00EBFF00FAFF00FAFF00FFF500FFF500FFE600FFE600
FFD700FFD700FFD700FFD700FFD700FFC700FFC700FFC700FFC700FFC700FFC700FFC700
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFA800FFA800FFA800FFB800FFA800FFA800FFA800FFB800FFA800FFA800FFA800FFA800
FFA800FFA800FFB800FFA800FFA800FFA800FFA800FFA800FFB800FFA800FFA800FFA800
FFA800FFB800FFA800FFB800FFA800FFB800FFA800FFB800FFA800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFC700FFC700
FFD700FFD700FFE600FFF500DCFF00BDFF00BDFF00FAFF00FFF500FFF500FFE600FFE600
FFD700FFD700FFD700FFD700FFC700FFC700FFB800FFB800FFB800FFB800FFA800FFA800
FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800
FFC700FFB800FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700
FFE600FFE600FFE600FFE600FFE600FFE600FFF500FFF500FFF500FAFF00FAFF00EBFF00
DCFF00AEFF0000FF66BDFF00DCFF00EBFF00FAFF00FFF500FFF500FFE600FFE600FFE600
FFD700FFD700FFD700FFD700FFC700FFC700FFC700FFC700FFC700FFC700FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFA800FFA800FFA800FFB800FFA800FFA800FFA800FFB800FFA800FFA800FFA800FFA800
FFA800FFA800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFB800FFA800FFB800FFA800FFB800FFA800FFA800FFA800FFA800
FFB800FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFB800FFC700FFC700FFC700FFC700
FFD700FFD700FFE600FFF5009EFF00AEFF00CCFF00FAFF00FFF500FFE600FFE600FFD700
FFD700FFD700FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFA800FFA800FFA800
FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700
FFD700FFC700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFE600FFD700FFE600
FFE600FFE600FFE600FFE600FFE600FFF500FFF500FFF500FFF500FAFF00FAFF00EBFF00
DCFF009EFF0005FF00BDFF00DCFF00EBFF00FAFF00FFF500FFF500FFF500FFE600FFE600
FFD700FFD700FFD700FFD700FFC700FFC700FFC700FFC700FFC700FFC700FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFA800FFB800FFB800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFB800FFA800FFA800FFB800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFB800FFA800FFB800FFA800FFA800FFA800FFA800
FFB800FFA800FFA800FFA800FFA800FFB800FFA800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFD700
FFD700FFD700FFE600FFE600FAFF00CCFF00CCFF00FAFF00FFF500FFE600FFD700FFD700
FFD700FFC700FFC700FFC700FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800
FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFD700FFC700
FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFF500FFF500FFF500FFF500FAFF00FAFF00EBFF00
CCFF0080FF0023FF00BDFF00DCFF00EBFF00FAFF00FFF500FFF500FFE600FFE600FFE600
FFD700FFD700FFD700FFD700FFC700FFC700FFC700FFC700FFC700FFC700FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFA800FFA800FFB800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFB800FFA800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFC700
FFD700FFD700FFD700FFE600FAFF00DCFF009EFF00FAFF00FFF500FFE600FFD700FFD700
FFD700FFC700FFC700FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800
FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700
FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFF500FFF500FFF500FFF500FAFF00FAFF00FAFF00EBFF00
DCFF009EFF0051FF0080FF00DCFF00EBFF00FAFF00FAFF00FFF500FFE600FFE600FFE600
FFD700FFD700FFD700FFD700FFC700FFC700FFC700FFC700FFC700FFB800FFC700FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700
FFC700FFD700FFD700FFE600FFF50080FF0080FF00FAFF00FFF500FFE600FFD700FFD700
FFC700FFC700FFC700FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800
FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFD700FFC700FFC700FFD700FFD700
FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFF500FFF500FFF500FFF500FAFF00FAFF00EBFF00EBFF00
CCFF0033FF0080FF00BDFF00DCFF00EBFF00FAFF00FFF500FFF500FFE600FFE600FFE600
FFD700FFD700FFD700FFC700FFC700FFC700FFC700FFC700FFC700FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFA800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700
FFC700FFD700FFD700FFE600FFF500DCFF009EFF00FAFF00FFE600FFE600FFD700FFD700
FFC700FFC700FFC700FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FF9900
FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFC700FFC700FFD700
FFD700FFC700FFC700FFC700FFC700FFC700FFC700FFD700FFC700FFD700FFD700FFD700
FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFF500FFF500FFF500FFF500FAFF00FAFF00FAFF00EBFF00EBFF00
CCFF00AEFF0080FF00BDFF00DCFF00EBFF00FAFF00FAFF00FFF500FFE600FFE600FFE600
FFD700FFD700FFD700FFD700FFC700FFC700FFC700FFC700FFC700FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFA800FFA800FFA800
FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFA800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFB800FFC700FFD700
FFC700FFD700FFD700FFE600FFF500EBFF0080FF00FAFF00FFF500FFD700FFD700FFC700
FFC700FFC700FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFC700FFD700FFD700
FFD700FFD700FFD700FFD700FFD700FFC700FFD700FFD700FFD700FFD700FFD700FFD700
FFD700FFD700FFD700FFD700FFD700FFD700FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFF500FFF500FFF500FAFF00FAFF00FAFF00FAFF00EBFF00DCFF00
CCFF00AEFF0051FF00BDFF00DCFF00EBFF00EBFF00FAFF00FFF500FFF500FFE600FFE600
FFD700FFD700FFD700FFC700FFC700FFC700FFC700FFC700FFC700FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFA800FFA800FFB800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFA800FFA800FFA800FFA800
FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700
FFC700FFD700FFD700FFE600FFF500EBFF008FFF00AEFF00FFF500FFD700FFD700FFC700
FFC700FFC700FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FF9900FFA800
FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF8A00FF8A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800
FFA800FFA800FFA800FFB800FFA800FFB800FFB800FFB800FFB800FFC700FFE600FFE600
FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700
FFD700FFD700FFD700FFD700FFD700FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFF500FFF500FFF500FFF500FFF500FAFF00FAFF00EBFF00EBFF00DCFF00
CCFF00AEFF0080FF00BDFF00CCFF00EBFF00EBFF00FAFF00FFF500FFF500FFE600FFE600
FFE600FFD700FFD700FFC700FFC700FFC700FFC700FFC700FFB800FFC700FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFB800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700
FFC700FFD700FFE600FFE600FFF500EBFF009EFF00DCFF00FFE600FFD700FFD700FFC700
FFC700FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFC700FFC700FAFF00FFF500
FFE600FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700
FFD700FFD700FFD700FFD700FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF500
FFF500FFF500FFF500FFF500FFF500FFF500FAFF00FAFF00EBFF00EBFF00DCFF00DCFF00
BDFF009EFF0061FF009EFF00CCFF00DCFF00EBFF00FAFF00FFF500FFF500FFE600FFE600
FFD700FFD700FFD700FFD700FFC700FFC700FFC700FFC700FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFB800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700
FFC700FFD700FFE600FFE600FFF500EBFF00BDFF00FAFF00FFE600FFE600FFD700FFC700
FFC700FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FF9900FF9900
FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFC700FFC700FFF500CCFF00
FFE600FFE600FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700
FFD700FFD700FFD700FFE600FFE600FFE600FFE600FFF500FFF500FFF500FFF500FFF500
FFF500FFF500FFF500FFF500FFF500FAFF00FAFF00FAFF00EBFF00DCFF00DCFF00CCFF00
9EFF0080FF0080FF0051FF00AEFF00BDFF00DCFF00EBFF00FAFF00FFF500FFE600FFE600
FFE600FFD700FFD700FFC700FFC700FFC700FFC700FFC700FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700
FFC700FFD700FFE600FFF500FAFF00DCFF00CCFF00FAFF00FFE600FFD700FFD700FFC700
FFC700FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFC700FFC700FFE600CCFF00
FFF500FFE600FFE600FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700
FFD700FFE600FFE600FFE600FFE600FFE600FFF500FFF500FFF500FFF500FFF500FFF500
FFF500FFF500FFF500FFF500FFF500FAFF00FAFF00EBFF00DCFF00CCFF00CCFF00BDFF00
05FF0051FF00AEFF0000FF2851FF00AEFF00BDFF00EBFF00EBFF00FAFF00FFF500FFE600
FFE600FFD700FFD700FFC700FFC700FFC700FFC700FFC700FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFC700
FFC700FFD700FFE600FFF500EBFF00CCFF00CCFF00FAFF00FFE600FFD700FFD700FFC700
FFC700FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800
FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFC700FFD700FFE60023FF00
FAFF00FFF500FFE600FFE600FFE600FFD700FFD700FFD700FFD700FFD700FFD700FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFF500FAFF00EBFF00FFF500FFF500FFF500
FFF500FFF500FFF500FFF500FAFF00FAFF00FAFF00EBFF00BDFF00BDFF00CCFF00AEFF00
00FFB361FF00BDFF00AEFF008FFF0051FF00AEFF00DCFF00DCFF00FAFF00FFF500FFE600
FFE600FFD700FFD700FFC700FFC700FFC700FFC700FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFA800FFA800FFB800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFB800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFC700
FFC700FFD700FFE600FAFF00AEFF009EFF00DCFF00FAFF00FFE600FFD700FFD700FFD700
FFC700FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFC700FFD700FFF5008FFF00
DCFF008FFF00FFF500FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFF500FFF500EBFF00CCFF00FAFF00FAFF00FFF500
FFF500FFF500FFF500FAFF00FAFF00FAFF00EBFF00DCFF009EFF009EFF00AEFF008FFF00
8FFF00BDFF00CCFF00BDFF00AEFF0000FF38AEFF00CCFF0080FF00EBFF00FFF500FFE600
FFE600FFD700FFD700FFC700FFC700FFC700FFC700FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFC700
FFC700FFD700FFF500EBFF00CCFF00DCFF00BDFF00EBFF00FFF500FFD700FFD700FFC700
FFC700FFB800FFB800FFB800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFC700FFD700BDFF00DCFF00
8FFF00CCFF00EBFF00FFF500FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFF500FFF500FFF500FAFF00DCFF00CCFF00FAFF00FAFF00FAFF00
FAFF00FAFF00FAFF00FAFF00FAFF00FAFF00EBFF00DCFF00AEFF0023FF009EFF0051FF00
AEFF00CCFF00DCFF00DCFF00AEFF009EFF0042FF00AEFF0080FF00EBFF00FAFF00FFF500
FFE600FFD700FFD700FFD700FFC700FFC700FFC700FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFA800FFA800FFA800FFB800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFC700
FFC700FFE6009EFF008FFF00FAFF00EBFF00AEFF00CCFF00FFF500FFE600FFD700FFC700
FFC700FFB800FFB800FFB800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFC700FFD700FFF500FAFF00
DCFF009EFF00AEFF00FAFF00FFF500FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFF500FFE600FFF500FFF500FAFF00EBFF00BDFF00CCFF00EBFF00FAFF00FAFF00
FAFF00FAFF00FAFF00FAFF00FAFF00EBFF00EBFF00CCFF00AEFF0000FF1961FF0042FF00
BDFF00DCFF00DCFF00DCFF00CCFF00CCFF00AEFF0061FF00AEFF00DCFF00EBFF00FAFF00
FFE600FFE600FFD700FFD700FFC700FFC700FFC700FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800
FFC700FFD700FAFF00FAFF00FFF500FAFF00EBFF0061FF00DCFF00FFE600FFD700FFC700
FFC700FFB800FFB800FFB800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800
FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFE600FFF500
EBFF009EFF00DCFF00FAFF00FFF500FFF500FFE600FFE600FFE600FFE600FFE600FFF500
FFF500FFF500FFF500FFF500FFF500EBFF00CCFF008FFF00CCFF00EBFF00FAFF00FAFF00
FAFF00FAFF00FAFF00FAFF00FAFF00EBFF00DCFF00BDFF008FFF0000FFB351FF009EFF00
BDFF00EBFF00EBFF00EBFF00DCFF00DCFF00CCFF00AEFF008FFF00CCFF00CCFF00CCFF00
FFF500FFE600FFD700FFD700FFC700FFC700FFC700FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFA800FFB800FFB800FFB800FFB800
FFC700FFC700FFE600FFE600FFE600FFF500FAFF00CCFF00DCFF00FFE600FFD700FFC700
FFC700FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FF9900FF9900FF9900
FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFC700FFC700FFD700FFE600
EBFF0051FF00DCFF00FAFF00FFF500FFF500FFF500FFE600FFF500FFF500FFF500FFF500
FFF500FFF500FFF500FFF500FAFF00EBFF0061FF0061FF00CCFF00DCFF00EBFF00FAFF00
FAFF00FAFF00FAFF00FAFF00EBFF00EBFF00CCFF0070FF0080FF0023FF0080FF00BDFF00
DCFF00EBFF00EBFF00FAFF00EBFF00EBFF00DCFF00BDFF0070FF0000FF0A42FF00EBFF00
FFF500FFE600FFD700FFD700FFC700FFC700FFC700FFB800FFB800FFB800FFB800FFB800
FFB800FFA800FFA800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FF9900FF9900FFA800FFA800FF9900FF9900FF9900
FFA800FFA800FF9900FF9900FFA800FFA800FF9900FF9900FFA800FFA800FFA800FF9900
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800
FFC700FFC700FFD700FFD700FFE600FFE600FAFF00CCFF00DCFF00FFF500FFD700FFC700
FFC700FFB800FFB800FFB800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFC700FFC700FFC700FFD700FFE600
EBFF0070FF00DCFF00FAFF00FAFF00FFF500FFF500FFF500FFF500FFF500FFF500FAFF00
FAFF00FAFF00FAFF00FAFF00FAFF00EBFF00AEFF0061FF00CCFF00DCFF00EBFF00EBFF00
EBFF00FAFF00EBFF00EBFF00EBFF00DCFF00CCFF0080FF0005FF0051FF0014FF00CCFF00
EBFF00FAFF00FAFF00FAFF00FAFF00EBFF00EBFF00BDFF0014FF0000FF0A00FF0AEBFF00
FFF500FFE600FFD700FFD700FFC700FFC700FFC700FFB800FFB800FFB800FFB800FFB800
FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FF9900FFA800FFA800FFA800FF9900FF9900FF9900FFA800FFA800FF9900FF9900FF9900
FFA800FF9900FF9900FF9900FFA800FFA800FF9900FF9900FF9900FFA800FF9900FF9900
FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800
FFC700FFC700FFC700FFD700FFD700FFE600FFF500CCFF00AEFF00DCFF00FFD700FFC700
FFC700FFB800FFB800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFC700FFC700FFD700FFE600
FFF500BDFF00CCFF00EBFF00FAFF00FFF500FFF500FFF500FFF500FFF500FAFF0080FF00
FAFF00FAFF00FAFF00FAFF00EBFF00EBFF00BDFF0070FF00BDFF00DCFF00EBFF00EBFF00
EBFF00EBFF00EBFF00EBFF00EBFF00DCFF00CCFF008FFF009EFF0051FF0070FF00DCFF00
EBFF00FAFF00FAFF00FAFF00FAFF00FAFF00EBFF00BDFF0080FF0080FF00AEFF00EBFF00
FAFF00FFF500FFE600FFD700FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900
FF9900FF9900FFA800FFA800FF9900FF9900FF9900FFA800FFA800FF9900FF9900FF9900
FFA800FF9900FF9900FF9900FF9900FFA800FF9900FF9900FF9900FFA800FF9900FF9900
FF9900FFA800FFA800FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800
FFB800FFC700FFC700FFC700FFD700FFD700FFF500BDFF0042FF00EBFF00FFE600FFD700
FFC700FFB800FFB800FFA800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFD700FFD700
FFF50000FF7500FF85DCFF00FAFF00FAFF00FAFF00FAFF00FAFF00FAFF00EBFF00AEFF00
EBFF00FAFF00FAFF00FAFF00EBFF00DCFF00CCFF0000FF38AEFF00CCFF00DCFF00EBFF00
EBFF00EBFF00EBFF00EBFF00DCFF00DCFF00BDFF0070FF00AEFF00BDFF008FFF00DCFF00
FAFF00FAFF00FAFF00FFF500FFF500FAFF00FAFF00CCFF0080FF00BDFF008FFF00DCFF00
FAFF00FAFF00FFF500FFD700FFC700FFC700FFC700FFB800FFB800FFB800FFB800FFB800
FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900
FF9900FF9900FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FF9900FF9900
FF9900FFA800FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFA800FFB800FFB800FFB800
FFB800FFC700FFC700FFC700FFD700FFD700FFF50070FF008FFF00FAFF00FFE600FFD700
FFC700FFB800FFB800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900
FF9900FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFC700FFC700FFD700FFD700
FFF500EBFF00BDFF00BDFF00EBFF00EBFF00FAFF00FAFF00FAFF00FAFF00DCFF0014FF00
EBFF00EBFF00FAFF00EBFF00EBFF00DCFF00CCFF0070FF009EFF0042FF00DCFF00DCFF00
DCFF00EBFF00EBFF00EBFF00DCFF00CCFF009EFF0042FF00BDFF00CCFF00CCFF00EBFF00
FAFF00FAFF00FFF500FFF500FFF500FFF500FAFF00AEFF00DCFF00DCFF009EFF0070FF00
DCFF00DCFF00AEFF00FFD700FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FFA800FFA800FF9900
FF9900FF9900FF9900FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FF9900FF9900
FF9900FFA800FF9900FF9900FF9900FFA800FFA800FF9900FF9900FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800
FFB800FFB800FFC700FFC700FFC700FFD700FFE600FAFF0070FF00FAFF00FFE600FFD700
FFC700FFB800FFB800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900
FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF8A00FF8A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFC700FFC700FFD700FFD700
FFE600FAFF009EFF00BDFF00DCFF00EBFF00EBFF00EBFF00EBFF00EBFF00DCFF0033FF00
DCFF00EBFF00EBFF00EBFF00DCFF00CCFF00BDFF009EFF0051FF009EFF00CCFF00CCFF00
DCFF00DCFF00DCFF00DCFF00DCFF00CCFF009EFF0042FF00CCFF00DCFF00EBFF00FAFF00
FAFF00FFF500FFF500FFF500FFF500FFF500FAFF00EBFF00FAFF00EBFF00DCFF0080FF00
9EFF00AEFF00FAFF00FFD700FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFA800
FFA800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FFA800FFA800FF9900
FF9900FF9900FF9900FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FFA800FF9900FF9900FF9900FFA800FF9900FF9900FF9900FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800
FFB800FFB800FFB800FFC700FFC700FFD700FFE600FFF5009EFF00EBFF00FFF500FFE600
FFD700FFC700FFB800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900
FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFC700FFC700FFD700FFD700
FFE600FFF500DCFF0023FF00CCFF00CCFF00CCFF009EFF00EBFF00DCFF00CCFF009EFF00
CCFF00DCFF00DCFF00DCFF00CCFF00BDFF00BDFF009EFF0033FF00AEFF00BDFF00BDFF00
BDFF00CCFF00DCFF00DCFF00CCFF00CCFF0042FF0080FF00CCFF00EBFF00EBFF00FAFF00
FFF500FFF500FFF500FFF500FFF500FFF500FFF500FFF500FFF500FAFF00EBFF00EBFF00
BDFF00EBFF00FFF500FFD700FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FFA800FF9900
FF9900FF9900FF9900FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FFA800FF9900FF9900FF9900FFA800FF9900FF9900FF9900FFA800FFA800FF9900
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800
FFB800FFB800FFC700FFC700FFC700FFC700FFD700FFE600EBFF0070FF00FAFF00FAFF00
FFE600FFC700FFB800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900
FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800
FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFD700FFD700
FFE600FAFF00EBFF008FFF0000FFFF8FFF0070FF00AEFF00DCFF00DCFF00BDFF0051FF00
CCFF00DCFF00CCFF00CCFF009EFF009EFF00AEFF008FFF0000FF478FFF00AEFF009EFF00
33FF00CCFF00CCFF00CCFF00CCFF00BDFF0070FF00AEFF00CCFF00EBFF00FAFF00FAFF00
FFF500FFF500FFF500FFE600FFE600FFE600FFE600FFF500FFF500FFF500FFF500FAFF00
CCFF00FAFF00FFE600FFD700FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FFA800FF9900
FF9900FF9900FF9900FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FFA800FF9900FF9900FF9900FFA800FF9900FF9900
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFA800
FFB800FFB800FFB800FFB800FFC700FFC700FFD700FFE600FFF500DCFF00DCFF00BDFF00
DCFF00FFC700FFB800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFC700FFC700FFD700FFE600
FFF500FAFF00DCFF0080FF00AEFF009EFF008FFF009EFF00CCFF00BDFF00AEFF0080FF00
BDFF00CCFF0080FF00BDFF009EFF0061FF008FFF0080FF0051FF0080FF008FFF008FFF00
8FFF00BDFF00CCFF00CCFF00BDFF00AEFF0023FF00AEFF00DCFF00EBFF00FAFF00FAFF00
FFF500FFF500FFF500FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF500FFF500
DCFF00EBFF00FFE600FFD700FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FF9900FFA800FFA800FF9900FF9900FF9900FF9900FF9900FFA800FF9900
FF9900FF9900FF9900FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FF9900FF9900
FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFB800FFB800FFB800FFB800FFC700FFC700FFD700FFD700FFF500EBFF00BDFF00FAFF00
FFD700FFC700FFB800FFB800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900
FF9900FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFC700FFC700FFD700FFE600
FFF500EBFF00CCFF0023FF00CCFF00CCFF009EFF008FFF00AEFF0051FF0080FF0061FF00
8FFF00AEFF0000FF47AEFF008FFF0023FF0042FF0070FF0051FF0051FF0061FF0070FF00
9EFF00BDFF00BDFF00BDFF00AEFF009EFF0042FF00AEFF00CCFF00EBFF00FAFF00FFF500
FFF500FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF500
AEFF0061FF00FFE600FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FF9900FF9900FF9900FFA800FFA800FF9900FF9900FF9900FF9900FFA800FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FFA800FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFB800FFB800FFB800FFC700FFC700FFC700FFD700FFE600FAFF00EBFF00FFE600
FFD700FFC700FFB800FFA800FFA800FFA800FF9900FFA800FF9900FF9900FF9900FF9900
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFC700FFC700FFD700FFE600
FAFF00CCFF009EFF00CCFF00DCFF00DCFF00AEFF0023FF0051FF0070FF008FFF009EFF00
00FF388FFF0061FF008FFF0000FF4700FF0A14FF0042FF0033FF0000FF6600FF7542FF00
80FF00AEFF00AEFF00AEFF009EFF0070FF0080FF0000FF0ABDFF00EBFF00FAFF00FFF500
FFF500FFE600FFE600FFE600FFE600FFE600FFD700FFD700FFE600FFE600FFE600FFE600
FFF500CCFF00FFE600FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FF9900FF9900FF9900FF9900FFA800FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFB800FFB800FFB800FFB800FFC700FFC700FFD700FFE600DCFF00EBFF00FFE600
FFD700FFC700FFB800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFD700FFF500
61FF0000FF6633FF00EBFF00EBFF00EBFF0061FF00BDFF009EFF00AEFF00BDFF00AEFF00
70FF0051FF0061FF0023FF0000FFB300FFD100FF5705FF0005FF0000FF85FF000005FF00
80FF009EFF00AEFF00AEFF0061FF0061FF00AEFF009EFF008FFF00DCFF00FAFF00FFF500
FFE600FFE600FFE600FFE600FFE600FFE600FFD700FFD700FFD700FFD700FFD700FFE600
FFF50051FF00FFD700FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FF9900FF9900FF9900FF9900FFA800FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FFA800FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFB800FFB800FFB800FFB800FFC700FFC700FFD700FFE600DCFF00EBFF00FFE600
FFD700FFC700FFB800FFB800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFC700FFC700FFE600BDFF00
8FFF00BDFF00DCFF00EBFF00FAFF00FAFF00EBFF00DCFF00CCFF00CCFF00CCFF00CCFF00
AEFF009EFF008FFF0061FF0014FF0000F0FF0500FF00FF9400FFC20028FFFF000000FF66
61FF0070FF009EFF008FFF0061FF008FFF00BDFF00BDFF0051FF00CCFF00FAFF00FFF500
FFE600FFE600FFE600FFE600FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700
FFE600BDFF00FFD700FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FF9900FF9900FF9900FF9900FFA800FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FFA800FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFB800FFB800FFB800FFC700FFC700FFD700FFE600FAFF0080FF00FFE600
FFD700FFC700FFB800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFC700FFD700EBFF00
DCFF00EBFF00FAFF00FAFF00FAFF00FAFF00EBFF00EBFF00DCFF00DCFF00DCFF00CCFF00
BDFF00AEFF009EFF0070FF0000FF1900C2FFFF00000066FFFF0000FF0000AE00FF00FFFF
23FF0080FF008FFF0080FF008FFF00BDFF00CCFF00CCFF00BDFF0080FF00FAFF00FFF500
FFE600FFE600FFE600FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700
FFD700FFE600FFD700FFC700FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FFA800FF9900FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFB800FFB800FFB800FFB800FFC700FFD700FFD700FFF50061FF00FFF500
FFD700FFC700FFB800FFB800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF8A00FF8A00
FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFC700FFC700FFD700FFF500
FAFF00FFF500FFF500FFF500FFF500FFF500FAFF00FAFF00EBFF00EBFF00DCFF00DCFF00
CCFF00AEFF009EFF0080FF0033FF00FF0000FF0000FA00FFFF0000FF0000FF0000FF0000
00FF2870FF0080FF0051FF008FFF00BDFF00DCFF00DCFF00DCFF00BDFF00FFF500FFE600
FFE600FFE600FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFC700FFC700FFD700
FFD700FFD700FFC700FFC700FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900FF9900FFA800
FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFB800FFA800FFB800FFB800FFB800FFC700FFC700FFD700FFF500BDFF00FFF500
FFD700FFC700FFC700FFB800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF8A00
FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFC700FFD700FFE600
FFE600FFE600FFE600FFF500FFF500FFF500FAFF00FAFF00FAFF00EBFF00DCFF00DCFF00
CCFF00BDFF009EFF0061FF0005FF0000FFE1FF0000FF0000FF0000FF0000FF0000FF0000
0028FF51FF0051FF0061FF0023FF00CCFF00DCFF00EBFF00EBFF00EBFF00FFF500FFE600
FFE600FFD700FFD700FFD700FFD700FFD700FFD700FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900
FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FFA800FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFB800FFB800FFB800FFC700FFC700FFD700FFF500DCFF00FAFF00
FFE600FFD700FFC700FFB800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00
FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFC700FFC700FFC700FFD700
FFE600FFE600FFE600FFE600FFE600FFF500FFF500FAFF00FAFF00EBFF00EBFF00DCFF00
CCFF00BDFF009EFF0014FF0014FF0000FFD1FF004CFF0000FF0000FF0000FF0000FF0000
0075FF42FF0000FFE18FFF009EFF00CCFF00EBFF00EBFF00FAFF00FAFF00FFF500FFE600
FFE600FFD700FFD700FFD700FFD700FFD700FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFA800FFB800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FFA800FF9900FFA800FFA800FFA800FFA800
FFA800FFA800FFB800FFB800FFB800FFB800FFC700FFC700FFD700FFF500BDFF00EBFF00
FFF500FFE600FFC700FFB800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF7A00FF7A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00
FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFC700FFC700FFD700
FFD700FFD700FFE600FFE600FFF500FFF500FFF500FFF500FAFF00FAFF00EBFF00DCFF00
CCFF00BDFF009EFF0070FF0014FF0000FFE1FF0000FF0000FF0000FF0000FF0000FF0000
FF000014FF0051FF009EFF00BDFF00DCFF00EBFF00FAFF00FAFF00FFF500FFF500FFE600
FFE600FFD700FFD700FFD700FFD700FFC700FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800
FF9900FF9900FF9900FF9900FF9900FF9900FFA800FF9900FF9900FFA800FFA800FFA800
FFA800FFA800FFA800FFB800FFB800FFB800FFC700FFD700FFE600FAFF00DCFF00DCFF00
9EFF0080FF00EBFF00FFB800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFC700FFC700FFC700
FFD700FFD700FFD700FFE600FFE600FFE600FFF500FFF500FAFF00FAFF00EBFF00DCFF00
BDFF00AEFF008FFF0070FF0000FF0A0094FFFF0000FF0000FF0000FF0000FF0000FF0000
FF000000FF9470FF009EFF00BDFF00CCFF00EBFF00FAFF00FFF500FFF500FFE600FFE600
FFD700FFD700FFD700FFD700FFD700FFC700FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900
FF9900FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800
FFA800FFA800FFA800FFB800FFB800FFB800FFC700FFD700FFE600EBFF00FAFF00FFF500
FFF500FFF500FFF500FFB800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFD700
FFD700FFD700FFD700FFE600FFE600FFE600FFF500FFF500FAFF00FAFF00EBFF00DCFF00
51FF009EFF0000FFC251FF0000FFF0FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0028FF00FF1961FF009EFF00BDFF00DCFF00EBFF00FAFF00FFF500FFF500FFE600FFE600
FFD700FFD700FFD700FFD700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700
FFB800FFB800FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFB800FFB800FFC700FFD700FAFF0070FF00FFF500FFE600
FFD700FFD700DCFF00FFB800FFA800FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFC700FFC700FFC700
FFC700FFD700FFD700FFD700FFE600FFE600FFE600FFF500FFF500FAFF00EBFF00DCFF00
BDFF0070FF0042FF0000FF2800FFE1FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000500FF33FF0080FF00AEFF00DCFF00EBFF00FAFF00FFF500FFF500FFE600FFE600
FFD700FFD700FFD700FFD700FFC700FFC700FFC700FFC700FFC700FFC700FFB800FFC700
FFB800FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FFA800FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800
FFA800FFA800FFA800FFA800FFB800FFB800FFC700FFD700DCFF00DCFF00FFE600FFD700
FFC700FFC700FFD700FFB800FFA800FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFC700FFC700
FFC700FFD700FFD700FFD700FFE600FFE600FFE600FFF500FFF500FAFF00EBFF00DCFF00
BDFF0070FF0051FF0042FF0000FF57FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF000000FFFF80FF0014FF00DCFF00EBFF00FAFF00FFF500FFE600FFE600FFE600
FFD700FFD700FFD700FFC700FFC700FFC700FFC700FFC700FFC700FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FFA800FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FF9900FF9900FFA800
FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFC700FFE600BDFF00FFD700FFC700
FFC700FFB800FFB800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFC700FFC700
FFC700FFD700FFD700FFD700FFE600FFE600FFF500FFF500FAFF00FAFF00EBFF00DCFF00
BDFF009EFF0070FF0042FF0000FF28FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF000061FF0080FF00CCFF00EBFF00FAFF00FFF500FFE600FFE600FFD700
FFD700FFD700FFD700FFC700FFC700FFC700FFC700FFC700FFC700FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFA800FFB800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800
FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFC700FFE600CCFF00FFD700FFC700
FFB800FFB800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFC700FFC700
FFC700FFC700FFD700FFD700FFD700FFE600FFE600FFF500FAFF00FAFF00EBFF00DCFF00
BDFF009EFF0080FF0000FF3800FF57FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF000000A3FF33FF009EFF00CCFF00EBFF00FAFF00FFF500FFE600FFE600FFD700
FFD700FFD700FFC700FFC700FFC700FFC700FFC700FFC700FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FFA800FFA800FFA800FFB800FFA800FFB800FFB800FFC700FFE600EBFF00FFD700FFC700
FFB800FFB800FFA800FFA800FFA800FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700
FFC700FFC700FFD700FFD700FFD700FFE600FFE600FFF500FAFF00EBFF00EBFF00DCFF00
BDFF009EFF0070FF0033FF0000FF47DC00FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000075FF51FF00AEFF00CCFF00DCFF00EBFF00FFF500FFE600FFE600FFD700
FFD700FFD700FFC700FFC700FFC700FFC700FFC700FFC700FFB800FFC700FFB800FFB800
FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FFA800FFA800FFA800FFB800FFB800FFB800FFC700FFE600EBFF00FFD700FFC700
FFB800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFC700FFC700
FFC700FFD700FFD700FFD700FFD700FFE600FFE600FFF500FAFF00EBFF00DCFF00CCFF00
BDFF009EFF0033FF0023FF0000FF570066FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF000023FF009EFF00BDFF00CCFF00BDFF00FAFF00FFE600FFE600FFD700
FFD700FFD700FFD700FFC700FFC700FFC700FFC700FFC700FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFC700FFE600CCFF00FFD700FFB800
FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFC700
FFC700FFC700FFD700FFD700FFD700FFE600FFE600FAFF00EBFF00DCFF00DCFF0080FF00
AEFF008FFF0042FF0000FF94FF00A82300FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF000000FF0A8FFF00AEFF00AEFF0080FF00FAFF00FFE600FFE600FFD700
FFD700FFD700FFC700FFC700FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FF9900FF9900FF9900FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FFA800FFA800FFA800FFB800FFB800FFC700FFE600FAFF00FFC700FFB800
FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00
FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFC700
FFC700FFC700FFD700FFD700FFD700FFE600FFE600FAFF00BDFF00CCFF00CCFF0070FF00
8FFF0070FF0023FF0000FF94FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF000023FF0080FF0061FF0014FF00CCFF00FAFF00FFF500FFE600FFD700
FFD700FFD700FFC700FFC700FFC700FFC700FFC700FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FFA800FFA800FFA800FFB800FFB800FFD700FAFF00FFF500FFC700FFB800
FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF8A00FF8A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFC700FFC700
FFC700FFC700FFC700FFD700FFD700FFE600FFE600FAFF00AEFF00BDFF00AEFF0080FF00
00FF0A00FF7500A3FF3300FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF000000FF0A42FF0000FF0A9EFF00BDFF0033FF00FAFF00FFE600FFE600FFD700
FFD700FFC700FFC700FFC700FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFA800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FF9900FF9900FF9900FF9900FFA800FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800
FF9900FF9900FF9900FFA800FFA800FFB800FFB800FFD700DCFF00AEFF00FFC700FFA800
FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF9900FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF8A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700
FFC700FFC700FFC700FFD700FFD700FFE600FFE600FFF500DCFF0051FF0000FFE151FF00
80FF0061FF0000FF94FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF000000E1FF00FF3880FF009EFF009EFF00DCFF00CCFF00EBFF00FFE600FFE600FFD700
FFD700FFC700FFC700FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF9900FF9900
FF9900FF9900FF9900FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FFA800FFA800FFA800FFB800FFD700FFE600FFE600FFB800FFA800
FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFC700
FFC700FFC700FFC700FFD700FFD700FFE600FFE600FFF500EBFF0051FF009EFF009EFF00
8FFF0070FF0000FF0AFF00E6FF0000FF0000FF00000019FFFF0000FF0000FF0000FF0000
FF0000FF000014FF008FFF00BDFF00CCFF00DCFF00EBFF00FAFF00FFE600FFE600FFD700
FFD700FFC700FFC700FFC700FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF8A00FF8A00FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF9900
FF9900FF9900FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FFA800FFA800FFB800CCFF00FFD700FFB800FFB800FFA800
FFA800FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFC700
FFC700FFC700FFC700FFD700FFD700FFD700FFE600FFF5008FFF00CCFF00CCFF00BDFF00
9EFF0061FF0000FF190057FFFF0000FF0000FF000000A3FFFF0000FF0000FF00007000FF
FF0000FF000000FF1980FF00BDFF00DCFF00EBFF00FAFF00FFF500FFE600FFE600FFD700
FFD700FFC700FFC700FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFA800
FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900
FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF9900
FF9900FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF8A00FF8A00FF8A00FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FFA800FFA800FFB800FFC700FFB800FFB800FFA800FFA800
FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00
FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFC700FFC700
FFC700FFC700FFD700FFD700FFD700FFD700FFE600FFF500FAFF00DCFF00CCFF00BDFF00
8FFF0033FF0000FF66FF0000FF0000FF0000FF000000FFA300FF7500FFD1FF000000FF94
FF003DFF000000FF0A8FFF00CCFF00DCFF00FAFF00FAFF00FFF500FFE600FFE600FFD700
FFD700FFD700FFC700FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900FF9900
FF9900FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF9900
FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF8A00FF8A00FF8A00FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFB800FFB800FFA800FFA800FF9900
FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFC700
FFC700FFC700FFC700FFD700FFD700FFD700FFE600FFF500FAFF00EBFF00DCFF00BDFF00
9EFF0051FF0000FF28FF0000FF00F5FF0000FF00B800FF6600FF0A00FF3800E1FF00FF57
00FF8500FFFF00FF1905FF00CCFF00EBFF00FAFF00FFF500FFF500FFE600FFE600FFD700
FFD700FFC700FFC700FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900
FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF9900
FF9900FF9900FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FF9900
FF9900FF9900FF9900FF9900FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700
FFC700FFC700FFC700FFD700FFD700FFD700FFE600FFF500FFF500EBFF00DCFF00BDFF00
8FFF0014FF0000FF570066FF00FFF09E00FF00FFB300FF0A23FF0023FF0014FF0042FF00
23FF0000FF9451FF009EFF00CCFF00EBFF00FAFF00FFF500FFF500FFE600FFD700FFD700
FFD700FFD700FFC700FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF9900
FF9900FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFC700FFC700FFC700
FFC700FFC700FFC700FFD700FFD700FFE600FFE600FFF500FFF500FAFF00DCFF0000FF47
00FF8523FF004200FF00FF5700FF3800C2FF00FF6600FF2851FF0051FF0042FF0070FF00
51FF0000FF1900FF75AEFF00CCFF00EBFF00FAFF00FFF500FFF500FFE600FFE600FFD700
FFD700FFC700FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFA800FFB800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00
FF9900FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFC700FFC700
FFC700FFC700FFC700FFD700FFD700FFD700FFE600FFF500FFF500EBFF00DCFF0070FF00
61FF00FF005C00FF2823FF0014FF0000FF8514FF0033FF0061FF0070FF0051FF0080FF00
80FF0033FF008FFF00BDFF00DCFF00EBFF00FAFF00FFF500FFF500FFE600FFE600FFD700
FFD700FFD700FFC700FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF8A00FF8A00FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFC700
FFC700FFC700FFD700FFD700FFD700FFE600FFE600FFF500FFF500FAFF00DCFF00BDFF00
61FF0000FF6623FF0051FF0033FF0033FF0042FF0070FF008FFF008FFF0042FF009EFF00
AEFF0070FF009EFF00BDFF00DCFF00EBFF00FAFF00FFF500FFF500FFE600FFE600FFD700
FFD700FFC700FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900FFA800FF9900FF9900
FF9900FF9900FF9900FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00
FF8A00FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFC700FFC700
FFC700FFC700FFC700FFD700FFD700FFE600FFE600FFF500FAFF00EBFF00DCFF00BDFF00
00FF4714FF0042FF0080FF0014FF0070FF0061FF008FFF009EFF00AEFF0070FF00AEFF00
BDFF008FFF0070FF00BDFF00CCFF00EBFF00FAFF00FAFF00FFF500FFE600FFE600FFD700
FFD700FFD700FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FFA800FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00
FF8A00FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700
FFC700FFD700FFD700FFD700FFD700FFE600FFE600FFF500FAFF00EBFF00DCFF008FFF00
70FF0080FF0023FF008FFF009EFF0070FF0033FF009EFF00AEFF00BDFF0000FF19BDFF00
CCFF0080FF008FFF009EFF00CCFF00DCFF00EBFF00FAFF00FFF500FFE600FFE600FFE600
FFD700FFD700FFC700FFC700FFC700FFB800FFB800FFB800FFB800FFA800FFB800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00
FF8A00FF8A00FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFC700FFC700
FFC700FFC700FFD700FFD700FFD700FFE600FFE600FFF500EBFF00EBFF00CCFF0080FF00
9EFF009EFF0080FF009EFF00AEFF009EFF0005FF009EFF00BDFF00CCFF00AEFF00CCFF00
DCFF00BDFF00AEFF0080FF00BDFF00DCFF00EBFF00FAFF00FAFF00FFF500FFE600FFE600
FFD700FFD700FFC700FFC700FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00
FF8A00FF8A00FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF9900FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFC700FFC700
FFC700FFC700FFD700FFD700FFD700FFE600FFE600EBFF00DCFF00CCFF00CCFF0070FF00
AEFF00BDFF008FFF009EFF00BDFF00AEFF0005FF008FFF00BDFF00CCFF00DCFF00DCFF00
DCFF00DCFF00BDFF0051FF009EFF00AEFF00AEFF00EBFF00FAFF00FFF500FFF500FFE600
FFE600FFD700FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF9900FF8A00FF8A00FF9900FF8A00FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFC700FFC700FFC700
FFC700FFD700FFD700FFD700FFD700FFE600FFE600FAFF008FFF00BDFF00AEFF0061FF00
BDFF00BDFF0070FF00CCFF00CCFF00AEFF008FFF0061FF00BDFF00DCFF00DCFF00EBFF00
EBFF00DCFF00CCFF008FFF009EFF0070FF00AEFF00DCFF00FAFF00FAFF00FFF500FFF500
FFE600FFD700FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFA800FFA800FFA800
FFB800FFA800FFA800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800
FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700
FFC700FFC700FFD700FFD700FFE600FFE600FFF500FAFF00CCFF0070FF0080FF00AEFF00
CCFF00CCFF00CCFF00DCFF00DCFF00CCFF00BDFF0000FFD1BDFF00DCFF00EBFF00EBFF00
EBFF00EBFF00DCFF0051FF00CCFF00BDFF0000FF198FFF00EBFF00FAFF00FAFF00FAFF00
FFF500FFE600FFC700FFC700FFB800FFB800FFB800FFB800FFA800FFB800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FF9900FF9900FFA800FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFC700
FFC700FFD700FFD700FFD700FFE600FFE600FFF500FAFF00DCFF00BDFF0023FF00BDFF00
CCFF00DCFF00DCFF00DCFF00DCFF00DCFF00CCFF0070FF00BDFF00DCFF00EBFF00FAFF00
FAFF00EBFF00DCFF008FFF00DCFF00DCFF0061FF0000FF19DCFF00EBFF00CCFF00BDFF00
EBFF00FFE600FFC700FFC700FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FF9900FF9900FF9900FFA800FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF8A00FF8A00FF8A00FF9900FF9900FF9900FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700
FFC700FFD700FFD700FFD700FFE600FFF500FFF500FAFF00EBFF00CCFF0070FF00CCFF00
DCFF00EBFF00EBFF00EBFF00EBFF00EBFF00DCFF009EFF009EFF00DCFF00FAFF00FAFF00
FAFF00FAFF00DCFF009EFF00EBFF00EBFF0014FF008FFF00BDFF00CCFF0000FF3800FF19
AEFF00FFF500FFC700FFC700FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00
FF7A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00
FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFC700
FFD700FFD700FFD700FFE600FFE600FFE600FFF500FAFF00EBFF00CCFF0051FF00CCFF00
DCFF00EBFF00EBFF00EBFF00EBFF00EBFF00DCFF009EFF00AEFF00DCFF00FAFF00FFF500
FFF500FAFF00DCFF00DCFF00FAFF00FAFF00EBFF008FFF0080FF0033FF00CCFF0042FF00
FAFF00BDFF00FFC700FFC700FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00
FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFD700FFD700
FFD700FFD700FFD700FFE600FFE600FFE600FFF500FAFF00EBFF00CCFF0033FF00CCFF00
EBFF00EBFF00FAFF00FAFF00EBFF00EBFF00DCFF0070FF00DCFF00EBFF00FFF500FFF500
FFF500FFF500EBFF00FAFF00FAFF00FAFF00FAFF00EBFF00CCFF00BDFF00EBFF00FAFF00
FFE600FFE600FFC700FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFD700
FFD700FFD700FFD700FFE600FFE600FFF500FFF500FAFF00EBFF00CCFF0061FF00DCFF00
EBFF00FAFF00FAFF00FAFF00FAFF00FAFF00EBFF00AEFF00EBFF00FAFF00FFF500FFF500
FFF500FFF500FFF500FFF500FFF500FFF500FFF500FAFF00DCFF00AEFF00FAFF00FFF500
FFE600FFD700FFC700FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFC700FFC700FFD700FFD700FFD700
FFD700FFD700FFE600FFE600FFE600FFF500FFF500EBFF00DCFF00BDFF0033FF00CCFF00
EBFF00FAFF00FAFF00FAFF00FAFF00FAFF00EBFF0080FF00FAFF00FFF500FFF500FFE600
FFE600FFE600FFE600FFF500FFE600FFF500FFF500FAFF00EBFF00AEFF00FAFF00FFF500
FFD700FFC700FFC700FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FF9900FF9900FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFC700FFC700FFD700FFD700FFD700
FFD700FFE600FFE600FFE600FFE600FFF500FAFF00EBFF0061FF009EFF009EFF00DCFF00
FAFF00FAFF00FAFF00FFF500FFF500FFF500FAFF00FAFF00FFF500FFF500FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFF500FFF500EBFF00AEFF00FAFF00FFE600
FFD700FFC700FFC700FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFC700FFD700FFD700FFD700FFD700
FFE600FFE600FFE600FFF500FFF500FFF500FAFF00EBFF008FFF0023FF00BDFF00DCFF00
FAFF00FAFF00FFF500FFF500FFF500FFF500FFF500FFF500FFF500FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF500FAFF009EFF00FAFF00FFE600
FFD700FFC700FFC700FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFB800FFB800FFC700FFC700FFE600FFE600FFE600FFE600
FFE600FFF500FFF500FFF500FFF500FFF500FAFF00DCFF0080FF0014FF00BDFF00EBFF00
FAFF00FAFF00FFF500FFF500FFF500FFF500FFF500FFE600FFE600FFE600FFE600FFE600
FFD700FFD700FFE600FFE600FFE600FFE600FFE600FFF500FAFF0070FF00FAFF00FFE600
FFD700FFC700FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00
FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF8A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFB800FFB800FFC700FFD700EBFF00FFF500FFE600FFE600
FFF500FAFF00FFF500FFF500FFF500FAFF00EBFF008FFF0061FF00AEFF00CCFF00EBFF00
FAFF00FFF500FFF500FFF500FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD700
FFD700FFD700FFD700FFD700FFD700FFE600FFE600FFE600EBFF0080FF00DCFF00FFE600
FFD700FFC700FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00
FF8A00FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFB800FFB800FFB800FFC700FFD700CCFF00EBFF00FFF500FAFF00
FAFF00DCFF00FAFF00FAFF00FAFF00FAFF00EBFF00BDFF009EFF00CCFF00DCFF00FAFF00
FFF500FFF500FFF500FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD700
FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFE600FFF500DCFF00EBFF00FFE600
FFC700FFC700FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFB800FFB800FFB800FFC700FFD700FFF500AEFF00FAFF00EBFF00
DCFF009EFF00EBFF00FAFF00FAFF00EBFF00DCFF00BDFF00AEFF00DCFF00EBFF00FAFF00
FFF500FFF500FFF500FFE600FFE600FFE600FFE600FFE600FFD700FFD700FFD700FFD700
FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFE600FFE600EBFF00EBFF00FFE600
FFC700FFC700FFC700FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800
FF9900FF9900FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFB800FFB800FFC700FFC700FFE6008FFF00CCFF00AEFF00
8FFF009EFF00DCFF00EBFF00EBFF00DCFF00DCFF009EFF00BDFF00DCFF00EBFF00FAFF00
FFF500FFF500FFE600FFE600FFE600FFE600FFE600FFD700FFD700FFD700FFD700FFD700
FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFE600FAFF00AEFF00FFF500
FFC700FFC700FFB800FFB800FFA800FFA800FFB800FFA800FFA800FFA800FFA800FFA800
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800
FFA800FFA800FFA800FFB800FFB800FFB800FFC700FFC700FFD700FAFF00BDFF00DCFF00
DCFF0000FF0AAEFF00DCFF00CCFF00CCFF00CCFF0023FF00CCFF00EBFF00FAFF00FFF500
FFF500FFF500FFE600FFE600FFE600FFE600FFD700FFD700FFD700FFD700FFD700FFD700
FFD700FFD700FFC700FFD700FFD700FFD700FFD700FFD700FFE600FFF500CCFF00EBFF00
FFC700FFC700FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF7A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800
FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFC700FFD700FAFF00EBFF00FAFF00
EBFF0080FF0051FF00AEFF0070FF009EFF0061FF0080FF00CCFF00EBFF00FAFF00FFF500
FFF500FFE600FFE600FFE600FFE600FFD700FFD700FFD700FFD700FFD700FFD700FFD700
FFD700FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFD700FFE600AEFF00FFE600
FFC700FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF7A00FF7A00FF7A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFB800FFB800FFC700FFC700FFD700BDFF00FFF500FFF500
FAFF0000FFC2CCFF00AEFF00BDFF009EFF009EFF0080FF00CCFF00EBFF00FAFF00FFF500
FFF500FFE600FFE600FFE600FFE600FFD700FFD700FFD700FFD700FFD700FFD700FFD700
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFD700FFE60080FF00FFD700
FFC700FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFC700FFD700FFE600FFE600FFE600
FFF500FAFF00EBFF00CCFF00DCFF00DCFF00CCFF00AEFF00BDFF00EBFF00FAFF00FFF500
FFF500FFE600FFE600FFE600FFE600FFD700FFD700FFD700FFD700FFD700FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFD70051FF00FFC700
FFC700FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF8A00FF8A00FF9900FF9900FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFC700FFC700FFD700FFE600FFE600
FFE600FFF500FAFF00EBFF00FAFF00EBFF00DCFF00BDFF0061FF00EBFF00FAFF00FFF500
FFF500FFE600FFE600FFE600FFD700FFD700FFD700FFD700FFD700FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFD700FFE600FFC700
FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF8A00FF8A00FF8A00FF8A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFC700FFC700FFD700FFD700FFD700
FFE600FFE600FFF500FFF500FAFF00FAFF00EBFF00CCFF00AEFF00DCFF00FAFF00FFF500
FFE600FFE600FFE600FFD700FFD700FFD700FFD700FFD700FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700
FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF8A00FF8A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFC700FFC700FFC700FFD700FFD700
FFD700FFE600FFE600FFF500FAFF00FAFF00EBFF00DCFF0061FF00BDFF00FAFF00FFF500
FFF500FFE600FFE600FFD700FFD700FFD700FFD700FFD700FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFB800
FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFD700
FFD700FFE600FFE600FFE600FFF500FAFF00FAFF00DCFF00AEFF00BDFF00FAFF00FFF500
FFE600FFE600FFE600FFD700FFD700FFD700FFD700FFD700FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF7A00FF7A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFD700
FFD700FFD700FFE600FFE600FFF500FFF500FAFF00DCFF00AEFF00CCFF00FAFF00FFF500
FFE600FFE600FFE600FFD700FFD700FFD700FFD700FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFC700FFB800FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900FFA800FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFD700
FFD700FFD700FFE600FFE600FFF500FFF500FAFF00DCFF008FFF00CCFF00FAFF00FFF500
FFE600FFE600FFD700FFD700FFD700FFD700FFD700FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900FF9900FFA800FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFC700
FFD700FFD700FFD700FFE600FFE600FFF500FAFF00CCFF0000FF57AEFF00FAFF00FFF500
FFE600FFE600FFD700FFD700FFD700FFD700FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFD700
FFD700FFD700FFD700FFE600FFE600FFF500FAFF00BDFF0042FF009EFF00EBFF00FFF500
FFE600FFE600FFD700FFD700FFD700FFD700FFC700FFC700FFC700FFC700FFC700FFC700
FFB800FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FFA800FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700
FFD700FFD700FFD700FFE600FFE600FFF500FFF500DCFF008FFF00CCFF00EBFF00FFF500
FFE600FFE600FFD700FFD700FFD700FFC700FFC700FFC700FFC700FFC700FFC700FFC700
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00
FF8A00FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700
FFC700FFD700FFD700FFD700FFE600FFF500FAFF00EBFF008FFF00DCFF00FAFF00FFF500
FFF500FFE600FFD700FFD700FFD700FFC700FFC700FFC700FFC700FFC700FFC700FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FF9900FFA800FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00
FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00
FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700
FFC700FFD700FFD700FFE600FFE600FFF500FFF500EBFF008FFF00DCFF00EBFF00FFF500
FFF500FFE600FFD700FFD700FFD700FFC700FFC700FFC700FFC700FFC700FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFA800FFB800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FF9900FF9900FFA800FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00
FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00
FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700
FFC700FFD700FFD700FFD700FFE600FFE600FFF500EBFF00AEFF00CCFF00EBFF00FFF500
FFF500FFE600FFD700FFD700FFC700FFC700FFC700FFC700FFC700FFC700FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00
FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00
FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700
FFC700FFD700FFD700FFD700FFE600FFE600FFF500FAFF00CCFF0080FF00EBFF00FAFF00
FFF500FFE600FFD700FFD700FFD700FFC700FFC700FFC700FFC700FFB800FFC700FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFA800FFB800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00
FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700
FFC700FFD700FFD700FFD700FFE600FFE600FFF500FAFF00DCFF009EFF00DCFF00EBFF00
FFF500FFE600FFD700FFD700FFC700FFC700FFC700FFC700FFC700FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700
FFC700FFD700FFD700FFD700FFE600FFE600FFF500FAFF00EBFF0033FF00AEFF00CCFF00
FAFF00FFE600FFD700FFD700FFC700FFC700FFC700FFC700FFC700FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700
FFC700FFD700FFD700FFE600FFE600FFE600FFF500FAFF00EBFF00AEFF00BDFF00AEFF00
EBFF00FFE600FFD700FFD700FFC700FFC700FFC700FFC700FFC700FFC700FFB800FFB800
FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FF9900FF9900FF9900FFA800FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFC700FFC700FFC700
FFC700FFC700FFD700FFD700FFE600FFE600FFF500FAFF00DCFF0042FF00DCFF00EBFF00
EBFF00FFE600FFD700FFD700FFC700FFC700FFC700FFC700FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFA800FFA800FFB800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFC700FFC700
FFC700FFD700FFD700FFD700FFE600FFF500FAFF00EBFF00DCFF008FFF00EBFF00FAFF00
FFF500FFE600FFD700FFD700FFC700FFC700FFC700FFC700FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF9900FF9900FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700
FFC700FFD700FFD700FFE600FFE600FFF500FFF500EBFF00CCFF00AEFF00FAFF00FFF500
FFE600FFD700FFD700FFC700FFC700FFC700FFC700FFC700FFB800FFB800FFB800FFC700
FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF9900FF9900FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700
FFD700FFD700FFD700FFE600FFE600FFF500FAFF00EBFF0080FF00CCFF00FAFF00FFF500
FFE600FFD700FFD700FFD700FFC700FFC700FFC700FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFA800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00
FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700
FFC700FFD700FFD700FFE600FFF500FFF500FAFF00DCFF0070FF00BDFF00FAFF00FFF500
FFE600FFD700FFD700FFC700FFC700FFC700FFC700FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FF9900FF9900FF9900FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF7A00
FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700
FFC700FFD700FFD700FFE600FFF500FAFF00EBFF00BDFF0061FF00DCFF00FAFF00FFF500
FFE600FFD700FFD700FFD700FFC700FFC700FFC700FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700
FFC700FFD700FFD700FFF500EBFF00EBFF00EBFF009EFF00BDFF00EBFF00FAFF00FFE600
FFE600FFD700FFD700FFC700FFC700FFC700FFC700FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700
FFC700FFD700FFD700FFF500AEFF00DCFF00CCFF00AEFF00BDFF00DCFF00FAFF00FFF500
FFE600FFD700FFD700FFD700FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700
FFC700FFD700FFD700FFE600EBFF00BDFF00CCFF008FFF00BDFF00DCFF00EBFF00FFF500
FFE600FFD700FFD700FFC700FFC700FFC700FFC700FFB800FFB800FFB800FFB800FFB800
FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900
FF9900FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700
FFC700FFD700FFD700FFE600EBFF0033FF0080FF0000FF0A70FF00CCFF00CCFF00FFF500
FFE600FFD700FFD700FFC700FFC700FFC700FFC700FFB800FFB800FFB800FFB800FFB800
FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700
FFC700FFD700FFD700FFE600EBFF0000FF0A8FFF00FF000061FF00AEFF00BDFF00FFF500
FFE600FFD700FFC700FFC700FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF8A00FF8A00FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700
FFC700FFD700FFD700FFE60080FF00CCFF00AEFF0000FF198FFF008FFF00DCFF00FFF500
FFE600FFD700FFC700FFC700FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700
FFD700FFD700FFD700FFE600FAFF00EBFF00CCFF0051FF00BDFF00CCFF00CCFF00FFF500
FFE600FFD700FFC700FFC700FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFB800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800
FFA800FFB800FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700
FFC700FFD700FFD700FFE600FFF500EBFF00CCFF0080FF00CCFF00DCFF0061FF00FFF500
FFE600FFD700FFC700FFC700FFC700FFC700FFB800FFC700FFB800FFB800FFB800FFB800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700
FFD700FFD700FFD700FFE600FFF500EBFF00CCFF0000FFE1DCFF00EBFF00EBFF00FAFF00
FFD700FFD700FFC700FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FFA800FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700
FFC700FFD700FFD700FFE600FFF500EBFF00BDFF00BDFF00EBFF00FAFF00FAFF00FFF500
FFD700FFD700FFC700FFC700FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFB800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900FF9900FF9900
FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FFA800FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFC700
FFC700FFD700FFD700FFE600FFF500EBFF0061FF00DCFF00FAFF00FAFF00FFF500FFE600
FFD700FFD700FFC700FFC700FFC700FFC700FFC700FFB800FFB800FFB800FFB800FFB800
FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700
FFC700FFD700FFD700FFE600FFF500EBFF0080FF00DCFF00FAFF00FFF500FFE600FFE600
FFD700FFD700FFC700FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700
FFD700FFD700FFE600FFF500FAFF00BDFF00CCFF00EBFF00FAFF00FFF500FFE600FFE600
FFD700FFD700FFC700FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFC700FFB800FFC700FFC700FFC700
FFC700FFD700FFE600FFF500EBFF00CCFF00DCFF00EBFF00FFF500FFF500FFE600FFD700
FFD700FFC700FFC700FFC700FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00
FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFC700
FFD700FFD700FFE600DCFF00CCFF009EFF00DCFF00FAFF00FFF500FFE600FFE600FFE600
FFD700FFD700FFC700FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900FFA800FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00
FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700
FFD700FFD700FFE60070FF00AEFF008FFF00DCFF00FAFF00FFF500FFE600FFE600FFD700
FFD700FFC700FFC700FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00
FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700
FFD700FFD700FFE600FAFF00EBFF00CCFF00DCFF00FAFF00FFF500FFE600FFE600FFD700
FFD700FFD700FFC700FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFB800FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFC700
FFD700FFD700FFE600FFF500FAFF00DCFF00CCFF00FAFF00FFF500FFE600FFE600FFD700
FFD700FFC700FFC700FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFC700
FFD700FFD700FFE600FFF500FAFF00EBFF008FFF00FAFF00FFF500FFE600FFE600FFD700
FFD700FFC700FFC700FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFC700
FFD700FFD700FFE600FFE600FAFF00EBFF0080FF00FAFF00FFF500FFE600FFE600FFD700
FFD700FFC700FFC700FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFC700
FFD700FFD700FFE600FFE600FFF500DCFF00AEFF00FAFF00FFF500FFE600FFE600FFD700
FFD700FFC700FFC700FFC700FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFB800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFC700
FFD700FFD700FFE600FFE600FFF5008FFF0080FF00EBFF00FFF500FFE600FFE600FFD700
FFD700FFD700FFC700FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFD700
FFD700FFD700FFE600FFF500FAFF009EFF008FFF00EBFF00FFF500FFE600FFE600FFD700
FFD700FFC700FFC700FFD700FFC700FFB800FFB800FFB800FFB800FFB800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF9900FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFC700FFD700
FFD700FFD700FFE600FFF500FFF500DCFF00AEFF00EBFF00FFF500FFE600FFE600FFE600
FFD700FFD700FFC700FFC700FFC700FFC700FFB800FFB800FFB800FFB800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF9900FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FFA800FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFD700
FFD700FFD700FFE600FFF500FFF500DCFF00CCFF00FAFF00FFF500FFE600FFE600FFD700
FFD700FFD700FFC700FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFD700
FFD700FFD700FFE600FFF500FAFF00AEFF00CCFF00FAFF00FFF500FFF500FFE600FFD700
FFD700FFD700FFC700FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFC700FFD700FFD700
FFD700FFE600FFE600FFF500FAFF00DCFF00BDFF00EBFF00FAFF00FFF500FFE600FFE600
FFD700FFD700FFC700FFC700FFC700FFC700FFB800FFB800FFB800FFB800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFD700FFD700FFD700
FFD700FFE600FFE600FFF500FAFF00EBFF009EFF00EBFF00FAFF00FFF500FFE600FFE600
FFD700FFD700FFD700FFC700FFC700FFC700FFB800FFB800FFB800FFB800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FF9900FFA800FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFD700FFD700
FFD700FFE600FFE600FFF500FAFF00DCFF008FFF00DCFF00EBFF00FAFF00FFF500FFE600
FFE600FFD700FFD700FFC700FFC700FFC700FFC700FFB800FFB800FFB800FFB800FFA800
FFA800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FFA800FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800
FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFD700
FFE600FFE600FFF500FFF500FAFF00DCFF0070FF00AEFF00DCFF00FAFF00FFF500FFE600
FFE600FFD700FFD700FFC700FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFA800
FFA800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800
FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFD700FFD700FFD700
FFE600FFE600FFF500FAFF00EBFF00CCFF00AEFF00BDFF009EFF00CCFF00FAFF00FFF500
FFE600FFD700FFD700FFD700FFC700FFC700FFB800FFC700FFB800FFB800FFB800FFA800
FFA800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00
FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800
FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFD700FFE600
FFE600FFF500FFF500FAFF00BDFF00AEFF00DCFF00DCFF00AEFF0051FF00EBFF00FFF500
FFE600FFE600FFD700FFD700FFC700FFC700FFC700FFB800FFB800FFB800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00
FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFC700FFD700FFD700FFD700FFE600
FFF500FFF500FAFF00EBFF0080FF00BDFF00EBFF00EBFF00EBFF00BDFF00DCFF00FAFF00
FFF500FFE600FFE600FFD700FFC700FFC700FFC700FFB800FFB800FFB800FFB800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00
FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800
FFB800FFB800FFC700FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFE600FFE600
FFF500FAFF00FAFF00CCFF00AEFF00EBFF00FAFF00FAFF00FAFF00DCFF00BDFF00DCFF00
FFF500FFE600FFE600FFE600FFD700FFC700FFC700FFB800FFB800FFB800FFB800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FF9900FFA800FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800
FFB800FFB800FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFD700FFE600FFF500
EBFF00FAFF00EBFF00BDFF00DCFF00FAFF00FAFF00FFF500FAFF00EBFF0061FF0051FF00
FAFF00FFF500FFF500FFE600FFD700FFC700FFC700FFB800FFB800FFB800FFB800FFA800
FFA800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800
FFB800FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFD700FFE600FFE600FAFF00
BDFF00DCFF00BDFF0070FF00EBFF00FFF500FFF500FFF500FFF500EBFF00BDFF008FFF00
EBFF00FAFF00FFF500EBFF00FFE600FFD700FFC700FFB800FFB800FFB800FFB800FFA800
FFA800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800
FFB800FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFE600FFE600FFF500EBFF00
9EFF009EFF00BDFF00CCFF00FAFF00FFF500FFF500FFE600FFF500FFF500EBFF00DCFF00
DCFF00EBFF00EBFF009EFF00FFE600FFD700FFC700FFB800FFB800FFB800FFB800FFB800
FFA800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00
FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800
FFC700FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFE600FFF500FAFF0070FF00
00FF85AEFF00EBFF00FAFF00FFF500FFE600FFE600FFE600FFF500FFF500FFF500EBFF00
9EFF00BDFF00AEFF00FAFF00FFE600FFD700FFC700FFC700FFB800FFB800FFB800FFA800
FFA800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFC700FFC700
FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFE600FFE600FAFF00EBFF00AEFF00
61FF009EFF00FAFF00FFF500FFE600FFE600FFE600FFE600FFE600FFE600FFF500FAFF00
EBFF0070FF00CCFF00FFF500FFE600FFD700FFC700FFC700FFB800FFB800FFB800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFB800FFC700
FFC700FFC700FFC700FFC700FFD700FFD700FFD700FFE600FFF50080FF00BDFF00BDFF00
9EFF00FAFF00FFF500FFE600FFE600FFE600FFD700FFD700FFE600FFE600FFE600FFF500
FAFF00EBFF00BDFF00FAFF00FFE600FFD700FFC700FFC700FFB800FFB800FFB800FFB800
FFB800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFC700FFC700
FFC700FFC700FFC700FFD700FFD700FFD700FFD700FFE600FFF500DCFF00CCFF00EBFF00
DCFF00FFF500FFE600FFE600FFD700FFD700FFD700FFD700FFD700FFD700FFE600FFE600
FFF500FAFF0080FF00FFF500FFE600FFD700FFC700FFC700FFC700FFB800FFB800FFB800
FFA800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFC700FFC700FFC700
FFC700FFD700FFD700FFD700FFD700FFD700FFE600FFE600FFF500DCFF00EBFF00FAFF00
FFF500FFE600FFE600FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFE600FFE600
FFE600FAFF009EFF00FAFF00FFE600FFD700FFD700FFC700FFB800FFB800FFB800FFB800
FFA800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800
FFA800FFA800FFA800FFB800FFA800FFB800FFB800FFB800FFB800FFC700FFC700FFD700
FFD700FFD700FFD700FFD700FFD700FFE600FFE600FFF500FAFF00BDFF00FAFF00FFF500
FFE600FFE600FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFE600
FFE600FFF5009EFF00FAFF00FFE600FFD700FFD700FFC700FFC700FFB800FFB800FFB800
FFB800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800
FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFC700FFC700FFC700FFD700FFD700
FFD700FFD700FFD700FFE600FFE600FFE600FFF500FFF500FAFF008FFF00FAFF00FFF500
FFE600FFE600FFD700FFD700FFD700FFD700FFC700FFC700FFC700FFD700FFD700FFD700
FFE600FFF500DCFF00EBFF00FFF500FFE600FFD700FFC700FFC700FFB800FFB800FFB800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900
FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00
FF7A00FF7A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800
FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFC700FFD700FFF500FFE600
FFD700FFD700FFD700FFE600FFE600FFF500FFF500FAFF00DCFF00DCFF00FFF500FFE600
FFD700FFD700FFD700FFC700FFC700FFD700FFC700FFC700FFC700FFC700FFD700FFD700
FFE600FFF500DCFF00EBFF00FFF500FFF500FFD700FFD700FFC700FFB800FFB800FFB800
FFA800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800
FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFC700FFC700FFD700FFF500FFF500
FFE600FFE600FFE600FFE600FFF500FAFF00FAFF00EBFF00CCFF00EBFF00FFF500FFE600
FFD700FFD700FFD700FFC700FFC700FFC700FFC700FFC700FFC700FFD700FFD700FFD700
FFD700FFF500EBFF00DCFF00FAFF00AEFF00FFE600FFD700FFC700FFC700FFB800FFB800
FFB800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800
FFA800FFB800FFA800FFB800FFB800FFB800FFB800FFC700FFC700FFE600CCFF00FAFF00
FFF500FFE600FFE600FFF500FAFF00DCFF00DCFF0080FF00BDFF00CCFF00FFF500FFE600
FFD700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFD700
FFD700FFF500FAFF00AEFF00DCFF009EFF00FFF500FFE600FFC700FFC700FFB800FFB800
FFB800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800
FFA800FFA800FFB800FFB800FFB800FFB800FFC700FFC700FFD700FFE600EBFF00BDFF00
FFF500FFF500FFF500FAFF00DCFF008FFF00BDFF00CCFF00EBFF00BDFF00FFF500FFE600
FFD700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFD700
FFD700FFE600DCFF00CCFF008FFF00BDFF00FAFF00FFF500FFD700FFC700FFB800FFB800
FFB800FFA800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800
FFA800FFA800FFB800FFB800FFB800FFB800FFC700FFC700FFD700FFE600FAFF0061FF00
FAFF00FFF500FAFF00EBFF00CCFF00DCFF00FAFF00FAFF00FAFF00DCFF00FFF500FFD700
FFD700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700FFC700
FFD700FFF500AEFF00EBFF0080FF0000FF0ADCFF009EFF00FFD700FFC700FFC700FFB800
FFB800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800
FFA800FFB800FFB800FFB800FFB800FFC700FFC700FFD700FFE600FFE600FAFF00AEFF00
DCFF00FAFF00FAFF00CCFF00EBFF00FFF500FFF500FFF500FFF500FAFF00FAFF00FFD700
FFC700FFC700FFC700FFB800FFB800FFB800FFB800FFC700FFB800FFC700FFC700FFC700
FFD700FFE600FFF500FFF50080FF00CCFF00AEFF00FFF500FFD700FFC700FFC700FFB800
FFB800FFB800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800
FFA800FFB800FFB800FFB800FFB800FFC700FFD700FFE600FFE600FFF500EBFF009EFF00
8FFF00DCFF00DCFF0042FF00FAFF00FFE600FFE600FFE600FFE600FFF500DCFF00FFD700
FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFC700
FFC700FFD700FFE600FFF5009EFF00EBFF009EFF00FFF500FFD700FFD700FFC700FFB800
FFB800FFB800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800
FFB800FFB800FFB800FFB800FFC700FFC700FFD700DCFF00FFF500FAFF00CCFF0000FF28
00FF38BDFF009EFF00AEFF00FFF500FFE600FFE600FFD700FFD700FFE600FFE600FFC700
FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700FFB800FFC700
FFC700FFC700FFD700FFE600FFF500FFF500CCFF00FFF500FFD700FFD700FFC700FFB800
FFB800FFB800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800
FFA800FFB800FFB800FFB800FFC700FFD700FFD700FAFF00EBFF009EFF009EFF000038FF
23FF00BDFF00DCFF00DCFF00FFF500FFD700FFD700FFD700FFD700FFD700FFD700FFC700
FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFC700
FFC700FFC700FFC700FFD700FFE600FFF50000FF0AFFF500FFE600FFD700FFC700FFC700
FFB800FFB800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FFA800FF9900FFA800FFA800FFA800FFA800FFA800
FFB800FFB800FFB800FFC700FFC700FFD700FFD700FFF500BDFF00BDFF00CCFF0070FF00
42FF00EBFF00FFF500FAFF00EBFF00FFD700FFC700FFC700FFD700FFC700FFC700FFC700
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFC700FFC700FFD700FFD700FFE600EBFF00FAFF00FFE600FFD700FFD700FFC700
FFB800FFB800FFB800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800
FFB800FFB800FFC700FFC700FFC700FFD700FFE600FFF50033FF00EBFF00EBFF00CCFF00
CCFF00FAFF00FFF500FFE600FFE600FFD700FFC700FFC700FFC700FFC700FFC700FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFC700FFC700FFC700FFD700FFE600EBFF00FAFF00FFF500FFD700FFD700FFC700
FFC700FFB800FFB800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFB800
FFB800FFB800FFC700FFC700FFD700FFD700FFE600FAFF00CCFF00FAFF00FAFF00EBFF00
DCFF00FFF500FFE600FFD700FFD700FFC700FFC700FFC700FFC700FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFC700FFC700FFC700FFD700FAFF00BDFF00FFF500FFE600FFD700FFC700
FFC700FFC700FFB800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF8A00
FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF8A00FF8A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFB800
FFB800FFB800FFC700FFD700FFD700FFE600FFF500EBFF00EBFF00FFF500FFF500FAFF00
AEFF00FFF500FFD700FFD700FFC700FFC700FFC700FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFA800FFB800FFA800FFA800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFC700FFC700FFD700BDFF00EBFF00EBFF00FFF500FFD700FFD700
FFD700FFC700FFB800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF8A00
FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFB800
FFB800FFB800FFD700FFE600FFE600FFF500DCFF00AEFF00FAFF00FFF500FFE600FFF500
DCFF00FFF500FFD700FFC700FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFA800FFB800FFA800FFA800FFB800FFA800FFA800FFB800FFA800FFB800FFB800
FFB800FFB800FFB800FFB800FFC700FFD700FAFF00FFF50080FF00FAFF00FFE600FFE600
FFD700FFD700FFD700FFB800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00
FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00
FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFB800
FFB800FFC700FFD70070FF00FFF500DCFF00DCFF00FAFF00FFF500FFE600FFE600FFE600
8FFF00FFE600FFC700FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFA800FFA800FFB800FFA800FFA800FFA800FFA800FFA800FFB800FFA800FFA800FFB800
FFB800FFB800FFB800FFB800FFC700FFC700FFD700FFE600FAFF00EBFF00FAFF008FFF00
FAFF00FFF500FFD700FFB800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00
FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00
FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFB800FFB800
FFB800FFC700FFD700FAFF00EBFF008FFF00FAFF00FFF500FFE600FFD700FFD700FFD700
DCFF00FFD700FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFB800
FFB800FFB800FFB800FFB800FFB800FFC700FFD700FFD700FFE600DCFF00CCFF00EBFF00
DCFF00FAFF00FFE600FFB800FFA800FF9900FFA800FF9900FF9900FF9900FF9900FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FFA800FF9900FFA800FFA800FFA800FFA800FFA800FFB800FFB800
FFB800FFC700FFD700FFF500CCFF00EBFF00FFF500FFE600FFD700FFD700FFD700FFD700
FFD700FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFB800FFB800FFB800FFB800FFC700FFC700FFD700FFE600FAFF00DCFF00FFF500
FFE600FFD700FFF500FFB800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800
FFB800FFC700FFD700FFE600EBFF00FAFF00FFE600FFD700FFD700FFD700FFD700FFC700
FFC700FFC700FFB800FFB800FFB800FFB800FFB800FFA800FFA800FFB800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFB800FFB800FFB800FFB800FFC700FFC700FFD700FFF500EBFF00FFE600
FFD700FFC700FFC700FFB800FFA800FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800
FFC700FFC700FFD700FFE600EBFF00FAFF00FFE600FFD700FFD700FFD700FFC700FFC700
FFC700FFC700FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFB800FFB800FFB800FFC700FFC700FFD700FFF500FAFF00FFD700
FFC700FFC700FFB800FFA800FFA800FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900
FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800
FFC700FFC700FFD700FFE600EBFF00FAFF00FFE600FFD700FFD700FFC700FFC700FFC700
FFC700FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFB800FFB800FFC700FFC700FFD700FFF500FAFF00FFD700
FFC700FFB800FFB800FFA800FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900
FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800
FFC700FFC700FFD700FFE600EBFF00DCFF00FFD700FFD700FFC700FFC700FFC700FFB800
FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFC700FFD700FFF500FAFF00FFD700
FFB800FFB800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FFA800FF9900FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFC700
FFC700FFD700FFD700FFF50080FF00FFF500FFD700FFC700FFC700FFC700FFC700FFB800
FFB800FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFC700FFD700EBFF00FFE600FFC700
FFB800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900
FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFC700
FFC700FFD700FFE600CCFF00DCFF00FFE600FFD700FFC700FFC700FFC700FFB800FFB800
FFB800FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FF9900FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFD700FAFF00FFE600FFC700
FFB800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900
FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFC700FFC700
FFC700FFD700FFE600BDFF00FAFF00FFE600FFD700FFC700FFC700FFB800FFB800FFB800
FFB800FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FF9900FF9900FFA800FF9900FFA800FF9900FF9900FFA800FFA800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFC700FFF500FFF500FFC700
FFB800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF9900
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900
FF9900FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFC700FFC700
FFD700FFD700FFF500EBFF00FFF500FFD700FFC700FFC700FFC700FFB800FFB800FFB800
FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900FFA800
FF9900FF9900FF9900FF9900FFA800FF9900FFA800FF9900FF9900FF9900FF9900FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFC700FFE600FFE600FFC700
FFB800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00
FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900
FF9900FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFC700FFC700FFC700FFC700
FFD700FFE600DCFF00FAFF00FFE600FFD700FFC700FFC700FFB800FFB800FFB800FFB800
FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FFA800FFA800FFA800FFA800FFA800FFB800FFB800FFC700FAFF00FFE600FFC700
FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF8A00FF9900FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900
FFA800FFA800FFA800FFA800FFB800FFB800FFB800FFB800FFC700FFC700FFC700FFD700
FFD700FFE600DCFF00FAFF00FFE600FFD700FFC700FFC700FFB800FFB800FFB800FFB800
FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FF9900FFA800FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFB800FFC700FFE600FFF500FFC700
FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FFA800
FFA800FFA800FFA800FFA800FFB800FFB800FFC700FFC700FFC700FFC700FFC700FFD700
FFE600FFF500AEFF00FFF500FFE600FFD700FFC700FFC700FFB800FFB800FFB800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FF9900FFA800FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFB800FFC700FFE600FAFF00FFC700
FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FFA800FFA800
FFA800FFA800FFA800FFB800FFB800FFB800FFC700FFC700FFC700FFD700FFD700FFD700
FFE600FFF500BDFF00FFF500FFE600FFD700FFC700FFB800FFB800FFB800FFB800FFA800
FFA800FFA800FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FFA800FF9900FF9900FF9900FFA800FFA800FFA800FFA800FFB800FFF500FFD700FFC700
FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FFA800
FFA800FFB800FFB800FFB800FFB800FFC700FFD700FFD700FFD700FFD700FFD700FFE600
FFF500FAFF00AEFF00FFF500FFE600FFD700FFC700FFC700FFB800FFB800FFA800FFA800
FFA800FFA800FFA800FFA800FF9900FFA800FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFB8009EFF00FFC700FFB800
FFA800FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FFA800FFA800
FFB800FFB800FFB800FFB800FFC700FFD700FFE600FFE600FFE600FFE600FFE600FAFF00
BDFF008FFF00DCFF00FAFF00FFE600FFD700FFC700FFB800FFB800FFB800FFA800FFA800
FFA800FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFB800FFE600FFB800FFA800
FFA800FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FFA800FFB800
FFB800FFB800FFB800FFC700FFD700FFE600AEFF0070FF00FAFF00FAFF00FAFF00CCFF00
FAFF00FAFF00FAFF008FFF00FFE600FFD700FFC700FFB800FFB800FFA800FFA800FFA800
FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFB800FFB800FFA800FFA800
FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FFA800FFB800
FFB800FFC700FFC700FFC700FFE600DCFF00FFF500FAFF00BDFF00CCFF00BDFF00FAFF00
FFE600FFE600FFF500DCFF00EBFF00FFD700FFC700FFB800FFB800FFB800FFA800FFA800
FFA800FFA800FFA800FF9900FF9900FF9900FFA800FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FFA800FFA800FF9900
FF9900FF9900FF9900FF9900FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF8A00FF8A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FFA800FFD700
FFC700FFD700FFD700FFD700FFF500FFF500FFE600FFE600FFE600FFF500FFE600FFF500
FFD700FFD700FFE600FFF500FAFF00FFD700FFC700FFB800FFB800FFA800FFA800FFA800
FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800FFA800FF9900FF9900
FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF8A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FFA800FFE600
FFF500DCFF00FFE600FFE600EBFF00FFE600FFD700FFD700FFD700FFD700FFD700FFD700
FFD700FFD700FFD700FFE600FAFF00FFD700FFC700FFC700FFB800FFA800FFA800FFA800
FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FFA800FFC700
FFF500FFE600EBFF00EBFF00FFF500FFD700FFC700FFC700FFC700FFC700FFC700FFC700
FFC700FFC700FFD700FFE600CCFF00FFD700FFC700FFB800FFB800FFA800FFA800FFA800
FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FFA800FFB800
FFC700FFC700FFE600FFF500FFE600FFD700FFC700FFC700FFB800FFB800FFB800FFC700
FFC700FFC700FFC700FFE600DCFF00FFD700FFC700FFB800FFA800FFA800FFA800FFA800
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FFA800
FFB800FFB800FFC700FFE600FFE600FFC700FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFC700FFD700CCFF00FFD700FFC700FFB800FFA800FFA800FFA800FFA800
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF9900FF9900FF8A00FF8A00FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FFA800
FFA800FFB800FFB800FFD700FFD700FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFC700FFD7009EFF00FFD700FFC700FFB800FFA800FFA800FFA800FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF8A00FF8A00FF9900FF9900FF8A00FF8A00FF9900FF8A00FF8A00FF9900
FF8A00FF8A00FF9900FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00
FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FFA800
FFA800FFA800FFB800FFD700FFD700FFB800FFB800FFA800FFB800FFA800FFB800FFA800
FFB800FFB800FFB800FFC700EBFF00FFE600FFC700FFB800FFA800FFA800FFA800FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00
FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF9900
FF8A00FF8A00FF9900FF8A00FF9900FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900
FFA800FFA800FFB800FFD700FFD700FFB800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFB800FFB800FFC700FFF500FFF500FFC700FFB800FFA800FFA800FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00
FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF9900
FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF7A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900
FF9900FFA800FFA800FFC700FFB800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFB800FFC700FFD700AEFF00FFF500FFB800FFA800FFA800FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF9900FF9900FF8A00
FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF7A00FF7A00FF7A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900
FF9900FF9900FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800FFA800
FFA800FFA800FFB800FFB800FFD700FFF500FFD700FFB800FFA800FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF9900FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF8A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900
FF9900FF9900FF9900FFA800FFA800FFA800FF9900FF9900FF9900FF9900FFA800FFA800
FFA800FFA800FFA800FFB800FFD700FFD700FFB800FFA800FFA800FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF8A00FF9900FF8A00FF8A00FF8A00FF9900FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00
FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA800
FFA800FFA800FFA800FFB800FFD700FFC700FFB800FFA800FFA800FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FFA800FFA800FFA800EBFF00FFB800FFA800FFA800FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FFA800FFA800FFB800FFA800FFA800FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF8A00FF8A00FF9900FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FFA800FFA800FFA800FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF9900
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF8A00FF8A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FFA800FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF8A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF8A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF9900
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF9900FF8A00FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF9900FF8A00FF9900
FF8A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8A00FF9900FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF7A00FF7A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF9900FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF7A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF9900FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00
FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00
FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF8A00FF8A00FF7A00FF7A00FF7A00
FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF8A00FF8A00FF7A00FF7A00FF7A00
FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00
FF7A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00
FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF8A00FF8A00FF8A00FF8A00FF7A00
FF7A00FF7A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00
FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF8A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF7A00FF7A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF8A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF8A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00
FF7A00FF7A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF8A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF8A00FF8A00FF8A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF8A00FF7A00FF7A00FF7A00FF8A00FF8A00FF7A00FF7A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF7A00FF7A00FF7A00FF8A00FF8A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF8A00FF8A00FF8A00
FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00
FF8A00FF7A00FF7A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF8A00FF8A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF8A00FF8A00FF7A00
FF7A00FF8A00FF8A00FF8A00FF7A00FF8A00FF8A00FF8A00FF7A00FF7A00FF8A00FF8A00
FF7A00FF7A00FF7A00FF8A00FF8A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00
FF7A00FF8A00FF8A00FF7A00FF7A00FF7A00FF8A00FF8A00FF7A00FF7A00FF8A00FF8A00
FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF8A00
FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF8A00
FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF8A00
FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF8A00
FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF8A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF8A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00
FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF8A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00
FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00
FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00
FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00
FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF6B00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00
FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00
FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00
FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00
FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00
FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00
FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00
FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00
FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00
FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF7A00
FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00
FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00
FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00
FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF7A00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00
FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF6B00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF6B00FF6B00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 144},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000T2000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`007?ooool2o`0000Cooooo00?o0000ooooooooool00_ooool3o`0001_o
oooo0_l00004ooooo`03o`000?oooooooooo00?ooooo0ol0000Jooooo`;o00001?ooool00ol0003o
ooooooooo`02ooooo`?o00006oooool2o`0000Cooooo00Co0000oooooooooooooooo1Ol0000Joooo
o`;o00001?ooool00ol0003oooooooooo`02ooooo`?o00007_ooool2o`00027ooooo0_l00004oooo
o`03o`000?oooooooooo00;ooooo0ol00003ooooo`006oooool01?l0003oooooooooool00007oooo
o`05o`000?ooooooooooooooool000006Oooool01?l0003oooooooooool0000:ooooo`03o`000?oo
oooooooo01Sooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo000001Wo
oooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool0000Iooooo`04o`000?oooooo
ooooo`0000Wooooo00?o0000ooooooooool07?ooool01?l0003oooooooooool0000Oooooo`04o`00
0?ooooooooooo`0000Wooooo00?o0000ooooooooool00_ooool001Cooooo1Ol00002ooooo`04o`00
0?ooooooooooo`0000_ooooo00?o0000ooooooooool04?ooool5o`0000;ooooo00Co0000oooooooo
oooo00001oooool5o`0001;ooooo1Ol00002ooooo`04o`000?ooooooooooo`0000_ooooo00?o0000
ooooooooool04?ooool5o`0000;ooooo00Co0000oooooooooooo00002Oooool00ol0003ooooooooo
o`0Booooo`Go00000_ooool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo01cooooo
00Co0000oooooooooooo00007oooool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo
00;ooooo000Kooooo`04o`000?ooooooooooo`0000_ooooo00?o0000ooooooooool05oooool01?l0
003oooooooooool00007ooooo`04o`000?ooooooooooo`0001[ooooo00Co0000oooooooooooo0000
2Oooool2o`0001[ooooo00Co0000oooooooooooo00002_ooool00ol0003oooooooooo`0Hooooo`04
o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool07?ooool01?l0003oooooooooool0000O
ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool00_ooool001_ooooo00Co0000
oooooooooooo00001oooool4o`0001[ooooo00Co0000oooooooooooo00002?ooool00ol0003ooooo
o`00000Jooooo`04o`000?ooooooooooo`0000_ooooo00?o0000ooooooooool05oooool01?l0003o
ooooooooool00007ooooo`05o`000?ooooooooooooooool000006Oooool01?l0003oooooooooool0
0009ooooo`03o`000?oooooooooo01cooooo00Co0000oooooooooooo00007oooool01?l0003ooooo
ooooool00009ooooo`03o`000?oooooooooo00;ooooo000Kooooo`04o`000?ooooooooooo`0000Oo
oooo00?o0000ooooooooool06oooool01?l0003oooooooooool00009ooooo`;o00006_ooool01?l0
003oooooooooool00007ooooo`05o`000?ooooooooooooooool000006Oooool01?l0003ooooooooo
ool00007ooooo`05o`000?ooooooooooooooool000006Oooool01?l0003oooooooooool00008oooo
o`;o00007_ooool01?l0003oooooooooool0000Oooooo`04o`000?ooooooooooo`0000Sooooo0_l0
0004ooooo`007?ooool2o`0000Sooooo1Ol0000Jooooo`;o00002oooool00ol0003oooooooooo`0I
ooooo`;o00002Oooool3o`0001_ooooo0_l00009ooooo`?o00006oooool2o`0000[ooooo00?o0000
ooooooooool07Oooool2o`00027ooooo0_l0000:ooooo`03o`000?oooooooooo00;ooooo003ooooo
ob7ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo0008ooooo`;o00001?ooool0
0ol0003oooooooooo`02ooooo`;o00001_ooooooo`00007o00001Oooool000Oooooo00Co0000oooo
oooooooo00002_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00Go0000
ooooooooooooooooo`000005ooooo`001oooool01?l0003oooooooooool0000;ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Vooooo`03o`000?oo
oooooooo02Kooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Vooooo`03o`000?oo
oooooooo02Kooooo00?o0000ooooooooool09_ooool01Ol0003ooooooooooooooooo000000Gooooo
0007ooooo`04o`000?ooooooooooo`0000Sooooo1?l00004ooooo`;o0000o?ooool2o`0000Gooooo
0007ooooo`04o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`000004ooooo`03
o`000?oooooooooo00;ooooo2@3oJ`0/0?mj00030?n4003oP000ogX000H0ogX000<0oh800?n:003o
RP003`3oRP000`3oT000ohX00?n:00020?n:00030?nB003oV@00oiT000P0oiT000<0oi/00?nM003o
V`002@3oZ000103oZP00ok000?nZ003o/0020?nb00T0okP000<0okX00?nl003o`P000P3oa`002P3o
b`00omL00?_]003:o@00]_l007Ko3@3Ho`00j?l0097o001/oah20=So000P0<ko002lo`00M?l;00_h
>P1no`00]_l00<Wo003<o`00b_l00<Wo002ho`00L?l204G0BP0=o6P02Om]03;o4`0jobD0B?l0023o
000PeWX0MUj[00N8iP01i6h07olU077o001ho`00?Ol601oo<`21o`80c?l00>3o003Yo`040>_o000:
0>Co002oo`00HOl006Co0`2=o`80Aol@0:Ko0039oP00ond00?oG0080olT000<0olL00?nh003o^000
0`3o^000103o]000ojX00?n^003o[0070?nX00030?nQ003oV@00oiT00080oi/0203oV@001@3oUP00
ohX00?n:003oS000oi0000h0ohX000<0oh@00?mj003oNP001P3oNP04ooooo`03o`000?oooooooooo
00?ooooo0007ooooo`04o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`000004
ooooo`03o`000?oooooooooo00;ooooo2@3oJ`0[0?mj00030?n2003oO000ogX000P0ogX02P3oRP00
0`3oS000ohX00?n:00030?n:00030?n<003oRP00ohX000<0ohX000<0oiL00?nI003oV@002`3oV@00
0`3oX`00oj400?nX00050?nX00050?nY003oZ000ojX00?nX003o[P000P3oZ0000`3o]000oj`00?nf
00080?nh000F0?nn003oa000olL00?o7003oc`00omT00?oQ003nm000[_l00?_l003mnP00mO`00?Sm
003fo`00kol00=co002Vo`D0BOlM01GOHP1<oB00`ol00=;o0080g?l002P0d_l00;ko001ImR00=oQC
073h800]iUP0C?l007Ko001Co`804?dc00g8K@00ci@00>>D01KO=P0XobD0Q?l009Go002?o`00@OPR
05go1@3Do`00jOl00>_o003co`00n?l00?[o003ho`00kOl00;Ko002FnR40]?l00>3o003;o`00O?l0
0<Go4@3oj`00omL00?o9003oa`00ol@00P3o^P030?nh00030?nd003oZ000ojP00080ojP000<0ojT0
0?nX003oZ0000`3oZ0000`3oX`00oiT00?nI000:0?nI00030?nD003oRP00ohX00080ohX000<0oh`0
0?n:003oRP00303oRP000`3oOP00ogX00?mj00050?mj00Cooooo00?o0000ooooooooool00oooool0
00Sooooo0_l00009ooooo`?o00001Oooool00ol0003oooooooooo`02ooooo`T0of/000<0ogD00?mj
003oNP009`3oNP000`3oOP00ogX00?mj00080?mj00030?n0003oRP00ohX001<0ohX000D0ohh00?nG
003oT000oi000?nG00090?nI00050?nK003oV@00oiT00?nX003oY0002P3oZ0001P3oZP00ojP00?nX
003o/P00ok000?nd00D0okP000T0okX00?nh003o`000olD00?o7003ob@00oll00?oG003og@000`3o
jP00903ok000oo<00?kh003ho`00h_l00;_o0015lRL07od]09?o0`3>o`00g?l00>3o003No`00g?l0
0<oo002Jo`<0_Ol00:ko000aocl0K_lJ09Oo002:o`00Eol903co000Za4400^ai04;o001[o`00Uol0
0:Ko002do`00^_l00;Co003No`00jol00?Go0080n_l000`0nod00?_n003ko@00loh00?On003jo@00
nod00?;n0023o`l0`oh00?oQ003oe@020?o700030?o0003o^000okP00080okP000<0okH00?n`003o
[0001`3oZ000103oW@00oiT00?nK003oW`0<0?nI00030?n>003oRP00ohX000`0ohX000H0oh@00?n2
003oPP00ohH00?n:003oOP060?mj00Cooooo00?o0000ooooooooool00oooool001_ooooo0_l00003
ooooo`T0of/000<0og<00?mj003oNP009P3oNP000`3oOP00ogX00?mj00090?mj00030?n4003oRP00
ohX00180ohX000<0oh`00?n@003oRP000P3oRP000`3oSP00oiT00?nI00060?nI00030?nK003oV@00
oiT00080oi/000<0oiT00?nS003oZ0002`3oZ0000`3o[000ojP00?n/00080?nh00050?nn003oa@00
olL00?o7003oc@000P3oe`00303of@00omd00?oT003oiP00oo000?cl0037o`00J_lA03GLG00cobL0
Pol20=ko00@0jol001P0j?l00=co003Fo`00aol008oo2`2^o`00[?l009_o0026o`00Fol000?QN001
/Zd0:?l:07Co002Eo`00/_l00<7o003<o`00f?l00>Wo003eo`00n_l00?_n003nn@030?oe00090?og
003ol`00oo400?oa003om@00nO`009?k2`3og@00oll00080olL000<0okX00?nh003o^0000P3o^000
0`3o/000ojP00?nX00070?nX00d0oiT000D0ohh00?n:003oS000oi800?n<000<0?n:00030?n4003o
NP00ogX00080ogX000<0og`00?n4003oP0001@3oNP03ooooo`;o00001Oooool001_ooooo00?o0000
ooooooooool00_ooool90?m[00030?mh003oNP00ogX002D0ogX000<0ogh00?mj003oNP002@3oNP00
0`3oO000ohX00?n:000C0?n:00030?n<003oRP00ohX00080ohX000<0oh`00?nI003oV@002@3oV@00
1P3oV`00oiT00?nI003oX`00oid00?nQ00T0ojP000@0ojX00?nX003oZ000ojh00P3oZP070?nh0006
0?o0003oa@00olL00?o7003ob@00oll00`3oe`00903oh`00onX00?gj003Uo`00B_lh06co0P1@nSd0
]_l00>_o003co`00mol00?[o003co`00kOl00>Oo003To`00e_l00=3o0035o`00^?l00:7o001Wo`00
B_l000[o5000lZd04oX/01So6P1fo`00]_l00<Go003Do`00g?l00>_o003ho`00n_l00?kh0080ooD0
00<0oo<00?o^003ojP00103oiP001P3ojP00on@00?oE003ob@00olL00?o000D0okP000<0okH00?nZ
003oZ0001`3oZ0000`3oX`00oiT00?nI000:0?nI00@0ohX00P3oS00;0?n:00L0ogX000<0og`00?mn
003oNP000`3oNP04ooooo`03o`000?oooooooooo00?ooooo000Kooooo`03o`000?oooooooooo00;o
oooo2@3oJ`0d0?mj00040?n6003oRP00oh@00?n00080ogh000<0oh@00?n:003oRP001@3oRP000`3o
S000ohX00?n:000:0?n:00040?nD003oU`00oiD00?nG00X0oiT000H0oi/00?nI003oV@00oiT00?nX
003oY@0:0?nX00030?nZ003oZ000ojP000L0okP000<0okX00?o0003oa@000P3oa`020?o90080omL0
00T0omT00?oU003mnP00g_l0073o0P2^o`00f_l00?7o003jo`000P3koP030?[o000E0?7o003[o`00
h?l00=[o003<o`00`Ol009go001?k3L03_lH00[LV00@QMl09MmR01cB@P19o``0Z?l00<?o003Bo`00
g_l00>ko003jo`00o?`00080ooD000<0oo400?oX003oiP000P3oiP000`3oh@00omd00?oI00020?oG
00050?o;003oa`00olL00?nl003o^P000`3o^0001@3o/000ojP00?nX003oZ000ojX000@0ojP000@0
oil00?nI003oW@00oid02`3oV@000`3oS000ohX00?n:000>0?n:00T0ogX000@0og`00?mj003oNP00
ogX01?ooool00ol0003oooooooooo`03ooooo`006oooool00ol0003oooooooooo`02ooooo`P0of/0
00<0ofd00?mj003oNP005`3oNP000`3oO000ogX00?mj000G0?mj00030?n2003oR000og`000D0ogX0
00<0oh@00?n:003oRP00403oRP000`3oSP00oi800?n:00020?n:00030?nG003oV@00oiT000X0oiT0
00<0oil00?nK003oV@00303oZ0000`3o[000ojX00?nX00030?nh00050?nj003o^000okP00?nj003o
_000103oa`002`3ob@00om<00?oG003oh000lOP007Wo4P1no`00dol00?Wn003nn@00o_P00080ooD0
01/0ooL00?_m003jo`00n?l00>_o003Yo`00g?l00=;o0035o`00/?l007Go6@0aobD08_l7003jSP0I
o``0HOl007Ko2`2Vo`00`Ol00<co003Jo`00j_l00?[o003mn@00ooD00?ob003oj0000P3oiP000`3o
i000omd00?oI00020?oG00060?oC003oc@00olT00?o7003oa000okX0103o^0000`3o]000ojP00?nX
00060?nX00d0oiT00P3oU@000`3oU`00oh`00?n:000>0?n:00030?n0003oNP00ogX000P0ogX000<0
og`00?mj0?ooool00oooool00ol0003oooooooooo`03ooooo`006oooool2o`0000?ooooo203oJ`00
0`3oL`00ogX00?mj00020?mj00080?mi003oMP00ofl00?m]003oJ`00ofh00?ma003oMP0V0?mj0003
0?mo003oP@00ogX000L0ogX02`3oRP000`3oS000ohX00?n:00030?n:0080oh`0103oRP000`3oTP00
oiT00?nI000:0?nI00060?nL003oV@00oiT00?nW003oXP00oj@0203oZ0001P3oZP00ojP00?nX003o
Z000okL00?ne00D0okP000<0okX00?nh003oa`000`3oa`002@3obP00om<00?oI003oh`00o^h00?ce
003km000oo400?o_00020?oa00<0ooD001P0o?/00?[o003ao`00j_l00=_o003?o`00`_l00;Co002M
o`00OOl004Oo0`0_^h005_lP05Si6P28o`00X_l00:go002^o`00Wol00<Co003io`00o_L00?oe003o
k0020?oV00030?oR003ofP00omL00080omL000L0om<00?o:003oa`00olL00?o6003o`000okX000<0
okP000D0okD00?n]003oZ`00ojP00?nZ00050?nX00030?nR003oV@00oiT000T0oiT000H0ohl00?n:
003oRP00ohX00?n=003oS00>0?n:00030?n9003oO@00ogX000X0ogX00oooool2o`0000Gooooo000K
ooooo`03o`000?oooooooooo00;ooooo203oJ`040?mj00030?me003oJ`00of/000H0of/000<0og<0
0?mj003oNP005@3oNP000`3oO000ogX00?mj000:0?mj00030?n0003oO000ogX000P0ogX05`3oRP00
0`3oU`00oiT00?nI000<0?nI00040?nL003oV`00oiT00?nI00/0ojP000@0oj`00?nX003oZ000ok@0
1@3o^0000`3o_000okP00?o400030?o700040?o9003od`00omL00?oM0080on@0103oiP006`3ojP00
ooD00?oe003om`00n_l00?7o003To`00d?l00<?o002ho`00[?l009_o001Oo`d07?lI007OE003od/0
2?m004[o3`2:o`00N?l0037d800kgbX0O_l60??o003om`00ooD00?oZ00020?oV00030?oK003oe`00
omL00080omL0103oa`000`3o`P00okP00?nh00030?nh00030?nb003oZ000ojP000H0ojP000@0oil0
0?nM003oW@00oi/02@3oV@000`3oS000ohX00?n:00030?n:00030?n<003oRP00ohX000P0ohX000H0
ohT00?n2003oPP00ohH00?n:003oOP0:0?mj00Cooooo00?o0000ooooooooool00oooool001_ooooo
00?o0000ooooooooool00_ooool70?m[00050?ma003oNP00ogX00?mh003oK`002P3oJ`000`3oM@00
ogX00?mj000P0?mj00030?mn003oNP00ogX000P0ogX000<0og`00?n:003oRP00503oRP001@3oT000
oi@00?n<003oRP00oi8000/0oiT000@0oiX00?nI003oV@00oiT02P3oZ000103o[000ojP00?nX003o
Z0070?nh00030?nj003o_000ol8000<0olL000L0ol/00?oG003oe`00omL00?oI003of`00on<000@0
onH001P0oo800?oe003jo`00kOl00=Co001Vo`/0Vol006Go5@2?o`00R?l004o`800Sd4P0D6Rb08e0
M@01k7h0;OlA04Ko0`0HodX0G]lP0:Co003Po`00n?l00?oe003ol0020?oV00030?oQ003of@00omL0
0080omL000H0olL00?o9003oa`00olL00?o5003o_0050?nh00040?nf003o[P00ojX00?nZ00@0ojP0
00<0oj<00?nI003oV@002`3oV@000`3oUP00ohX00?n:000>0?n:00050?mk003oNP00ogX00?mj003o
O0000P3oP0090?mj00Cooooo00?o0000ooooooooool00oooool001_ooooo00?o0000ooooooooool0
0_ooool70?m[00040?mh003oNP00ogP00?m]00`0of/08@3oNP000`3oOP00ogX00?mj00090?mj0003
0?n2003oRP00ohX001<0ohX000<0oh`00?n>003oRP000`3oRP060?nI00050?nK003oV@00oiT00?nI
003oV`000`3oV@020?nO00030?nI003oV`00ojH000T0ojP000<0ojh00?nZ003oZ0001`3o^0000`3o
`P00ol@00?o700020?o700030?o9003od@00omL00080omL000<0omT00?oO003oi0000P3oiP00603o
jP00ooD00?cl002Vo`T0POl703[O=00Zo`d07Mm002Ko<P1=o`807>XZ017FR01l@YX0`0i00076V`0B
kU809^PU033o4@2Go`00`Ol00>Ko003jo`00ooD00?o`0080onH000H0omd00?oI003oe`00omL00?o=
003ob@040?o700030?nj003o^000okP000<0okP0103oZ0001@3oZP00ojP00?nX003oZ000ojL000`0
oiT00P3oU@000`3oU000oh`00?n:000<0?n:00030?n2003oNP00ogX000D0ogX000<0oh000?ml003o
NP001P3oNP04ooooo`03o`000?oooooooooo00?ooooo000Kooooo`;o00000oooool60?m[00030?ma
003oNP00ogL000h0of/000<0ogD00?mj003oNP00:@3oNP001P3oO000ohX00?n:003oRP00ohH00?n8
0100ohX00P3oS0050?n:00d0oiT000<0oi/00?nM003oV@000P3oV@000`3oX@00ojP00?nX000:0?nX
00P0okP000<0okX00?o7003oa`000P3oa`000`3ob@00oll00?oG00030?oG000K0?oM003oh`00onH0
0?oV003olP00oOT00>So002To`00Tol=07Oo7`23o`D0Jol001oo2P0aoa807_lM00G;U00l[kL00Olo
04ko001jo`00<olQ02[m<P2@o`00aol00?So003om@00oo000080onH000H0omT00?oG003oe`00omL0
0?o=003ob@030?o700030?nj003o^000okX000@0okP000<0ojh00?nX003oZ0001P3oZ0000`3oX`00
oid00?nK00080?nI00050?n>003oRP00ohX00?n:003oS0003@3oRP000`3oPP00ogX00?mj00070?mj
00030?ml003oNP00ogX000@0ogX00oooool2o`0000Gooooo000Kooooo`03o`000?oooooooooo00;o
oooo1P3oJ`020?mh00l0of/000<0og<00?mj003oNP00:@3oNP000`3oQP00ohP00?n000030?mj0003
0?ml003oQP00ohX000d0ohX000<0oh`00?n:003oRP000`3oRP00103oSP00oiT00?nG003oU`0?0?nI
00`0ojP00`3o[P060?nh00030?nl003o^P00olL000<0olL000<0olT00?o?003oe`000`3oe`007@3o
g@00on@00?oV003ojP00ooD00?cm003eo`00j?l00=So002ko`00I_l503?o9024o`00GOl202Sj:@03
oeH0>>XP08Ko002Lo`00P?l006So5@0Miel0K?l80>_o003om`00onX00?oV003oh`00omT00080omL0
00<0om<00?o7003oa`000`3oa`000`3o`000okX00?nh00030?nh00030?nf003o[P00ojX000H0ojP0
00<0oih00?nI003oV@002@3oV@0B0?n:00030?n8003oNP00ogX000h0ogX01?ooool00ol0003ooooo
ooooo`03ooooo`006oooool00ol0003oooooooooo`02ooooo`D0of/000<0og400?mh003oK@003`3o
J`000`3oL`00ogX00?mj000X0?mj00030?n4003oPP00ogX000D0ogX000<0og`00?n:003oRP004@3o
RP000`3oS000oiD00?n<00020?n:00030?nB003oV@00oiT000/0oiT000@0oj400?nO003oV@00oi/0
1`3oZ0020?nZ00<0ojP0103o^0001@3o^P00okP00?nh003o^P00ol<000@0olL000<0olT00?oC003o
e`000`3oe`004P3og`00onH00?oV003okP00ooD00?gk003go`00i?l009Co0P0eob40POPP0:Ko002E
o`00Kol000_hN@18o`80Rol00;;o0080^ol000L0QoY00;Go0P2inR00ooD00?oX003oiP00on4000<0
omL000L0omD00?o9003oa`00olT00?o7003oa@00okX000D0okP000<0ok000?nX003oZ0001P3oZ000
0`3oVP00oiT00?nI00090?nI00030?n>003oRP00ohX00100ohX000<0oh400?mj003oNP003@3oNP04
ooooo`03o`000?oooooooooo00?ooooo000Kooooo`03o`000?oooooooooo00;ooooo103oJ`000`3o
K@00ogX00?m]000@0?m[00030?mc003oNP00ogX002L0ogX000<0oh000?mn003oNP001`3oNP000`3o
QP00ohX00?n:000@0?n:00030?n>003oRP00ohX000<0ohX0303oV@000`3oV`00oiT00?nI00020?nI
00030?nQ003oZ000ojP000P0ojP000<0ojh00?nh003o^000103o^000103o^P00okP00?nh003o`P05
0?o700@0omL000X0omT00?oT003oiP00onH00?ob003om@00o?d00<_o001^oa<0UOl00P2mo`003`2M
o`00;olI02[5PP08oc@0MOl=0;oo003>o`00e_l00>Ko003_o`00n_d00?oe003oj000onH00?oQ0003
0?oG00030?oA003oa`00olL000<0olL000<0ok`00?nh003o^0000`3o^0000`3o]P00ojh00?nZ0006
0?nX00030?nR003oV@00oiT000X0oiT000<0oi000?n:003oRP003`3oRP000`3oR@00og`00?mj000=
0?mj00Cooooo00?o0000ooooooooool00oooool001_ooooo0_l00003ooooo`@0of/000<0ogD00?m_
003oJ`00403oJ`000`3oL`00ogX00?mj000V0?mj00030?n0003oO000ogX000P0ogX000<0oh@00?n:
003oRP003P3oRP000`3oS000ohX00?n:00050?n:0140oiT02P3oZ0020?nZ00030?nX003o[000okP0
00D0okP000<0okX00?o2003oa`000`3oa`020?o900@0omL001L0oml00?oV003oiP00onX00?oe003n
n000mol00=ko003Lo`00f?l00<ko002lo`00N_l003So4015oa`0SOl00<Go003Fo`00i_l00>oo003i
oP00ooL00?oc00020?oV00060?oS003oe`00omL00?oG003od`00ol/0103oa`000`3o_000okP00?nh
00030?nh00030?nd003oZP00ojP000H0ojP000@0oj@00?nO003oV`00oi/01`3oV@001@3oU000ohh0
0?n>003oT000oh`000/0ohX000L0ohP00?ml003oNP00ogX00?mm003oQ000oh0000d0ogX00oooool2
o`0000Gooooo000Kooooo`03o`000?oooooooooo00;ooooo0`3oJ`000`3oK`00og400?m[000A0?m[
00030?mh003oNP00ogX002D0ogX000<0ogh00?mj003oNP002@3oNP0H0?n:00030?n@003oV@00oiT0
00h0oiT00P3oX`000`3oX@00ojH00?nX00090?nX00030?n/003o^000okP000@0okP000<0okX00?nh
003oa`00103oa`000`3ob`00omD00?oG00030?oG00<0onH001<0oo000?oe003mnP00n?l00>oo003T
o`00f?l00<Go002To`00Bol703;o6P2Go`00_?l00=[o003[o`00mOl00?_m003om@00oo000080onH0
00H0on<00?oG003oe`00omL00?oC003ob@040?o700030?nj003o^000okP000<0okP000<0ok800?nX
003oZ0001P3oZ00:0?nI00030?nB003oRP00ohX000<0ohX000<0oh`00?n:003oRP00203oRP000`3o
O000ogX00?mj00030?mj00030?ml003oOP00og`000/0ogX01?ooool00ol0003oooooooooo`03oooo
o`000_ooool2o`0000Cooooo00?o0000ooooooooool00_ooool2o`0000Cooooo0ol00005ooooo`03
o`000?oooooooooo00;ooooo0`3oJ`000`3oL`00of/00?m[000@0?m[00030?m]003oNP00ogX00340
ogX000<0oh000?n:003oRP005@3oRP000`3oSP00oiL00?n@00020?n>00030?nG003oV@00oiT000P0
oiT000<0oi/00?nM003oV@000P3oV@000`3oV`00ojP00?nX00070?nX00030?nZ003o]000okH000H0
okP000<0ok`00?o7003oa`000P3oa`000`3ob@00olL00?o700030?oG00050?oI003og`00onH00?oV
003ojP000P3om@00403koP00mol00>_o003Fo`00S_l005go1@18o`00:MmG03ko1P1lo`00e?l00>Wo
003jo`00o?`00?oe003ol0020?oV00030?oS003of@00omL00080omL01@3oa`000`3oa000okX00?nh
00040?nh00040?nb003o[000ojP00?nZ00@0ojP000<0oiX00?nI003oV@001`3oV@000`3oTP00ohX0
0?n:000>0?n:00P0ogX000<0og`00?mj003oNP002@3oNP04ooooo`03o`000?oooooooooo00?ooooo
00001Ooooooo0000oooooooooooo000000[ooooo00Co0000oooooooooooo00000oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00;ooooo0P3oJ`000`3oL`00of/00?m[000A0?m[0003
0?mc003oNP00ogX000<0ogX000H0ogP00?me003oL`00og<00?me003oN00X0?mj00040?n8003oRP00
ohX00?n601<0ohX000<0oh`00?n>003oRP000`3oRP000`3oS000oiT00?nI000>0?nI00P0ojP000D0
oj`00?nZ003oZ000ojP00?nd00040?nh00030?nj003o^@00okP000@0olL000<0olT00?o=003oe@00
0`3oe`005P3og@00onH00?oV003oiP00oo800?oe003mn@00n_l00??o003Ro`00^?l007;o0`0Fk5l0
2=EL02OmA`1Vo`L0bol00>_o003jo`00o?`00?oe003olP030?oV00060?oK003oe`00omL00?oG003o
c`00olT00`3oa`000`3o_P00okP00?nj00040?nh00030?nZ003oZ000ojP000D0ojP000<0ojL00?nM
003oV`00203oV@000`3oSP00ohX00?n:000=0?n:00030?ml003oNP00ogX000L0ogX000<0og`00?mj
003oNP001`3oNP04ooooo`03o`000?oooooooooo00?ooooo00001Ooooooo0000oooooooooooo0000
00_ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`;o00000oooool00`3o
J`00ofl00?m]000C0?m[00@0ogX000<0ogD00?m_003oJ`001@3oJ`000`3oL@00ogX00?mj000G0?mj
00030?ml003oNP00ogX000X0ogX000@0ohH00?n8003oP000og/00P3oNP000`3oP000ohX00?n:000>
0?n:0080oh`01P3oRP0?0?nI00030?nS003oZ000ojP000X0ojP000<0ok@00?nh003o^000103o^000
0`3o^P00olL00?o700040?o700050?o?003oe`00omL00?oI003of`000P3oiP004@3oj000oo800?oe
003om`00n_l00?Oo003Yo`00e?l007go1@1do`007?a708So002Oo`00`ol00>Wo003ho`00nod00080
ooD000@0onP00?oV003oiP00oml00`3oe`000`3od@00olT00?o700030?o700030?nn003o^000okP0
00<0okP000@0ojh00?n/003oZP00ojX0103oZ0000`3oW`00oiT00?nI00080?nI00040?nG003oT000
ohh00?n<00`0ohX000<0ohH00?mj003oNP004@3oNP03ooooo`;o00001Oooool00005ooooool0003o
ooooooooool000002?ooool4o`0000Gooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`02ooooo`030?m[003oK`00of/00180of/000D0og<00?mj003oNP00ogP00?ma00090?m[00030?m_
003oNP00ogX00280ogX000<0oh@00?n2003oNP001@3oNP000`3oPP00ohX00?n:000<0?n:00030?n<
003oRP00ohX000D0ohX000<0oi000?nI003oV@00303oV@030?nQ00030?nV003oZ000ojP000H0ojP0
00<0ojX00?nb003o^0001P3o^0000`3o_000ol800?o700030?o700030?o;003od`00omL000<0omL0
00H0on@00?oV003oiP00oo000?oe003om`020?[o000;0>_o003Lo`00aOl009go000/oaD0Q?l00<Go
003Ho`00jol00??o003joP000P3om@00103okP00onH00?oV003oiP040?oG00030?o9003oa`00olL0
0080olL000<0ok`00?nj003o^000103o^0000`3o[000ojP00?nX00040?nX00030?nL003oV@00oiT0
00L0oiT000<0oi000?n:003oRP003`3oRP000`3oQP00ogX00?mj000@0?mj00Cooooo00?o0000oooo
ooooool00oooool00005ooooool0003oooooooooool000001oooool01_l0003ooooooooooooooooo
0000ooooo`Co00001Oooool00ol0003oooooooooo`02ooooo`030?m_003oJ`00of/00180of/00P3o
NP000`3oM`00ofd00?m[000:0?m[00030?me003oNP00ogX00200ogX000<0oh000?ml003oNP001`3o
NP0E0?n:00030?n<003oU`00oiT000`0oiT000<0oi/00?nI003oV@000P3oV@080?nX00040?nZ003o
Z000ojP00?nd0080okP000D0okX00?nh003o^000okP00?nj00050?o700050?o;003oe`00omL00?oI
003of`000`3oiP004@3ol000ooD00?og003jo`00mol00>_o003No`00c_l00:;o0017`7@0I?l20<7o
003Do`00h?l00>_o003io`00o?`00080ooD000D0oo000?oV003oiP00on<00?oI00020?oG00030?oE
003ob@00olL000<0olL000<0okX00?nh003o^0000`3o^0000`3oZ000ojX00?nX00040?nX00050?nT
003oW`00oi/00?nI003oV`00103oV@000`3oUP00ohX00?n:000=0?n:00060?n8003oPP00oh800?n4
003oQP00ogh0403oNP04ooooo`03o`000?oooooooooo00?ooooo00001Ooooooo0000oooooooooooo
000000Oooooo00Oo0000ooooooooooooooooo`000?oooooo000000Sooooo00?o0000ooooooooool0
0_oooolD0?m[00030?me003oNP00ogD000d0of/000<0ofd00?mj003oNP004@3oNP000`3oO000ogX0
0?mj000;0?mj00030?n0003oNP00ogX000P0ogX0503oRP000`3oS000oiD00?n@00020?n<00030?n@
003oV@00oiT000d0oiT02`3oZ0000`3o/000okP00?nh00030?nh00030?nl003oa000olL000<0olL0
00@0ol/00?oC003oe`00omL00P3of@030?oV000E0?oc003om@00oO/00?[o003ao`00jOl00=co003:
o`00]?l005Go0`1no`00]_l00<_o003Ho`00i?l00>ko003jo`00o?d00?og003om@00onh00080onH0
00D0on<00?oG003oe`00omL00?o?00040?o700030?o0003o_000okP000@0okP000<0oj`00?nX003o
Z0000`3oZ0000`3oYP00oiT00?nI00070?nI00030?n<003oRP00ohX000/0ohX000<0oh@00?mj003o
NP000`3oNP020?mn00l0ogX01?ooool00ol0003oooooooooo`03ooooo`000_ooool2o`0000Wooooo
0ol00002ooooo`Go00001?ooool2o`0000?ooooo4`3oJ`000`3oL000ogX00?ma000?0?m[0200ogX0
00<0ogd00?mj003oNP00203oNP000`3oP@00ohX00?n:000A0?n:00030?n<003oS@00ohX000@0ohX0
00<0oi@00?nI003oV@000`3oV@000`3oV`00oiT00?nI00050?nI00030?nR003oZ000ojP000L0ojP0
00<0oj/00?n`003o^0001`3o^0040?o700030?o9003odP00omL00080omL00280om`00?oV003oj000
on/00?oe003omP00n_l00?Ko003]o`00hOl00;ko002do`00LoPW04Wo8@1:o`@0HOl005oo6`2/o`00
aOl00;Oo4`3To`00lol00?_m003nn000o_L00?oa003ok000onH00?oP003og000omL00?oF003oc`00
olT00`3oa`000`3o_P00okX00?nh00030?nh00030?n]003oZ`00ojP000<0ojP000@0oj@00?nI003o
V@00oi/01P3oV@001@3oV000oi<00?n=003oRP00oh`000T0ohX0203oNP000`3oO@00ogX00?mj000<
0?mj00?ooooo0_l00005ooooo`006oooool00ol0003oooooooooo`02oooooa<0of/000<0ogP00?m_
003oJ`003`3oJ`0[0?mj00030?n8003oRP00ohX00100ohX000<0oh`00?n:003oRP001@3oRP000`3o
U000oiT00?nI00090?nI00040?nM003oW`00oj400?nS00L0ojP000@0ojX00?nX003oZ000ojX01@3o
^0001@3o_000ol000?o7003oa`00olT00080olL000D0om400?oG003oe`00omT00?oQ00020?oV000D
0?ob003om@00o?d00>oo003Wo`00h?l00<ko0026o`00C_lE04W^8P2?o`/0Z_l005go1`0Mof80EOlH
08So001^oa00KolB0=co003_o`020?Go00060>Ko003in`00oo000?oV003oi000omd00P3oe`000`3o
c@00olL00?o700020?o70080ok`0103o^0060?nX00030?nV003oW@00oiT000H0oiT000<0oh`00?n:
003oRP000P3oRP000`3oS000ohX00?n:00060?n:00030?mn003oNP00ogX001@0ogX01?ooool00ol0
003oooooooooo`03ooooo`006oooool00ol0003oooooooooo`02oooooa80of/000<0ogL00?m_003o
J`00403oJ`0N0?mj00030?ml003oNP00ogX000T0ogX000<0oh@00?n:003oRP006@3oRP000`3oV000
oiT00?nI00070?nI00030?nK003oV@00oiT000<0oiT000<0oj400?nX003oZ000203oZ0070?nh00@0
olL000D0old00?oG003oe`00omL00?oK00020?oV000N0?oX003ol`00o_T00??o002To`00_Ol00<[o
002no`00Dol3023o9`1no`00aOl00<co002oo`00Xol007;o000HobX0;?hY0:Go003@o`00h?l00>Co
002io`D0POl?0>Oo003lo000oo<00?o`003oj000om/00P3oe`000`3oc`00olL00?o700020?o70003
0?nn003o^P00okP00080okP000<0ok@00?nZ003oZ0000`3oZ0000`3oW@00oiT00?nI00050?nI0003
0?nB003oRP00ohX000`0ohX000<0ohP00?mj003oNP002@3oNP000`3oO000ogX00?mj00080?mj00Co
oooo00?o0000ooooooooool00oooool001_ooooo00?o0000ooooooooool00_oooolA0?m[00030?ma
003oL`00of/00140of/0:@3oNP00103oPP00ohX00?n4003oOP020?mj00030?ml003oQ000ohX001<0
ohX000<0oiH00?nI003oV@003P3oV@000`3oX@00ojP00?nX00060?nX00030?n/003o/P00okP000@0
okP000<0okX00?nn003oa`000`3oa`001@3od@00omL00?oG003of@00on400080onH000`0oo000?oe
003lo@00lol00:3o001Eo`<0YOl007oo0P15hD00POl70<Go003Jo`020>;o000A0<go001Foa80K_l0
04So8P1Xo`D0ROlA0<Oo0038o`00R?l004ko003Go`00kol00>Ko003>o`00k?L00?oV003of`000P3o
e`000`3od@00olT00?o700020?o700030?o2003o^000okP00080okP000<0ojh00?nZ003oZ0000P3o
Z0000`3oYP00oil00?nK00060?nI00030?n<003oRP00ohX000`0ohX000<0ohP00?ml003oNP004`3o
NP04ooooo`03o`000?oooooooooo00?ooooo000Kooooo`;o00000oooool@0?m[00030?m]003oL`00
of/00140of/000<0ofl00?mj003oNP009P3oNP000`3oPP00oh@00?ml00060?mj00030?n6003oRP00
ohX000l0ohX000D0oh`00?nD003oTP00ohh00?nB000=0?nI00030?nK003oYP00ojP000L0ojP000<0
ojX00?n^003o^0001@3o^0001P3o_P00olL00?o7003oa`00ol/00?oC0080omL00100on400?oV003o
j000onX00?oe003om`00n?l00>3o0031o`00E_lB03oo5012o`L0Uol00<go003Po`00kOl00P3_o`00
4@3No`00/?l00;;o002go`00EolC04Ko2@2Go`00Z?l005Wo0`1]o`00`ol00<_o001Do``0/ol70?_j
003ojP00on<000<0omL000L0om<00?oA003oa`00olT00?o7003oa000okX000<0okP000<0oj`00?nZ
003oZ0000P3oZ0000`3oV`00oiT00?nI00060?nI00030?nB003oS000ohX000T0ohX000D0ohH00?n2
003oPP00ohH00?n2000C0?mj00?ooooo0_l00005ooooo`006oooool00ol0003oooooooooo`02oooo
oa00of/000<0og<00?m[003oJ`004@3oJ`000`3oL`00ogX00?mj000H0?mj00030?ml003oNP00ogX0
00X0ogX00P3oOP080?mj00030?n2003oRP00ohX000h0ohX000<0ohh00?n<003oRP000`3oRP000`3o
SP00oiT00?nI00080?nI00030?nM003oW`00oj@000/0ojP000<0ok000?nh003o^0000P3o^0000`3o
_000ol000?o700020?o700070?o;003oe`00omL00?oS003oiP00onP00?o^00020?oe000:0?cm003c
o`00_?l003ko:@19jSL00?bF04go5P1>oal0^_l00>oo00<0n_l001D0n?l00?Go003_o`00h?l00<Oo
002Eo`00AolW03ko1@0YaFd0:NQ808Ko001So`00POl30>3o003mnP00oo800?oX003oh`00oml00?oG
003of@000`3oe`000`3ob@00olL00?o500040?nh00060?nZ003oZ000ojP00?nX003oX`00oil01P3o
V@000`3oS000ohX00?n:00090?n:00030?n2003oNP00ogX000<0ogX000<0ogh00?mj003oNP00403o
NP04ooooo`03o`000?oooooooooo00?ooooo000Kooooo`03o`000?oooooooooo00;ooooo3`3oJ`00
0`3oK`00of/00?m[000B0?m[02L0ogX000<0og`00?mk003oNP00203oNP000`3oPP00ohX00?n:000E
0?n:00h0oiT000<0ojD00?nX003oZ0001@3oZ0000`3oZP00ojh00?nh00050?nh00090?o4003oa`00
olL00?o7003od@00omL00?oQ003ojP00oo000080ooD000h0ooL00?cl003jo`00kOl00=Co002Vo`00
COl705Go1@1Qo`80aol00=ko003jo`00o?`00?og0080ooD00100oO/00?_n003`o`00e?l006ko1`22
o`00J_l704K0EP0mk400DoPP07Go0`3;o`00j?l00?cm003om@00oo000P3oiP002P3oi000onH00?oV
003mj`00onP00?oO003od`00olL00?o4003o^P020?nh00030?nb003o[000ojP00080ojP01`3oV@0<
0?n:01T0ogX01?ooool00ol0003oooooooooo`03ooooo`006oooool00ol0003oooooooooo`02oooo
o`l0of/000<0ofl00?m[003oJ`004@3oJ`000`3oL`00ogX00?mj00020?mj00030?me003oL@00ofd0
0080of/000<0ofl00?mf003oNP006P3oNP020?ml00X0ogX000<0oh800?n:003oRP00503oRP000`3o
T000oiT00?nI000<0?nI00030?nQ003oZ000ojP000D0ojP000<0oj`00?nb003o^000103o^000703o
_000ol@00?o7003oa`00olT00?oG003of`00o_000=Wn003ko000o?`00?[o003ho`00m_l00>oo003V
o`00^ol006co2@1_o``0]ol006SQ8039o`00moh00?kh003om@00oo<00?oa003ol0020?oe000H0?Gn
002Vo`80I?l=0<Go002bo`00Gol009Oo002^o`00BOl@0:co003Po`00mOl00?gk003om`00oo<00?o/
003ojP00oo000?og003CoP00coh00;3o003oj000om400P3oa`00103o_P00okP00?nh003o/P030?nX
00030?nQ003oW@00oiT000@0oiT000@0oi@00?n@003oSP00ohh0203oRP000`3oO000ogX00?mj000F
0?mj00Cooooo00?o0000ooooooooool00oooool001_ooooo0_l00003ooooo`h0of/000<0ofl00?m[
003oJ`004@3oJ`001P3oK@00ogX00?mj003oNP00ogD00?m]00L0of/000<0ogL00?mj003oNP00903o
NP0F0?n:00030?n<003oU`00oiT000`0oiT000<0oi/00?nV003oZ000203oZ0050?nh00090?nj003o
a`00olL00?o7003oc@00omL00?oO003mm000UOl00080e?l000h0`Ol00>Ko003Yo`00i_l00=Ko001j
o`<05_mJ0:Go003Fo`00h?l00>_o003nn000oo800?o^00<0onH00240onX00?o`003jnP00Wol00;co
003[o`00col006Ko2@3;o`00e_l00:3o0`1Xo`P0Qol00=Co003Yo`00o?`00?kh003om@00o_P00?Wl
003Jo`00X_l=09Ko5P3[o@00onH00?oG003od@00ol/00?o7003o`P00okX00?nh003o[0000P3oZ000
0`3oX@00oiT00?nI00040?nI00030?nF003oS000ohX000T0ohX000<0ohH00?mj003oNP005P3oNP03
ooooo`;o00001Oooool001_ooooo00?o0000ooooooooool00_ooool=0?m[0080ofd04`3oJ`00103o
M@00ogX00?mh003oL@0:0?m[00030?mg003oNP00ogX001@0ogX000<0og`00?mj003oNP002`3oNP00
0`3oQP00ohX00?n:000C0?n:00030?n>003oV@00oiT000T0oiT000@0oi/00?nI003oW@00oil0203o
Z0000`3oZP00oj`00?n^00030?nh00030?nj003o^@00ol0000<0olL001<0old00?oG003og`00n?@0
0;[o001loa<0C?lT08Ko003>o`00f?l00=Ko0037o`00Q?l007ko0033o`00jOl00?So003nn000oo80
00@0onH001/0on@00?oV003oiP00n?800;[m2@3ko000o_T00?3n003Ao`00lOl00>oo0037o`00IOlG
03Co601So`00f?l00?7o003ho`00n_l00??o003Lo`00Ool708?o4`3No`00noX00?o/003oi0000P3o
f@001@3oe@00nM`00?o9003o^P00ok<000<0ojP000<0oj400?nK003oV@000`3oV@000`3oSP00ohX0
0?n:000:0?n:00030?n8003oO000ogX001D0ogX01?ooool00ol0003oooooooooo`03ooooo`006ooo
ool00ol0003oooooooooo`02ooooo`d0of/000<0ofd00?m[003oJ`004@3oJ`00103oK`00ogX00?mg
003oK@0;0?m[00030?m_003oNP00ogX00240ogX000<0oh800?n:003oR0000P3oQP000`3oR000ohX0
0?n:000>0?n:00060?n>003oS@00ohX00?n:003oS000oiH02`3oV@000`3oV`00ojD00?nX00060?nX
00030?n/003o]P00okP000@0okP000h0ol000?o7003oa`00olL00?oA003of@00oml00?o`003jo@00
]?l004Co2@2@o`00/?l00;Wo0080/?l000/0E?l<0:Ko003Do`00lol00?cl003olP00onP00?oV003o
h`00omd00?oG00020?oI00030?oK003ohP00onX00080onX001`0oo000?oe003om`00oOX00??o003J
o`00[_l005ko602]o`/0h_l00>Oo003To`00`ol009Go000noa80Xol00;Wo003[o`00o_T00?o^003o
j000on`00?7h002loP00cO<00?o9003o^000ojX00P3oZ0000`3oX`00oi/00?nI00030?nI00050?nF
003oT000ohh00?n>003oS0001P3oRP001P3oQ000oh000?mn003oPP00oh000?ml01@0ogX01?ooool0
0ol0003oooooooooo`03ooooo`006oooool00ol0003oooooooooo`02ooooo``0of/000<0ofd00?m[
003oJ`004@3oJ`000`3oK@00ogP00?me000>0?m[0280ogX00P3oQ0000`3oOP00ogX00?mj00020?mj
00030?n0003oRP00ohX000X0ohX00P3oS0060?n:00030?n<003oV@00oiT000X0oiT000<0oj400?nX
003oZ0001P3oZ0000`3o/000okP00?nh00020?nh000I0?nk003oa000olL00?o7003ob@00om<00?oG
003oh@00on`00?gj003Zo`00P?l004co3P0aoa80E_l0063o2@1Koa40G_l206_o002@o`T0j?l00?gj
003ok000onH00?oM00080?oG000N0?oK003oh@00on800?oV003oj000oo800?kh003eo`00h?l00;3o
001[oa00[?l009Oo0031o`00XOl003KO>02PH1@09_9903go3033o`00^Ol00?_l003mnP00l_h009co
003co000onL00?o=003o^000ojh00`3oZ0000`3oV`00oiT00?nI00020?nI00030?nG003oS000ohX0
00L0ohX000<0oh@00?mj003oNP001@3oNP000`3oO000ogX00?mj000>0?mj00030?mh003oMP3ooooo
00?ooooo00?o0000ooooooooool00oooool001_ooooo0_l00003ooooo`/0of/000<0ofd00?m[003o
J`004P3oJ`000`3oM`00og<00?m[000>0?m[0200ogX000<0og`00?n2003oO0001`3oNP000`3oPP00
ohX00?n:000B0?n:00/0oiT000<0oi/00?nU003oZ000103oZ000103oZP00oj`00?n`003o]P050?nh
00<0olL001@0old00?oG003oe`00onH00?o^003mnP00kol00=;o0027o`l0>?lJ042COP0BfUT0FOPP
0;So002fo`00N?lE08_o5@3gnP00onH00?oM00<0omL000D0omD00?oC003od`00om<00?oD00030?oG
000M0?oI003of`00on@00?oX003om@00o?d00=;o0020o`00UOl008Go001ho`D0LOl0063o0`20OS80
o`000=LC@001o7<0I_l509?o0`3Lo`00i_l009go002Vo`00onh00?oG003oa`00okP00?nd003oZP00
0P3oZ0000`3oX`00oiT00?nI00020?nI00030?nD003oRP00ohX000L0ohX000<0oh800?mj003oNP00
1P3oNP000`3oOP00ogX00?mj000;0?mj00040?mg003oK@00of/00?m[00?ooooo0_l00005ooooo`00
6oooool00ol0003oooooooooo`02ooooo`X0of/000<0ofd00?m[003oJ`004P3oJ`000`3oL@00og<0
0?m[000?0?m[01l0ogX000<0og`00?mn003oNP00203oNP000`3oO000ohX00?n:000A0?n:00030?nD
003oV@00oiT000H0oiT00P3oW@000`3oX@00ojH00?nX00070?nX00030?nb003o^000okP00080okP0
00<0okX00?nn003oa`000P3oa`006@3ob`00omL00?oI003oj000o_H00?On003To`00d_l008So000:
d840_d1604NWBP1Foal0d?l00>Ko003Yo`00d_l00?kb003oh`00omT00?oG003oe@00ol/00?o=003o
b@000`3oa`000`3ob@00old00?oC00020?oG000K0?oK003oi000onh00?cl003Fo`00F?lE0=[o003T
o`00g?l009go002Oo`00Kl0e0;la9@13gbh0Col@0<?o002FoB00Rol308oo0`2ko`00m?d00?oU003o
d@00olL00?nl003o^000ojh00080ojP000<0ojD00?nO003oV`000`3oV@000`3oU000ohX00?n:0006
0?n:00030?n6003oNP00ogX000P0ogX000<0og/00?mj003oNP00203oNP000`3oM`00of/00?m[0002
0?m[00Cooooo00?o0000ooooooooool00oooool001?ooooo0ol00005ooooo`03o`000?oooooooooo
00;ooooo7P3oJ`000`3oK`00og<00?m[000@0?m[01h0ogX00P3oO00:0?mj00030?mn003oRP00ohX0
00l0ohX000<0oh`00?nD003oV@00303oV@000`3oYP00ojP00?nX00020?nX0080ojX000<0ojP00?nb
003o^000103o^0005P3o_@00olL00?o7003oa`00om400?oG003og@00oo000<Go002Aoa40_ol00;Ko
001Tob00E?l001c^K@0[o`<0TOl00=7o003co`00o_T00?o`003oi0020?oG00030?oA003ob@00olT0
00P0olL00140old00?oC003oe`00oml00?o^0038o`80Uol509go003ao`00noh00?Kn003Lo`00h?l0
073o301GlRT0VOl00;go00020>Wo000:0<_o002Jo`/0kol00?oc003oh@00omL00?o7003o`000okP0
0?nf00<0ojP000<0oj<00?nI003oV@000P3oV@0:0?n:00030?n6003oO000ogX00180ogX000<0og40
0?m[003oJ`000P3oJ`04ooooo`03o`000?oooooooooo00?ooooo000Dooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool00_oooolM0?m[00030?m^003oL@00of/00100of/000<0ofh00?mj
003oNP006`3oNP000`3oO000ogX00?mj000:0?mj00030?n5003oRP00ohX000d0ohX000H0oh`00?n=
003oT000oi000?nB003oV00;0?nI00030?nU003oZ000ojP000@0ojP000<0ok<00?nh003o^0000`3o
^0006@3o^P00olL00?o7003oa`00olT00?oB003oe`00on000?o^003/o@00/ol009Ko001no`T0J?l1
0;7o002/o`00YOl004Oo502:o`00lOl00?o_003oi@00omT00?oG003obP001`3oa`000`3oaP00olL0
0?o700020?o700080?o:003oe000omT00?oY003Mo@00Nol70=3o003mn0020?o^000D0?oa003kn`00
iol009Go002ao`00nO`00?gi003mnP00i_l009So102mo`H0o_P00?oX003og000oll00?o6003o^`00
okP00?ne003o[`020?nX00060?nL003oV@00oiT00?nI003oT`00oh`01P3oRP001P3oR@00oh800?n0
003oP000ogl00?mm0140ogX01@3oJ`04ooooo`03o`000?oooooooooo00?ooooo000Dooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool00_ooool80?m[00030?m]003oJ`00of/00140of/0
00<0ofd00?ma003oJ`004@3oJ`000`3oM@00ogX00?mj000I0?mj00030?mk003oNP00ogX000/0ogX0
00<0oh000?n:003oRP003@3oRP000`3oS000ohX00?n:00030?n:00030?n<003oV@00oiT000@0oiT0
0`3oW@000`3oX@00ojH00?nX00040?nX00030?nZ003o[000ok8000@0okP000<0okX00?o2003oa`00
0P3oa`00503ob`00omL00?oG003oh@00onH00?og003go`00h?l00:So001^o`l0e?l00>;o003Ho`00
Rol005Go9@3Jo`00onh00?oK003oe`00ol/00`3oa`020?o500070?nn003o_000ok`00?nk003o^P00
okh00?o500020?o7000P0?o9003oe`00on400?Gj002Uo`00i_`00?oZ003og`00on400?oR003ol000
e?l00:Ko003nm`00on`00?oX003ok000o_P00>Oo002Io`00jOl00?7h003ojP00om/00?o>003oa`00
ol800?nl003o^000ok@00?nZ003oYP030?nI00030?n>003oRP00ohX000D0ohX000<0og`00?mj003o
NP00503oNP000`3oK@00of/00?m[00020?m[00Cooooo00?o0000ooooooooool00oooool001Cooooo
00?o0000ooooooooool01?ooool2o`0000?ooooo703oJ`000`3oK`00of/00?m[000@0?m[00030?m]
003oNP00ogX002L0ogX000<0ogh00?n:003oRP005@3oRP0:0?nI00030?nO003oZ000ojP000@0ojP0
00<0ok800?nh003o^0000P3o^0000`3o^P00ok`00?o700020?o7000D0?o;003od@00omL00?oG003o
h`00onH00?oe003jo`00i?l007;o6@2?o`00i?l00?7o003fo`00moh00>Wo002^o`00onH00?oG003o
c`030?o70080ol0000<0ok`00?nh003o^P00103o^0007@3o_000okh00?o5003oa`00om400?oQ003I
o@00Z?l00?oY003of@00omL00?oE003oe`00onP00>gh003?lP/0on@00?oM003of`00on<00?o/0039
o`00[_l008go0021o`T0g_h00?Kd003of000oll00080ol/000D0olD00?o0003o^000ojP00?nQ0002
0?nI00030?nF003oRP00oh`000D0ohX000<0og`00?mj003oNP00503oNP000`3oL`00of/00?m[0002
0?m[00?ooooo0_l00005ooooo`005?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00;ooooo6`3oJ`000`3oL@00of/00?m[000A0?m[00030?me003oNP00ogX000<0ogX00`3oMP000`3o
N000ogX00?mj000M0?mj00030?n2003oR000oh@00080oh8000<0oh@00?n8003oRP00403oRP000`3o
SP00oiT00?nI00080?nI00030?nO003oZ000ojP00080ojP000<0ojX00?n`003o]P000`3o^0000`3o
^P00okP00?o700030?o7000C0?o;003oe`00omL00?oI003oiP00onP00?kh003_o`00e?l008Oo4@2g
o`00lOl00?cm003om`00oo400?o^003jk@00omT00?o?00030?o700030?nn003o^P00okP000T0okP0
00h0okX00?o4003ob@00kN/00>Ke003WlP00omT00?o;003ob@00olL00?o9003oc@00oll00?oA0080
oll001D0om400?oG003og`00o_800?ke002goP80e?l00:Go003jo000onL00?oO003oh`00k_400>3f
003Xl000om`00?n^003oX@00oi/00?nI003oT0001`3oRP000`3oQP00og`00?mj000D0?mj00030?mh
003oJ`00of/00080of/01?ooool00ol0003oooooooooo`03ooooo`004oooool2o`0000Kooooo00?o
0000ooooooooool00_oooolJ0?m[00030?m]003oJ`00of/00140of/000H0ofh00?mj003oNP00ogX0
0?me003oL@050?m[00030?ma003oN000ogX001X0ogX000<0og`00?n4003oP0001@3oNP000`3oO000
ohH00?n:000=0?n:00030?n<003oU000oiT000P0oiT000<0oid00?nS003oZ0000P3oZ0030?nZ0006
0?nb003o^000okP00?nh003o^P00okP0103oa`00503ob@00omL00?oG003oe`00oml00?oV003okP00
oOX00;_o0P1do`00FOl20:So003co`00ooL00?o^003oiP00on400?oI003od@00olT00P3oa`000`3o
_000okP00?nh000<0?nh00040?o2003oa`00ol/00?o;0080olD000@0ol000?o4003oa000ol801@3o
a`004@3ob@00om<00?oI003oh@00on`00?_k0035o`00^ol00?[j003cn000iod00;kn003MmP00c?/0
0?OU003o]000oj<00080oiT000<0oi800?n<003oRP00103oRP00103oR000ohH00?n4003oP0090?mj
00030?mk003oNP00ogX000T0ogX000@0ogD00?m[003oJ`00of/01?ooool00ol0003oooooooooo`03
ooooo`005?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo6@3oJ`020?m]
01<0of/000@0og@00?mj003oN000ofl0203oJ`000`3oK@00ogP00?mj000H0?mj00030?mn003oP000
ogX000L0ogX000<0ogh00?n:003oRP002@3oRP000`3oR`00oh`00?n>00020?nB00030?nD003oV@00
oiT000P0oiT000H0ojH00?nX003oZ000ojP00?nZ003o/0030?nh00030?nl003o_P00olL000<0olL0
00D0ol/00?oG003oe`00omL00?oK00020?oV000=0?o`003lo000h?l007co0P1]gaD0Yol00?[m003o
l000onH00?oK003oe`00omD00?o900020?o700030?nj003o^000okP000@0okP00P3o]P001@3o/`00
okP00?n`003o^000okH000@0okP000@0okh00?nh003o^000okX0103o^0001@3o^P00okP00?nn003o
`000ol@00080olL000l0old00?oG003oh@00oo000??n002`o`00/_l00<ko0034o@00nnH00?oC003g
fP00knL00?o6003oX`000P3oV@000`3oT000ohX00?n:00040?n:00050?ml003oNP00ogX00?mj003o
OP005@3oNP000`3oK`00of/00?m[0004ooooo`03o`000?oooooooooo00?ooooo000Kooooo`;o0000
0ooooolH0?m[0080ofd04`3oJ`000`3oK@00ogX00?mc000;0?m[00030?m_003oNP00ogX001H0ogX0
00<0ogh00?mj003oNP002@3oNP080?n:00030?n<003oRP00ohX000H0ohX000<0oi000?nI003oV@00
1P3oV@000`3oW@00ojP00?nX00020?nX00060?n`003o^000okP00?nh003o`P00ol@0103oa`00503o
b@00om<00?oG003oe`00om/00?oS003oiP00onX00?oe003lo@00cOl007Ko0031o`00e?l00?cl003o
kP00on@00?oI003oe`00olT00P3oa`000`3o^P00okP00?nh00030?nh00080?nd003o/000ok000?nX
003o[@00ojX00?nX003o/0020?n/0080ok@01@3o]P080?nh000D0?nj003o_000olL00?o7003oc`00
omL00?o^003Xo`00VmlP0?[h003ok000oNL00?o=003oa000ok`00?nj003o[000oil00?nI003oU`06
0?n:00030?n8003oNP00ogX00140ogX000X0ogD00?m_003oJ`00of/00?m_003oM@00ogP00?mj003o
K`00of/00oooool2o`0000Gooooo000Kooooo`03o`000?oooooooooo00;ooooo;@3oJ`000`3oN000
og<00?m[000<0?m[00030?mh003oNP00ogX00200ogX000<0ogh00?n:003oRP00403oRP070?nI0003
0?nK003oX`00ojP000<0ojP00P3o^0000`3o`P00olD00?o700030?o7000E0?o9003od@00omL00?oG
003of@00oml00?oT003oiP00onP00?oc003om`00n_l00>;o001Mo`d0aOl00??o003om`00onP00?oO
003oe`00oll00080olL000<0ol000?nh003o^0000P3o^0001`3o]P00ojh00?n^003oZ000ojX00?nX
003oZ@000P3oZ0000`3o/000ojX00?nX00030?nX00030?nZ003o[000oj`00080ojP00P3o[0020?n`
00030?nd003o^000okP00080okP000l0okX00?o5003ob@00omD00?oU003=oP00e?l00?oW003oe@00
olT00?nl003o]P00ojh00?nX003oY@000P3oV@000`3oU000oh`00?n:00050?n:00030?mn003oNP00
ogX000H0ogX000<0og`00?mj003oNP001P3oNP000`3oL`00of/00?m[00050?m[00030?ma003oNP00
ofl000Cooooo00?o0000ooooooooool00oooool001_ooooo00?o0000ooooooooool00_oooolG0?m[
00030?m]003oJ`00of/00180of/000<0ogL00?mc003oJ`003@3oJ`000`3oL`00ogX00?mj000P0?mj
00030?n6003oRP00ohX000l0ohX000<0oi@00?nI003oV@001P3oV@003@3oV`00ojP00?nX003oZP00
oj`00?nh003o`000omD00?oA003oc`00old00?oC003od@000`3oe`005@3of`00on@00?oV003oiP00
onP00?oc003om`00noh00?7o003Ho`00P_l00<_o003_o`00oOT00?oZ003oh@00omL00?o9003oa`00
olD00?nj00030?nh0080ok8000<0ojP00?nZ003oZ0000`3oZ0000`3oZP00ojP00?nZ000=0?nX0005
0?nZ003oZ000oj`00?nb003o]P000P3o^0003P3o_P00olT00?o?003oh@00loX00;[o003oh000olT0
0?o0003o^000ojX00?nX003oY@00oi/00P3oV@000`3oT000ohX00?n:00040?n:0080oh@000<0oh00
0?mj003oNP003P3oNP090?m[00030?m]003oM@3ooooo00?ooooo00?o0000ooooooooool00oooool0
01_ooooo00?o0000ooooooooool00_oooolF0?m[00030?m]003oJ`00of/00180of/00P3oL`0?0?m[
00030?mc003oNP00ogX001l0ogX000<0oh@00?n:003oRP003P3oRP000`3oT000oiL00?nI00060?nI
00030?nM003oW`00ojH00080ojP000P0ojX00?nb003o^000olT00=Og003oj`00omd00?oI0080omL0
00H0omT00?oM003oh@00onT00?cd003ol@020?oe000?0?og003koP00j?l00=Co002?oaL0Q?l007oo
1@2jo`00k_h00?kd003oi000omL00?o9003oa`00okh000<0okP000<0ok@00?n/003oZ0006@3oZ000
0`3oZP00ojh00?nd00020?nh00090?o4003oc`00ond00=Wn003So`00omd00?o9003o^000ok@00080
ojP000@0oi/00?nI003oV@00oi@01P3oRP001@3oP000ogX00?mj003oNP00og`000h0ogX000<0ogL0
0?m[003oJ`002@3oJ`04ooooo`03o`000?oooooooooo00?ooooo000Kooooo`;o00000ooooolZ0?m[
00030?m_003oL@00of/000l0of/000<0ogL00?mj003oNP007@3oNP000`3oO000ohH00?n:000=0?n:
00030?n<003oRP00ohh00080ohh000<0oi@00?nI003oV@001P3oV@002`3oX@00ojP00?nX003oZP00
ok800?nh003oc@00i?T00;[o003]nP00on`00080onH000H0onP00?o/003okP00moP00<Wo003go`02
0?_m000>0?[o003]o`00^Ol005So6P2?o`00f?l00<go002Go`L0VOl00>Kn003hl000om/00?o=003o
a`040?nh00030?nX003oZP00ojP000`0ojP000<0ojH00?nX003oZ000303oZ0003P3oZP00ok800?nh
003o_000oll00>;h003anP00aol00?WV003oa`00okP00?n^003oZ000oj<00`3oV@020?n>00D0ohX0
00<0oh000?mj003oNP000`3oNP000`3oO000ogX00?mj000;0?mj00/0of/00oooool2o`0000Gooooo
000Kooooo`03o`000?oooooooooo00;ooooo:@3oJ`020?m_0140of/07`3oNP000`3oP000oh@00?n2
00020?mn00030?n0003oQ000ohX000l0ohX000<0oiH00?nI003oV@00103oV@00903oW`00ojH00?nX
003oZ000ojX00?nb003o^P00olL00?oM002[o@l0b?lA0?gk003nmP00o_P00>;l003jo@00nod00=Go
0027o`L0h?l00>oo003ao`00jol00=Co001ho`00Hol00=ko003fo`00n_d00>oo002Ao`00F?l40?;m
003oj@00oll00?o500<0okP000<0ojP00?nZ003oZ0001`3oZ000103oY@00oil00?nX003oV`020?nO
00070?nI003oX`00oiT00?nS003oV@00oj<00?nK00020?nS00030?nU003oZ000ojP000@0ojP000d0
ojX00?nd003o^000ol@00?o=003og@00f?`00=Od003ob`00okP00?nZ003oZ000oi/00080oiT000<0
oiD00?n>003oRP001@3oRP000`3oR000og`00?mj000A0?mj00/0of/01?ooool00ol0003ooooooooo
o`03ooooo`006oooool00ol0003oooooooooo`02ooooobP0of/00P3oK@0A0?m[00030?ma003oNP00
ogX001/0ogX000<0ogh00?n0003oO0001P3oNP000`3oQ000ohX00?n:000=0?n:00030?nF003oV@00
oiT000D0oiT002<0oj<00?nX003oZ000ojX00?nb003o^000olL00?oG003lm000Z_l00;Wo803:o`00
jOl008oo003No`00h_l00<?o001/o`T0Y_l00;Ko003Jo`00f?l00:;o002Ko`00i?l00?[m003om`00
oo400?kd003^nP00iOd00;_o003Sn`00oll00?o000020?nh00030?n/003oZP00ojP000H0ojP000D0
oj400?nL003oX@00oiT00?nQ00040?nI000<0?nK003oV@00oiT00?nI003oV`00oiT00?nO003oV@00
oj400?nK003oX@00oj<0103oZ0002`3oZP00ok800?nh003o`P00ol/00?oX003En`00l^P00?nn003o
Z000ojH000<0oiT000<0oh`00?n:003oRP000`3oRP001@3oQP00og`00?mj003oP000ogh00140ogX0
00<0og<00?m[003oJ`00203oJ`04ooooo`03o`000?oooooooooo00?ooooo000Kooooo`03o`000?oo
oooooooo00;ooooo4`3oJ`000`3oK@00of/00?m[000B0?m[00030?ma003oJ`00of/00100of/000<0
ogP00?mj003oNP009@3oNP0>0?n:00030?nB003oV@00oiT000@0oiT000<0oi/00?nM003oY@000P3o
Z0007`3oZP00ok800?nh003oa`00on400<7m3@2Ko`00c_l008Wo002Co`00UOl008?o1`1/o`T0=ol_
04?o001Hgb`0Kol00;Ko002Zo`00M_l009ko0P3ao`00ooD00?oZ003oiP00on<00?oQ003oi000lO@0
0<ga003ob@000P3o^0000`3o/P00ojP00?nX00050?nX00070?nK003oW`00oil00?nI003oW@00oiT0
0?nK000>0?nI00040?nK003oV@00oil00?nQ00@0ojP000d0ok800?nh003oa000om400>gh003ohP00
ol000?n/003oX`00oi/00?nI003oU000oh`000D0ohX000<0oh800?mj003oNP000P3oNP000`3oO000
ogX00?mj000?0?mj00030?m]003oJ`00of/000L0of/01?ooool00ol0003oooooooooo`03ooooo`00
6oooool2o`0000?ooooo9`3oJ`000`3oK`00of/00?m[000@0?m[00030?ma003oNP00ogX002H0ogX0
2`3oRP020?n>00030?nD003oU`00oiT000L0oiT002D0oj<00?nX003oZ000ojP00?nb003o^000ol@0
0?GY003Rn000moP00?gj003ao`00h_l00=Ko002ho`00Q?l005b>E@2OCF/0e@E0056UDP1fo`00KOl0
0<?o0035o`00gOd00?oZ003oh@00omT00?oG003od`00oll00?oE003gf000ol800?nh003o/P00ojX0
00@0ojP000<0ojH00?nQ003oYP000P3oV@000`3oV`00oiT00?nI00040?nI00030?nK003oV@00oiT0
00T0oiT000D0oi/00?nI003oV`00oi/00?nO00030?nX00090?nZ003o]000okX00?o;003Ol@00onP0
0?o6003o[P00oj400080oiT000<0oi000?n<003oRP001@3oRP000`3oO000ogX00?mj000=0?mj0007
0?mi003oM@00og<00?me003oN000ogX00?mh00090?m[00?ooooo0_l00005ooooo`006oooool00ol0
003oooooooooo`02ooooobH0of/000<0ofd00?m[003oJ`00403oJ`001P3oKP00ogX00?mj003oNP00
ogT00?md00<0og4000<0og<00?mi003oNP003`3oNP000`3oO000ogX00?mj000;0?mj00030?n2003o
RP00ohX000H0ohX000<0oh/00?n:003oRP00103oRP000`3oT`00oiT00?nI00030?nI00030?nK003o
W000oj@000<0ojP000d0ok800?nh003o`@00ol`00?oI003oh000on/00?oe003ioP00i?l00:Wo001E
oaP0NX5C0080o`000140c10c02_V@P2Uo`00hOl00?[l003olP00on800?oG003oe000olT00?o7003o
aP00ol@00?nm003o^000ok@00?nZ00040?nX00050?nU003oX@00oiT00?nI003oV`005@3oV@004`3o
V`00oiT00?nI003oV@00oi`00?nQ003oY`00ojP00?n_003o^000olh00>Sf003`k000kNP00?n`003o
W000oiT00?nE003oS000103oRP001@3oR@00og`00?ml003oO@00og`000h0ogX000<0ofd00?m[003o
J`000P3oJ`00103oL000ogH00?mg003oK@070?m[00Cooooo00?o0000ooooooooool00oooool001_o
oooo00?o0000ooooooooool00_oooolU0?m[00030?m_003oJ`00of/00140of/000@0ogP00?mj003o
N000og401`3oJ`000`3oL`00ogX00?mj000J0?mj00030?n0003oRP00ohX000h0ohX000<0oi800?nI
003oV@001@3oV@001@3oX`00ojP00?nX003oZ000ok800080okP000X0olL00?o;003oe`00on<00?o`
003ioP00i?l00:So001=o`L0YeD]0`3o00001`2P@f00JOl00=co003knP00onH00?oI003od`000P3o
a`001P3oa000okX00?nh003o^000ok800?n/00@0ojP000<0ojD00?nI003oV`000P3oV@000`3oV`00
oiT00?nI000H0?nI000=0?nK003oW@00ojH00?nZ003o]000ol000?;Y003o`P00ok000?nU003oV@00
oiH00?n>00050?n:00030?n6003oNP00ogX000l0ogX000<0og<00?m[003oJ`001@3oJ`000`3oK@00
ogD00?m]00060?m[00Cooooo00?o0000ooooooooool00oooool001_ooooo00?o0000ooooooooool0
0_oooolh0?m[00030?mg003oNP00og4000X0of/000<0ogD00?mj003oNP005`3oNP000`3oO000oh@0
0?n:000?0?n:00030?n@003oU`00oiT000D0oiT000<0oi/00?nU003oZ0000P3oZ0003@3o[000okP0
0?nh003oa000olT00?oE003og`00oO800=Co002^o`00Lol@01kDI@327T000`3o00002P3O8080Aol3
09Oo0035o`00onP00?oG003oc`00olL00?o4003o^P020?nh00030?nb003oZ000ojP000<0ojP000<0
oid00?nO003oV`007`3oV@00203oV`00oid00?nV003o/000ol@00?3Y003o[P00ojH00P3oV@000`3o
T000oh`00?n<00030?n:0080oh@000<0oh000?mj003oNP003P3oNP000`3oL`00of/00?m[00070?m[
00030?ma003oK@00of/000@0of/01?ooool00ol0003oooooooooo`03ooooo`006oooool2o`0000?o
oooo8`3oJ`000`3oK@00of/00?m[000A0?m[00030?me003oM`00ofd000/0of/000<0ofd00?mj003o
NP005P3oNP000`3oP000oh@00?n200020?n200030?n4003oRP00ohX000L0ohX000D0oh`00?n:003o
SP00oi000?nE00070?nI00030?nK003oY@00ojP00080ojP001T0ojh00?nh003o^000ol800?o7003o
d@00om/00?o^002do`00U?lL07Co001PRf00o`00081HH`3O81X0cR0j06:L;02Qo`00f?l00?;m003o
iP00omL00?o9003oa`00okX00080okP000<0ok800?nX003oZ0000P3oZ0000`3oYP00oj<00?nK000@
0?nI0080oi0000X0oiT00?nD003oRP00oi@00?nF003oS000oi800?nI003oTP00oiH01`3oV@001@3o
V`00ojH00?W5003o_P00oj<00080oiT000<0oi000?n:003oRP00103oRP020?mj00030?ml003oOP00
ogX000h0ogX000<0og<00?m[003oJ`00203oJ`020?m]00@0of/00oooool2o`0000Gooooo000Koooo
o`03o`000?oooooooooo00;ooooo=P3oJ`020?mc00h0of/05@3oNP000`3oO000ogX00?mn00060?mj
00030?mn003oRP00ohX000/0ohX000<0ohh00?nI003oV@001@3oV@00703oX`00ojP00?nX003oZ000
ok800?nh003o^P00ol@00?o7003oc`00omT00?o^003go000[?l906?O700][600D:F9027o5@0bo2L0
AOlL02?oB02Zo`00lol00?oe003oi000omL00?o;003oa@020?nh00030?nd003oZP00ojP000<0ojP0
00<0oj400?nI003oV@00303oV@00103oT000ohX00?nB003oU0020?n:00050?nB003oRP00ohX00?n:
003oTP000P3oRP001`3oTP00ohX00?n>003oTP00ohX00?nI003oU@00103oV@001`3oV`00oj400?nN
003oV@00oiL00?n@003oS0001P3oRP0C0?mj00030?me003oJ`00of/000X0of/000@0ofd00?m[003o
J`00of/01?ooool00ol0003oooooooooo`03ooooo`0000Coooooo`000?l0003o00001?ooool00ol0
003oooooooooo`03ooooo`;o00000oooool3o`0000Gooooo00?o0000ooooooooool00_oooolR0?m[
00030?m]003oJ`00of/00100of/000<0og400?mc003oJ`003P3oJ`0D0?mj00030?mn003oO000ogX0
00P0ogX03P3oRP050?nI00030?nM003oW`00ojH000<0ojP001/0ok800?nh003o^000olD00?o9003o
e@00oml00?o^003doP00_Ol005Go5P1Qo`00F?l009_o0025o`<0_Ol0097o002io`00k?l00?gk003o
j000om/00?o=003o`P00okP00?nf003o[P00103oZ0001@3oV`00oid00?nI003oV@00oi/000L0oiT0
00@0oiP00?n<003oSP00oiT00`3oRP00103oT000ohX00?n:003oS0030?n:00040?nB003oRP00ohX0
0?n@00@0ohX000@0oi000?n:003oTP00oi000P3oU`030?nI00030?nD003oS000ohX000@0ohX000@0
ohP00?mj003oO000oh804`3oNP000`3oK000of/00?m[00090?m[0080ofd00P3oJ`04ooooo`03o`00
0?oooooooooo00?ooooo0002ooooo`03o`000?oooooooooo00Sooooo00Ko0000oooooooooooo0000
ooooool00003ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_oooold0?m[0080
ofl0403oJ`040?mj00030?ml003oNP00ogX001P0ogX0303oRP000`3oS000oiH00?nI00060?nI000N
0?nS003oZ000ojP00?nZ003o]000okP00?o0003oa`00ol/00?oG003oh`00noL00;[o002;o`00aOl0
0;[o002co`00RolJ0=ko003[o`00f_l009Go002?o`<0`ol30?Gl003dl`00om<00?o0003o^000ok80
0P3oZP00103oZ000ojH00?nQ003oW@090?nI00030?nE003oU`00oi@00080ohX000D0oi000?n:003o
RP00ohX00?n<00060?n:00030?nB003oRP00ohX000D0ohX000T0ohh00?n:003oS000ohX00?n<003o
SP00oh`00?n>003oR`001`3oRP000`3oQP00ogX00?mj00070?mj00030?ml003oNP00ogX000D0ogX0
00H0ogH00?mc003oMP00ogP00?mj003oL`0<0?m[00030?m]003oJ`00of/000Cooooo00?o0000oooo
ooooool00oooool000;ooooo00?o0000ooooooooool02?ooool01?l0003oooooooooool00005oooo
o`03o`000?oooooooooo00;ooooo0_l00003oooooc<0of/00P3oK`0@0?m[00030?ma003oNP00ogX0
01`0ogX000<0ogh00?n:003oRP001@3oRP001P3oS000ohX00?n:003oSP00oi000?nD00L0oiT001l0
oil00?nX003oZ000ojP00?nZ003o^000okX00?o5003oc@00omD00?oM003ojP00oOX00=co002Co`00
j_l00??o003Zo`00[_l00?;m003nn000lo`00>_m003Ko@00_Ol00:Co1`2mn0<0mmX00?nl003o^000
ojX000<0ojP000<0oj<00?nI003oV@00203oV@00103oUP00ohX00?n:003oT0030?n:00040?n>003o
RP00ohX00?n<00/0ohX000<0oh`00?n:003oRP00203oRP000`3oR`00ohX00?n:00030?n:00040?n4
003oNP00oh000?mn00l0ogX000<0og400?m[003oJ`000P3oJ`000`3oL@00ogT00?m]000>0?m[00?o
oooo0_l00005ooooo`000_ooool00ol0003oooooooooo`08ooooo`04o`000?ooooooooooo`0000Go
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02oooooal0of/000<0ofd00?m[003o
J`00403oJ`020?m_0140of/000<0ogL00?mj003oNP006`3oNP000`3oOP00ohP00?n:000<0?n:0003
0?n<003oV@00oiT000D0oiT001<0ojD00?nX003oZ000ojX00?nh003o`P00omL00?oK003oh`00on`0
0?ob003aoP00O?l00;So003ho`00o_T00?ci003^m@00on`00080on@000P0onP00?o/003io000bol0
0?oQ003oa@00okP00?nb00<0ojP000<0oj400?nK003oV@001`3oV@000`3oU@00oiL00?nB00020?n:
00030?n=003oRP00ohX001l0ohX00P3oR000103oPP00ogX00?mj003oO00>0?mj00030?me003oJ`00
of/000@0of/000<0ofh00?mf003oJ`003@3oJ`04ooooo`03o`000?oooooooooo00?ooooo0002oooo
o`03o`000?oooooooooo00Sooooo00Go0000oooooooooooo0000ooooo`04o`0000Gooooo00?o0000
ooooooooool00_oooola0?m[0080ofd04@3oJ`000`3oK`00ogX00?mj000J0?mj00030?ml003oQ000
ohX000l0ohX01P3oV@00503oW`00ojP00?nX003oZ000oj`00?nh003oc@00g?X00>_h003?oP00m?d0
0?Cn0037o`00]?l00>_o003om`00onh00?oV003oh@00oml00`3oe`001`3of`00oNT00=Co003of`00
ol800?nf003o[0000P3oZ0000`3oY@00oil00?nI00070?nI00040?nD003oRP00ohX00?nD00<0ohX0
00<0oh`00?n:003oRP003`3oRP000`3oS000ohX00?n:000<0?n:00030?ml003oNP00oh000140ogX0
00<0og<00?m[003oJ`001@3oJ`000`3oK@00og<00?m[000<0?m[00Cooooo00?o0000ooooooooool0
0oooool00003ooooool0003o000000[ooooo00Ko0000oooooooooooo0000ooooool00008ooooo`03
o`000?oooooooooo00;ooooo<03oJ`020?m]0180of/000<0ogP00?mj003oNP00603oNP000`3oO000
ogh00?n200030?mn00030?n4003oRP00ohX000T0ohX000<0oi000?nF003oV@001P3oV@00703oY@00
ojP00?nX003o[P00okP00?o4003fj000l?H00:Sn6P2ho`00]ol008go003Jo`00oOX00?o`003oiP00
omd00?oG003oe@00om400?o9003ob`00old00?oC0039l`00oM@00?nj003o/0020?nX00030?nV003o
W`00oiT000H0oiT00P3oU`001@3oTP00ohX00?n:003oRP00oh`00200ohX000<0oh@00?ml003oQP00
0`3oNP000`3oO000ogX00?mj000>0?mj00030?mc003oJ`00of/000L0of/000<0og400?m[003oJ`00
2P3oJ`04ooooo`03o`000?oooooooooo00?ooooo0002ooooo`03o`000?oooooooooo00Wooooo0_l0
0002ooooo`Go00001?ooool2o`0000?ooooo;`3oJ`020?m]0180of/000D0ogD00?mj003oNP00ogX0
0?me00030?mc00030?mh003oNP00ogX00100ogX000<0ogh00?mj003oNP001@3oNP000`3oQ000ohX0
0?n:00050?n:00<0ohh000<0oi000?nG003oV@001@3oV@004`3oW`00ojP00?nX003oZ000oj`00?nh
003o_P00ol/00?oI003oi@00o?800?Wn003No`00[?l00?gj003ojP00on400?oG003od@00103oa`02
0?o300030?o9003o_000ok@000<0ojP000<0oj400?nI003oV@001P3oV@020?n:00050?nB003oRP00
ohX00?n:003oS0006`3oRP001P3oQP00ohX00?n8003oO000oh<00?mn0080ogX000<0ogh00?mj003o
NP004@3oNP000`3oM`00of/00?m[00080?m[00030?m_003oJ`00of/000T0of/00oooool2o`0000Go
oooo000Kooooo`03o`000?oooooooooo00;ooooo@P3oJ`00103oL`00ogX00?mh003oL@060?m[0003
0?md003oNP00ogX001P0ogX02`3oRP000`3oS000oiT00?nI00050?nI00<0ojP000h0oj`00?nh003o
^P00olL00?o=003oe`00on<00?ob003Uo`00SOl;0?_j003oiP00omT00?oD0080olL000<0olD00?o2
003o^P000`3o^0001P3o/000ojP00?nX003oZ000oj400?nM00P0oiT00`3oRP000`3oSP00ohX00?n:
00040?n:00030?n<003oRP00ohX00100ohX000P0ohH00?mn003oQP00ohX00?mn003oNP00ogh00?n2
0080ogX000@0oh800?mj003oNP00og`03`3oNP000`3oN000ogH00?mj00020?mj00030?m]003oJ`00
of/000P0of/000<0ofl00?m[003oJ`00203oJ`04ooooo`03o`000?oooooooooo00?ooooo000Koooo
o`03o`000?oooooooooo00;ooooo@@3oJ`000`3oK`00ogX00?ma00090?m[00030?mh003oNP00ogX0
01H0ogX000<0oh000?n:003oRP002@3oRP001@3oSP00oiT00?nI003oV@00oi/00080oiT000D0oj40
0?nX003oZ000ojP00?nZ00020?nh000>0?nn003oa`00om400?oK003ok000lo`00;Ko003gnP00on`0
0?oG003ob`00olL00?o4003o^P030?nh00030?nd003o[P00ojP00080ojP000<0oj400?nO003oV@00
1@3oV@00103oU000ohX00?n@003oSP0G0?n:00050?n6003oO000og`00?n6003oRP000`3oNP001@3o
R000ogX00?mj003oNP00ogh00080ogX000<0og`00?mj003oNP003`3oNP001`3oL@00of/00?m[003o
J`00og400?mh003oM`005@3oJ`04ooooo`03o`000?oooooooooo00?ooooo000Kooooo`03o`000?oo
oooooooo00;ooooo;P3oJ`000`3oK000of/00?m[000?0?m[00030?m_003oM`00ofd000X0of/000<0
og<00?mj003oNP005@3oNP000`3oO000ohP00?n:00070?n:00030?n<003oSP00oiD000P0oiT00`3o
Z000403oZP00okP00?nh003o_000olL00?o?003of@00onH00?gj002`o`00dol00?c`003oe`00olP0
0?o7003o_0020?nh00030?nf003o[P00ojX000<0ojP000<0oj<00?nO003oV@001P3oV@00103oTP00
ohX00?n:003oS00B0?n:00060?n8003oO000og`00?n6003oRP00ogh00P3oNP000`3oO000ohX00?mj
00020?mj00050?n2003oNP00ogX00?mj003oOP004`3oNP000`3oL`00of/00?m[00030?m[00030?m]
003oM`00og4001@0of/01?ooool00ol0003oooooooooo`03ooooo`006oooool2o`0000?ooooo?`3o
J`000`3oK`00og<00?m[000;0?m[00030?m_003oNP00ogX001<0ogX000<0og`00?n4003oRP00303o
RP000`3oUP00oiT00?nI00030?nI00030?nK003oY@00ojP00080ojP001@0ojX00?nd003o^000ok`0
0?o7003oc`00om/00?o/003fo@00Z_l00?Cm003mj000omD00?o7003o_P00okP00?nj003o^000ok00
0?nZ00<0ojP000<0oj@00?nM003oV@001@3oV@000`3oTP00oi000?nD000A0?n:0080ohP00P3oRP00
1@3oP000ogX00?mj003oNP00ohP000@0ogX000<0oh@00?mj003oNP006@3oNP000`3oL`00of/00?m[
00050?m[00030?mc003oK`00of/00180of/00oooool2o`0000Gooooo000Kooooo`03o`000?oooooo
oooo00;ooooo;03oJ`000`3oK@00of/00?m[000?0?m[0080og003@3oJ`000`3oL000ogX00?mj000A
0?mj00070?ml003oO@00oh000?mm003oO`00oh800?n9000:0?n:00030?nB003oV@00oiT000@0oiT0
00D0oih00?nX003oZ000ojP00?n[00020?nh000;0?nj003oa`00oll00?oR003Wo000b_l00;[o003k
n@00oml00?oB003oaP000`3o^0000`3o[`00ojP00?nX00020?nX00030?nU003oW000oi/000H0oiT0
0`3oRP000`3oS000ohX00?n:000=0?n:00050?n2003oNP00ogX00?n1003oRP00103oNP000`3oO`00
og`00?mj00020?mj00030?mm003oNP00ogX00080ogX000<0og`00?mj003oNP00503oNP000`3oL`00
of/00?m[00060?m[00030?m`003oKP00of/000X0of/000<0ofd00?m[003oJ`00103oJ`04ooooo`03
o`000?oooooooooo00?ooooo000Kooooo`03o`000?oooooooooo00;ooooo00@0oe`00?mP003oI000
ofT09P3oJ`000`3oK@00of/00?m[000@0?m[00030?ma003oK@00of/000d0of/000<0og<00?mj003o
NP005`3oNP000`3oOP00ohX00?n:00050?n:00030?n>003oT000oi@000H0oiT000<0oil00?nV003o
Z0000`3oZ0020?nh000;0?nj003oa`00om400?oO002Xo`80Nml509ko003VnP00oml00?o9003o``00
0P3o^0000`3o]P00ojX00?nX00030?nX00L0oiT00P3oT0000`3oTP00ohX00?n:000<0?n:0080ohP0
0P3oRP040?mj00030?n0003oO000ogX000<0ogX000<0oh000?mj003oNP000P3oNP000`3oO000ogX0
0?mj000D0?mj00050?mf003oN000ogX00?mj003oL`002@3oJ`020?m]0140of/01?ooool00ol0003o
ooooooooo`03ooooo`006oooool00ol0003oooooooooo`02ooooo`@0oe`000<0of800?mY003oJ`00
=@3oJ`000`3oK`00of/00?m[000>0?m[01/0ogX02@3oRP000`3oS000oiT00?nI00020?nI0080oi/0
00H0oiT00?nU003oZ000ojP00?nZ003o[P020?nh000>0?nn003oa`00om400?oO003enP00V_lL0>Wo
003Xn@00omT00?o7003o`P00okX00?nh003o/P040?nX0080oid01P3oV@030?n:00030?n<003oRP00
ohX000X0ohX000D0oh800?mj003oNP00oh800?n:00050?mj00030?n0003oNP00ogX00080ogX000<0
og`00?mj003oNP005`3oNP001`3oM`00of/00?m[003oJ`00og400?mh003oNP00703oJ`04ooooo`03
o`000?oooooooooo00?ooooo000Kooooo`;o00000oooool50?mL00030?mN003oJ000of/003<0of/0
00<0ofl00?m[003oJ`003P3oJ`000`3oL000ogX00?mj000H0?mj00030?n4003oRP00ohX000P0ohX0
00<0oiH00?nI003oV@000`3oV@000`3oY@00ojP00?nX00020?nX000>0?nd003o^000okX00?o2003o
a`00om<00?_[003IoP00e_l00?kf003oi000omD00?o7003o_P020?nh00@0ojP000<0ojH00?nM003o
V@00103oV@000`3oUP00oi@00?n@000?0?n:00@0ogX000<0oh@00?ml003oNP000`3oNP000`3oOP00
ogX00?mj00070?mj00030?ml003oNP00ogX00180ogX01P3oJ`000`3oM`00og<00?m[00090?m[0003
0?m_003oJ`00of/000X0of/000@0ofd00?m[003oJ`00of/00oooool2o`0000Gooooo000Kooooo`03
o`000?oooooooooo00;ooooo1`3oG0000`3oJ@00of/00?m[000`0?m[00030?m_003oJ`00of/000l0
of/000<0ogP00?mj003oNP005P3oNP000`3oO000oh@00?n:00070?n:00030?n>003oT000oi@000D0
oiT000<0oid00?nS003oZ0000P3oZ0004P3o[000ok@00?nh003o^000ol@00?o7003oe`00kO000=Ko
003Po`00onh00?oO003od@00olL00?nm003o^000ok@00?nZ00<0ojP01`3oV@020?n:00030?n<003o
RP00ohX000T0ohX000@0ohP00?n6003oR000ohX01@3oNP000`3oP000ogX00?mj000P0?mj00030?me
003oJ`00of/000D0of/000<0ogL00?m]003oJ`002@3oJ`000`3oK000of/00?m[000=0?m[00Cooooo
00?o0000ooooooooool00oooool001_ooooo00?o0000ooooooooool00_ooool70?mL00030?mN003o
J`00of/00440of/000@0og<00?mj003oNP00ogH00P3oL`000`3oM@00ogX00?mj000?0?mj0080ogh0
0P3oPP000`3oR000ohX00?n:00070?n:00030?nF003oV@00oiT000<0oiT000H0oi/00?nX003oZ000
ojP00?nZ003o/0020?nh000?0?nn003oa`00olT00?oG003oj000gOd00<7o003okP00oml00?oA003o
b@00okh00?nh003o]000ojX00080ojP000<0ojD00?nM003oV@00103oV@000`3oU@00oi000?n:000<
0?n:00050?ml003oNP00ogX00?n5003oO000103oNP000`3oO000ogX00?mj00030?mj00030?ml003o
NP00ogX00080ogX000<0og`00?mj003oNP001`3oNP000`3oO000ogX00?mj000;0?mj00030?me003o
J`00of/000H0of/000<0og<00?m[003oJ`00603oJ`04ooooo`03o`000?oooooooooo00?ooooo000K
ooooo`03o`000?oooooooooo00;ooooo203oG0000`3oI000of/00?m[000o0?m[00030?ma003oNP00
og<000D0of/000<0ofd00?mg003oNP003@3oNP000`3oO000ogX00?mj00030?mj00030?n6003oRP00
ohX000H0ohX000<0oi800?nI003oV@000P3oV@000`3oW@00oj<00?nX00020?nX000B0?n/003o^000
okP00?nj003oa000olL00?oA003of@00onh00>Om003Jo`00oo<00?oS003oe`00olL00?o0003o^000
ok@00`3oZ0000`3oX`00oiT00?nI00030?nI00040?nB003oRP00oh`00?n<00`0ohX00`3oNP000`3o
N`00oh000?mj00040?mj00030?ml003oNP00ogX00080ogX000<0og`00?mj003oNP00503oNP001@3o
N000og400?m_003oL@00ogL00080ogX02@3oJ`000`3oK`00of/00?m[00080?m[00030?m]003oJ`00
of/000`0of/01?ooool00ol0003oooooooooo`03ooooo`006oooool2o`0000?ooooo2@3oG0100?m[
00030?m_003oN000ofd000P0of/0503oNP000`3oPP00ohX00?n:00040?n:00030?n>003oU000oiT0
00<0oiT000<0oi/00?nI003oZ0000P3oZ0004`3oZP00ok800?nh003o^000okh00?o7003oc@00omL0
0?oS003ol`00jOl00;3o003ToP00onl00?oM003od@00ol<00?nj003o]P000`3oZ0030?nK00<0oiT0
00<0oi@00?n:003oRP002@3oRP00103oR000ohH00?n:003oRP040?mj00030?mn003oNP00ogX000T0
ogX000<0og`00?mj003oNP004`3oNP000`3oK@00of/00?m[00020?m[00030?mc003oNP00ofd000P0
of/00P3oK@0H0?m[00?ooooo0_l00005ooooo`006oooool00ol0003oooooooooo`02ooooo`T0oe`0
00<0ofH00?m[003oJ`00:P3oJ`000`3oK@00of/00?m[000?0?m[00030?m_003oL`00of/000T0of/0
00<0og<00?mj003oNP004@3oNP000`3oQP00ohX00?n:00050?n:00030?n<003oV@00oiT000<0oiT0
00D0oj<00?nX003oZ000ojP00?nd00020?nh000@0?o2003oa`00olT00?oG003oi@00o?L00>[n0033
o`00l?h00<co0032oP00onl00?oS003obP00okP00?nf00<0ojP000<0oid00?nK003oV@000P3oV@00
0`3oT000ohh00?n>00090?n:00060?n8003oNP00ogX00?ml003oQP00ogh0103oNP000`3oO000ogX0
0?mj00030?mj00030?ml003oNP00ogX001L0ogX000<0ogD00?m[003oJ`00103oJ`000`3oL`00ogD0
0?m[000Q0?m[00Cooooo00?o0000ooooooooool00oooool000Oooooo0ol00004ooooo`03o`000?oo
oooooooo00;ooooo0ol00005ooooo`03o`000?oooooooooo00;ooooo2@3oG0000`3oI000of/00?m[
000k0?m[0080ofl02`3oJ`000`3oL`00ogX00?mj000?0?mj00030?n0003oR000ohX000D0ohX000<0
oh`00?n>003oT000103oV@006@3oX@00ojH00?nX003oZ000ok000?nh003o_000ol@00?o7003ob@00
omT00?oY003Mn`00TOlA0=?n003llP00on`00?gc003Oo@00cOl00=gm003oe`00ok`00?nh003oZP00
0P3oZ0000`3oW@00oiT00?nI00020?nI00030?n>003oRP00ohX000T0ohX000<0oh800?mj003oNP00
0P3oNP000`3oPP00ogX00?mj00020?mj00030?ml003oNP00ogX001d0ogX000<0og<00?m[003oJ`00
1@3oJ`000`3oM@00ofd00?m[00080?m[00030?m_003oJ`00of/001D0of/01?ooool00ol0003ooooo
ooooo`03ooooo`002?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool00_ooool90?mL00030?mP003oJ`00of/002P0of/000<0ofd00?m[003oJ`003`3o
J`020?m]00`0of/000<0og<00?mj003oNP00303oNP030?ml0080ogh000<0oh@00?n:003oRP00103o
RP000`3oS000oiL00?nI00020?nI000J0?nK003oY@00ojP00?nZ003o[000okP00?nl003oa`00old0
0?oA003of@00onD00=kl003RoP00k_<00?oS003of`00omL00?oK003oiP00noL00<gn003of@00ol@0
0?nh003o]0020?nX00@0oiT000<0oi800?n@003oSP002P3oRP000`3oQP00ogX00?mj00030?mj0003
0?ml003oNP00ogX001/0ogX000L0ogD00?m[003oJ`00og400?mh003oNP00og<000P0of/000<0og<0
0?m[003oJ`007`3oJ`04ooooo`03o`000?oooooooooo00?ooooo0008ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`X0oe`0>`3oJ`020?m]
00d0of/05@3oNP050?n:00030?n<003oSP00oiL000<0oiT001X0oid00?nX003oZP00oj`00?nh003o
_P00oll00?S^003oh@00onD00?[c003Wo000dOl00?oa003of@00oll00?o=003oa`00ol/00?oE003o
jP00h?l00>ga003oc`00ok`00?nd0080ojP000D0oid00?nI003oV@00oiT00?n>00090?n:00050?n0
003oNP00og`00?n6003oO000103oNP000`3oO000ogX00?mj000J0?mj00030?mg003oJ`00of/00080
of/000<0ofd00?mh003oN000203oJ`020?m]00X0of/000<0ofd00?m[003oJ`004`3oJ`04ooooo`03
o`000?oooooooooo00?ooooo0008ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
1?ooool2o`0000?ooooo2P3oG0190?m[00030?mc003oNP00ogX00180ogX000<0og`00?n:003oRP00
103oRP005P3oU000oiT00?nI003oV@00oi/00?nS003oZ000oj`00?nh003o_000oll00?oU0037o`00
io`00=Wn003On`00koH00>oj003jj`00ol/00?o2003o`0020?o2000:0?o9003og@00j?P00:Ko0@3c
j000olL00?nh003o[000ojP00?nK0080oiT000<0oiH00?n>003oRP00203oRP040?mj00030?n2003o
NP00ogX001l0ogX000<0og<00?m[003oJ`000`3oJ`000`3oK@00ogX00?m[00080?m[00030?m]003o
J`00of/001h0of/00oooool2o`0000Gooooo0008ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`02ooooo`X0oe`0B03oJ`000`3oK@00ogX00?mj000B
0?mj00030?n0003oR000ohX000<0ohX00P3oS0001@3oUP00oiT00?nI003oV`00oj400080ojP000d0
okH00?nn003oc@00n^/00<Cn002<iRD0T_l70>3j003mj000om400?oC003ob`00ok`000<0okP000/0
okX00?nl003oa000om400>;`0@3nl000om<00?o0003o]000ojP00?nM00020?nI00030?nD003oRP00
ohX000P0ohX000<0og`00?mj003oNP000P3oNP000`3oO000ogX00?mj000H0?mj00030?me003oL`00
ogP000<0ogX000<0ofd00?m[003oJ`00103oJ`000`3oK`00og<00?m[00080?m[00030?m]003oJ`00
of/001d0of/01?ooool00ol0003oooooooooo`03ooooo`001oooool2o`0000[ooooo0_l00006oooo
o`03o`000?oooooooooo00;ooooo2P3oG0170?m[00040?m]003oN000ogX00?mf00<0og<000<0ogP0
0?mj003oNP002P3oNP001@3oOP00og`00?mn003oOP00ohH000D0ohX00`3oV@007`3oW@00ojP00?nX
003o/000okX00>gH003ki`00jO/00?Gi003ll`00g_P00?oC003oa`00okh00?nj003o^000ok800?nd
003o/000oj`00?nd003o]P00okP00?nn003ifP00h_X00?c^003ag`00om000?n/003oV`000P3oV@00
0`3oRP00ohh00?n:00050?n:00040?n0003oNP00oh000?n400@0ogX00P3oO00G0?mj00030?mh003o
K@00of/00080of/000@0og400?mj003oNP00og401`3oJ`000`3oL`00of/00?m[000W0?m[00Cooooo
00?o0000ooooooooool00oooool000Sooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00;ooooo2@3oG0000`3oH@00of/00?m[00140?m[00040?m]003o
M`00og<00?m]00D0of/000<0og@00?mj003oNP003@3oNP000`3oPP00ohX00?n:00020?n:000A0?nB
003oV@00oiT00?nN003oY@00ojP00?n_003o^000ol<00?oS003To`00onL00?oG003oc`00o<h00?nm
003o]`000P3o/0000`3oZP00ojP00?nX00030?nX000=0?nZ003o[@00ok@00?o0003oe@00l?`00?[R
003od@00oj`00?nK003oV@00oi800?n<00070?n:00<0ogX000<0og`00?mm003oNP000`3oNP000`3o
O000ogX00?mj000E0?mj00030?m`003oJ`00of/000<0of/000<0ofh00?mi003oL`001`3oJ`000`3o
K@00og000?m[000W0?m[00Cooooo00?o0000ooooooooool00oooool001_ooooo0_l00003ooooo`T0
oe`000<0of@00?m[003oJ`00@`3oJ`000`3oK@00ogD00?m]00080?m[00h0ogX000<0oh000?n8003o
RP000P3oRP004@3oSP00oiL00?nI003oV`00ojD00?nX003o[000okP00?o0003oc@00lN/00>?h003o
d@00olD00?nl003o^000ok8000D0ojP000@0oj@00?nU003oYP00ojH00`3oZ0002P3o]000olX00?ce
003o`P00ojX00?nQ003oV@00oiH00?n>003oS0040?n:00040?n8003oQP00ohP00?ml00<0ogX000<0
og`00?mj003oNP000`3oNP000`3oO000ogX00?mj000D0?mj00L0of/000<0ofl00?mg003oJ`001`3o
J`000`3oK@00of/00?m[00080?m[00030?m]003oJ`00of/001/0of/00oooool2o`0000Gooooo000K
ooooo`03o`000?oooooooooo00;ooooo2@3oG0000`3oI000of/00?m[00090?m[00030?mY003oI`00
ofL00080ofL0=03oJ`000`3oK@00og400?m[00090?m[00d0ogX00`3oOP004`3oR000ohX00?n:003o
S000oiT00?nK003oY@00ojP00?nb003o_000ol<00?o;003oh@00jOd00?oQ003oa`00okX00?nf003o
[0000P3oZ0000`3oYP00oj<00?nK00020?nI0080oi/000T0oiT00?nK003oW`00ojP00?n[003o`000
o^h00?nj003oX`000P3oV@000`3oSP00ohX00?n:00040?n:00040?ml003oNP00og`00?n201P0ogX0
00D0ogP00?ma003oK@00ofd00?me00030?mj00P0of/000<0ogD00?m[003oJ`001`3oJ`000`3oK@00
of/00?m[000U0?m[00Cooooo00?o0000ooooooooool00oooool001_ooooo00?o0000ooooooooool0
0_ooool90?mL00T0of/000<0ofT00?mR003oGP001P3oG0000`3oHP00ofT00?m[000_0?m[00030?m]
003oK`00of/000X0of/0403oNP005@3oQP00ohX00?n:003oS000oiT00?nX003o/P00okP00?o:003S
h@00o^<00?SZ003WnP00fOd00?oO003o`P00okH00?nZ003oZ000ojH00?nO00050?nI000:0?nK003o
V@00oiT00?nI003oV`00oiT00?nR003o/000lm<00?n/0080oiT000<0ohh00?n:003oRP001@3oRP00
1@3oO000ogX00?mj003oNP00og`000@0ogX000<0og`00?mj003oNP00403oNP000`3oK`00of/00?m[
00020?m[00030?m_003oNP00ogX000T0of/000<0og<00?m[003oJ`001P3oJ`000`3oK@00of/00?m[
000U0?m[00Cooooo00?o0000ooooooooool00oooool001_ooooo00?o0000ooooooooool00_ooool9
0?mL00L0of/000<0ofT00?mR003oG0002P3oG0000`3oI000of/00?m[000/0?m[00030?m/003oK@00
of/000X0of/000<0ofl00?mj003oNP003@3oNP005`3oPP00ohP00?n:003oRP00oh`00?nI003o_000
nmh00?[Q003hl000on000?7S003gh`00omL00?_Y003ej`00ol800?nb003oZ000ojD00?nM003oV@00
oi/000/0oiT00P3oW`00103oV@00oiL00?n@003oS0040?n:00040?n8003oO000oh000?n201X0ogX0
00<0ogL00?m[003oJ`00103oJ`000`3oK`00ogX00?m_00080?m[00030?m_003oJ`00of/000L0of/0
00<0ofd00?m[003oJ`00903oJ`04ooooo`03o`000?oooooooooo00?ooooo000Kooooo`;o00000ooo
ool80?mL00030?mT003oJ`00of/000@0of/000<0ofH00?mL003oG000303oG0000`3oI000of/00?m[
000[0?m[00030?m^003oJ`00of/000X0of/000<0ogL00?mj003oNP003`3oNP020?n:000?0?n<003o
U`00ojD00?nf003oe@00om800?nj003o]P00okP00?nl003oc@00i^d00?o0003oZ000ojD000D0oiT0
0P3oU`000`3oTP00oiD00?n@00020?nD00070?nB003oUP00oiH00?nG003oU@00oi@00?n<00060?n:
00030?n2003oNP00ogX00080og`00`3oNP000`3oO000ogX00?mj000C0?mj00030?mc003oJ`00of/0
00D0of/000<0og400?mc003oJ`00203oJ`000`3oK`00of/00?m[000[0?m[00030?mY003oHP3ooooo
00;ooooo0_l00005ooooo`006oooool00ol0003oooooooooo`02ooooo`P0oe`000<0ofP00?m[003o
J`000`3oJ`000`3oI000oe`00?mL000>0?mL00030?mV003oJ`00of/002T0of/000<0ofl00?m[003o
J`002P3oJ`001P3oL`00ogX00?mh003oM@00og<00?me00P0ogX000H0og`00?mj003oNP00ogX00?mn
003oR@020?n:00030?n<003oU`00oil00080ok800P3oY0001P3oZ000ojX00?nj003ej000ol@00?nU
00<0oiT000D0oiL00?nF003oT000oi800?n>00030?n:00040?n<003oT000ohX00?n<00T0ohX000<0
oh@00?ml003oQ0005P3oNP001@3oN000og400?m_003oL@00ogP00080ogX000<0og<00?m[003oJ`00
1P3oJ`000`3oMP00of/00?m[00070?m[00030?m]003oJ`00of/002X0of/000<0of800?mL003oG000
1?ooool00ol0003oooooooooo`03ooooo`006oooool00ol0003oooooooooo`02ooooo`P0oe`01@3o
J`000`3oHP00oe`00?mL000@0?mL03L0of/000<0ofl00?mh003oL@00103oJ`000`3oK`00ogX00?mj
00090?mj00030?ml003oN`00ohX00080ohX000<0oh`00?nF003oV@000`3oV@001P3oV`00oil00?nX
003m`@00ojD00?nK0080oiT00P3oTP000`3oS000ohX00?n<00040?n:0080oh`02@3oRP020?n80004
0?n2003oNP00ogX00?n001D0ogX000<0ofd00?m[003oJ`000P3oJ`000`3oL`00ogX00?mc00080?m[
0080ofl02@3oJ`000`3oK000of/00?m[000X0?m[00040?mP003oG000oe`00?mL00Cooooo00?o0000
ooooooooool00oooool001_ooooo00?o0000ooooooooool00_ooool70?mL00030?mT003oJ`00of/0
0080of/000<0of000?mL003oG0004@3oG0000`3oI000of/00?m[000c0?m[00030?m]003oM@00of/0
00H0of/000<0ogD00?mj003oNP002@3oNP000`3oO`00oh800?n:00030?n:00030?n<003oTP00oiH0
0080oiL00P3oV@001@3oV`00oiT00?nI003oU000oh`001@0ohX00P3oNP000`3oP000ogX00?mj000E
0?mj00030?mc003oJ`00of/000@0of/000<0ogD00?mj003oJ`00203oJ`000`3oL@00of/00?m[0007
0?m[00030?m/003oJ`00of/000L0of/000<0ofd00?m[003oJ`007@3oJ`000`3oIP00oe`00?mL0002
0?mL00Cooooo00?o0000ooooooooool00oooool001_ooooo0_l00003ooooo`L0oe`000D0ofT00?m[
003oJ`00of/00?mP000E0?mL02L0of/000<0ofd00?m[003oJ`002P3oJ`000`3oK@00og400?m[0007
0?m[00030?mc003oNP00ogX000P0ogX000D0og`00?mk003oNP00ohX00?n800040?n:00@0oh`000@0
oi000?nD003oSP00oh`04@3oRP020?n800030?n4003oNP00oh8000<0ogX000<0og`00?mj003oNP00
503oNP000`3oL`00of/00?m[00050?m[00030?mg003oK@00of/000L0of/000<0ofl00?m[003oJ`00
1`3oJ`000`3oK000of/00?m[000W0?m[00D0oe`00oooool2o`0000Gooooo000Kooooo`03o`000?oo
oooooooo00;ooooo1P3oG0001@3oH000of/00?m[003oJ`00of0001H0oe`0<`3oJ`000`3oK@00og40
0?m[00080?m[00030?mg003oNP00ogX000P0ogX000<0og`00?mj003oO0000P3oO0000`3oR000ohX0
0?n:000E0?n:0080ohP000H0ohX00?mo003oR000og`00?mj003oP0020?mj00030?ml003oNP00ogX0
0140ogX000@0ogP00?ma003oK`00ogD00P3oNP000`3oL`00of/00?m[00050?m[00030?m]003oL`00
of/000P0of/000<0ofl00?m[003oJ`001`3oJ`000`3oK@00of/00?m[000U0?m[00030?mV003oG000
oe`000<0oe`01?ooool00ol0003oooooooooo`03ooooo`006oooool00ol0003oooooooooo`02oooo
o`H0oe`000@0ofP00?m[003oJ`00of@05`3oG0000`3oI000of/00?m[000`0?m[00030?m_003oJ`00
of/000L0of/000<0ofd00?mj003oNP003@3oNP001@3oOP00ogX00?n2003oQP00ohP000h0ohX000/0
ohP00?n2003oRP00oh800?ml003oR000og`00?mj003oQP00ogX00?mn00020?mj00030?mn003oNP00
ogX001<0ogX000<0ogL00?m[003oJ`000P3oJ`000`3oL000ogX00?mc00080?m[00030?mc003oJ`00
of/000L0of/000<0ofd00?m[003oJ`001`3oJ`000`3oK@00of/00?m[000U0?m[00030?mT003oG000
oe`000<0oe`01?ooool00ol0003oooooooooo`03ooooo`006oooool00ol0003oooooooooo`02oooo
o`D0oe`000@0oeh00?m[003oJ`00ofP0603oG0000`3oI000of/00?m[000_0?m[00030?m_003oJ`00
of/000P0of/000<0ogD00?mj003oM@000P3oK`000`3oM@00ogX00?mj000:0?mj00050?mn003oNP00
oh800?n0003oQ0000P3oR0001P3oRP00ohP00?n:003oQP00ohX00?n40080ohH000D0ogX00?n4003o
P000ogX00?n200020?mj00040?n0003oNP00ogX00?n20080ogX000<0og`00?mj003oNP000`3oNP00
0`3oO000ogX00?mj000?0?mj00030?mc003oJ`00of/000<0of/000<0ogD00?mg003oJ`00203oJ`00
0`3oK`00of/00?m[00070?m[00030?m]003oJ`00of/000L0of/000<0ofd00?m[003oJ`00903oJ`00
0`3oI000oe`00?mL00030?mL00Cooooo00?o0000ooooooooool00oooool001_ooooo0_l00003oooo
o`D0oe`000<0ofH00?m[003oJ@006@3oG0000`3oI000of/00?m[000i0?m[00030?m_003oM`00ofd0
00@0of/000<0ogL00?mj003oNP001P3oNP000`3oO000ogX00?mj00020?mj000:0?ml003oNP00oh80
0?mj003oO000oh000?mj003oQ000ogX00?n40080ogX000<0oh800?mj003oNP008`3oNP070?m[0003
0?mh003oJ`00of/000L0of/000<0ofd00?m[003oJ`001`3oJ`000`3oK@00of/00?m[00070?m[0003
0?m]003oJ`00of/002@0of/01P3oG003ooooo`;o00001Oooool001_ooooo00?o0000ooooooooool0
0_ooool40?mL00040?mN003oJ`00of/00?mN01T0oe`000<0of@00?m[003oJ`00>03oJ`000`3oK@00
og<00?m[00050?m[00030?mc003oNP00ogX000D0ogX000<0og`00?mj003oNP000`3oNP000`3oO000
ogX00?ml00040?mj00030?n0003oNP00oh800080ogX000@0og`00?mj003oNP00ogh0703oNP00103o
L@00ofl00?m_003oM@020?mj00L0of/000<0ofl00?ma003oJ`00203oJ`000`3oK@00of/00?m[000g
0?m[00030?mT003oG000oe`000<0oe`01?ooool00ol0003oooooooooo`03ooooo`0000Coooooo`00
0?l0003o00001?ooool00ol0003oooooooooo`02ooooo`?o00000oooool3o`0000Gooooo00?o0000
ooooooooool00_ooool40?mL00030?mU003oJ`00of4001X0oe`000<0of@00?m[003oJ`00>03oJ`00
0`3oL000of/00?m[00050?m[00030?mc003oNP00ogX001d0ogX000@0og`00?mj003oNP00og`05@3o
NP000`3oL@00of/00?m[00020?m[00030?ma003oNP00og<000L0of/000<0og400?m[003oJ`00@@3o
J`000`3oI000oe`00?mL00030?mL00Cooooo00?o0000ooooooooool00oooool000;ooooo00?o0000
ooooooooool02Oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`02ooooo`<0oe`000<0oeh00?m[003oHP006`3oG00j0?m[00030?m_003o
J`00of/000H0of/00P3oN0000`3oL@00ofl00?ma000@0?mj00030?ml003oNP00ogX00240ogX01P3o
J`000`3oL@00og<00?m[00070?m[00030?m_003oJ`00of/000L0of/000<0ofd00?m[003oJ`001`3o
J`000`3oK@00of/00?m[000Q0?m[0080ofL02@3oJ`000`3oI000oe`00?mL00030?mL00Cooooo00?o
0000ooooooooool00oooool000;ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00;ooooo0_l00003ooooo`<0oe`000<0ofH00?mX003oG0006`3oG00;
0?m[00040?mY003oI`00ofL00?mY02X0of/000<0ofd00?m[003oJ`001P3oJ`000`3oK`00ogL00?m]
00030?m[00030?mc003oNP00ogX002/0ogX000@0og400?m[003oK@00ogD00P3oNP070?m[00030?mg
003oJ`00of/000H0of/000<0ofd00?m[003oJ`00<P3oJ`000`3oJ000of000?mL00030?mL00030?mP
003oIP00of/000D0of/000<0ofT00?mL003oG0000`3oG003ooooo`;o00001Oooool000;ooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool00_ooool20?mL00030?mN003oJ`00oeh001/0oe`000<0of000?m[003oJ`001P3o
J`000`3oJ@00of800?mN00040?mL00030?mN003oI000of/002H0of/000<0ofd00?m[003oJ`001`3o
J`000`3oL`00of/00?m[00040?m[02`0ogX000<0ogD00?m[003oJ`000P3oJ`000`3oL`00ogX00?m[
00060?m[00030?m]003oK`00of/003X0of/000<0of@00?mL003oG0001P3oG0000`3oGP00ofP00?m[
00040?m[00D0oe`01?ooool00ol0003oooooooooo`03ooooo`000_ooool00ol0003oooooooooo`09
ooooo`04o`000?ooooooooooooooo`Co00001Oooool00ol0003oooooooooo`02ooooo`80oe`000<0
ofH00?mR003oG0006`3oG0000`3oI000of/00?m[00040?m[00030?mY003oHP00oe`000P0oe`000<0
oeh00?mX003oJ`00;@3oJ`000`3oK`00ofd00?m[00040?m[00060?m]003oNP00ogH00?m_003oL@00
ogP08@3oNP00103oN000og<00?mc003oN0020?mj00030?m]003oJ`00of/000<0of/000<0ogL00?m_
003oJ`001P3oJ`000`3oK`00of/00?m[000@0?m[00030?m]003oJ`00of/002D0of/000<0ofH00?mL
003oG0002@3oG0000`3oHP00of/00?m[00020?m[00030?mT003oG000oe`00080oe`01?ooool00ol0
003oooooooooo`03ooooo`0000?oooooo`000?l000002_ooool2o`0000?ooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`02ooooo`030?mL003oGP00ofP001d0oe`000<0ofP00?m[003o
J`000`3oJ`000`3oIP00oe`00?mL000;0?mL00030?mX003oJ`00of/002/0of/000<0ofd00?m[003o
J`00103oJ`000`3oL`00ogL00?m[00020?m[00030?ma003oNP00ogX001l0ogX000H0ofd00?m[003o
J`00of/00?mg003oNP060?m[00030?m]003oL`00of/000H0of/000<0ofd00?m[003oJ`001P3oJ`00
0`3oK@00of/00?m[000^0?m[00030?mY003oG000oe`000/0oe`000D0of000?m[003oJ`00of/00?mY
00040?mL00Cooooo00?o0000ooooooooool00oooool000;ooooo00?o0000ooooooooool02Oooool0
1?l0003oooooooooooooool5o`0000Cooooo0_l00003ooooo`030?mL003oJ000of0001d0oe`01@3o
J`000`3oHP00oe`00?mL000<0?mL00030?mN003oJ`00of/002X0of/000<0ofl00?m[003oJ`001@3o
J`000`3oM@00of/00?m[00030?m[0080ogX000<0og400?m[003oL@005P3oNP000`3oL000of/00?ma
00020?mj00030?mc003oJ`00of/00080of/000<0ofd00?mj003oJ`001P3oJ`000`3oL@00of/00?m[
00060?m[00030?m_003oJ`00of/003H0of/000<0of@00?mL003oG000303oG0001@3oGP00ofT00?m[
003oJ`00of0000<0oe`00oooool2o`0000Gooooo000Kooooo`03o`000?oooooooooo00;ooooo00<0
of000?mV003oG000703oG0000`3oI000of/00?m[00020?m[00030?mP003oG000oe`000h0oe`000<0
of@00?m[003oJ`007P3oJ`020?m]0140of/000<0og400?m[003oJ`000`3oJ`000`3oNP00ofl00?m[
00020?m[00060?mc003oNP00ogX00?ma003oK@00og400`3oNP000`3oN000og400?mc00030?mj0004
0?mg003oK@00of/00?ma0080ogX000L0ogL00?m[003oJ`00of/00?m_003oNP00og<000D0of/000<0
og<00?ma003oJ`001@3oJ`000`3oK@00of/00?m[00060?m[00030?m]003oJ`00of/003H0of/000<0
oeh00?mL003oG0003@3oG000103oH000of/00?m[003oIP030?mL00Cooooo00?o0000ooooooooool0
0oooool001_ooooo00?o0000ooooooooool00_ooool00`3oIP00oe`00?mL000L0?mL00050?mY003o
J`00of/00?m[003oH0004P3oG00Z0?m[00030?m]003oJ`00of/000D0of/000<0ofl00?m[003oJ`00
103oJ`000`3oM@00of/00?m[00030?m[00030?mj003oL@00of/00080of/000<0og400?mj003oN000
0`3oJ`00103oK`00ogX00?mj003oK@030?m[00030?ma003oNP00og<000@0of/000<0ogD00?mc003o
J`001@3oJ`000`3oL`00of/00?m[00050?m[00030?m_003oJ`00of/000H0of/000<0ofd00?m[003o
J`00=@3oJ`0A0?mL00040?mP003oJ`00of/00?mN0080oe`01?ooool00ol0003oooooooooo`03oooo
o`006oooool00ol0003oooooooooo`02ooooo`030?mR003oG000oe`001/0oe`000D0of000?m[003o
J`00of/00?mP000C0?mL00030?mY003oJ`00of/002l0of/000<0ofd00?m[003oJ`000`3oJ`000`3o
L`00ofd00?m[00040?m[00030?mh003oJ`00of/000<0of/000<0ogX00?ma003oJ`000`3oJ`000`3o
M@00ogL00?m[00040?m[00030?mh003oJ`00of/000<0of/000<0ofl00?mc003oJ`001@3oJ`000`3o
K@00of/00?m[00050?m[00030?m]003oJ`00of/000l0of/000<0ofd00?m[003oJ`00703oJ`000`3o
K@00of/00?m[000=0?m[0180oe`000<0of800?m[003oI0000P3oG004ooooo`03o`000?oooooooooo
00?ooooo000Kooooo`;o00000ooooolN0?mL00040?mV003oJ`00of/00?mR01@0oe`000<0of@00?m[
003oJ`00;P3oJ`000`3oK@00of/00?m[00040?m[00030?m_003oJ`00of/000@0of/000<0og<00?m[
003oJ`000`3oJ`000`3oN000of/00?m[00030?m[00030?ma003oL`00of/000@0of/000<0og<00?m[
003oJ`00103oJ`000`3oL`00of/00?m[00040?m[00030?m_003oJ`00of/004H0of/04`3oG000103o
IP00of/00?mL003oG003ooooo`;o00001Oooool001_ooooo00?o0000ooooooooool00_oooolN0?mL
0080of/000<0ofH00?mL003oG0004`3oG0000`3oI000of/00?m[000e0?m[00030?m_003oJ`00of/0
00@0of/000<0ofl00?m[003oJ`000`3oJ`000`3oL`00of/00?m[00040?m[00030?mc003oJ`00of/0
00<0of/000<0og400?m[003oJ`00303oJ`000`3oK@00of/00?m[00050?m[00030?m]003oJ`00of/0
0300of/00`3oI`000`3oJ@00of/00?m[00070?m[01@0oe`000<0ofT00?mT003oG0001?ooool00ol0
003oooooooooo`03ooooo`006oooool00ol0003oooooooooo`02oooooad0oe`000<0of@00?m[003o
J0005P3oG0000`3oI000of/00?m[000k0?m[00030?m_003oJ`00of/000/0of/000<0og<00?m[003o
J`002P3oJ`000`3oL@00of/00?m[000n0?m[00030?mV003oGP00oe`000<0oe`000<0oeh00?mV003o
J`001P3oJ`0D0?mL00030?mN003oJ`00oeh000Cooooo00?o0000ooooooooool00oooool001_ooooo
00?o0000ooooooooool00_oooolM0?mL0080of/000<0oeh00?mL003oG000503oG0000`3oI000of/0
0?m[000d0?m[00030?m]003oJ`00of/000@0of/000<0ofl00?m[003oJ`002`3oJ`000`3oL`00of/0
0?m[00040?m[00030?ma003oJ`00of/000/0of/000<0ofd00?m[003oJ`00=@3oJ`000`3oH000oe`0
0?mL00060?mL00030?mN003oJ@00of/000@0of/05@3oG0000`3oHP00ofH0ooooo`03ooooo`03o`00
0?oooooooooo00?ooooo000Kooooo`;o00000ooooolL0?mL00030?mR003oJ`00of8001L0oe`000<0
of@00?m[003oJ`00B@3oJ`000`3oL`00of/00?m[00040?m[00030?m_003oJ`00of/000@0of/000<0
ofd00?m[003oJ`00>`3oJ`000`3oH000oe`00?mL00090?mL00030?mV003oJ`00of/00080of/000<0
of@00?mL003oG0004`3oG000103oJ03oooooooooooooool2o`0000Gooooo000Kooooo`03o`000?oo
oooooooo00;ooooo703oG0000`3oJ@00ofP00?mL000G0?mL00030?mT003oJ`00of/000L0of/000D0
ofL00?mT003oI000of@00?mW000_0?m[00030?m]003oJ`00of/000@0of/000<0ofd00?m[003oJ`00
103oJ`000`3oL`00of/00?m[00180?m[00030?mV003oG000oe`000/0oe`000D0of@00?m[003oJ`00
of/00?mT000E0?mL00030?mN0?oooooooooo00;ooooo00?o0000ooooooooool00oooool001_ooooo
00?o0000ooooooooool00_oooolK0?mL00030?mR003oJP00oeh001P0oe`000<0ofX00?m[003oJ`00
103oJ`000`3oI`00of400?mN00050?mL00030?mN003oI000of/003<0of/000<0og000?m[003oJ`00
C`3oJ`000`3oGP00oe`00?mL000<0?mL00040?mT003oJ`00of/00?mZ01H0oe`01?ooool00ol0003o
ooooooooo`03ooooo`006oooool00ol0003oooooooooo`02oooooa/0oe`000<0ofT00?mP003oG000
603oG0050?m[00030?mY003oHP00oe`000T0oe`000<0of000?m[003oJ`00AP3oJ`000`3oK@00of/0
0?m[000i0?m[00030?mY003oG000oe`000h0oe`000@0of@00?m[003oJ`00of005@3oG004ooooo`03
o`000?oooooooooo00?ooooo000Kooooo`;o00000ooooolJ0?mL00030?mR003oIP00oe`001P0oe`0
00<0of800?m[003oJ`000P3oJ`000`3oJ@00oeh00?mL000;0?mL00030?mR003oJ`00of/003h0of/0
00<0ofd00?m[003oJ`00@03oJ`000`3oI000oe`00?mL000?0?mL00030?mX003oJ`00of@001D0oe`0
0oooool2o`0000Gooooo000Kooooo`03o`000?oooooooooo00;ooooo6P3oG0000`3oJ@00oe`00?mL
000H0?mL00050?mT003oJ`00of/00?m[003oJ0003`3oG0000`3oJ000of/00?m[001d0?m[00030?mY
003oI`00ofL000T0of/000<0of@00?mL003oG0003`3oG0000`3oGP00of/00?m[000E0?mL00Cooooo
00?o0000ooooooooool00oooool000Oooooo0ol00004ooooo`04o`000?ooooooooooooooo`Go0000
1?ooool00ol0003oooooooooo`02oooooaT0oe`00P3oHP0J0?mL00<0of/000<0ofT00?mL003oG000
3P3oG0000`3oHP00of/00?m[001b0?m[00030?mV003oGP00oe`000<0oe`000<0of800?mY003oJ`00
1@3oJ`000`3oI000oe`00?mL000@0?mL00030?mR003oJ`00of8001@0oe`01?ooool00ol0003ooooo
ooooo`03ooooo`002?ooool00ol0003oooooooooo`08ooooo`04o`000?ooooooooooo`0000Cooooo
00?o0000ooooooooool00_oooolI0?mL00030?mV003oG000oe`001P0oe`000D0of000?m[003oJ`00
ofT00?mN000A0?mL07<0of/000<0of000?mL003oG0001P3oG0000`3oHP00of/00?m[00030?m[0003
0?mT003oG000oe`00140oe`00P3oJ00D0?mL00Cooooo00?o0000ooooooooool00oooool000Sooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo
603oG0000`3oHP00of000?mL000I0?mL00040?mT003oJ`00of/00?mP0180oe`0LP3oJ`000`3oH000
oe`00?mL00080?mL00030?mR003oJ`00of/00080of/000<0of@00?mL003oG0004@3oG0000`3oGP00
of/00?mN000C0?mL00Cooooo00?o0000ooooooooool00oooool000Sooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`03ooooo`;o00000ooooolH0?mL00030?mV003oG000oe`001T0oe`0
0P3oJ`000`3oHP00oe`00?mL000A0?mL00030?mT003oJ`00of/006h0of/000<0ofH00?mL003oG000
2P3oG0001@3oIP00of/00?m[003oJ`00ofP001@0oe`000<0of800?mV003oG0004P3oG0000ol0003o
ooooooooo`02o`0000Gooooo0008ooooo`03o`000?oooooooooo00Oooooo00Go0000oooooooooooo
ooooo`000004ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00Go0000ooooooooooooooooo`000005oooo
o`001oooool2o`0000Wooooo00Go0000ooooooooooooooooo`000004oooooooo00000Ol00005oooo
o`002?ooool00ol0003oooooooooo`08ooooo`?o0000ooooool;ooooo`00oooooolQooooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {143, 0}} -> {-0.578369, 0.863136, 0.00244019, \
0.00244019}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(mandelbrotSet[{{\(-0.11\), \(-0.1\)}, {0.92, 0.93}}, 500, {0, 100}, 
        ColorFunction \[Rule] Hue];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
10.5962 96.1538 -88.4423 96.1538 [
[.01923 -0.0125 -15 -9 ]
[.01923 -0.0125 15 0 ]
[.21154 -0.0125 -18 -9 ]
[.21154 -0.0125 18 0 ]
[.40385 -0.0125 -18 -9 ]
[.40385 -0.0125 18 0 ]
[.59615 -0.0125 -18 -9 ]
[.59615 -0.0125 18 0 ]
[.78846 -0.0125 -18 -9 ]
[.78846 -0.0125 18 0 ]
[.98077 -0.0125 -12 -9 ]
[.98077 -0.0125 12 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01923 -24 -4.5 ]
[-0.0125 .01923 0 4.5 ]
[-0.0125 .21154 -30 -4.5 ]
[-0.0125 .21154 0 4.5 ]
[-0.0125 .40385 -30 -4.5 ]
[-0.0125 .40385 0 4.5 ]
[-0.0125 .59615 -30 -4.5 ]
[-0.0125 .59615 0 4.5 ]
[-0.0125 .78846 -30 -4.5 ]
[-0.0125 .78846 0 4.5 ]
[-0.0125 .98077 -24 -4.5 ]
[-0.0125 .98077 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.01923 0 m
.01923 .00625 L
s
[(-0.11)] .01923 -0.0125 0 1 Mshowa
.21154 0 m
.21154 .00625 L
s
[(-0.108)] .21154 -0.0125 0 1 Mshowa
.40385 0 m
.40385 .00625 L
s
[(-0.106)] .40385 -0.0125 0 1 Mshowa
.59615 0 m
.59615 .00625 L
s
[(-0.104)] .59615 -0.0125 0 1 Mshowa
.78846 0 m
.78846 .00625 L
s
[(-0.102)] .78846 -0.0125 0 1 Mshowa
.98077 0 m
.98077 .00625 L
s
[(-0.1)] .98077 -0.0125 0 1 Mshowa
.125 Mabswid
.06731 0 m
.06731 .00375 L
s
.11538 0 m
.11538 .00375 L
s
.16346 0 m
.16346 .00375 L
s
.25962 0 m
.25962 .00375 L
s
.30769 0 m
.30769 .00375 L
s
.35577 0 m
.35577 .00375 L
s
.45192 0 m
.45192 .00375 L
s
.5 0 m
.5 .00375 L
s
.54808 0 m
.54808 .00375 L
s
.64423 0 m
.64423 .00375 L
s
.69231 0 m
.69231 .00375 L
s
.74038 0 m
.74038 .00375 L
s
.83654 0 m
.83654 .00375 L
s
.88462 0 m
.88462 .00375 L
s
.93269 0 m
.93269 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01923 m
.00625 .01923 L
s
[(0.92)] -0.0125 .01923 1 0 Mshowa
0 .21154 m
.00625 .21154 L
s
[(0.922)] -0.0125 .21154 1 0 Mshowa
0 .40385 m
.00625 .40385 L
s
[(0.924)] -0.0125 .40385 1 0 Mshowa
0 .59615 m
.00625 .59615 L
s
[(0.926)] -0.0125 .59615 1 0 Mshowa
0 .78846 m
.00625 .78846 L
s
[(0.928)] -0.0125 .78846 1 0 Mshowa
0 .98077 m
.00625 .98077 L
s
[(0.93)] -0.0125 .98077 1 0 Mshowa
.125 Mabswid
0 .06731 m
.00375 .06731 L
s
0 .11538 m
.00375 .11538 L
s
0 .16346 m
.00375 .16346 L
s
0 .25962 m
.00375 .25962 L
s
0 .30769 m
.00375 .30769 L
s
0 .35577 m
.00375 .35577 L
s
0 .45192 m
.00375 .45192 L
s
0 .5 m
.00375 .5 L
s
0 .54808 m
.00375 .54808 L
s
0 .64423 m
.00375 .64423 L
s
0 .69231 m
.00375 .69231 L
s
0 .74038 m
.00375 .74038 L
s
0 .83654 m
.00375 .83654 L
s
0 .88462 m
.00375 .88462 L
s
0 .93269 m
.00375 .93269 L
s
.25 Mabswid
0 0 m
0 1 L
s
.01923 .99375 m
.01923 1 L
s
.21154 .99375 m
.21154 1 L
s
.40385 .99375 m
.40385 1 L
s
.59615 .99375 m
.59615 1 L
s
.78846 .99375 m
.78846 1 L
s
.98077 .99375 m
.98077 1 L
s
.125 Mabswid
.06731 .99625 m
.06731 1 L
s
.11538 .99625 m
.11538 1 L
s
.16346 .99625 m
.16346 1 L
s
.25962 .99625 m
.25962 1 L
s
.30769 .99625 m
.30769 1 L
s
.35577 .99625 m
.35577 1 L
s
.45192 .99625 m
.45192 1 L
s
.5 .99625 m
.5 1 L
s
.54808 .99625 m
.54808 1 L
s
.64423 .99625 m
.64423 1 L
s
.69231 .99625 m
.69231 1 L
s
.74038 .99625 m
.74038 1 L
s
.83654 .99625 m
.83654 1 L
s
.88462 .99625 m
.88462 1 L
s
.93269 .99625 m
.93269 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .01923 m
1 .01923 L
s
.99375 .21154 m
1 .21154 L
s
.99375 .40385 m
1 .40385 L
s
.99375 .59615 m
1 .59615 L
s
.99375 .78846 m
1 .78846 L
s
.99375 .98077 m
1 .98077 L
s
.125 Mabswid
.99625 .06731 m
1 .06731 L
s
.99625 .11538 m
1 .11538 L
s
.99625 .16346 m
1 .16346 L
s
.99625 .25962 m
1 .25962 L
s
.99625 .30769 m
1 .30769 L
s
.99625 .35577 m
1 .35577 L
s
.99625 .45192 m
1 .45192 L
s
.99625 .5 m
1 .5 L
s
.99625 .54808 m
1 .54808 L
s
.99625 .64423 m
1 .64423 L
s
.99625 .69231 m
1 .69231 L
s
.99625 .74038 m
1 .74038 L
s
.99625 .83654 m
1 .83654 L
s
.99625 .88462 m
1 .88462 L
s
.99625 .93269 m
1 .93269 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.01923 .01923 translate
.96154 .96154 scale
1500 string
500 500 8 [500 0 0 500 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
33FF0033FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
42FF0033FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
42FF0042FF0042FF0042FF0042FF0042FF0042FF0033FF0042FF0042FF0042FF0042FF00
42FF0042FF0042FF0033FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0005FF0005FF0005FF0000FF0A00FF1900FF1900FF3800FFF000FF94
00FFB30094FF00FF8500FF7500FF7500FFB300F0FF0085FF00E1FF5100FF0085FF00E1FF
0094FF3300FF5100FF00E1FF00FFC200FFB30094FF00FF9400FF8500FF7500FF7500FF94
FF00E600FFF000FF8500FF7500FF6600FF6600FF5700FF5700FF5700FF5700FF5700FF57
00FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF6600FF6600FF6600FF75
00FF7500FF9400FF8500FF8500FF8500FF8500FF9400FFA300FFB30038FF0075FF00C2FF
00FFF000FFD100FFC200FFC200FFB300FFB300FFB300FFC200FFD100F0FF00E1FF00F0FF
00E1FF00A3FF0094FF00A3FF0057FF0047FFBD00FF0075FF00A3FF00C2FF00C2FF0066FF
FF000000FFFF00FFD100FFC200FFB300FFB300FFA300FFA300FFA300FFA300FFA300FF94
00FF9400FF9400FF9400FF9400FF8500FF94FF000000FF7500FF6600FF6600FF5700FF57
00FF5700FF5700FF5700FF5700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0005FF00
05FF0005FF0005FF0000FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF19
00FF1900FF1900FF1900FF2800FF2800FF2800FF3800FF6600FF8500FFB300FF9400FF94
00FFC20085FF00A3FF0019FF0047FF1400FF0094FF00FFA300FF9400FF8500FF7500FF57
00FF4700FF3800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF4700FF8500FF852300FF00FF3800FF2800FF1900FF280057FF0094FF00FF1923FF00
23FF0033FF0033FF0033FF0033FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
42FF0042FF0042FF0042FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF00
51FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0061FF0061FF0051FF0051FF00
61FF0061FF0061FF0061FF0061FF0051FF0061FF0061FF0061FF0061FF0061FF0061FF00
61FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF00
61FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF00
33FF0033FF0033FF0033FF0033FF0042FF0042FF0042FF0033FF0042FF0042FF0042FF00
42FF0042FF0042FF0042FF0042FF0042FF0033FF0042FF0042FF0042FF0042FF0042FF00
42FF0042FF0042FF0042FF0042FF0042FF0042FF0033FF0042FF0042FF0042FF0042FF00
42FF0042FF0042FF0033FF0033FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0014FF0023FF0023FF0023FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0005FF0005FF0005FF0000FF0A00FF0A00FF1900FF2800FF3800FF47
00FF6600FF940047FF00FFC200E1FF0038FF0019FF00F0FF00FFD100E1FF00FFD100FFD1
00C2FF00B3FF00D1FF8000FF00FFA300FF9400FF9400FF8500FF7500FF6600FF7500FF75
00FF9400FFFF00FF7500FF6600FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF57
00FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF6600FF6600FF66
00FF6600FF7500FF7500FF7500FF8500FF8500FF8500FF9400FFA300FFFF0075FF0075FF
0066FF00FFC200FFB300FFB300FFB300FFB300FFB300FFB300FFC200FFD100FFD100FFF0
00E1FF5100FF00C2FF00D1FF00B3FF0085FFFF00000085FF00C2FF00E1FF00F0FF00E1FF
0085FF00C2FF00FFD100FFC200FFB300FFA300FFA300FFA300FF9400FF9400FF9400FF94
00FF9400FF8500FF8500FF8500FF8500FF8500FF7500FF7500FF6600FF6600FF5700FF57
00FF5700FF5700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF3800FF3800FF38
00FF4700FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A05FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0014FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0005FF0005FF00
05FF0005FF0000FF0A00FF0A00FF0A00FF0A00FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF2800FF2800FF2800FF3800FF3800FF4700FF5700FF7500FF7500FF85
00FFA300D1FF00F0FF00A3FF0019FF0019FF00F0FF00FFC200FFE100FFF000FFFF0019FF
00FF4700FF2800FF2800FF2800FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF28
00FF3800FF9400FF3800FF2800FF1900FF0A00FF0A00FF0A00FF1900FF1900FF4714FF00
23FF0033FF0033FF0033FF0033FF0033FF0033FF0042FF0042FF0042FF0042FF0042FF00
42FF0042FF0042FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF00
51FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF00
61FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF00
61FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF00
61FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF00
33FF0033FF0033FF0033FF0033FF0033FF0042FF0033FF0033FF0042FF0042FF0042FF00
42FF0042FF0042FF0042FF0042FF0042FF0033FF0042FF0042FF0042FF0042FF0042FF00
42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
42FF0042FF0042FF0042FF0033FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0005FF0005FF0005FF0005FF0000FF0A00FF0A00FF1900FF2800FF38
00FF4700FF7500FFFF00FFA300FFC200FF9400E1FF00FFB300FF8500FFA300FF9400FFA3
00FFB300F0FF0019FF00FFB300FF9400FF8500FF7500FF6600FF6600FF6600FF6600FF66
00FF8500FF6600FF5700FF5700FF5700FF5700FF5700FF4700FF4700FF4700FF5700FF47
00FF4700FF4700FF4700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF6600FF66
00FF6600FF7500FF6600FF7500FF7500FF7500FF8500FF9400FFA300FFD100C2FF00FFF0
00FFD100FFB300FFA300FFA300FFA300FFA300FFB300FFB300FFB300FFC200FFD100FFE1
00E1FF0066FF00F0FF00F0FF00B3FF0066FF6100FF0038FF00B3FF00F0FF00FFFF00FFF0
00FFE100FFE100FFC200FFB300FFB300FFA300FFA300FFA300FF9400FF9400FF9400FF85
00FF8500FF8500FF8500FF7500FF7500FF7500FF7500FF6600FF6600FF6600FF5700FF57
00FF5700FF5700FF5700FF5700FF4700FF4700FF4700FF4700FF4700FF4700FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF1900FF1900FF1900FF2800FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF0A00FF0A00FF1900FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0023FF00
23FF0023FF0023FF0023FF0023FF0014FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0014FF0023FF0023FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0005FF0005FF0005FF0005FF00
05FF0000FF0A00FF0A00FF3800FF2800FF2800FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF2800FF2800FF2800FF2800FF3800FF3800FF4700FF5700FF6600FF7500FF94
00FFA300FFD100F0FF2300FF00C2FF00F0FF00F0FF0094FF00FFC200FF9400FF8500FF66
00FF3800FF2800FF2800FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF5700FF1900FF1900FF0A00FF0A05FF0005FF0005FF0005FF0014FF0023FF00
23FF0033FF0033FF0033FF0033FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
42FF0042FF0042FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF00
51FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF00
61FF0061FF0061FF0061FF0051FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF00
61FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF00
61FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0042FF0042FF0042FF00
33FF0042FF0042FF0042FF0042FF0042FF0033FF0042FF0042FF0042FF0042FF0042FF00
33FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0033FF0042FF0042FF0042FF00
42FF0042FF0042FF0042FF0033FF0033FF0042FF0042FF0042FF0042FF0042FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0005FF0005FF0005FF0005FF0000FF0A00FF0A00FF1900FF2800FF38
00FF5700FFE100FFF000FF7500FF6600FF7500FF9400FFA300FF6600FF6600FF7500FF85
00FFA300FFE100E1FF00FFC200FF9400FF8500FF7500FF6600FF5700FF5700FF5700FF57
00FF5700FF5700FF5700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF47
00FF4700FF4700FF4700FF4700FF4700FF5700FF5700FF5700FF5700FF5700FF5700FF66
00FF6600FF6600FF6600FF6600FF7500FF7500FF7500FF9400FFD100E1FF00FFD100FFB3
00FFA300FFA300FFA300FFA300FFA300FFA300FFA300FFB300FFB300FFB300FFC200FFD1
00FFF000FFF000FFF000FFFF00E1FFDC00FF0038FF0085FF00B3FF00F0FF00FFF000FFE1
00FFD100FFD100FFC200FFC200FFB300FFA300FFA300FF9400FF9400FF9400FF9400FF85
00FF8500FF8500FF7500FF7500FF7500FF7500FF6600FF6600FF6600FF6600FF5700FF57
00FF5700FF5700FF4700FF4700FF4700FF4700FF4700FF4700FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF2800FF2800FF2800FF3800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0023FF00
23FF0023FF0023FF0023FF0014FF0014FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0005FF0005FF0005FF00
05FF0000FF0A00FF1900FF8500FF4700FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF3800FF3800FF3800FF4700FF5700FF6600FF7500FF94
00B3FF00FFF00066FF00B3FF00FFE100FFB300FFB300C2FF00FFB300FF7500FF5700FF47
00FF3800FF2800FF2800FF1900FF1900FF1900FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A05FF0005FF0005FF0014FF0014FF0014FF0014FF0023FF00
23FF0033FF0033FF0033FF0033FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
42FF0042FF0042FF0051FF0051FF0051FF0042FF0051FF0051FF0051FF0051FF0051FF00
51FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF00
51FF0061FF0061FF0051FF0051FF0061FF0061FF0061FF0061FF0051FF0061FF0061FF00
61FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF00
61FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0042FF0042FF0042FF0042FF0042FF0033FF0042FF0042FF0042FF0042FF0042FF00
33FF0042FF0042FF0042FF0042FF0042FF0042FF0033FF0033FF0042FF0042FF0042FF00
42FF0042FF0042FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0023FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0005FF0005FF0005FF0005FF0000FF0A00FF0A00FF1900FF1900FF38
00FF940085FF00FF8500FF5700FF4700FF4700FF5700FF5700FF5700FF5700FF6600FF85
00FFC24200FF00FFC20057FF0047FF00FF8500FF7500FF6600FF5700FF5700FF5700FF57
00FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF47
00FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF5700FF5700FF5700FF5700FF57
00FF5700FF6600FF6600FF6600FF6600FF7500FF7500FF8500FF9400FFA300FFB300FF94
00FF9400FF9400FF9400FF9400FF9400FFA300FFA300FFA300FFB300FFB300FFC200FFC2
00FFD100FFE100FFF000FFFF00F0FF00C2FF0066FF0057FF00D1FF00F0FF00FFFF00FFE1
00FFD100FFD100FFC200FFB300FFB300FFA300FFA300FF9400FF9400FF9400FF8500FF85
00FF8500FF8500FF7500FF7500FF7500FF6600FF6600FF6600FF6600FF5700FF5700FF57
00FF5700FF5700FF4700FF4700FF4700FF4700FF4700FF4700FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0014FF0014FF0014FF0014FF0014FF0014FF0005FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0023FF0023FF0014FF0014FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
14FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0014FF0023FF0023FF0023FF00
23FF0023FF0014FF0023FF0023FF0023FF0023FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0005FF0005FF0005FF0005FF0000FF0A
00FF0A00FF1900FF1900FF5700FFA300FF4700FF3800FF3800FF3800FF2800FF2800FF28
00FF2800FF3800FF3800FF3800FF3800FF3800FF4700FF5700FF6600FF6600FF7500FFA3
8000FF0047FF0094FF00FFE100FFA300FF9400FF9400FFF00085FF00FF9400FF5700FF38
00FF2800FF2800FF1900FF1900FF1900FF0A00FF0A00FF0A00FF0A00FF0A00FF0A05FF00
05FF0005FF0005FF0005FF0014FF0014FF0014FF0014FF0014FF0014FF0023FF0023FF00
33FF0033FF0033FF0033FF0033FF0033FF0042FF0042FF0042FF0042FF0042FF0042FF00
42FF0042FF0042FF0042FF0042FF0042FF0051FF0051FF0051FF0051FF0051FF0051FF00
51FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF00
51FF0051FF0051FF0051FF0051FF0061FF0061FF0061FF0061FF0051FF0061FF0061FF00
61FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF00
61FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF00
33FF0023FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0042FF0042FF0042FF0033FF0033FF0042FF0042FF0042FF0042FF0042FF00
33FF0033FF0042FF0042FF0042FF0042FF0042FF0033FF0033FF0033FF0042FF0042FF00
42FF0042FF0042FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0023FF0033FF0033FF0033FF0033FF0033FF00
33FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0005FF0005FF0005FF0005FF0000FF0A00FF0A00FF1900FF2800FF47
00FFD100FFB300FF8500FF4700FF3800FF3800FF3800FF4700FF4700FF5700FF6600FF94
4200FF00E1FF00FF9400FFB30019FF00FFE100FF6600FF5700FF5700FF4700FF4700FF47
00FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF47
00FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF5700FF5700FF5700FF57
00FF5700FF5700FF6600FF6600FF6600FF6600FF7500FF7500FF8500FF8500FF8500FF85
00FF8500FF9400FF9400FF9400FF9400FF9400FFA300FFA300FFB300FFB300FFC200FFC2
00FFD100FFD100FFE100FFFF00D1FF00C2FF0066FF0057FF00A3FF6100FF00FFFF00FFE1
00FFD100FFD100FFC200FFB300FFB300FFA300FFA300FF9400FF9400FF9400FF8500FF85
00FF8500FF7500FF7500FF7500FF7500FF7500FF6600FF6600FF6600FF5700FF5700FF57
00FF5700FF5700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF3800FF38
00FF3800FF3800FF3800FF3800FF2800FF2800FF2800FF3800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF0A00FF0A00FF1900FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0014FF0014FF0014FF0005FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
14FF0023FF0023FF0023FF0023FF0023FF0023FF0014FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0014FF0023FF0023FF0023FF00
23FF0023FF0014FF0014FF0023FF0023FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0005FF0005FF0005FF0005FF0000FF0A
00FF0A00FF1900FF3800FF662300FF00FF5700FF4700FF5700FF4700FF5700FF4700FF38
00FF3800FF3800FF3800FF3800FF3800FF4700FF4700FF5700FF7500FF7500FF8500FF94
00FFC200A3FFFF000000F0FF00FFB300FF8500FF7500FF8500FFB30047FF00FF6600FF38
00FF2800FF1900FF1900FF1900FF0A00FF0A00FF0A00FF0A00FF0A05FF0005FF0005FF00
05FF0005FF0005FF0005FF0014FF0014FF0014FF0014FF0023FF0023FF0023FF0023FF00
23FF0033FF0033FF0033FF0033FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
42FF0042FF0042FF0042FF0042FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF00
51FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF00
51FF0051FF0051FF0051FF0051FF0051FF0061FF0061FF0051FF0051FF0061FF0061FF00
61FF0051FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF00
61FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF00
23FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0042FF0042FF0042FF0033FF00
33FF0033FF0042FF0042FF0042FF0042FF0042FF0033FF0033FF0033FF0033FF0042FF00
42FF0042FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0023FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0005FF0005FF0005FF0005FF0005FF0000FF0A00FF0A00FF3800F0FF
00FF9400FF4700FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF4700FF6600C2FF
00FFE100FF7500FF7500FFB300FFE100FFB300FF6600FF5700FF4700FF4700FF4700FF47
00FF4700FF4700FF3800FF3800FF4700FF3800FF3800FF4700FF3800FF4700FF4700FF47
00FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF5700FF5700FF5700FF57
00FF5700FF5700FF5700FF6600FF6600FF6600FF6600FF7500FF7500FF7500FF8500FF85
00FF8500FF8500FF8500FF9400FF9400FF9400FF9400FFA300FFA300FFB300FFB300FFC2
00FFD100FFD100FFE100F0FF0094FF0066FF7000FF9E00FF9E00FF0085FF0057FF00FFF0
00FFE100FFD100FFC200FFC200FFB300FFB300FFA300FF9400FF9400FF9400FF8500FF85
00FF8500FF7500FF7500FF7500FF7500FF6600FF6600FF6600FF6600FF5700FF5700FF57
00FF5700FF5700FF4700FF4700FF4700FF4700FF4700FF4700FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0023FF0023FF0023FF0023FF0023FF0014FF00
14FF0023FF0023FF0023FF0023FF0023FF0023FF0014FF0023FF0023FF0023FF0023FF00
23FF0023FF0014FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0005FF0005FF0005FF0005FF0005FF0000FF0A
00FF0A00FF1900FFF000FF8500FF941400FF00FF7500FFA300FF8500FFD100FF5700FF47
00FF3800FF3800FF4700FF3800FF4700FF4700FF5700FF660094FF00FFC200FFA300FFB3
00FFFF00A3FF00FFD13300FF00FF8500FF7500FF6600FF6600FF8500FF660047FF00FF38
00FF2800FF1900FF1900FF1900FF0A00FF0A00FF0A00FF0A05FF0005FF0005FF0005FF00
05FF0005FF0014FF0014FF0014FF0014FF0014FF0023FF0023FF0023FF0023FF0023FF00
33FF0033FF0033FF0033FF0033FF0033FF0042FF0033FF0042FF0042FF0042FF0042FF00
42FF0042FF0042FF0042FF0042FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF00
51FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF00
51FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0061FF0061FF00
61FF0051FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF00
61FF0051FF0061FF0061FF0061FF0061FF0061FF0061FF00
23FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0042FF0042FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0005FF0005FF0005FF0005FF0005FF0000FF0A00FF0A00FF1900FF28
00FF4700FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF3800FF4700FF6600D1FF
00A3FF00FF5700FF5700FF5700FF7500FFD100FF6600FF4700FF4700FF4700FF3800FF47
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF5700FF57
00FF5700FF5700FF5700FF5700FF6600FF6600FF6600FF6600FF7500FF7500FF7500FF85
00FF8500FF8500FF8500FF8500FF9400FF9400FF9400FFA300FFA300FFB300FFB300FFC2
00FFD100FFD100FFE100FFFF0066FF0085FF1400FF8000FF0085FF00B3FF00D1FF00FFFF
00FFE100FFE100FFD100FFD100FFD100FFC200FFA300FF9400FF9400FF9400FF8500FF85
00FF7500FF7500FF7500FF7500FF6600FF6600FF6600FF6600FF6600FF5700FF5700FF57
00FF5700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF1900FF2800FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0023FF0023FF0023FF0023FF0023FF0014FF00
14FF0023FF0023FF0023FF0023FF0023FF0023FF0014FF0023FF0023FF0023FF0023FF00
23FF0023FF0014FF0023FF0023FF0023FF0023FF0023FF0023FF0014FF0023FF0023FF00
23FF0023FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0005FF0005FF0005FF0005FF0005FF0000FF0A
00FF0A00FF1900FF2800FF3800FF5700FFA300D1FF00FFFF00FFC200FF8500FF5700FF47
00FF4700FF4700FF4700FF4700FF4700FF5700FF5700FF7500FFA30085FF00FFC200FFD1
0094FF00A3FF00FFB300FF9400FF7500FF6600FF5700FF5700FF4700FF4700FF4700FF28
00FF2800FF1900FF1900FF0A00FF0A00FF0A00FF0A05FF0005FF0005FF0005FF0005FF00
05FF0014FF0014FF0014FF0014FF0014FF0023FF0023FF0023FF0023FF0023FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0042FF0042FF0042FF0042FF0042FF0042FF00
42FF0042FF0042FF0042FF0042FF0042FF0051FF0051FF0042FF0051FF0051FF0051FF00
51FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF00
51FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF00
51FF0051FF0051FF0061FF0061FF0051FF0051FF0061FF0061FF0051FF0061FF0061FF00
61FF0051FF0061FF0061FF0061FF0061FF0061FF0061FF00
23FF0023FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0005FF0005FF0005FF0005FF0000FF0A00FF0A00FF0A00FF19
00FF1900FF1900FF1900FF1900FF1900FF2800FF2800FF2800FF2800FF4700FFD100FFF0
00FF5700FF4700FF4700FF4700FF5700FF5700FF4700FF4700FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF5700FF4700FF57
00FF5700FF5700FF5700FF5700FF5700FF6600FF6600FF6600FF7500FF7500FF7500FF75
00FF7500FF8500FF8500FF8500FF8500FF9400FF9400FFA300FFA300FFB300FFC200FFC2
00FFD100FFE100FFF000FFFF00E1FF00C2FF0066FF9E00FFFF00A800D1FF00E1FF00FFFF
00FFF000FFF000FFF000A3FF0038FF0066FF00FFB300FFA300FF9400FF9400FF8500FF85
00FF8500FF7500FF7500FF7500FF7500FF6600FF6600FF6600FF6600FF5700FF5700FF57
00FF5700FF5700FF4700FF4700FF4700FF4700FF4700FF4700FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0023FF0023FF0014FF0014FF0014FF00
14FF0023FF0023FF0023FF0023FF0023FF0023FF0014FF0023FF0023FF0023FF0023FF00
23FF0023FF0014FF0023FF0023FF0023FF0023FF0023FF0014FF0014FF0014FF0014FF00
23FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0005FF0005FF0005FF0005FF0005FF0005FF0000FF0A00FF0A
00FF0A00FF1900FF1900FF2800FF5700FF9400B3FF8000FF00FFC200FF8500FF6600FF57
00FF5700FF4700FF4700FF4700FF5700FF5700FF6600FFA300FFD100E1FF00E1FF00A3FF
0075FF00FFE100FFB300FF8500FF7500FF5700FF5700FF4700FF4700FF3800FF3800FF28
00FF1900FF1900FF1900FF0A00FF0A00FF0A05FF0005FF0005FF0005FF0005FF0005FF00
14FF0014FF0014FF0014FF0014FF0023FF0023FF0023FF0023FF0023FF0023FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0042FF0042FF0042FF0042FF0042FF0042FF00
42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0051FF0051FF0051FF00
51FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF00
51FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF00
51FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0061FF00
61FF0051FF0061FF0061FF0051FF0051FF0061FF0061FF00
23FF0023FF0023FF0023FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0005FF0005FF0005FF0005FF0005FF0000FF0A00FF0A00FF0A00FF0A
00FF0A00FF1900FF1900FF1900FF1900FF1900FF2800FF2800FF2800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF57
00FF5700FF5700FF5700FF5700FF5700FF6600FF6600FF6600FF6600FF7500FF7500FF75
00FF7500FF7500FF8500FF8500FF8500FF9400FFA300FFA300FFB300FFC200FFD100FFE1
00FFE100FFE100FFF000FFFF00F0FF00D1FF0085FFFF00E60085FF00C2FF00D1FF00F0FF
00FFFF00F0FF0066FF1400FF0075FF00FFD100FFB300FFA300FF9400FF9400FF8500FF85
00FF8500FF8500FF7500FF7500FF7500FF6600FF6600FF6600FF6600FF6600FF5700FF57
00FF5700FF5700FF4700FF4700FF4700FF4700FF4700FF4700FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A05FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0014FF0014FF0014FF0014FF0014FF0014FF0005FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0023FF0023FF0023FF0023FF0023FF0014FF0014FF0023FF0023FF0023FF0023FF00
23FF0023FF0014FF0014FF0023FF0023FF0023FF0023FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0005FF0014FF0014FF0014FF0005FF0005FF0005FF0005FF0005FF0005FF0000FF0A
00FF0A00FF1900FF1900FF2800FF5700FF8500FFB300FFD18F00FF00FFB300FFC200FF75
00FF6600FF5700FF5700FF5700FF5700FF6600FF7500FFA300FFD100FFE100D1FF2300FF
0085FF00E1FF00FFC200A3FF00FFA300FF5700FF5700FF4700FF3800FF3800FF2800FF28
00FF1900FF1900FF1900FF0A00FF0A00FF0A05FF0000FF0A05FF0005FF0005FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0023FF0023FF0023FF0023FF0023FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0042FF0033FF0042FF0042FF0042FF00
42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0051FF0051FF0051FF00
51FF0042FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF00
51FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF00
51FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF00
51FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF00
23FF0023FF0023FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
14FF0023FF0023FF0023FF0023FF0023FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0005FF0005FF0005FF0005FF0005FF0000FF0A00FF0A00FF0A
00FF1900FF0A00FF0A00FF1900FF1900FF1900FF1900FF1900FF1900FF2800FF2800FF28
00FF2800FF2800FF3800FF2800FF3800FF3800FF3800FF3800FF2800FF3800FF3800FF28
00FF3800FF2800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF47
00FF5700FF5700FF5700FF5700FF5700FF5700FF6600FF6600FF6600FF6600FF7500FF75
00FF7500FF7500FF8500FF8500FF8500FF9400FF9400FFD100FFD100FFE10094FF00FFFF
00FFFF00FFFF00FFFF00F0FF00D1FF0085FF0094FF7000FF8F00FF0085FF0085FF00B3FF
00E1FF00D1FFAE00FF00D1FF00FFF000FFC200FFB300FFA300FF9400FF9400FF8500FF85
00FF8500FF7500FF7500FF7500FF7500FF6600FF6600FF6600FF6600FF5700FF5700FF57
00FF5700FF5700FF5700FF4700FF4700FF4700FF4700FF4700FF4700FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0014FF0014FF0014FF0014FF0014FF0005FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0023FF0023FF0023FF0014FF0014FF0014FF0014FF0023FF0023FF0023FF00
23FF0014FF0014FF0014FF0014FF0023FF0023FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0000FF0A00FF0A
00FF0A00FF1900FF1900FF2800FF3800FF8500FF7500FF8500FFD1FF000000C2FF00E1FF
00FF8500FF6600FF6600FF6600FF6600FF6600FF7500FF8500FFA300FFC20057FF0094FF
AE00FF0038FF3300FF00FFB300FF7500FF6600FF4700FF4700FF3800FF2800FF2800FF19
00FF1900FF1900FF1900FF0A00FF0A00FF0A00FF0A05FF0005FF0005FF0014FF0005FF00
14FF0014FF0014FF0014FF0023FF0023FF0023FF0014FF0023FF0023FF0023FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0042FF0042FF0042FF0042FF00
42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0051FF0051FF0051FF00
42FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF00
51FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF00
51FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF00
51FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF00
23FF0023FF0023FF0023FF0023FF0023FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
23FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0005FF0005FF0005FF0005FF0005FF0005FF0000FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF1900FF1900FF1900FF1900FF1900FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF3800FF2800FF3800FF2800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF4700FF3800FF4700FF4700FF4700FF4700FF4700FF4700FF47
00FF5700FF5700FF5700FF5700FF5700FF5700FF6600FF6600FF6600FF6600FF6600FF75
00FF7500FF7500FF7500FF8500FF8500FF9400FF9400FFB300D1FFFF008A8F00FF0085FF
FF008A00E1FF00F0FF00E1FF0085FF1400FF0047FF1400FF000AFF3300FF0057FF00A3FF
0085FF0094FF00A3FF00FFFF00FFE100FFD100FFC200FFB300FFA300FF9400FF8500FF85
00FF8500FF7500FF7500FF7500FF7500FF6600FF6600FF6600FF6600FF6600FF5700FF57
00FF5700FF5700FF5700FF5700FF4700FF4700FF4700FF4700FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0023FF0023FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0005FF0005FF0005FF0005FF0005FF0005FF0000FF0A00FF0A00FF0A
00FF0A00FF1900FF1900FF2800FF3800FF4700FF5700FF8500A3FF0085FF00E1FF00FFA3
00FF8500FF7500FF6600FF6600FF7500FF7500FF8500FF9400FFA30047FF00F0FF4200FF
00C2FF00FFE10038FF00FFF000FF8500FF5700FF4700FF3800FF3800FF2800FF2800FF19
00FF1900FF1900FF1900FF0A00FF0A00FF0A05FF0005FF0005FF0005FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0023FF0023FF0023FF0023FF0023FF0023FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0042FF0042FF0042FF0042FF0042FF00
42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
42FF0051FF0051FF0051FF0051FF0042FF0051FF0051FF0051FF0051FF0051FF0051FF00
51FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF00
51FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF00
51FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF00
23FF0023FF0023FF0023FF0023FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0023FF0023FF0033FF0033FF0033FF0033FF0033FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0000FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF3800FF2800FF2800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF4700FF4700FF4700FF4700FF4700FF4700FF47
00FF4700FF5700FF5700FF5700FF5700FF5700FF6600FF6600FF6600FF6600FF6600FF75
00FF7500FF7500FF7500FF8500FF8500FF8500FF9400FFA300FFC200FFF00075FF00E1FF
0094FFFF003D00C2FF00C2FF00A3FF7000FFFF00007000FF9E00FFEB00FF8F00FF8F00FF
1400FF0085FF0094FF00D1FF00E1FF00FFFF0075FF00FFC200FFB300FF9400FF9400FF85
00FF8500FF7500FF7500FF7500FF7500FF7500FF6600FF6600FF6600FF6600FF6600FF57
00FF5700FF5700FF5700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF3800FF38
00FF3800FF3800FF3800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
05FF0014FF0014FF0005FF0005FF0005FF0005FF0005FF0000FF0A00FF0A00FF0A00FF0A
00FF1900FF1900FF1900FF2800FF3800FF3800FF4700FF6600FFC200FFB300E1FF00FFE1
00FFA300FF8500FF7500FF7500FF7500FF8500FFB300FFA300FFB30085FF2300FF00C2FF
00FFE100FFC200FFB300FFE100FFB300FF6600FF5700FF4700FF3800FF3800FF2800FF28
00FF1900FF1900FF1900FF0A00FF0A05FF0005FF0005FF0005FF0014FF0014FF0014FF00
14FF0014FF0014FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0042FF0042FF0042FF0042FF0042FF00
42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
42FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0042FF0051FF0051FF00
51FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF00
51FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF00
51FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF00
23FF0023FF0023FF0023FF0023FF0023FF0033FF0023FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF4700FF4700FF4700FF4700FF4700FF47
00FF4700FF5700FF5700FF5700FF5700FF5700FF6600FF6600FF6600FF6600FF6600FF75
00FF7500FF8500FF7500FF8500FF8500FF8500FF9400FFA300FFA300FFC200FFD100FFE1
00FFFF00C2FFFF00D71400FFFF003D2300FFFF0000BD00FFAE00FFFF00D71400FF0094FF
00C2FF00D1FF0075FF0038FF0019FF6100FF0066FF8000FF00FFE100FFA300FF9400FF85
00FF8500FF8500FF7500FF7500FF7500FF7500FF7500FF6600FF7500FF6600FF6600FF66
00FF5700FF5700FF5700FF5700FF4700FF4700FF4700FF4700FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A05FF0005FF0005FF0005FF0005FF0005FF0000FF0A05FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0000FF0A00FF0A00FF0A
00FF1900FF1900FF2800FF2800FF3800FF4700FF4700FF5700FF6600FF940057FF0085FF
00FFC200FF9400FF8500FF8500FF9400FFA30094FF00FFC200FFD100FFFFBD00FF00C2FF
00FFD100FFA300FF9400FF8500FF7500FF5700FF4700FF4700FF3800FF3800FF2800FF28
00FF1900FF1900FF1900FF0A00FF0A05FF0005FF0005FF0005FF0005FF0014FF0014FF00
14FF0014FF0014FF0014FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0042FF0042FF00
42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
42FF0042FF0051FF0051FF0042FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF00
51FF0051FF0051FF0051FF0051FF0051FF0051FF0042FF0051FF0051FF0051FF0051FF00
51FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF00
51FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF2800FF1900FF2800FF1900FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF4700FF4700FF4700FF4700FF47
00FF4700FF5700FF5700FF5700FF5700FF5700FF6600FF6600FF6600FF6600FF6600FF75
00FF7500FF7500FF7500FF8500FF8500FF9400FF9400FF9400FFA300FFB300FFC200FFE1
00F0FF5100FF0094FF00B3FF00A3FF0066FF0500FF0019FF6100FF0028FF0047FF0085FF
00E1FF00F0FF00F0FF0075FF00E1FF00D1FF0019FF00FFD100FFC200FFA300FF9400FF94
00FF8500FF8500FF8500FF7500FF7500FF7500FF7500FF7500FF6600FF6600FF6600FF66
00FF6600FF5700FF5700FF5700FF5700FF4700FF4700FF4700FF4700FF3800FF3800FF38
00FF3800FF3800FF3800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A05FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0005FF0014FF0014FF00
14FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0000FF0A00FF0A00FF0A00FF19
00FF1900FF1900FF2800FF2800FF3800FF4700FF5700FF5700FF6600FF8500FFA300D1FF
00FFF000FFA300FF9400FFA300FFC200B3FFFA00FF00FFF0FF001E00A3FF00C2FF00FFE1
00FFC200FFA300FF8500FF7500FF6600FF5700FF5700FF4700FF4700FF3800FF3800FF38
00FF2800FF2800FF1900FF0A00FF0A05FF0005FF0005FF0005FF0014FF0014FF0014FF00
14FF0014FF0014FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0042FF0042FF0042FF00
42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
42FF0042FF0042FF0042FF0042FF0042FF0051FF0051FF0042FF0051FF0051FF0051FF00
51FF0051FF0051FF0051FF0051FF0051FF0051FF0042FF0051FF0051FF0051FF0051FF00
51FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF00
51FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0033FF0033FF0023FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0023FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0000FF0A
05FF0005FF0000FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF0A00FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF2800FF1900FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF3800FF2800FF2800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF4700FF4700FF4700FF4700FF4700FF47
00FF4700FF5700FF5700FF5700FF5700FF5700FF6600FF6600FF6600FF6600FF6600FF75
00FF7500FF7500FF7500FF8500FF8500FF8500FF9400FF9400FFA300FFB300FFD10500FF
00C2FF000AFF00E1FF00E1FF00B3FF0094FF0075FF5100FFFF00000066FF00A3FF9E00FF
00F0FF00FFFF00FFF000FFF000FFE100FFF000FFD100FFC200FFB300FFA300FF9400FF94
00FF8500FF8500FF8500FF8500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF66
00FF6600FF6600FF6600FF5700FF5700FF4700FF4700FF4700FF4700FF3800FF3800FF38
00FF3800FF3800FF3800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0014FF0014FF0014FF00
14FF0005FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
05FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0005FF0014FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0000FF0A00FF0A00FF0A00FF1900FF19
00FF1900FF2800FF2800FF3800FF4700FF5700FF5700FF6600FF7500FF8500FFA300FFE1
00FFF000FFC200FFD100FFC200FFD100FFFF7000FF00A3FF00C2FFFF00000094FF00FFD1
00FFC200FFA300FF8500FF7500FF6600FF6600FF5700FF5700FF4700FF4700FF4700FF38
00FF3800FF2800FF1900FF0A00FF0A05FF0005FF0005FF0005FF0014FF0014FF0014FF00
14FF0014FF0014FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0042FF0042FF0042FF00
42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0051FF0051FF00
42FF0051FF0051FF0051FF0042FF0051FF0051FF0042FF0051FF0051FF0042FF0051FF00
51FF0051FF0051FF0042FF0051FF0042FF0051FF0042FF0051FF0042FF0051FF0051FF00
51FF0051FF0051FF0051FF0051FF0051FF0051FF0042FF00
14FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0033FF00
33FF0033FF0023FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
14FF0023FF0023FF0023FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0000FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF0A
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF4700FF4700FF4700FF47
00FF4700FF5700FF5700FF5700FF5700FF6600FF6600FF6600FF6600FF6600FF6600FF75
00FF7500FF7500FF7500FF8500FF8500FF8500FF9400FF9400FFA300FFC200FFF00057FF
00A3FF00A3FF00FFFF00FFFF00F0FF00D1FF00C2FF0094FF8F00FF0075FF00C2FF00E1FF
00FFFF00FFF000FFF000FFE100FFD100FFD100FFC200FFB300FFA300FFA300FF9400FF94
00FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF7500FF7500FF7500FF7500FF75
00FF7500FF7500FF7500FF6600FF5700FF5700FF4700FF4700FF4700FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0014FF0005FF00
05FF0005FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0000FF0A00FF0A00FF0A00FF0A00FF1900FF28
00FF2800FF3800FF3800FF4700FFB300FF6600FF6600FF8500FFA300FFB300FFE16100FF
00F0FF0019FF000AFF00FFFF0075FF00B3FFFF00D7FF0000000AFF0085FF00F0FF00FFE1
00FFD100FFF000FFA300FF8500FF7500FF6600FF6600FF5700FF5700FF5700FF8500FFE1
00FF5700FFE100FF2800FF1900FF0A05FF0005FF0005FF0005FF0014FF0014FF0014FF00
14FF0014FF0014FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0042FF0042FF0033FF00
42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
14FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0023FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0000FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF0A00FF0A
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF3800FF28
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF4700FF4700FF4700FF4700FF47
00FF4700FF5700FF5700FF5700FF5700FF5700FF6600FF6600FF6600FF6600FF7500FF75
00FF7500FF7500FF7500FF8500FF8500FF8500FF9400FF9400FFA300FFB300B3FF00FFF0
00FFFF00FFF000FFF000FFF000FFFF00F0FF00D1FF0085FFFF00A80038FF00B3FF00D1FF
00F0FF00FFF000FFE100FFE100FFD100FFC200FFB300FFB300FFA300FFA300FF9400FF94
00FF9400FF9400FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF9400FFA300FF85
00FF8500FF9400D1FF00FF7500FF6600FF5700FF4700FF4700FF4700FF3800FF3800FF38
00FF3800FF3800FF3800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0000FF0A00FF0A00FF1900FF2800FFB3
00FF5700FF4700FF4700FFB300FFC200FF9400FF9400FFFF00FFF000C2FF00A3FF00FFC2
00FFC200E1FF00F0FF00D1FF000AFF0500FF2300FF0500FF0094FF00C2FF00F0FF00FFFF
00FFFF00A3FF00FFB300FFA300FF8500FF7500FF6600FF6600FF7500FF8500FFB300E1FF
00A3FF3300FF00FF6600FF1900FF0A00FF0A05FF0005FF0005FF0014FF0014FF0014FF00
14FF0014FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
42FF0042FF0042FF0042FF0033FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
14FF0014FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0023FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0023FF0023FF0023FF0033FF0033FF0033FF00
33FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0000FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF2800FF1900FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF4700FF4700FF4700FF47
00FF4700FF5700FF5700FF5700FF5700FF6600FF6600FF6600FF6600FF6600FF7500FF75
00FF7500FF7500FF8500FF8500FF8500FF8500FF9400FF9400FFA300FFA300FFB300FFC2
00FFD100FFD100FFE100FFF000FFFF00E1FF00C2FF00A3FF0038FF0047FF0094FF0057FF
00D1FF00FFF000FFE100FFD100FFD100FFC200FFB300FFB300FFA300FFA300FFA300FF94
00FF9400FF9400FF9400FF9400FF9400FF9400FF9400FFA300FFC200FFB3FF008A00FFA3
00FFA300FFB300FFD100FF8500FF7500FF6600FF5700FF4700FF4700FF3800FF3800FF38
00FF3800FF3800FF3800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0014FF0014FF0014FF0014FF0014FF0014FF0005FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0005FF0005FF0014FF0005FF0005FF00
05FF0005FF0000FF0A05FF0005FF0005FF0000FF0A00FF0A00FF0A00FF1900FF2800FF47
00FFFF00FF7500FF8500FF9400D1FF00FFFF00D1FFFF004C0028FF00FFC200FFF000FF94
00FF9400FFA300FFC200FFE100F0FF0057FFCC00FF0038FF0075FF0047FF00B3FF00B3FF
00D1FF0085FF0057FF00FFB300FF8500FF8500FF7500FF9400FFF000FFE10047FF00E1FF
00FF6600FF4700FF3800FF1900FF0A00FF0A05FF0005FF0005FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0042FF00
42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
42FF0042FF0042FF0042FF0042FF0042FF0042FF0033FF0042FF0042FF0042FF0042FF00
42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
14FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0033FF0033FF0033FF0023FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0023FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0000FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF28
00FF1900FF1900FF1900FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF4700FF4700FF4700FF4700FF47
00FF5700FF5700FF5700FF5700FF6600FF6600FF6600FF6600FF6600FF7500FF7500FF75
00FF7500FF7500FF8500FF8500FF8500FF8500FF9400FF9400FFA300FFA300FFB300FFB3
00FFC200FFD100FFD100FFE100F0FF0028FFBD00FF0066FFFF0000FF001E7000FF0075FF
00D1FF00FFFF00FFE100FFD100FFD100FFC200FFB300FFB300FFB300FFA300FFA300FFA3
00FF9400FF9400FF9400FF9400FF9400FF9400FFA300FFB300A3FF00F0FF00FFFF00FFD1
00B3FF0038FF00D1FF00C2FF00FFD100FF7500FF5700FF4700FF4700FF4700FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A05FF0000FF0A00FF0A05FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0014FF0014FF0014FF0014FF0014FF0005FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0005FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0000FF0A05FF0000FF0A00FF0A00FF0A00FF1900FF1900FF38
00FF6600FFC20075FF00B3FFFF00E600FFF000FFE100FFB300FFE100FFA300FF8500FF85
00FF8500FF9400FFA300FFD100FFFF00B3FF0057FF0028FF0500FFFF004C0057FF0075FF
2300FF00F0FF00FFE100FFB300FF9400FF9400FF9400FFC20057FF00FFF000FF9400FFD1
00FF5700FF3800FF2800FF1900FF0A00FF0A05FF0005FF0005FF0014FF0014FF0014FF00
14FF0014FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
42FF0042FF0033FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
42FF0042FF0042FF0042FF0042FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
14FF0014FF0014FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0033FF0023FF0023FF0033FF0033FF0033FF0033FF0023FF0033FF00
33FF0033FF0033FF0023FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0023FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0014FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0000FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF1900FF0A00FF0A00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF3800FF3800FF3800FF3800FF3800FF3800FF4700FF4700FF4700FF47
00FF5700FF5700FF5700FF5700FF6600FF6600FF6600FF6600FF7500FF7500FF7500FF75
00FF7500FF8500FF8500FF8500FF8500FF9400FF9400FFA300FFA300FFA300FFB300FFB3
00FFC200FFC200FFD100FFE100FFF000F0FF0066FF0075FF000AFF6100FF0085FF00A3FF
1400FF00E1FF00FFE100FFD100FFD100FFC200FFC200FFB300FFB300FFA300FFA300FFA3
00FFA300FFA300FF9400FFA300FFA300FFA300FFB300FFC200FFD100E1FF0057FF0075FF
00FFFF00FFC200FFA300FFC200FF8500FF7500FF5700FF4700FF4700FF4700FF3800FF38
00FF3800FF3800FF3800FF3800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A05FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0014FF0014FF0014FF0014FF0005FF0005FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0005FF0014FF0014FF0014FF0014FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0000FF0A00FF0A00FF0A00FF1900FF1900FF38
00FFE100FF6600FF6600FF85FF00C700FFB300FF8500FF8500FF8500FF7500FF7500FF75
00FF7500FF8500FFB30085FF0057FF0085FF00D1FF2300FF0038FF0500FF0066FF2300FF
CC00FF00B3FF3300FF00FFD100FFE100FFB300FFC20028FF00FFC200D1FF00FF6600FF57
00FF3800FF2800FF1900FF1900FF0A00FF0A05FF0005FF0005FF0005FF0014FF0014FF00
14FF0014FF0014FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
42FF0042FF0042FF0033FF0033FF0033FF0033FF0023FF0023FF0014FF0023FF0033FF00
33FF0033FF0042FF0042FF0042FF0042FF0042FF0042FF00
14FF0014FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0033FF0033FF0033FF0033FF0023FF0033FF00
33FF0033FF0033FF0023FF0033FF0033FF0033FF0033FF0023FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0023FF0023FF00
33FF0033FF0033FF0033FF0033FF0033FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0000FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF3800FF3800FF3800FF3800FF4700FF4700FF4700FF4700FF4700FF47
00FF5700FF5700FF5700FF6600FF6600FF6600FF7500FF7500FF7500FF8500FF7500FF85
00FF8500FF8500FF8500FF8500FF9400FF9400FF9400FF9400FFA300FFA300FFB300FFB3
00FFC200FFC200FFD100FFE100FFF000F0FF00C2FF00B3FF0075FF1400FF9E00FF00D1FF
00E1FF00FFFF00FFF000FFE100FFD100FFD100FFC200FFC200FFB300FFB300FFA300FFA3
00FFA300FFA300FFA300FFA300FFB300FFC200FFD100FFD10057FF00C2FFFF00A800C2FF
00FFD100FFA300FF8500FF7500FF6600FF6600FF5700FF4700FF4700FF4700FF3800FF38
00FF3800FF3800FF3800FF3800FF2800FF2800FF2800FF2800FF3800FF2800FF2800FF28
00FF2800FF1900FF1900FF1900FF1900FF1900FF1900FF2800FF1900FF1900FF1900FF19
00FF1900FF1900FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A05FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0005FF0014FF0014FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0000FF0A00FF0A00FF0A00FF0A00FF1900FF1900FF28
00FF3800FF3800FF4700FF9400FF7500A3FF00FF6600FF6600FF6600FF6600FF6600FF66
00FF7500FF8500FFB300FFC200FFE100C2FF00FFFF00FFFF00D1FF00B3FF0085FF3300FF
0038FF0075FF8F00FF9E00FF0047FF0094FFEB00FF00FFC200FF9400FF7500FF5700FF47
00FF3800FF2800FF1900FF1900FF0A00FF0A05FF0005FF0005FF0014FF0014FF0014FF00
14FF0014FF0014FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0042FF0042FF0042FF0033FF0042FF0042FF0042FF0042FF0042FF00
42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
42FF0042FF0042FF0042FF0033FF0042FF0042FF0042FF0042FF0033FF0042FF0033FF00
33FF0033FF0033FF0033FF0033FF0023FF0014FF0014FF0005FF0000FF5714FF0023FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
14FF0014FF0014FF0014FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0033FF00
33FF0033FF0033FF0023FF0033FF0033FF0033FF0033FF0023FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0023FF0033FF0033FF0033FF00
33FF0033FF0033FF0023FF0033FF0033FF0033FF0033FF0033FF0033FF0023FF0023FF00
23FF0033FF0033FF0033FF0033FF0033FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0014FF0014FF0023FF00
23FF0023FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0000FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF4700FF4700FF4700FF4700FF57
00FF5700FF5700FF6600FF6600FF6600FF7500FF8500FF8500FF8500FF8500FF8500FF85
00FF8500FF8500FF8500FF8500FF9400FF9400FF9400FFA300FFA300FFA300FFB300FFB3
00FFC200FFD100FFD100FFE100FFF000FFFF00F0FF00D1FF0066FFFF000F0094FF00D1FF
00F0FF00FFFF00FFF000FFF000FFF000FFF000FFD100FFC200FFC200FFB300FFB300FFB3
00FFA300FFA300FFB300FFB300FFC200FFE100E1FF00FFFF00A3FF0094FF00C2FF0066FF
00B3FF00FF9400FF7500FF7500FF6600FF5700FF5700FF4700FF4700FF4700FF4700FF38
00FF3800FF3800FF3800FF3800FF3800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A05FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0014FF0014FF0014FF0014FF0014FF0014FF00
05FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0000FF0A00FF0A00FF0A00FF0A00FF1900FF1900FF19
00FF2800FF2800FF3800FF4700FF4700FF5700FF5700FF5700FF5700FF5700FF5700FF66
00FF6600FF7500FF8500FFA300E1FF00FFE100FFE100FFF000E1FF0094FFFF00B85100FF
0028FF00F0FF00FFF000FFF000C2FF00FFD1FA00FF00FFB300FF8500FF6600FF5700FF47
00FF3800FF2800FF1900FF1900FF0A00FF0A05FF0005FF0005FF0014FF0014FF0014FF00
14FF0014FF0014FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
33FF0033FF0033FF0033FF0023FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0042FF0033FF0033FF0042FF0042FF0042FF0033FF0042FF00
42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
42FF0042FF0042FF0042FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0023FF0023FF0014FF0000FFA300FF1900FF6600FF4714FF0023FF00
23FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
14FF0014FF0014FF0014FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
33FF0033FF0023FF0023FF0033FF0033FF0033FF0033FF0023FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0023FF0033FF0033FF0033FF00
33FF0033FF0033FF0023FF0033FF0033FF0033FF0033FF0033FF0033FF0023FF0023FF00
23FF0023FF0033FF0033FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0000FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF3800FF3800FF3800FF3800FF3800FF4700FF4700FF4700FF5700FF57
00FF5700FF6600FF6600FF6600FF7500FF8500B3FF00FF9400FF9400FF8500FF8500FF85
00FF8500FF9400FF9400FF9400FF9400FF9400FF9400FFA300FFA300FFA300FFB300FFB3
00FFD100FFD100FFE100FFF000FFFF00FFFF00E1FF00B3FF0094FF6100FF0075FF8F00FF
00D1FF00F0FF00F0FF00FFFF0094FF00D1FF00FFE100FFD100FFD100FFC200FFC200FFB3
00FFB300FFB300FFB300FFC200FFE10057FF0094FF0085FF00C2FF00B3FF00FFD10028FF
00FFC200FF9400FF7500FF6600FF6600FF5700FF5700FF4700FF4700FF4700FF4700FF38
00FF3800FF3800FF3800FF3800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A05FF0005FF0005FF0005FF0000FF0A05FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0014FF0014FF0014FF0014FF0005FF00
14FF0014FF0014FF0014FF0014FF0014FF0005FF0014FF0014FF0014FF0014FF0014FF00
05FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0005FF0014FF0014FF0014FF0014FF0014FF0005FF00
14FF0014FF0014FF0014FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0000FF0A05FF0005FF0000FF0A00FF0A00FF0A00FF0A00FF1900FF1900FF19
00FF2800FF2800FF2800FF3800FF3800FF4700FF4700FF4700FF5700FF5700FF5700FF66
00FF6600FF7500FF7500FF8500FFA300FFB300FFC200E1FF0094FF8000FF00B3FF0085FF
CC00FF00FFFF00FFC200FFA300FFA300FFA300FFF000D1FF0028FF00FF8500FF6600FF57
00FF4700FF3800FF2800FF1900FF1900FF0A00FF0A05FF0005FF0005FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0033FF0023FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0042FF0042FF0042FF0033FF0042FF00
42FF0042FF0042FF0042FF0042FF0033FF0042FF0042FF0033FF0042FF0042FF0042FF00
42FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0023FF0023FF0023FF0014FF0000FF1900FF8500FF4700FF0A14FF0014FF00
23FF0023FF0033FF0033FF0033FF0033FF0033FF0033FF00
14FF0014FF0014FF0014FF0014FF0014FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0033FF0033FF0033FF0023FF0023FF0033FF0033FF0033FF00
33FF0023FF0023FF0033FF0033FF0033FF0033FF0023FF0023FF0033FF0033FF0033FF00
33FF0033FF0023FF0023FF0023FF0033FF0033FF0033FF0033FF0033FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0000FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF3800FF3800FF3800FF3800FF3800FF4700FF4700FF5700FF5700FF57
00FF6600FF6600FF7500FF7500FF8500FF940028FF00FFB300FF9400FF9400FF9400FF94
00FF9400FF9400FF9400FFA300FF9400FFA300FFA300FFA300FFA300FFB300FFB300FFC2
00FFE100FFFF00FFFF00FFFF00FFFF00F0FF00E1FF0094FF0047FF9E00FF4200FF2300FF
DC00FF00D1FF00E1FF00E1FF0094FF00C2FF00FFFF00F0FF0019FF00FFF000FFC200FFC2
00FFC200FFC200FFC200FFD100FFE100F0FF0057FFFF000000F0FF00FFD100FFB300FFB3
00FFFF00FF8500FF7500FF6600FF6600FF5700FF5700FF4700FF4700FF4700FF4700FF38
00FF3800FF3800FF3800FF3800FF3800FF2800FF3800FF2800FF2800FF2800FF2800FF28
00FF2800FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A05FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0014FF0014FF0014FF0005FF0005FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0005FF00
05FF0014FF0014FF0014FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0000FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF19
00FF1900FF2800FF2800FF2800FF3800FF3800FF3800FF4700FF4700FF4700FF5700FF57
00FF6600FF6600FF7500FF8500FF9400FFB300FFC200FFF000B3FF0500FF00D1FF00FFF0
0075FF00FFE100E1FF00FF9400FF8500FF9400FFE100FFFF0057FF00FFD100D1FF00FF66
00FF6600FF5700FF3800FF2800FF1900FF0A00FF0A05FF0005FF0005FF0014FF0014FF00
14FF0014FF0014FF0014FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0042FF00
42FF0033FF0033FF0042FF0042FF0033FF0042FF0042FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
23FF0023FF0023FF0023FF0014FF0005FF0000FF1900FF8500FF4700FF0A05FF0014FF00
23FF0023FF0023FF0023FF0033FF0033FF0033FF0033FF00
14FF0014FF0014FF0014FF0014FF0014FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0033FF0033FF00
23FF0023FF0023FF0033FF0033FF0033FF0033FF0023FF0023FF0023FF0033FF0033FF00
33FF0033FF0023FF0023FF0023FF0023FF0033FF0033FF0033FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0000FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF3800FF3800FF3800FF4700FF4700FF5700FF6600FF6600FF66
00FF7500FF7500FF7500FF8500FFB300FFB37000FF00FFC200FFA300FFA300FFA300FFA3
00FFA300FFA300FFA300FFA300FFA300FFA300FFA300FFA300FFB300FFB300FFB300FFC2
00FFE100A3FF00A3FF00E1FF00F0FF00E1FF00D1FF8000FF0066FF1400FF0019FF0085FF
00A3FF00C2FF00D1FF00C2FF0085FF00B3FF00B3FF0500FF00A3FF00FFE100FFD100FFC2
00FFC200FFC200FFD100FFE100E1FF00B3FF0085FF00D1FF00FFFF00FFC200FFA300FF94
00FF8500FF7500FF7500FF6600FF6600FF5700FF5700FF4700FF4700FF4700FF4700FF47
00FF3800FF3800FF3800FF3800FF3800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A05FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
14FF0014FF0014FF0014FF0014FF0005FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0000FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF19
00FF1900FF1900FF2800FF2800FF2800FF3800FF3800FF3800FF4700FF4700FF5700FF57
00FF6600FF7500FF7500FF8500FF9400FFB30066FF00FFFF3300FF00F0FF00FFE100FFC2
00FFFF00FFB300FF9400FF8500FF7500FF7500FF8500FF9400FFD10019FF5100FF00FFB3
00FFA300D1FF00FF6600FF3800FF2800FF1900FF0A05FF0005FF0005FF0014FF0014FF00
14FF0014FF0014FF0014FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0014FF0014FF0005FF0000FF1900FF2800FF9400FF4700FF1905FF0014FF00
14FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0023FF0014FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0033FF00
33FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0014FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0000FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF0A00FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF3800FF3800FF3800FF3800FF4700FF4700FF5700FFD100FF8500FF94
00FF8500FF8500FF8500FFA300E1FF00F0FF00D1FF00FFD100FFB300FFB300FFB300FFB3
00FFC200B3FF00FFB300FFA300FFB300FFA300FFB300FFB300FFB300FFB300FFC200FFD1
00FFE100F0FF0057FF0085FF00D1FF00D1FF00C2FF00A3FF0066FF0019FF1400FF0066FF
00A3FF00B3FF00B3FF00B3FF0085FF3300FF0047FF00B3FF00F0FF00FFF000FFE100FFD1
00FFD100FFD100FFE100C2FFFF00990038FF00F0FF00FFF000F0FF00FFB300FFA300FF94
00FF8500FF7500FF7500FF6600FF6600FF5700FF5700FF5700FF4700FF4700FF4700FF47
00FF3800FF3800FF3800FF3800FF3800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF0A00FF1900FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A05FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0014FF0014FF0014FF0014FF0005FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0005FF0014FF0014FF0014FF0014FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0000FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF1900FF19
00FF1900FF1900FF2800FF2800FF2800FF3800FF3800FF3800FF4700FF4700FF4700FF57
00FF6600FF7500FF8500FF9400FFA300FFB300F0FF0047FF0075FF00F0FF00FFC200FFB3
00FFA300FF9400FF7500FF7500FF7500FF6600FF7500FF8500A3FF00FFD100FFC200B3FF
00B3FF00FFF000FF8500FF6600E1FF00FF2800FF0A00FF0A05FF0005FF0005FF0014FF00
14FF0014FF0014FF0014FF0014FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0033FF0033FF0023FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0023FF0023FF0023FF0023FF0014FF0005FF0014FF0014FF0023FF0023FF00
23FF0014FF0014FF0014FF0005FF0000FF4700FF7500FFE100FF6600FF9400FF1905FF00
14FF0014FF0023FF0023FF0023FF0023FF0023FF0023FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0014FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0000FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF2800FF1900FF1900FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF3800FF3800FF3800FF3800FF4700FF57FF00000500FF00FFFF
00FFA300FF9400FFB300FFB300FFE100D1FF00F0FF00FFE100FFD100FFD100FFD100C2FF
00E1FF00A3FF00FFC200FFB300FFB300FFB300FFB300FFB300FFB300FFC200FFC200FFE1
00FFFF00F0FF00B3FF0028FF00C2FF00C2FF00A3FF0094FF0075FF0028FF2300FF0057FF
0085FF9E00FF0028FF0075FF1400FF0094FF00C2FF00E1FF00F0FF00FFF000FFF000FFF0
00FFE100FFE100FFF000F0FF1400FF0094FF00FFF000FFD100FFC200FFA300FF9400FF85
00FF8500FF7500FF7500FF6600FF6600FF5700FF5700FF5700FF4700FF4700FF4700FF47
00FF3800FF3800FF3800FF3800FF3800FF3800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A05FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0014FF0005FF0005FF0005FF0014FF0014FF0014FF0014FF0014FF0005FF00
14FF0014FF0014FF0014FF0014FF0014FF0005FF0014FF0014FF0014FF0014FF0014FF00
05FF0014FF0014FF0014FF0014FF0014FF0005FF0005FF0014FF0014FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0000FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF19
00FF1900FF1900FF2800FF2800FF2800FF2800FF3800FF3800FF3800FF4700FF4700FF57
00FF9400FFA300FFD100FFA300FFB300FFC200FFF000B3FF5100FF00B3FF00FFC200FFA3
00FF8500FF7500FF7500FF6600FF6600FF6600FF6600FF7500FF7500FF7500FF8500FFA3
0085FF00FFB300FFC200FFA300FF8500FF3800FF1900FF0A05FF0005FF0005FF0014FF00
14FF0014FF0014FF0014FF0014FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0023FF0023FF0014FF0005FF0000FF4700FF0A14FF0014FF0014FF0014FF00
14FF0014FF0014FF0005FF0000FF19FA00FF00FF8500D1FF00A3FF00FFA300FF9400FF28
05FF0014FF0014FF0023FF0023FF0023FF0023FF0023FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0014FF0023FF0023FF0023FF0023FF0023FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0000FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF3800FF3800FF3800FF3800FF4700FF5700FF6600FF8500FFB3
000AFF00FFFF0047FF00F0FF00B3FF0500FF0066FF00D1FFAE00FF00FFFF00FFFF00C2FF
00C2FF00FFF000FFD100FFC200FFC200FFC200FFC200FFC200FFC200FFC200FFD100D1FF
FF00000057FF0047FF0057FF0094FF0057FF0047FF0066FF0066FF0028FFFF002E5100FF
0047FF0047FFFF00E6CC00FF0500FF0075FF00B3FF00D1FF00E1FF00F0FF00F0FF00E1FF
00D1FF00FFFF00FFFF00B3FF0066FF00FFFF00FFE100FFC200FFB300FFA300FF9400FF94
00FF8500FF7500FF7500FF7500FF6600FF6600FF6600FF5700FF5700FF4700FF4700FF47
00FF4700FF3800FF3800FF3800FF3800FF3800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A05FF0005FF00
00FF0A00FF0A05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0014FF0014FF0014FF0014FF0005FF00
05FF0014FF0014FF0014FF0014FF0005FF0005FF0014FF0014FF0014FF0014FF0014FF00
05FF0014FF0014FF0014FF0014FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0000FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF1900FF1900FF19
00FF1900FF1900FF2800FF2800FF2800FF2800FF3800FF3800FF3800FF4700FF4700FF66
00FFB300FFE1DC00FFAE00FF00FFD100FFE100F0FF7000FF00D1FF00FFE100FFB300FF94
00FF8500FF7500FF6600FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF6600FFB3
00FFA300FF8500FF5700FF4700FF9400E1FF00FF2800FF0A05FF0005FF0005FF0014FF00
14FF0014FF0014FF0014FF0014FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0033FF0033FF0033FF0023FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0023FF0023FF0014FF0005FF0000FF0A00FF8500FF5705FF0005FF0014FF0014FF00
14FF0005FF0005FF0005FF0000FF0A00FF2800FF6600C2FF00FF8500FF5700FFE100FF19
05FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
05FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0023FF00
23FF0014FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0000FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF3800FF3800FF3800FF3800FF4700FF4700FF5700FF6600FF94
3300FF00FFC200D1FF00FFE100FFFFFF00B80085FF0047FF0038FFFA00FF9E00FFFF00F5
4200FF00F0FF00FFF000FFF000FFE100FFD100FFC200FFC200FFC200FFD100FFD100FFF0
00F0FF00C2FF00A3FF0028FF0028FF0047FF2300FF0047FF0038FF5100FFFF00002300FF
0019FF2300FF9E00FFFF00A8FF003D2300FF0075FF00B3FF0085FF00B3FF00C2FF0047FF
00C2FF2300FF00C2FF0057FF00E1FF00FFF000FFD100FFC200FFB300FFA300FFA300FF94
00FF8500FF8500FF8500FF7500FF7500FF6600FF6600FF5700FF5700FF5700FF4700FF47
00FF4700FF4700FF3800FF3800FF3800FF3800FF3800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF1900FF1900FF2800FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0014FF0014FF0014FF0014FF0005FF0005FF0014FF0014FF0014FF0014FF0005FF00
05FF0005FF0014FF0014FF0014FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF19
00FF1900FF1900FF1900FF2800FF2800FF2800FF3800FF3800FF3800FF4700FF4700FF57
00FF6600FF8500FFB300E1FF00F0FF00E1FF0500FF0057FF00E1FF00FFE100FFB300FFA3
00FF9400FF7500FF6600FF5700FF5700FF4700FF5700FF4700FF4700FF4700FF5700FF94
00FF5700FF4700FF3800FF3800FF3800FF3800FF2800FF0A05FF0005FF0005FF0005FF00
14FF0014FF0014FF0014FF0014FF0014FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0033FF0023FF0023FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0023FF0033FF00
23FF0023FF0023FF0014FF0000FFC200FF5700D1FF00FF2800FF0A00FF0A05FF0005FF00
05FF0005FF0005FF0000FF0A00FF1900FF3800FF5700F0FF0500FF00FF3800FF2800FF19
00FF0A05FF0014FF0014FF0014FF0014FF0014FF0014FF00
05FF0014FF0005FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0014FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0000FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF0A00FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF3800FF3800FF3800FF3800FF4700FF4700FF5700FF6600FFB3
00FFD100FF8500FF9400FFA300FFD100A3FF00FFFF00FFF000C2FF00FFFF0075FFFF001E
6100FF0066FF00D1FF0028FF0075FF00FFE100FFD100FFD100FFD100FFE100FFE100FFF0
00FFFF00E1FF00B3FF0075FF000AFFAE00FFAE00FFFA00FF0019FF3300FFFF00005100FF
9E00FF2300FF6100FFFF00E6FF00F50019FF0057FF000AFF5100FF0028FFFF00A8FF003D
4200FF0066FF00A3FF2300FF00B3FF00FFFF00FFE100FFD100FFC200FFB300FFA300FFA3
00FF9400FF8500FF8500FF8500FF7500FF7500FF6600FF6600FF5700FF5700FF5700FF47
00FF4700FF4700FF3800FF3800FF3800FF3800FF3800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF0A00FF0A00FF1900FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0014FF0014FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0000FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF1900FF1900FF19
00FF1900FF1900FF2800FF2800FF2800FF3800FF3800FF3800FF3800FF4700FF5700FF57
00FF6600FF8500FFB300F0FF00F0FF00C2FFFF00D78F00FFAE00FF00F0FF00FFE100FFFF
2300FF00FF8500FF5700FF5700FF4700FF4700FF4700FF4700FF3800FF3800FF4700FF47
00FF3800FF2800FF2800FF2800FF1900FF1900FF0A00FF0A05FF0005FF0005FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0033FF0033FF0033FF0023FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0023FF0023FF00
23FF0023FF0014FF0005FF0000FF0A00FF2800F0FF00FFFF00FF3800FF6600FF2800FF38
00FF0A00FF0A00FF0A00FF0A00FF2800FFA300FF850075FF00FF6600FF3800FF1900FF0A
00FF0A05FF0005FF0005FF0005FF0014FF0014FF0005FF00
05FF0005FF0014FF0014FF0005FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0014FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0000FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF3800FF3800FF3800FF3800FF4700FF4700FF5700FF75
00FF7500FF7500FF7500FFA30085FF00FFE100FFE100FFB300FFB300FFE10038FF00E1FF
00D1FF00D1FF0047FF1400FF00E1FF00FFFF00FFE100FFE100FFE100FFF000FFFF00FFFF
00E1FF00D1FF00B3FF1400FFFF0099FF0000BD00FF3300FF2300FFAE00FFFF0099FF000F
7000FF8000FFCC00FFFF0000FF0000FF00A80500FF1400FF1400FF0085FF00A3FF0085FF
00A3FF00F0FF00F0FF00E1FF0057FF00A3FF00F0FF00F0FF00F0FF00FFC200FFE100FFB3
00FFB300FF9400FF9400FFA300FFA300FF9400FF9400FF7500FF6600FF6600FF6600FF57
00FF5700FF4700FF4700FF3800FF3800FF3800FF3800FF3800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A05FF0005FF0005FF0000FF0A05FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0000FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF1900FF19
00FF1900FF1900FF2800FF2800FF2800FF2800FF3800FF3800FF3800FF4700FF4700FF57
00FF6600A3FF000AFF00D1FF00FFD100FFFF00B3FF0057FF000AFF0066FF00A3FF00FFD1
00FF9400FF7500FF5700FF5700FF4700FF4700FF3800FF3800FF3800FF3800FF3800FF38
00FF2800FF2800FF1900FF1900FF1900FF0A00FF0A05FF0005FF0005FF0005FF0005FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0033FF0023FF0023FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0023FF0023FF0023FF00
23FF0023FF0014FF0014FF0005FF0000FF1900FF577000FF00FF9400FFC200FFFF00FF38
00FF1900FF1900FF1900FF1900FF2800F0FF00FFD10085FF1400FF00FF4700FF1900FF0A
00FF0A00FF0A05FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0014FF0014FF0014FF0014FF0005FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0023FF0023FF0014FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0014FF0023FF0023FF0014FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0000FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF3800FF3800FF3800FF3800FF4700FF4700FF5700FF57
00FF5700FF6600FF6600FF8500FF9400FFA300FFB300FFA300FFA300E1FF00FFD17000FF
00FFD100FFFF0057FF00A3FF0038FF0066FF00FFFF00FFF000FFFF00D1FF00B3FF00E1FF
0085FF0085FF0085FF0047FF1400FFFF00E6FF00A8FF00F59E00FFFF00F5FF0000FF0000
BD00FF8000FFAE00FFFF00E68F00FF8000FF0066FF00A3FF0075FF00C2FF00E1FF000AFF
00F0FF00FFF000FFF000FFFF00B3FF0094FF0066FF00A3FF00FFFF00FFF000E1FF00F0FF
00FFFF00FFB300FFB300FFD100FFFF00FFF000FFC200FF8500FF7500FF7500FF9400FFC2
00FF5700FF4700FF4700FF3800FF3800FF3800FF3800FF3800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF0A00FF0A00FF0A00FF0A
00FF1900FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A05FF0005FF0005FF0005FF0005FF0000FF0A05FF00
05FF0005FF0005FF0000FF0A05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0000FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF1900FF28
00FF1900FF1900FF2800FF2800FF2800FF2800FF3800FF3800FF3800FF4700FF4700FF57
00FF6600FF7500FF9400FFA300FFB300FFD100B3FF0094FF0028FF00FFE10075FF00FFF0
00FF8500FF6600FF5700FF4700FF4700FF3800FF3800FF3800FF3800FF2800FF2800FF28
00FF2800FF2800FF1900FF1900FF1900FF0A00FF0A05FF0005FF0005FF0005FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
33FF0033FF0023FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0023FF0033FF0023FF0033FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0014FF0014FF0014FF0000FF0A00FF1900FF3800FF8500E1FF00D1FF00FF6600FF38
00FF2800FF2800FF2800FF2800FF3800FF5700E1FF00FFD100FF9400FFD100FF2800FF19
00FF0A00FF0A00FF0A05FF0005FF0005FF0005FF0000FF0A
05FF0005FF0005FF0005FF0014FF0005FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0023FF0023FF00
14FF0023FF0023FF0014FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0005FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0000FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF3800FF3800FF3800FF3800FF3800FF4700FF4700FF57
00FF5700FF5700FF6600FF6600FF7500FF7500FF8500FF8500FF9400FF9400FFA300FFB3
00FFC200FFD100FFFF00FFFF0085FFFF00B800D1FF00E1FF00D1FF0094FF0075FFDC00FF
0057FF2300FFFF00009E00FF6100FFCC00FFFF001EAE00FF6100FF7000FFFF001EFA00FF
FF00F51400FF4200FFFF00F5FF001E3300FF0057FF00C2FF00D1FF00F0FF00FFFF00FFFF
00FFF000FFE100FFE100FFE100FFF000E1FF000AFF0047FFFF00F500B3FF0075FF00D1FF
00FFF000FFD100FFE100FFE100C2FF00FFFF00FFB300FF9400FF9400FF94CC00FF00FF85
00FF6600FF5700FF4700FF4700FF3800FF3800FF3800FF3800FF3800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF0A00FF0A00FF0A00FF19
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A05FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0000FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF1900FF19
00FF1900FF1900FF2800FF2800FF3800FF3800FF3800FF3800FF4700FF4700FF4700FF57
00FF6600FF7500FF8500FF9400FFA3FF0000FF000000D1FF00FFD100FFB300FFC200FFFF
00FFE100FF7500FF5700FF4700FF4700FF3800FF3800FF2800FF2800FF2800FF2800FF19
00FF1900FF1900FF1900FF0A00FF0A00FF0A00FF0A05FF0005FF0005FF0005FF0005FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0023FF0023FF0014FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0033FF0023FF0023FF0033FF0023FF0023FF0033FF0023FF00
33FF0033FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0014FF0014FF0005FF0005FF0000FF4700D1FF00F0FFBD00FF00E1FF2300FF00FF66
00FF8500FF6600FF3800FF3800FF4700FFC2AE00FF00FF9400FF5700FF3800FF2800FF19
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
05FF0005FF0005FF0005FF0005FF0005FF0014FF0005FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0023FF0014FF0014FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0014FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0014FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
14FF0014FF0023FF0023FF0023FF0023FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0005FF00
14FF0014FF0014FF0014FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0000FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF3800FF3800FF3800FF3800FF3800FF4700FF4700FF47
00FF5700FF5700FF5700FF6600FF6600FF7500FF7500FF8500FF8500FF9400FF9400FFA3
00FFB300FFB300FFC200FFE100FFFF00D1FF0066FF0019FF8F00FF0028FF2300FF0028FF
0085FF0047FF0075FF0066FF000AFFFA00FFFF00B86100FF1400FF1400FF5100FF8F00FF
1400FF0019FF1400FFFF00A83300FF0500FF0094FF00C2FF00E1FF00FFFF00FFF000FFE1
00FFD100FFD100FFD100FFD100FFE10094FF0075FF00F0FF0500FF0066FFFF001E0057FF
8000FF00D1FF00C2FF00C2FFFF002E0057FF00FFFF00FFF000FFE100FFD100FFD100FF85
00FF6600FF5700FF4700FF4700FF3800FF3800FF3800FF3800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A05FF0005FF0005FF0000FF0A05FF0005FF00
05FF0005FF0000FF0A05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0000FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF1900FF19
00FF1900FF2800FF2800FF2800FF3800FF3800FF3800FF4700FF4700FF4700FF5700FF57
00FF6600FF6600FF7500FF9400FFA300FFF000A3FF00C2FF00FFC200FFA300FF9400FF94
00FF8500FF7500FF5700FF4700FF3800FF3800FF3800FF2800FF2800FF2800FF2800FF19
00FF1900FF1900FF0A00FF0A00FF0A00FF0A00FF0A05FF0005FF0005FF0005FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
14FF0014FF0014FF0005FF0005FF0000FF1900FF3800D1FF00FF6600FFD10047FF00FFE1
00E1FF00FF8500FF5700FF4700FF5700FF850085FF00FFD100FF5700FF3800FF2800FF19
00FF1900FF1900FF1900FF0A00FF0A00FF1900FF1900FF19
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0023FF0014FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0000FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF3800FF3800FF3800FF3800FF3800FF3800FF4700FF47
00FF4700FF5700FF5700FF5700FF6600FF7500FF7500FF7500FF8500FF8500FF9400FF94
00FFA300FFB300FFC200FFE100FFFF00C2FF0085FF00E1FF00E1FF00B3FFFF005C00D1FF
00A3FF0094FF00B3FF6100FF1400FFFF00A8FF00005100FF0028FF0019FF5100FFFF00B8
5100FF0047FF0047FF7000FF0057FF0019FF0066FF00A3FF0047FF00E1FF00FFF000FFE1
00FFD100FFC200FFC200FFC200FFD100FFD100FFD100FFE100FFF000E1FF0500FF00D1FF
00B3FF0094FF0085FF1400FF7000FF0066FF0500FF0085FF00FFFF00FFC20057FF00FFD1
00FFB300FF7500FF5700FF4700FF4700FF3800FF3800FF3800FF3800FF3800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A05FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0000FF0A05FF0005FF0000FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF1900FF1900FF19
00FF2800FF2800FF2800FF3800FF3800FF3800FF4700FF4700FF4700FF5700FF5700FF66
00FF6600FF7500FF8500FFB300FFC200FFF00500FF00FFE100FFB300FF9400FF8500FF75
00FF6600FF5700FF4700FF4700FF3800FF3800FF2800FF2800FF2800FF2800FF1900FF19
00FF1900FF1900FF0A00FF1900FF0A00FF0A05FF0005FF0005FF0005FF0005FF0005FF00
05FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0014FF00
14FF0014FF0014FF0005FF0005FF0000FF0A00FF2800FF4700FF3800FF5700FF850066FF
0057FF00A3FF0028FF00FF7500FF7500FFF000FFC200FF7500FF4700FF3800FF2800FF28
00FF1900FF1900FF1900FF1900FF1900FF284200FF00FF38
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0014FF0014FF0005FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0023FF0023FF0014FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0000FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF3800FF3800FF3800FF3800FF3800FF4700FF47
00FF4700FF5700FF5700FF5700FF6600FF6600FF6600FF7500FF7500FF8500FF9400FF94
00FFA300FFB300FFD100F0FF00E1FF5100FF00D1FF00FFFF00FFF00094FF00FFFF00FFFF
00FFFF00F0FF00D1FF00B3FF0085FFFF006B0028FF4200FF0057FF0057FF0028FFFF000F
0038FF0075FF0066FF0075FF00A3FF00A3FFBD00FF0094FF00A3FF00A3FF00FFF000FFD1
00FFC200FFC200FFB300FFC200FFC200FFC200FFC200FFD100FFF00085FF0057FF00FFF0
00FFE1FF000000FFFF00C2FFCC00FF00FFFF00FFD100FFB300FFA300FF9400FFA300F0FF
00E1FF00FFC200FF6600FF4700FF4700FF3800FF3800FF3800FF3800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF1900FF2800FF2800FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF0A00FF0A00FF1900FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A05FF0005FF00
05FF0000FF0A05FF0005FF0005FF0005FF0000FF0A05FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0000FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF1900FF1900FF19
00FF2800FF2800FF2800FF3800FF4700FF4700FF5700FF5700FF5700FF5700FF6600FF66
00FF6600FF7500FF940094FF00E1FF00E1FF0038FF00FFF000FFC200FF9400FF7500FF66
00FF6600FF5700FF4700FF4700FF4700FF3800FF2800FF2800FF2800FF1900FF1900FF19
00FF1900FF1900FF0A00FF0A00FF0A00FF0A00FF0A05FF0005FF0005FF0005FF0005FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0023FF00
14FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0014FF0014FF00
14FF0014FF0005FF0005FF0005FF0000FF0A00FF1900FF1900FF2800FF4700FFF000B3FF
00FFA300FFD10094FF00FFE100FFB32300FF00FFA300FF6600FF4700FF3800FF3800FF28
00FF2800FF2800FF2800FF3800FF4700FF4700FFD100FF75
00FF0A05FF0000FF0A05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0014FF0005FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
23FF0023FF0014FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0014FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0014FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0000FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF3800FF3800FF3800FF3800FF3800FF3800FF4700FF47
00FF4700FF4700FF5700FF5700FF6600FF6600FF6600FF7500FF7500FF8500FF9400FFA3
00FFB300FFD100FFE10094FF5100FF00A3FF00FFFF00FFE100FFE100FFE100FFE100FFE1
00FFFF00F0FF00D1FF00B3FF0075FF8F00FF0085FF0066FF0066FF0085FF0047FF6100FF
0500FF0085FF00A3FF00B3FF00C2FF00B3FF0019FF00C2FF00F0FF00FFF000FFD100FFC2
00FFC200FFB300FFB300FFB300FFB300FFB300FFB300FFC200FFF00066FF00FFE100FFE1
00FFC200FFC200FFC200FFE10085FF00D1FF00FFC200FF9400FF8500FF8500FF8500FF85
00FF7500FF7500FF6600FF4700FF4700FF3800FF3800FF3800FF3800FF3800FF2800FF38
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0000FF0A05FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0000FF0A05FF0005FF0005FF0005FF0000FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF1900FF1900FF1900FF1900FF19
00FF2800FF2800FF3800FF5700FF8500FF6600FF6600FF6600FF9400FF6600FF6600FF66
00FF7500FF8500FF943300FF00B3FF5100FFFF005C00E1FF00E1FF00FF9400FF8500FF66
00FF6600FF5700FF4700FF4700FF3800FF3800FF2800FF2800FF2800FF1900FF1900FF19
00FF1900FF0A00FF0A00FF0A00FF0A00FF0A05FF0005FF0005FF0005FF0005FF0005FF00
05FF0014FF0005FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0023FF0023FF0014FF0023FF0023FF0023FF0023FF0023FF0014FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0014FF0014FF0014FF0014FF00
14FF0014FF0005FF0005FF0005FF0000FF0A00FF0A00FF1900FF1900FF3800FF4700B3FF
00FF6600FFFF00FFA300FFB300FFB300FFD100FF8500FF6600FF5700FF4700FF4700FF38
00FF3800FF3800FF3800FF476100FF00FF8500FFF000FF85
00FF0A00FF0A00FF0A00FF0A05FF0000FF0A05FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0014FF0014FF0005FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0023FF0023FF0014FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0014FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0000FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF3800FF3800FF3800FF3800FF3800FF3800FF47
00FF4700FF4700FF5700FF5700FF5700FF6600FF6600FF7500FF8500FF8500FF9400FFA3
00FFC29E00FF00FFFF00B3FF0066FF0094FF00FFF000FFD100FFD100FFD100FFD100FFE1
00FFF000E1FF0038FF4200FF0066FF0094FF00B3FF00C2FF00B3FF00A3FF2300FF1400FF
0038FF0085FF00B3FF00D1FF00D1FF00D1FF1400FF0085FF00F0FF00FFE100FFD100FFC2
00FFB300FFB300FFB300FFA300FFA300FFA300FFA300FFB300A3FF00FFC200FFB300FFA3
00FFA300FFB300FFB300FFF00057FF00FFD100C2FF00FF8500FF7500FF7500FF7500FF66
00FF6600FF5700FF5700FF4700FF4700FF3800FF3800FF3800FF3800FF3800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF1900FF1900FF19
00FF2800FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF0A00FF0A00FF1900FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A05FF0005FF0000FF0A05FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0000FF0A05FF0005FF0005FF0000FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF1900FF1900FF1900FF19
00FF2800FF2800FF3800FF4700FF9400FF9400FF9400FFD100FFD100FF8500FF7500FF75
00FF8500FF8500FF9400FFC200FFE100C2FF0057FF00F0FF5100FF00FFD100FF8500FF75
00FF6600FF5700FF5700FF4700FF4700FF3800FF2800FF2800FF2800FF1900FF1900FF19
00FF1900FF0A00FF0A00FF0A00FF0A00FF0A00FF0A05FF0005FF0005FF0005FF0005FF00
05FF0005FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0023FF0023FF0014FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0014FF0023FF0023FF0023FF0023FF00
23FF0014FF0023FF0023FF0014FF0023FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0005FF0005FF0005FF0005FF0000FF0A00FF0A00FF1900FF1900FF2800FF3800FF38
00FF4700FF5700FF6600FF7500FF940028FF00FFA300FF7500FF6600FF5700FF5700FF47
00FF4700FF4700FF4700FF5700FF7500FFC200FFFF00FFA3
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A05FF0005FF0005FF0005FF0005FF0005FF0005FF0014FF0014FF00
05FF0014FF0014FF0005FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0014FF0014FF0023FF0023FF0023FF0023FF0023FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0005FF0014FF0014FF0014FF00
14FF0014FF0014FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0000FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF3800FF3800FF3800FF3800FF4700FF4700FF47
00FF4700FF4700FF5700FF5700FF5700FF6600FF6600FF8500FF8500FFA300FFA300FFB3
00F0FF0038FF0057FF0047FF00F0FF00FFF000FFD100FFC200FFC200FFC200FFC200FFD1
00FFF00085FF00A3FF00D1FF0094FF0094FF00D1FF00D1FF00C2FF0094FF0066FF2300FF
6100FF0057FF000AFF00E1FF00F0FF00F0FF00E1FF0066FF0094FF00FFE100FFC200FFB3
00FFB300FFA300FFA300FFA300FFA300FFA300FFA300FFA300FFA300FFA300FF9400FF94
00FF9400FFA300FFB35100FF2300FF00FF9400FF8500FF7500FF7500FF7500FF6600FF66
00FF5700FF5700FF4700FF4700FF4700FF3800FF3800FF3800FF3800FF3800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF1900FF28
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A05FF0005FF0000FF0A05FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0000FF0A05FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0000FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF2800FF2800FF3800FF470094FF00D1FF2300FF1400FF00FFC200FFA300FF9400FF85
00FF8500FF9400FFA300FFB300FFE10085FF00C2FF00FFE100FFC200FFA300FF8500FF75
00FF6600FF6600FF5700FF5700FF4700FF3800FF3800FF2800FF2800FF1900FF1900FF19
00FF1900FF1900FF0A00FF0A00FF0A00FF0A05FF0005FF0005FF0005FF0005FF0005FF00
05FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0023FF0014FF0014FF0023FF0023FF0023FF0023FF0014FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0014FF0023FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0005FF0005FF0005FF0005FF0000FF0A00FF0A00FF1900FF1900FF2800FF2800FF38
00FF3800FF4700FF5700FF6600FFB300F0FF2300FF00FFC200FF7500FF7500FFA300FF75
00FFA300FF5700FF5700FF6600FF7500FFA300F0FFFF0099
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF1900FF19
00FF1900FF2800FF0A00FF0A05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0014FF0014FF0005FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0023FF0023FF0014FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0014FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0014FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0014FF0014FF0014FF0014FF0023FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0005FF0014FF00
14FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0000FF0A05FF0005FF0005FF0000FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF3800FF3800FF3800FF3800FF3800FF3800FF47
00FF4700FF4700FF5700FF5700FF5700FF6600FF7500FF7500FFA3AE00FF00FFD100FFD1
00FFF000C2FF2300FFFF00E600FFFF00FFD100FFC200FFC200FFB300FFC200FFC200FFC2
00A3FF00F0FF00FFFF00FFFF00A3FF00B3FF00E1FF00F0FF00C2FFCC00FF000AFFEB00FF
1400FF0057FF0094FF00E1FF00FFFF00FFFF00FFFF00FFF000FFFF00FFE100FFC200FFB3
00FFB300FFA300FFA300FFA300FF9400FF9400FF9400FF9400FF9400FF9400FF9400FF94
00FF9400FF9400FF9400FFB300FFF000FF8500FF7500FF7500FF6600FF6600FF5700FF57
00FF5700FF4700FF4700FF4700FF4700FF4700FF3800FF3800FF3800FF3800FF3800FF38
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF1900FF1900FF1900FF2800FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A05FF00
05FF0000FF0A05FF0005FF0005FF0000FF0A05FF0005FF0005FF0000FF0A05FF0005FF00
05FF0000FF0A05FF0005FF0005FF0005FF0005FF0005FF0005FF0000FF0A05FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0000FF0A05FF0005FF0005FF0005FF0000FF0A
05FF0005FF0005FF0005FF0000FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF1900FF1900FF1900FF1900FF28
00FF2800FF2800FF3800FF4700FF5700FF75FF005C00FFE10047FF0094FF00FFE100FFA3
00FF9400FFA300FFB300FFE100FFF00028FF00D1FF00FFD100FFB300FFA300FF8500FF85
00FF8500FF7500FF8500FF7500FF5700FF3800FF3800FF2800FF2800FF2800FF1900FF19
00FF1900FF0A00FF0A00FF0A00FF0A00FF0A00FF0A05FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
05FF0005FF0005FF0005FF0005FF0000FF0A00FF0A00FF0A00FF1900FF1900FF2800FF28
00FF4700FF4700FF4700FF6600FF8500FFC20047FF00FFD100FFA300FFA33300FF00FFF0
00FFA300FF7500FF7500FF9400FFA300FFC200D1FF00B3FF
00FF1900FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF1900FF2800FF9400FF38
00FFA300FF4700FF1900FF0A00FF0A00FF0A05FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0023FF0023FF00
23FF0023FF0014FF0023FF0023FF0023FF0023FF0023FF0014FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0014FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0000FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF3800FF3800FF3800FF3800FF3800FF47
00FF4700FF4700FF5700FF5700FF6600FF6600FF7500FF8500FFB300FFF000FFFF00FFFF
00A3FF0075FF00E1FF0066FF5100FF00FFD100FFB300FFB300FFB300FFB300FFB300FFC2
00FFC200FFD100FFD100FFF0FF00C700E1FF00FFFF00FFFF00F0FF00D1FF0094FF2300FF
2300FF00A3FF00C2FF00F0FF00FFFF00FFF000FFE100FFE100FFD100FFC200FFB300FFB3
00FFA300FFA300FFA300FF9400FF9400FF9400FF9400FF9400FF8500FF8500FF8500FF85
00FF8500FF8500FF8500FF9400FF9400FF7500FF7500FF6600FF6600FF5700FF5700FF57
00FF5700FF4700FF4700FF4700FF4700FF3800FF3800FF3800FF3800FF3800FF3800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF1900FF1900FF2800FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF0A00FF0A00FF19
00FF0A00FF0A00FF1900FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A05FF0005FF0000FF0A05FF0005FF0005FF0000FF0A05FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0000FF0A05FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
00FF0A05FF0005FF0005FF0000FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF1900FF1900FF1900FF2800FF28
00FF2800FF2800FF3800FF3800FF4700FF5700FF8500FF9400A3FF00F0FF00E1FF00A3FF
00FFB300FFC200FFFF000AFF00D1FF9E00FF00E1FF00FFE100FFC200FFA300FF9400FF94
00FF9400FFA300E1FF00D1FF00E1FF00FF4700FF3800FF2800FF2800FF1900FF1900FF19
00FF1900FF0A00FF0A00FF0A00FF0A00FF0A00FF0A05FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
05FF0005FF0014FF0014FF0014FF0014FF0014FF0014FF0005FF0014FF0014FF0005FF00
05FF0005FF0005FF0005FF0000FF0A00FF0A00FF0A00FF1900FF1900FF1900FF2800FF28
00FF3800FF4700FF5700FF6600FF7500FF9400E1FFFF004C00FFE100FFD100D1FF00FFE1
00FFA300FF9400FF942300FF00FFE100E1FF00B3FF000AFF
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF2800FF6600FFB3
00FF7500FF3800FF1900FF0A00FF0A00FF0A00FF0A00FF0A05FF0005FF0005FF0005FF00
00FF0A00FF0A00FF0A00FF0A05FF0005FF0005FF0005FF0005FF0005FF0005FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0023FF00
23FF0014FF0014FF0023FF0023FF0023FF0023FF0023FF0014FF0023FF0023FF0023FF00
23FF0023FF0023FF0014FF0023FF0023FF0023FF0023FF0023FF0023FF0014FF0014FF00
23FF0023FF0023FF0023FF0023FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0000FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF3800FF3800FF3800FF3800FF3800FF3800FF4700FF47
00FF4700FF4700FF5700FF5700FF6600FF7500FF8500FF9400FFB300FFFF0038FF0047FF
0085FF00D1FF00FFE1BD00FF00FFC200FFB300FFB300FFA300FFA300FFB300FFB300FFB3
00FFB300FFC200FFC200FFD100FFF000FFF000FFF000FFF000FFFF00E1FF00C2FF0066FF
1400FF0094FF00D1FF00F0FF00FFFF00FFF000FFE100FFD100FFC200FFC200FFB300FFB3
00FFA300FFA300FFA300FF9400FF9400FF9400FF9400FF9400FF8500FF8500FF8500FF85
00FF8500FF8500FF7500FF7500FF7500FF7500FF6600FF6600FF6600FF5700FF5700FF57
00FF4700FF4700FF4700FF4700FF4700FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A05FF0000FF0A00FF0A05FF0005FF00
05FF0000FF0A05FF0005FF0005FF0005FF0005FF0005FF0005FF0000FF0A05FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0000FF0A05FF0005FF0005FF0000FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF28
00FF2800FF2800FF3800FF3800FF4700FF5700FF6600FF7500FF8500FFB300C2FFFF00B8
00FFD100FFE100FFFF0075FF1400FF0075FF00D1FF00E1FF00FFFF0066FF00FFB300FFA3
000AFF0066FF00FFF000FF8500FF5700FF4700FF3800FF2800FF2800FF1900FF1900FF19
00FF1900FF0A00FF0A00FF0A00FF0A00FF0A00FF0A05FF0000FF0A05FF0005FF0005FF00
05FF0005FF0005FF0005FF0014FF0005FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0005FF0005FF0005FF0005FF00
00FF0A00FF0A05FF0005FF0005FF0005FF0014FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0000FF0A00FF0A00FF0A00FF0A00FF1900FF1900FF2800FF2800FF28
00FF3800FF4700FF5700FF7500FF8500FF9400FFD10075FF00E1FFFF003D000AFF00B3FF
00FFD100FFF000FFC200FFFF0075FF0085FF00FFFF00F0FF
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF2800FF2800FF4700FF6600C2FF
00FF5700FF3800FF2800FF1900FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF1900FF1900FF0A00FF0A00FF0A00FF0A00FF0A05FF0005FF0005FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0023FF0023FF0023FF0023FF0014FF0014FF0023FF0023FF0023FF00
23FF0023FF0014FF0014FF0023FF0023FF0023FF0023FF0023FF0023FF0014FF0014FF00
14FF0023FF0023FF0023FF0023FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0000FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF3800FF3800FF3800FF3800FF3800FF3800FF47
00FF4700FF4700FF5700FF6600FF8500FF9400FF9400FFA300FFD100C2FF2300FFFA00FF
00FFFF00FFE100FFC200FFC200FFB300FFA300FFA300FFA300FFA300FFA300FFA300FFB3
00FFB300FFB300FFC200FFC200FFD100FFE100FFE100FFF000FFFF00E1FF00C2FF0085FF
FF00C70085FF00B3FF0075FF00FFFF00FFE100FFE100FFD100FFC200FFC200FFB300FFB3
00FFA300FFA300FF9400FF9400FF9400FF9400FF8500FF8500FF8500FF8500FF8500FF75
00FF7500FF7500FF7500FF7500FF6600FF6600FF6600FF6600FF5700FF5700FF5700FF57
00FF4700FF4700FF4700FF4700FF4700FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF1900FF1900FF2800FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A05FF0005FF0000FF0A00FF0A05FF0005FF0005FF0000FF0A05FF0005FF00
05FF0005FF0000FF0A05FF0005FF0005FF0005FF0000FF0A05FF0005FF0005FF0000FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF1900FF1900FF1900FF1900FF1900FF28
00FF2800FF2800FF3800FF3800FF4700FF4700FF5700FF7500FF8500FFA300FFC200D1FF
0075FF0066FF8000FF0028FF5100FF0047FF0075FF0075FF00C2FF00FFF000FFD100FFD1
4200FF0085FF00FF9400FF6600FF5700FF4700FF3800FF2800FF2800FF1900FF1900FF19
00FF1900FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A05FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0014FF0014FF0005FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0005FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0005FF0005FF0000FF0A00FF0A00FF0A
00FF3800FF4700FF0A05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0000FF0A00FF0A00FF0A00FF0A00FF1900FF1900FF1900FF2800FF2800FF38
00FF3800FF470066FF00C2FF00FFB300FFB300FFD100A3FF0066FF0500FFBD00FF0019FF
FF007A3300FF0085FF00F0FF2300FF00FFC200FF9400FFA3
00FF2800FF1900FF1900FF1900FF1900FF2800FF2800FF2800FF4700FF6600FF8500FFE1
00FF6600FF3800FF2800FF1900FF1900FF1900FF0A00FF0A00FF0A00FF0A00FF1900FF0A
00FF1900FF1900FF4700FF4700FF2800FF1900FF1900FF2800FF1900FF0A05FF0005FF00
05FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0023FF0023FF0014FF0014FF0014FF0023FF0023FF0023FF00
23FF0023FF0014FF0014FF0014FF0023FF0023FF0023FF0023FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0005FF0014FF0014FF0014FF0014FF0014FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
00FF0A05FF0005FF0005FF0005FF0000FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF3800FF3800FF3800FF3800FF3800FF3800FF47
00FF4700FF4700FF5700FF6600F0FF8F00FF0019FF00FFE17000FF00C2FF00FFFF000AFF
00FFFF00FFC200FFB300FFA300FFA300FF9400FF9400FFA300FFA300FFA300FFA300FFA3
00FFA300FFB300FFB300FFC200FFC200FFD100FFE100FFF0000AFF0066FF0094FF0057FF
FA00FF2300FF0066FF00B3FF00F0FF00FFF000FFE100FFD100FFC200FFC200FFB300FFA3
00FFA300FFA300FFA300FF9400FF9400FF8500FF8500FF8500FF8500FF7500FF7500FF75
00FF7500FF7500FF7500FF6600FF6600FF6600FF6600FF5700FF5700FF5700FF5700FF47
00FF4700FF4700FF4700FF4700FF4700FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF1900FF2800FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF0A00FF1900FF0A00FF0A00FF1900FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A05FF0005FF0000FF0A00FF0A05FF0005FF00
05FF0000FF0A00FF0A05FF0005FF0005FF0000FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF1900FF0A00FF0A00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF28
00FF2800FF2800FF3800FF3800FF4700FF5700FF6600FF8500FF9400FFF000B3FF00F0FF
00FFE100FFFF00E1FF0057FF0038FF4200FF000AFFFF00C70085FF00B3FF00A3FF00E1FF
00FFE100FFB300FF8500FF6600FF5700FF4700FF3800FF3800FF2800FF2800FF1900FF19
00FF1900FF1900FF0A00FF0A00FF0A00FF0A00FF0A00FF0A05FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0014FF0014FF0014FF0014FF00
14FF0005FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0000FF0A00FF8500FF47
00FFE100FF3800FF1900FF0A05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0000FF0A00FF0A00FF0A00FF0A00FF1900FF1900FF1900FF2800FF2800FF2800FF38
00FF3800FF4700FF7500FFB300A3FF00FFFF00FFF000B3FF9E00FF0075FF00C2FF00E1FF
00D1FF00B3FF00FFE100FFB30075FF00FF9400FF7500FF75
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF3800FF5700F0FF00FFC200F0FF
0066FF00FF5700FF3800FF2800FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF2800FF6600FFA300FF4700FF4700FF5700FFA33300FF00FF1900FF0A05FF00
05FF0005FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0023FF0023FF00
23FF0014FF0014FF0014FF0014FF0014FF0023FF0023FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0005FF0014FF0014FF0014FF0014FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0000FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF47
00FF4700FF4700FF5700FF6600FF7500FF9400FFC200FFD100C2FF00FFB300FFD10094FF
00D1FF00FFD100FFA300FF9400FF9400FF9400FF9400FF9400FF9400FF9400FFA300FFA3
00FFA300FFB300FFB300FFC200FFC200FFD100FFD100FFF000FFFF00D1FF0057FF0028FF
8000FFFF00E60085FF000AFF0066FF00FFFF00FFE100FFD100FFD100FFC200FFB300FFB3
00FFA300FF9400FF9400FF9400FF8500FF8500FF8500FF8500FF7500FF7500FF7500FF75
00FF7500FF7500FF6600FF6600FF6600FF6600FF6600FF5700FF5700FF5700FF5700FF57
00FF5700FF4700FF4700FF4700FF4700FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF2800FF3800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF1900FF2800FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF28
00FF2800FF2800FF3800FF3800FF4700FF5700FF7500FFFF00FFC20028FF00FFFF00FFC2
00FFB300FFD100D1FF0047FF00B3FF0075FF0066FF7000FF0085FF00F0FF00FFFF00FFF0
00F0FF00FFC200FF9400FF7500FF6600FF5700FF4700FF3800FF2800FF2800FF1900FF28
00FF1900FF1900FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A05FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0014FF0005FF0014FF00
14FF0005FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0000FF0A00FF1900FF3800FF85
00FF6600FF2800FF1900FF0A00FF0A00FF0A05FF0005FF0005FF0005FF0000FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF1900FF1900FF2800FF2800FF2800FF2800FF3800FF38
00FF4700FF5700FF6600FF9400FFC200C2FFFF001E0066FF00B3FF2300FF8F00FF00FFFF
00FFD100FFFF00FFA300FF9400FF8500FF6600FF6600FF66
00FF2800FF2800FF2800FF2800FF2800FF3800FF3800FF4700FFC200FFE10094FF00D1FF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00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF4700FF5700FF8500F0FF00E1FF
00FF8500FF6600FF4700FF3800FF2800FF2800FF2800FF2800FF2800FF3800FF5700FF66
00FF4700FF5700FF8500B3FF00FF7500FF660019FF00FF3800FF1900FF1900FF0A05FF00
05FF0005FF0005FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0000FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF3800FF3800FF3800FF3800FF3800FF4700FF47
00FF4700FF4700FF4700FF5700FF5700FF7500FFA300FF8500FF8500FF8500FF8500FF94
00FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF9400FF9400FF9400FF94
00FFA300FFB300FFB300FFC200FFC200FFD100FFE100FFE100FFF000F0FF00D1FF00A3FF
FF00990500FF0066FF00D1FF00F0FF00FFFF00FFF000FFF000FFF000F0FF00FFF000FFE1
00FFB300FFA300FF9400FF9400FF8500FF8500FF8500FF7500FF7500FF7500FF7500FF75
00FF6600FF6600FF6600FF6600FF6600FF5700FF5700FF5700FF5700FF5700FF5700FF47
00FF4700FF4700FF4700FF4700FF4700FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF0A
00FF1900FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF2800FF28
00FF2800FF2800FF3800FF3800FF5700FF8500FFC200FFC2000AFF00FF9400FF9400FF94
00FF9400FFA300FFB300FFD100FFF000C2FF0057FF00FFFF000AFF00FFC200FFA300FFA3
00FFB300B3FF00FFD100D1FF00A3FF7000FF00FFB300FF4700FF3800FF2800FF1900FF19
00FF1900FF1900FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A05FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0000FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF3800FF7500E1FF
00FF9400FF6600FF3800FF1900FF1900FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF1900FF1900FF2800FF3800FFA300FF5700FF4700FF4700FF3800FF4700FF47
00FF5700FF6600FF850047FF00FFC200FFC200FFD100FFF00085FF0019FF0094FF00FFE1
00FFC200FFA300FF9400FF8500FF6600FF5700FF4700FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF4700FF4700FF6600FF8500FFC200FFF0
00FF8500FF5700FF4700FF3800FF3800FF3800FF3800FF3800FF4700FF7500FF8500FF94
00FF6600FF944200FF00FF8500FF4700FF3800FF3800FF2800FF1900FF0A00FF0A05FF00
05FF0005FF0005FF0005FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
05FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0000FF0A05FF00
05FF0005FF0000FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF4700FF4700FF4700FF5700FF5700FF6600FF6600FF7500FF7500FF7500FF7500FF75
00FF7500FF8500FF7500FF8500FF8500FF8500FF8500FF8500FF8500FF9400FF9400FF94
00FFA300FFA300FFB300FFC200FFD100FFD100FFE100FFF000FFFF00F0FF00D1FF00B3FF
0075FF0038FF00A3FF00B3FF00E1FF00F0FF00FFFF00F0FF00D1FF0500FF00D1FF00FFFF
00FFB300FFA300FF9400FF9400FF8500FF8500FF8500FF7500FF7500FF7500FF7500FF75
00FF6600FF6600FF6600FF6600FF6600FF5700FF5700FF5700FF5700FF5700FF4700FF47
00FF4700FF4700FF4700FF4700FF4700FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF3800FF2800FF2800FF2800FF3800FF2800FF2800FF2800FF2800FF2800FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF0A00FF1900FF1900FF0A00FF1900FF0A00FF1900FF0A00FF1900FF0A
00FF1900FF0A00FF1900FF0A00FF1900FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF2800FF2800FF28
00FF2800FF2800FF3800FF3800FF4700FF7500FF7500FF7500FF7500FF7500FF7500FF85
00FF8500FF9400FFA300FFC200FFF000A3FF00B3FF00FFE100FFC200FFA300FF9400FF85
00FF8500FF9400FF9400FFF00066FF00FF7500FFA300FFC200FF3800FF2800FF2800FF19
00FF1900FF1900FF1900FF1900FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A05FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0000FF0A00FF0A
00FF190066FF00FF2800FF1900FF1900FF0A00FF1900FF2800FF2800FF4700FFD1FF00C7
00E1FF00FFA300FF5700FF3800FF1900FF1900FF1900FF0A00FF0A00FF0A00FF0A00FF19
00FF1900FF1900FF1900FF2800FF3800FF7500FFC200D1FF00FF5700FF4700FF4700FF47
00FF5700FF6600FF7500FF8500FFA300FFB300FFC200FFFF0057FFBD00FF0094FF00FFF0
00FFD100FFC200FFF000FFFF00FF7500FF4700FF3800FF38
00FF4700FF4700FF3800FF4700FF3800FF4700FF4700FF5700FF6600FFFF00FFFF1400FF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00FF8500FF5700FF4700FF4700FF4700FF4700FF5700FF5700FF6600E1FF00FFE100F0FF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00FFA300FF6600FF5700FF5700FF4700FF5700FF5700FF5700FF7500FF8500FFC200B3FF
00FFA300FF7500FF6600FF5700FF5700FF6600FF9400FF9400FF85BD00FF00E1FF00C2FF
4200FF00FFC200FF8500FF5700FF3800FF2800FF1900FF1900FF1900FF0A00FF0A00FF0A
05FF0005FF0005FF0005FF0005FF0005FF0014FF0014FF0014FF0005FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF0A00FF0A
00FF0A00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF3800FF3800FF3800FF3800FF3800FF3800FF4700FF47
00FF4700FF4700FF4700FF4700FF5700FF5700FF5700FF5700FF5700FF6600FF6600FF66
00FF6600FF6600FF7500FF7500FF7500FF7500FF7500FF7500FF8500FF8500FF8500FF94
00FFA300FFD10075FF00A3FF00A3FF0085FFFF004C0057FF00C2FF00A3FF0066FF6100FF
DC00FFFF0000FF004CFF006B1400FF0038FF0075FF0066FF00E1FF00FFFF00FFE100FFC2
00FFB300FFA300FF9400FF9400FF8500FF8500FF8500FF7500FF7500FF7500FF7500FF66
00FF6600FF6600FF6600FF6600FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF47
00FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF4700FF47
00FF7500FFB300FF5700FF5700FF5700FF5700FF6600FFF03300FF00FFF000FF3800FF28
00FF2800FF2800FF2800FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF2800FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF2800FF2800FF28
00FF2800FF2800FF3800FF3800FF3800FF4700FF4700FF4700FF5700FF5700FF6600FF66
00FF7500FF8500FFA30038FF00D1FF0047FFBD00FF0075FF00FFE100FF9400FF8500FF75
00FF6600FF5700FF5700FF5700FF4700FF4700FF3800FF3800FF2800FF2800FF2800FF19
00FF1900FF1900FF1900FF1900FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A05FF0000FF0A05FF0000FF0A05FF0005FF00
05FF0005FF0005FF0005FF0000FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF28
00FF5700B3FF00FF850047FF00FFA300FF4700FF3800FF3800FF4700FF5700B3FF0075FF
00FFA300FF6600FF4700FF3800FF2800FF2800FF2800FF1900FF1900FF1900FF2800FF28
00FF2800FF4700FFD100FFB300FF7500FF8500FFF000FFB300FF8500FF7500FF7500FF85
00FFA300FFC200FFA300FFA300FFF000FFF000FFE100FFFF00B3FF0075FF0047FFFF004C
00F0FF00FFD100FFF00028FF0094FF00FF5700FF3800FF28
00FFD100FF6600FF6600FF5700FF5700FF5700FF6600FF6600FF7500FF8500FFE10066FF
00F0FF00FF8500FF7500FF7500FF7500FFA300FFF000FFB300FFE100B3FF00C2FF00FFC2
00FFC200A3FF00FFD100FF7500FF3800FF2800FF1900FF1900FF1900FF0A00FF0A05FF00
05FF0005FF0005FF0005FF0005FF0005FF0014FF0014FF0005FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0000FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF0A
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF4700FF4700FF4700FF4700FF4700FF5700FF5700FF5700FF5700FF5700FF6600FF66
00FF6600FF6600FF6600FF7500FF7500FF7500FF7500FF7500FF8500FF8500FF8500FF94
00FF9400FFB300FFC200FFF000FFF000FFFF00F0FF00B3FF0057FFBD00FF0500FF1400FF
FF001EFF003D4200FFCC00FF0075FF00C2FF00D1FF0075FFFF004C0057FF00F0FF00C2FF
00FFD100FFB300FF9400FF9400FF8500FF8500FF8500FF7500FF7500FF7500FF7500FF66
00FF6600FF6600FF6600FF6600FF6600FF5700FF5700FF5700FF5700FF5700FF5700FF47
00FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF4700FF4700FF57
00FF8500FFE100FF7500FF6600FF6600FF9400FFA300FFC200FF7500FF4700FF3800FF38
00FF3800FF2800FF2800FF2800FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF1900FF19
00FF1900FF1900FF1900FF0A00FF1900FF0A00FF0A00FF1900FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF0A00FF0A00FF0A00FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF2800FF1900FF1900FF2800FF2800FF28
00FF2800FF2800FF3800FF3800FF3800FF3800FF4700FF4700FF5700FF5700FF5700FF66
00FF7500FF8500FFA300FFE100FFE100C2FF00D1FF00FFE100F0FF00FFF000FF7500FF66
00FF6600FF5700FF5700FF4700FF4700FF4700FF3800FF3800FF2800FF2800FF2800FF28
00FF1900FF1900FF1900FF1900FF1900FF1900FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF1900FF1900FF28
00FF4700FF8500B3FF00A3FF00FF8500FF5700FF4700FF4700FF5700FF6600FFB30085FF
00A3FF00FF7500FF4700FF4700FF3800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF3800FF4700FFC200FFF00500FF00FFD100D1FF00FFB300FF9400FF8500FF8500FFD1
00FFE100FFFF00FFC200FFD100D1FF00A3FF0500FF00C2FF00B3FF0057FF6100FFFF00D7
00E1FF00FFC200FFA300FF9400FF6600FF5700FF3800FF38
00FF8500FF7500FF6600FF6600FF6600FF6600FF6600FF7500FF7500FF8500FFB300B3FF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00FF8500FF8500FF7500FF7500FF7500FF8500FF8500FF8500FF8500FF9400FFB300FFF0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00FF9400FF9400FF8500FFA300FF9400FFD100FFA300FF9400FFA300B3FF00FFD100A3FF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00FFFF00FFA300FFA300F0FF00FFE10075FF00FFC200FFB300FFC20066FF00A3FF00FFF0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00FFF000FFC200FFC200FFD100B3FF00E1FF00FFE100FFD100FFF00085FF00A3FF0038FF
00FFA300FF9400FF8500FF8500FF8500FF7500FF7500FF9400FF7500FF5700FF4700FF47
00FF3800FF3800FF3800FF2800FF2800FF1900FF1900FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
14FF0014FF0014FF0005FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0005FF0014FF0014FF0014FF0014FF0014FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0000FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF1900FF0A00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF2800FF1900FF1900FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF3800FF28
00FF2800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF47
00FF4700FF4700FF4700FF4700FF4700FF4700FF5700FF5700FF5700FF5700FF5700FF57
00FF6600FF6600FF6600FF6600FF6600FF7500FF7500FF7500FF7500FF7500FF8500FF85
00FF9400FF9400FF9400FFA300FFB300FFC200FFD100FFD100FFD100FFE100FFFF6100FF
0047FF0047FFFF007A5100FF0094FF00F0FF00FFF000FFD100FFD100FFC200FFC200FFB3
00FFB300FFA300FF9400FF9400FF9400FF8500FF8500FF8500FF8500FF7500FF7500FF75
00FF7500FF6600FF6600FF6600FF6600FF6600FF5700FF5700FF5700FF5700FF5700FF57
00FF5700FF5700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF47
00FF4700FF4700FF4700FF3800FF4700FF3800FF3800FF4700FF3800FF3800FF4700FF38
00FF4700FF4700FF4700FF4700FF4700FF4700FF5700FF5700FF5700FF6600FF6600FF75
00FF85FF002E00F0FF00FFE100FF9400FF7500FF6600FF5700FF5700FF4700FF4700FF38
00FF3800FF3800FF3800FF2800FF3800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF3800FF3800FF3800FF4700FF5700FF85
00E1FF00FFD100FF8500FF8500FFC20047FF4200FF00FF7500FF4700FF3800FF3800FF28
00FF2800FF2800FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF0A00FF1900FF1900FF1900FF0A00FF0A00FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF3800FF3800FF3800FF3800FF3800FF4700FF4700FF5700FF5700FF940066FF
0028FF00D1FF00FFE100FFD100D1FF0085FF00A3FF00E1FF00FFD100FFE100D1FF00FFA3
00FF7500FF5700FF5700FF4700FF4700FF3800FF3800FF3800FF3800FF2800FF2800FF28
00FF2800FF2800FF2800FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF2800FF2800FF28
00FF3800FF4700FF4700FF5700FF6600FF7500FF9400FFA300FFC200B3FF00FFB300FF94
00FF7500FF7500FF6600FF6600FF5700FF5700FF6600F0FF00FF7500FFA300FFF000FF75
00FF7500FF7500FFA300FFF000FFB300FFD100FFFF00B3FF000AFF00E1FF00FFF000FFB3
00FFB30038FF00FF9400FF7500FF7500FF7500FFA3CC00FF00FFA30028FF00FF9400FF75
00FF8500F0FF00FFD100F0FF00F0FF00FF9400A3FF00FFE1
1400FF0066FF00E1FF00FFF000C2FF00B3FF00B3FF00E1FF2300FF00F0FF00FFD100FFD1
00FF9400FF8500FF7500FF7500FF6600FF6600FF6600FF6600FF5700FF4700FF4700FF38
00FF3800FF2800FF2800FF2800FF1900FF1900FF1900FF1900FF1900FF0A00FF0A00FF0A
00FF0A05FF0005FF0005FF0000FF0A05FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0014FF0014FF0014FF0014FF0005FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0005FF0014FF0014FF0014FF00
14FF0014FF0014FF0005FF0005FF0014FF0014FF0014FF0014FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0000FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF4700FF3800FF3800FF3800FF47
00FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF5700FF5700FF5700FF5700FF57
00FF5700FF6600FF6600FF6600FF6600FF7500FF7500FF7500FF7500FF8500FF8500FF85
00FF9400FF9400FF9400FFA300FFA300FFB300FFC200FFC200FFD100FFD100FFF000FFFF
0066FF0085FF1400FF0094FF00B3FF00C2FF00FFF000FFD100FFD100FFC200FFB300FFB3
00FFA300FFA300FF9400FF9400FF9400FF8500FF8500FF8500FF8500FF7500FF7500FF75
00FF7500FF7500FF6600FF6600FF6600FF6600FF5700FF5700FF5700FF5700FF5700FF57
00FF5700FF5700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF47
00FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF47
00FF4700FF4700FF4700FF4700FF4700FF5700FF5700FF7500FF7500FF7500FF7500FF75
00FF941400FF000AFF0075FF00FFB300FF7500FF6600FF5700FF5700FF4700FF4700FF47
00FF3800FF3800FF3800FF3800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF3800FF3800FF3800FF3800FF4700FF4700FF5700FF66
00FF9400F0FF00FFB300F0FF00F0FF00FF9400E1FF00FF6600FF4700FF3800FF3800FF28
00FF2800FF2800FF2800FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF3800FF3800FF3800FF3800FF3800FF4700FF4700FF5700FF5700FF6600FF85
00FFA300F0FF000AFF00E1FF0075FFBD00FF000AFF0075FF00A3FF0019FF00FFD100FF94
00FF7500FF6600FF5700FF4700FF4700FF3800FF3800FF3800FF3800FF3800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF2800FF2800FF2800FF28
00FF2800FF2800FF1900FF1900FF1900FF1900FF1900FF2800FF2800FF2800FF2800FF38
00FF3800FF4700FF4700FF5700FF6600FF7500FF8500FF9400FFB34200FF00FFFF00FFA3
00FF8500FF8500FF7500FF6600FF6600FF6600FF7500F0FF00FFD100FFD100E1FF00FF94
00FF8500FF9400B3FF00E1FF00FFFF00E1FF0075FF0085FFFF002E0085FF00FFE100FFA3
00FF8500FF8500FF7500FF6600FF6600FF6600FF8500FFD100FF7500FF8500FF7500FF66
00FF6600FF7500FF8500FF9400FFD100C2FF0085FF00FFC2
0075FFFF00F500C2FF00C2FF9E00FFDC00FF0094FF000AFF00B3FF8F00FF00FFB300FFA3
00FF8500FF7500FF7500FF6600FF6600FF5700FF5700FF5700FF4700FF4700FF3800FF38
00FF3800FF2800FF2800FF2800FF1900FF1900FF1900FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0005FF0014FF0014FF0014FF00
14FF0014FF0014FF0005FF0005FF0005FF0014FF0014FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0000FF0A
05FF0005FF0005FF0005FF0000FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF1900FF1900FF1900FF1900FF1900FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF4700FF4700FF47
00FF4700FF4700FF4700FF4700FF4700FF5700FF5700FF5700FF5700FF5700FF5700FF57
00FF6600FF6600FF6600FF6600FF6600FF7500FF7500FF7500FF7500FF8500FF8500FF94
00FF8500FF9400FF9400FFA300FFA300FFB300FFB300FFC200FFC200FFD100FFE100FFF0
00E1FF00C2FF5100FF3300FF00E1FF00FFFF00FFF000FFE100FFD100FFC200FFB300FFB3
00FFA300FFA300FFA300FF9400FF9400FF9400FF8500FF8500FF8500FF8500FF7500FF75
00FF7500FF7500FF6600FF6600FF6600FF6600FF6600FF5700FF5700FF5700FF5700FF57
00FF5700FF5700FF5700FF5700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF47
00FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF47
00FF4700FF4700FF4700FF4700FF5700FF5700FF6600FFA300FFA300FF9400FF8500FF85
00FFA300FFC26100FF00FFD100FFB300FF8500FF6600FF6600FF5700FF5700FF4700FF47
00FF3800FF3800FF3800FF3800FF3800FF3800FF2800FF3800FF2800FF2800FF2800FF28
00FF3800FF2800FF3800FF3800FF3800FF3800FF3800FF4700FF4700FF4700FF5700FF66
00FF8500FFB300FFD100FFA300FFD100FF7500FF6600FF5700FF4700FF3800FF3800FF28
00FF2800FF2800FF2800FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF2800FF1900FF1900FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF3800FF3800FF3800FF3800FF3800FF3800FF4700FF4700FF4700FF5700FF6600FF75
00FF9400FFC21400FF00FFFF00D1FF0066FF0038FF6100FF00F0FF00FFFF2300FF00FFE1
00FFC200FF9400FF5700FF5700FF4700FF4700FF3800FF3800FF3800FF3800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF1900FF2800FF1900FF1900FF2800FF19
00FF1900FF1900FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF3800FF4700FFC2
00FF3800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF38
00FF3800FF4700FF4700FF5700FF5700FF6600FF7500FF8500FFB300D1FF00C2FF00FFC2
00FFA300FFE100FF9400E1FF00FF8500FF7500FF8500FFA300FFE10057FF00FFC200FFB3
00FFC200FFC200FFFF0019FF0085FF00C2FF00F0FF000AFF0075FF00FFFF00FFD100FF94
00FF8500FF7500FF6600FF5700FF5700FF5700FF6600FF6600FF5700FF5700FF5700FF57
00FF5700FF5700FF6600FF850019FF00FFA300FF7500FF66
0085FF0057FF0019FF3300FF0038FF8000FF0028FF0057FF00C2FF00FFE100FFB300FFA3
00FF8500FF7500FF6600FF6600FF6600FF5700FF5700FF4700FF4700FF4700FF3800FF38
00FF2800FF2800FF2800FF1900FF1900FF1900FF1900FF1900FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0014FF0014FF0014FF0005FF0014FF0014FF0014FF0014FF00
14FF0005FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0005FF0014FF0014FF00
14FF0014FF0014FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
00FF0A05FF0005FF0005FF0000FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF1900FF1900FF1900FF1900FF1900FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF4700FF3800FF3800FF3800FF3800FF4700FF47
00FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF5700FF5700FF5700FF5700FF57
00FF6600FF6600FF6600FF6600FF7500FF7500FF7500FF7500FF7500FF8500FF8500FF85
00FF8500FF9400FF9400FFA300FFA300FFA300FFB300FFC200FFC200FFD100FFE100FFF0
00F0FF00B3FF0057FF0085FF00D1FF00FFFF00FFF000FFE100FFD100FFC200FFC200FFB3
00FFA300FFA300FFA300FF9400FF9400FF9400FF9400FF8500FF8500FF8500FF8500FF75
00FF7500FF7500FF7500FF6600FF6600FF6600FF6600FF6600FF6600FF5700FF5700FF57
00FF5700FF5700FF5700FF5700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF47
00FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF47
00FF4700FF4700FF5700FF5700FF5700FF5700FF6600FF9400B3FF00FFF000FFA300FFA3
00FFB3FF002E4200FF00FFFF00FFA300FF8500FF7500FF6600FF5700FF5700FF4700FF47
00FF4700FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF4700FF4700FF4700FF5700FF5700FF6600FF75
00FF9400D1FF00FFFF00FF8500FF7500FF6600FF5700FF4700FF3800FF3800FF3800FF28
00FF2800FF2800FF2800FF2800FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF3800FF28
00FF2800FF3800FF3800FF3800FF4700FF4700FF4700FF4700FF4700FF5700FF6600FF75
00FFA300D1FF00E1FF00FFD100FFE100E1FF0047FF00D1FF00FFE100FFC200FFD100FFF0
00FFB30038FF00FF6600FF5700FF4700FF4700FF3800FF3800FF3800FF3800FF3800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF3800FF3800FF5700FFE100FF75
00FF4700FF3800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF3800FF3800FF38
00FF4700FF4700FF4700FF5700FF6600FF6600FF7500FF9400FFB300FFE1000AFF00E1FF
00FFD10085FF00FFF000FFF000FF9400FF9400FF9400FFA300FFD100C2FF0094FF00FFF0
0038FF6100FF00B3FF0094FF00FFF000FFC200FFD100D1FF00FFF00085FF00FFB300FF94
00FF7500FF6600FF5700FF5700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF47
00FF4700FF5700FF6600FF8500A3FF00FFC200FF6600FF57
00FFF000F0FF00D1FF00B3FF0094FF0047FFDC00FF0019FF00D1FF00FFF000FFFF00E1FF
00FF8500FF7500FF6600FF6600FF5700FF5700FF4700FF4700FF3800FF3800FF3800FF38
00FF2800FF2800FF2800FF1900FF1900FF1900FF1900FF1900FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0014FF0014FF0014FF0014FF00
14FF0005FF0014FF0014FF0014FF0014FF0014FF0005FF0014FF0014FF0014FF0014FF00
14FF0014FF0005FF0014FF0014FF0014FF0014FF0014FF0014FF0005FF0014FF0014FF00
14FF0014FF0014FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0000FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF19
00FF1900FF1900FF1900FF1900FF2800FF3800FFA300FF3800FF3800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF3800FF2800FF2800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF4700FF47
00FF4700FF4700FF4700FF4700FF4700FF4700FF5700FF5700FF5700FF5700FF5700FF66
00FF6600FF6600FF6600FF6600FF6600FF7500FF7500FF7500FF7500FF8500FF8500FF85
00FF8500FF9400FF9400FFA300FFA300FFB300FFB300FFC200FFD100FFE100FFF000FFFF
00E1FF0094FF6100FF0047FF0085FF00E1FF00F0FF00C2FFFF008A00FFD100FFC200FFB3
00FFB300FFA300FFA300FFA300FF9400FF9400FF9400FF9400FF9400FF9400FF8500FF85
00FF8500FF7500FF7500FF7500FF6600FF6600FF6600FF6600FF5700FF5700FF5700FF57
00FF5700FF5700FF5700FF5700FF5700FF5700FF4700FF4700FF4700FF4700FF4700FF47
00FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF47
00FF4700FF5700FF5700FF5700FF5700FF6600FF7500FF8500FFC20038FF00FFFF00FFB3
00FFC200F0FF0085FF00F0FF00FFB300FF9400FFB300FFB300FF6600FF5700FF5700FF47
00FF4700FF4700FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF4700FF5700FFA300FF5700FF5700FF6600FF7500FFA3
00FFE11400FF00FFB300FF8500FF6600FF5700FF5700FF4700FF3800FF3800FF3800FF28
00FF2800FF2800FF2800FF2800FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF28
00FF1900FF1900FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF4700FF4700FF4700FF5700FF6600FF75
0094FF00D1FF00FFB300FFB300FFC200FFFF0057FF00F0FF00FFD100FFA300FFA300FF94
00FF8500FF7500FF6600FF5700FF4700FF4700FF4700FF3800FF3800FF3800FF3800FF38
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF3800FF3800FF6600FF3800FF3800FF3800FF3800FF5700FF75FA00FF00FF66
00FF4700FF3800FF3800FF3800FF2800FF2800FF2800FF2800FF3800FF3800FF3800FF47
00FF4700FF4700FF5700FF5700FF6600FF7500FFA300FFA300FFB300FFE100C2FF00A3FF
00F0FF00C2FF00F0FF00FFD100FFB300FFB300FFF000FFD100E1FF0075FF0028FF00C2FF
00E1FF00FFFF00FFB300C2FF00F0FF00FF9400FF9400FF9400FFB300FFFF00E1FF00FFC2
00FFA300FF7500FF5700FF4700FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF4700FF4700FF6600FF8500A3FF00FFB300FF7500FF47
00FFD100FFF000E1FF00C2FF0094FF0066FF0057FF9E00FFBD00FFBD00FF5100FF00FFB3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00FFE100FFF000A3FF000AFF000AFF0038FF0038FF00D1FF00F0FF0066FF00F0FF00FFC2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00FFFF00F0FF00C2FF000AFFFF00000047FF00D1FF00FFFF00FFF000FFF00085FF3300FF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00B3FF00C2FF0500FFFF00992300FF0085FF0094FF00FFF000FFE100FFD100FFC200FFC2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00C2FF6100FF8000FF0075FF00A3FF00C2FF00F0FF00FFFF00FFE100FFC200FFB300FFA3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00C2FFFF00003300FF0038FF0085FF00B3FF00D1FF00E1FF00FFFF00FFC200FFB300FFA3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00A3FFFF00B80500FF000AFFFF00000019FF0038FF0057FF6100FF00FFD100FFC200FFA3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0500FF00E1FF0057FFFF002E0038FF00E1FF00B3FFBD00FF0038FF00FFFF00FFFF00FFD1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00FFFF00FFE100FFFF1400FF00FFFF00FFE100B3FF00F0FF0094FF0038FF0085FF00A3FF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00FFB300FFC200E1FF00E1FF00FFF000FFC200FFC200FFD100FFFF0047FF0057FF00F0FF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00FF9400FFB300D1FF00FFB300E1FF00FFA300FFB300FFD1CC00FF00B3FF0085FF0047FF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00FF8500FF9400FF9400FF8500FF9400FF8500FF9400FFA300FFD100FFF000FFFF00B3FF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00FF7500FF7500FF6600FF7500FF7500FF7500FF8500FF9400FFA300FFC200FFF000D1FF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00FF6600FF5700FF5700FF6600FF6600FF7500FF8500FF8500FFA300FFB300FFE10028FF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00FF5700FF5700FF5700FF5700FF6600FF6600FF7500FF9400FFB300FFC200FFE10028FF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00FF4700FF4700FF4700FF5700FF5700FF6600FF9400FFC20066FF1400FF00C2FF00E1FF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00FF4700FF4700FF4700FF4700FF5700FF6600FFA38000FF00FFD100FFC27000FF00FFD1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00FF3800FF3800FF3800FF4700FF4700FF66FF00C700FF8500FF8500FFA30075FF00FFB3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00FF3800FF3800FF3800FF3800FF3800FF4700FF5700FF5700FF6600FF9400FFF000FF94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00FF2800FF2800FF2800FF3800FF3800FF3800FF4700FF4700FF5700FF7500FF7500FF75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00FF2800FF2800FF2800FF3800FF3800FF3800FF3800FF4700FF4700FF5700FF5700FF66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00FF2800FF2800FF2800FF2800FF2800FF2800FF3800FF3800FF4700FF4700FF5700FF57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00FF1900FF1900FF2800FF2800FF2800FF2800FF3800FF3800FF3800FF4700FF4700FF57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00FF1900FF1900FF1900FF2800FF2800FF2800FF2800FF3800FF3800FF4700FF4700FF57
00FF5700FF6600FF7500FF9400FFB300FFB300FFD100E1FF00A3FF8F00FF00D1FF00B3FF
00D1FF00FFFF00F0FF00A3FF0094FF00D1FF0085FF00C2FF0500FF5100FF0085FF0028FF
00B3FF0066FF00FFA300FF7500FF6600FF5700FF4700FF3800FF2800FF2800FF1900FF19
00FF1900FF1900FF1900FF1900FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF1900FF0A00FF0A00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF2800FF1900FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF38
00FF3800FF3800FF3800FF4700FF4700FF5700FF6600FF7500FF7500FF8500FF8500FF94
00FF9400FFB3000AFF00FFFF00B3FF1400FF00FFFF00FFD100FFC200FFB300FFB300FFB3
00A3FF00FFB300FF8500FF8500FF7500FF7500FF7500FF6600FF6600FF6600FF6600FF66
00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF66
00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7500FF7500FF7500FF75
00FF8500FF8500FF9400FFA300FFA300FFC200FFFF00FFF000E1FF00FFE100FFD100FFD1
00FFD100FFD100FFD100FFD100FFD100FFE100FFE100FFE100FFF000FFFF00E1FF0057FF
0094FF00C2FF00C2FF0094FF0066FF0019FF9E00FF0047FF0028FF00C2FF00D1FF00E1FF
00E1FF00F0FF00FFFF00FFF000FFE100FFD100FFD100FFD100FFC200FFC200FFC200FFB3
00FFB300FFB300FFB300FFA300FFA300FFA300FFA300FF9400FF9400FF9400FF9400FF94
00FF8500FF8500FF8500FF8500FF8500FF8500FF7500FF7500FF7500FF7500FF7500FF75
00FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF85
00FF8500FF8500FF8500FF8500FF8500FF8500FF9400FF9400FF9400FFA300FFA300FFB3
00FFC200FFE100D1FF00C2FF00C2FF6100FF0085FF00E1FF00FFF000FFE100FFC200FFC2
00FFB300FFB300FFB300FFB300FFC200FFC200FFE100E1FF00B3FF0085FF0085FF5100FF
FF00B800F0FF00FFF000FFF000FFC200FFC200FFB300FFC200FFE10047FF00C2FF3300FF
00FF9400FF7500FF7500FF6600FF6600FF6600FF5700FF5700FF5700FF5700FF5700FF47
00FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF47
00FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF47
00FF5700FF5700FF6600FF9400FFB300FFFF00FFFF00FFF000A3FF00FFB300FFA300FFA3
00FFA300FFB300FFE10038FF0094FF00FFD100FFB300FFA300FFA300FFA300FFA300FFA3
00F0FF0019FF00FFFF00E1FF00FFF000D1FF00B3FF0066FF0066FF00FFFF00FFD100FFD1
00F0FF00E1FF00FFC200FFA300FF8500FF7500FF6600FF6600FF5700FF5700FF5700FF57
00FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF6600FFA300FFE1
00FF7500FF6600FF5700FF5700FF5700FF5700FF4700FF5700FF4700FF4700FF4700FF57
00FF5700FF5700FF6600FF6600FF8500FFE10038FF00FFF000FFA300FF8500FF7500FF85
00FFC200E1FF00F0FF00FF7500FF4700FF4700FF3800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF3800FF3800FF3800FF4700FF57
00FF6600FF94BD00FF00FFB300FF7500FF5700FF4700FF2800FF1900FF1900FF1900FF0A
00FF0A00FF0A05FF0005FF0005FF0005FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0033FF0023FF0033FF0033FF00
00FF1900FF1900FF1900FF1900FF2800FF2800FF2800FF3800FF3800FF4700FF4700FF57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00FF0A00FF1900FF1900FF1900FF2800FF2800FF3800FF3800FF3800FF4700FF5700FF57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00FF0A00FF1900FF1900FF1900FF1900FF2800FF2800FF3800FF4700FF4700FF5700FF66
00FF6600FF7500FF7500FF8500FF9400FFB300F0FF00C2FF00D1FF0066FF0038FF3300FF
000AFF00B3FF00F0FF00FFD100FFA300FF9400FF9400FF9400FF9400FF8500FF7500FF75
00FF7500FFA300FF6600FF4700FF4700FF3800FF3800FF2800FF2800FF2800FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF3800FF2800FF3800FF3800FF38
00FF3800FF3800FF4700FF4700FF4700FF5700FF5700FF5700FF6600FF6600FF7500FF85
00FF9400FF9400FFB300FFC200FFF000E1FF2300FF00B3FF0075FF00F0FF00F0FF0057FF
00FFE100FFC200FFD100F0FF00FFD100FFC200FFA300FF8500FF7500FF7500FF6600FF66
00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF66
00FF6600FF6600FF6600FF6600FF6600FF7500FF7500FF7500FF7500FF7500FF7500FF85
00FF8500FF8500FF8500FF9400FF9400FF9400FFA300FFA300FFA300FFB300FFB300FFB3
00FFB300FFC200FFC200FFC200FFC200FFD100FFD100FFD100FFE100FFE100FFF000FFFF
00FFFF00F0FF00D1FF00A3FF0094FF0075FF0500FF0038FF0075FF5100FF00C2FF00E1FF
00F0FF00FFFF00FFF000FFF000FFE100FFE100FFD100FFD100FFC200FFC200FFB300FFB3
00FFB300FFB300FFA300FFA300FFA300FFA300FFA300FF9400FF9400FF9400FF9400FF94
00FF8500FF9400FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF85
00FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF85
00FF8500FF8500FF9400FF8500FF9400FF9400FF9400FF9400FF9400FFA300FFA300FFB3
00FFB300FFC200FFC200FFD100FFF000E1FF00A3FFFA00FF0500FF00D1FF00FFF000FFE1
00FFD100FFE100FFE100F0FF6100FF00E1FF00D1FF000AFF0038FF0094FF0085FF5100FF
0094FF00B3FF00FFF000FFB300FFB300FFA300FF9400FF9400FF9400FF9400FF8500FF85
00FF7500FF7500FF6600FF6600FF6600FF6600FF6600FF5700FF5700FF5700FF5700FF57
00FF5700FF5700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF47
00FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF5700FF57
00FF5700FF6600FF6600FF6600FF7500FF9400FFC200FFD100FFC200FFF00028FFAE00FF
00A3FF5100FF00A3FFBD00FF00F0FF00FFF000FFD100FFD100FFE100FFF000FFE100FFE1
00FFE100F0FF00D1FF0057FF7000FF0085FF00FFFF00FFD100FFB300FFA300FF9400FF94
00FFA300FFA300FFD100FFA300FF6600FF6600FF5700FF5700FF5700FF4700FF4700FF47
00FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF47
00FF4700FF4700FF4700FF4700FF3800FF3800FF4700FF3800FF3800FF3800FF3800FF47
00FF4700FF4700FF5700FF9400FFD100FFD18F00FF00FFC200FF9400FF5700FF4700FF47
00FF4700FF3800FF4700FF4700FF3800FF2800FF2800FF2800FF1900FF1900FF1900FF28
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF2800FF2800FF3800FF4700FF94
00FFC200FFF00066FF0066FF00D1FF00FFC27000FF00FF3800FF1900FF0A00FF0A05FF00
05FF0005FF0005FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0033FF0033FF00
23FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
00FF0A00FF0A00FF1900FF1900FF2800FF2800FF3800FF3800FF4700FF6600FF7500FF75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00FF0A00FF0A00FF1900FF1900FF1900FF2800FF3800FF4700FF5700FF9400FFA300FF94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00FF0A00FF0A00FF1900FF1900FF1900FF3800FF6600FF6600FF8500FFD10085FF00FFFF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00FF0A00FF0A00FF1900FF1900FF1900FF2800FF5700FFA300FFD100FFB300FFFF00FFB3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00FF0A00FF0A00FF0A00FF1900FF1900FF2800FF381400FF00FF5700FFA300FFA300FF75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00FF0A00FF0A00FF0A00FF0A00FF1900FF2800FF2800FF3800FF3800FF4700FF4700FF57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00FF0A00FF0A00FF0A00FF1900FF1900FF1900FF1900FF2800FF2800FF3800FF4700FF47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00FF0A00FF0A00FF0A00FF0A00FF1900FF1900FF1900FF1900FF2800FF2800FF3800FF47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05FF0000FF0A00FF0A00FF0A00FF0A00FF1900FF1900FF1900FF2800FF2800FF3800FF47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00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF1900FF1900FF2800FF2800FF3800FF57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05FF0000FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF1900FF1900FF2800FF3800FF57
00FF7500FF7500FF6600FF5700FF5700FF5700FF5700FF6600FF6600FF8500FF9400E1FF
00FFE100FFE100B3FF0085FF00FFF000FFB300FF9400FF8500FF7500FF7500FF6600FF66
00FF5700FF5700FF4700FF4700FF3800FF3800FF3800FF3800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF2800FF2800FF28
00FF2800FF2800FF3800FF3800FF5700E1FF00FFF000F0FF00FFD100FFD100C2FF00FFC2
00FFB300FF9400FF8500FF940066FF00FFA300FF9400C2FF00FFF000FF8500FF7500FF75
00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7500FF7500FF7500FF85
00FF8500FF8500FF9400FFA300FFF000F0FF00FFF000FFFF00C2FF4200FF00C2FF00F0FF
00E1FF0047FF00FFE100FFB300FFA300FFA300FF9400FF9400FF9400FF8500FF8500FF85
00FF8500FF8500FF8500FF8500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF75
00FF7500FF7500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF94
00FF9400FF9400FF9400FF9400FF9400FF9400FF9400FFA300FFA300FFA300FFA300FFA3
00FFB300FFB300FFB300FFB300FFC200FFC200FFD100FFE100FFF000F0FF00C2FF0066FF
FF00E60085FF00B3FF00A3FF6100FF0019FF0028FF0019FFFA00FF0038FF0047FF0500FF
00B3FF00C2FF00D1FF00D1FF00D1FF00E1FF00E1FF4200FF00FFFF00FFF000FFE100FFD1
00FFD100FFC200FFC200FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB3
00FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA300FFA300FFA300FFA300FFA3
00FFA300FFB300FFB300FFD10019FF00E1FF00E1FF00FFD100FFC200FFB300FFB300FFB3
00FFB300FFB300FFA300FFA300FFB300FFB300FFB300FFB300FFB300FFB300FFC200FFD1
00FFF00057FF0075FF00F0FF00FFFF00F0FF00E1FF0094FF1400FF00A3FF00E1FF00F0FF
00FFF000FFE100FFD100FFD100FFC200FFB300FFB300FFB300FFA300FFA300FFA300FFA3
00FF9400FF9400FF9400FF9400FF9400FF8500FF8500FF8500FF8500FF8500FF7500FF75
00FF7500FF7500FF7500FF7500FF7500FF7500FF6600FF6600FF6600FF6600FF6600FF66
00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF66
00FF6600FF6600FF7500FF7500FF9400FFA300F0FF00FF9400FF8500FF8500FF8500FF85
00FF8500FF8500FF8500FF8500FF8500FF9400FF9400FFB300FFFF1400FF00FFF000FFE1
00FFD100FFE100FFFF00F0FF00E1FF0500FF0038FF8000FF000AFFFF000F1400FF0057FF
2300FF6100FF00F0FF00FFF000FFD100FFC200FFC200FFD100FFE100FFC200FFD100F0FF
00FFC200FF8500FF7500FF6600FF5700FF4700FF4700FF4700FF3800FF3800FF3800FF38
00FF3800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF1900FF1900FF1900FF1900FF1900FF2800FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A05FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0014FF0014FF0014FF0014FF00
14FF0014FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0042FF0042FF0042FF0042FF00
05FF0000FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF1900FF1900FF2800FF2800FF38
00FF4700FF4700FF4700FF4700FF4700FF5700FF5700FF5700FF6600FF7500FF8500FFF0
00FFA300FFC200FFF01400FF00FFFF2300FF00FFA300FF9400FF8500FF8500FF8500FF85
00FF7500FF5700FF5700FF4700FF4700FF3800FF3800FF3800FF3800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF2800FF1900FF1900FF2800FF2800FF28
00FF2800FF3800FF3800FF3800FF4700FF5700FF7500FF8500FF8500FFA300FFF08000FF
00FFF000FFB300FFA300FFA300B3FF00FFE100FFF00066FF00FFD100FF9400FF8500FF75
00FF7500FF7500FF6600FF6600FF6600FF6600FF7500FF7500FF7500FF7500FF7500FF85
00FF8500FF8500FF9400FFA300FFD100C2FF0038FF00D1FF0057FF000AFF6100FF00A3FF
2300FF00F0FF00FFE100FFC200FFB300FFA300FF9400FF9400FF9400FF9400FF8500FF85
00FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF7500FF8500FF7500FF7500FF85
00FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF9400FF94
00FF9400FF9400FF9400FF9400FF9400FF9400FFA300FFA300FFA300FFA300FFA300FFB3
00FFB300FFB300FFB300FFB300FFC200FFC200FFD100FFE100FFFF00D1FF5100FF000AFF
1400FF00C2FF00C2FF00C2FF00A3FF0066FF0075FF0038FFFF00003300FF0085FF0094FF
00C2FF00D1FF00E1FF00E1FF00F0FF00F0FF00F0FF00FFFF00FFF000FFE100FFE100FFD1
00FFD100FFC200FFC200FFC200FFB300FFB300FFC200FFB300FFB300FFB300FFB300FFB3
00FFC200FFC200FFD100FFD10028FF00FFE100FFB300FFB300FFB300FFB300FFB300FFB3
00FFB300FFB300FFC200FFD100FFFF0057FF00FFF000FFD100FFC200FFC200FFB300FFB3
00FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC200FFC200FFD1
00FFE100B3FFDC00FF00B3FF00E1FF00E1FF0094FF0047FFAE00FFFF005C00E1FF00FFFF
00FFF000FFE100FFD100FFC200FFC200FFB300FFB300FFB300FFA300FFA300FFA300FFA3
00FF9400FF9400FF9400FF9400FF8500FF8500FF8500FF8500FF8500FF8500FF7500FF75
00FF7500FF7500FF7500FF7500FF7500FF7500FF6600FF6600FF6600FF6600FF6600FF66
00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7500FF75
00FF7500FF7500FF7500FF8500FFC20066FF00FFD100FFA300FF9400FF8500FF8500FF85
00FF8500FF8500FF8500FF9400FF9400FF9400FFA300FFB300FFE100C2FF00B3FF00FFF0
00FFF000FFF000D1FF00B3FF0094FF0500FF000AFF00A3FF0066FF000AFF0066FF00B3FF
0500FF0066FF0085FF0094FF00FFF000FFF000D1FF00FFFF0019FF00D1FF00D1FFDC00FF
00C2FF00FFD100FFF000FF6600FF5700FF4700FF4700FF4700FF3800FF3800FF3800FF38
00FF3800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF0A00FF1900FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A05FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0042FF0042FF0042FF0042FF00
05FF0000FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF1900FF1900FF2800FF2800FF28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05FF0000FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF1900FF1900FF2800FF28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00FF0A00FF0A00FF0A00FF0A00FF1900FF0A00FF1900FF1900FF1900FF1900FF1900FF28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05FF0000FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF1900FF1900FF2800FF28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05FF0000FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF1900FF1900FF1900FF28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00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF1900FF1900FF1900FF19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00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF1900FF1900FF1900FF1900FF19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00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF1900FF1900FF1900FF19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00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF1900FF1900FF1900FF1900FF19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00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF1900FF1900FF1900FF2800FF19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00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF1900FF1900FF1900FF1900FF1900FF19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00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF1900FF1900FF1900FF1900FF1900FF28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00FF0A00FF0A00FF0A00FF0A00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF28
00FF2800FF2800FF2800FF2800FF3800FF3800FF3800FF3800FF4700FF4700FF5700FF57
00FF6600FF7500FF8500FF8500FFA300FFC2FF0000FF004C00B3FF00FFC200FFB300FFA3
00FF7500FF6600FF6600FF5700FF5700FF5700FF4700FF5700FF4700FF4700FF4700FF38
00FF4700FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF2800FF3800FF2800FF3800FF2800FF3800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF3800FF2800FF3800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF3800FF2800FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF4700FF4700FF4700FF4700FF4700FF5700FF5700FF5700FF66
00FF6600FF7500FF7500FF7500FF8500FF8500FF9400FFB32300FF0038FF00E1FF00D1FF
00E1FF00FFF000FFF00047FF00C2FF00F0FF00D1FF00B3FFBD00FF0500FF6100FF5100FF
0028FF000AFF000AFF0085FFFF008A00B3FF00B3FF3300FF00D1FF00FFFF00FFF000FFE1
00FFD100FFD100FFC200FFC200FFC200FFB300FFB300FFB300FFB300FFA300FFA300FFA3
00FFA300FFA300FFA300FFA300FFA300FFA300FFA300FFA300FFA300FFA300FFA300FFB3
00FFB300FFC200FFC200FFB300FFB300FFB300FFB300FFC200FFC200FFD100FFE10085FF
00B3FF00A3FF0019FF0094FF00D1FF00F0FF00FFFF00FFF000FFE100FFE100FFE100FFD1
00FFD100FFE100FFD100FFE100FFE100FFE100FFE100FFE100FFF000FFF000FFFF00F0FF
00D1FF0094FF0057FF3300FF0085FF0094FF0094FF0066FF4200FF000AFF8F00FF000AFF
5100FF0028FF0066FF0066FF1400FF0085FF0094FF0094FF0085FF0057FF0019FF00C2FF
00E1FF00FFFF00FFFF00FFF000FFF000FFF000FFF000FFF000FFF000FFF000FFF000FFFF
00FFFF00F0FF00E1FF00C2FF00B3FF0094FF3300FF0028FF7000FF00B3FF00C2FF00C2FF
00B3FF0066FFFF00E6FF00991400FF00D1FF00E1FF00F0FF00F0FF00FFFF00FFF000FFF0
00FFF000FFF000FFF000FFF000FFF000FFF000FFF000FFFF00F0FF00E1FF00C2FF2300FF
0066FF00A3FF00A3FF0085FF0028FF1400FF6100FF00B3FF00D1FF00E1FF00F0FF00FFFF
00FFF000FFE100FFE100FFD100FFD100FFD100FFD100FFC200FFC200FFC200FFC200FFC2
00FFC200FFC200FFE100FFE100FFD100FFD100FFB300FFA300FFA300FFA300FFA300FFA3
00FFA300FFA300FFA300FFA300FF9400FF9400FF9400FF9400FF9400FF9400FF9400FF94
00FF9400FF9400FF9400FF9400FF9400FFA300FFA300FFA300FFB300FFB300FFC200FFC2
00FFD100FFE100FFF000FFFF00F0FF00B3FF0019FF0038FF00B3FF00C2FF0085FF0085FF
0066FF00D1FF00C2FF0066FFBD00FF0075FF0094FF0094FF00B3FF00D1FF00FFE100FFC2
00FFB300FFB300FFA300FFA300FFA300FF9400FF8500FF8500FF8500FF7500FF7500FF75
00FF7500FF7500FF7500FF7500FF7500FF9400FFB300FF8500FF8500FF8500FF8500FFA3
00FFF000FF7500FF5700FF4700FF3800FF3800FF3800FF3800FF2800FF2800FF2800FF28
00FF2800FF2800FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0023FF0023FF0023FF0014FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0042FF00
42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
00FF0A00FF0A00FF0A00FF0A00FF1900FF1900FF1900FF1900FF1900FF1900FF2800FF28
00FF2800FF2800FF2800FF2800FF3800FF3800FF3800FF3800FF4700FF4700FF5700FF57
00FF6600FF6600FF7500FF9400FFB300FFC200FFFF000AFF00B3FF00FFF000A3FF00FFA3
00FF8500FF7500FF6600FF5700FF5700FF5700FF5700FF4700FF4700FF4700FF4700FF47
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF2800FF3800FF2800FF3800FF2800FF3800FF2800FF28
00FF3800FF2800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF4700FF4700FF4700FF4700FF4700FF5700FF5700FF5700FF66
00FF6600FF6600FF7500FF7500FF7500FF8500FF940094FF00FFF000FFF000FFD100F0FF
00B3FF00FFE100FFD100FFD100FFD100FFE100FFFF00D1FFAE00FF0075FF00C2FF0047FF
00C2FF0019FF0075FF0094FFFF006B0094FF00A3FF0066FF00D1FF00F0FF00FFF000FFE1
00FFE100FFD100FFD100FFC200FFC200FFC200FFC200FFB300FFB300FFB300FFA300FFB3
00FFA300FFA300FFA300FFA300FFA300FFA300FFA300FFA300FFA300FFB300FFB300FFB3
00FFD100E1FF00FFD100FFC200FFC200FFC200FFC200FFC200FFC200FFD100FFE100FFFF
00F0FF0094FF7000FF0047FF4200FF00F0FF00FFFF00FFF000FFF000FFE100FFE100FFE1
00FFE100FFE100FFE100FFE100FFE100FFE100FFE100FFE100FFF000FFF000FFFF00F0FF
00D1FF00C2FF00A3FF0047FF0019FF0075FF0075FF0028FFCC00FFFF00F5FF0000FF0000
7000FF000AFF000AFFFF00006100FF0500FF0028FF5100FFFF00D70500FF0047FF00D1FF
00F0FF00F0FF00FFFF00FFF000FFF000FFF000FFF000FFF000FFF000FFFF00FFFF00FFFF
00FFFF00F0FF00E1FF00D1FF00C2FF0019FFFF0000FF00000075FF00A3FF00B3FF00A3FF
DC00FF0019FF4200FF0066FF0057FF00D1FF00E1FF00F0FF00FFFF00FFFF00FFFF00FFF0
00FFF000FFF000FFF000FFF000FFF000FFF000FFFF00D1FF00D1FF00C2FF00B3FF0075FF
0038FF0085FF0075FF0057FFCC00FF000AFF0085FF00B3FF00C2FF00C2FF00C2FF00F0FF
00FFF000FFF000FFE100FFE100FFD100FFD100FFD100FFD100FFC200FFC200FFC200FFC2
00FFD100FFD100FFF00075FF7000FF00FFE100FFC200FFB300FFB300FFA300FFA300FFA3
00FFA300FFA300FFA300FFA300FFA300FFA300FFA300FFA300FF9400FF9400FF9400FF94
00FF9400FF9400FF9400FF9400FFA300FFA300FFA300FFA300FFB300FFB300FFC200FFC2
00FFD100FFE100FFE100FFF000FFFF00E1FF00B3FF0057FF4200FF0094FF0075FFFF0000
0094FF0094FF0066FFFF002E0047FF0500FF00D1FF00C2FF0066FF00FFF000FFD100FFB3
00FFB300FFA300FFA300FF9400FF9400FF8500FF8500FF8500FF7500FF7500FF7500FF75
00FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF6600FF7500FF85
00FFC200FF9400FF5700FF4700FF3800FF3800FF3800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF0A00FF0A00FF1900FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
23FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
00FF0A00FF0A00FF0A00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF2800FF28
00FF2800FF2800FF3800FF3800FF3800FF3800FF3800FF3800FF4700FF4700FF5700FF57
00FF5700FF6600FF8500A3FF00A3FF00FFFF0085FF0019FFFF00000028FF00FFF000FFB3
00FF9400FF7500FF6600FF6600FF5700FF5700FF5700FF4700FF4700FF4700FF4700FF47
00FF4700FF4700FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF4700FF4700FF4700FF4700FF4700FF5700FF5700FF5700FF5700FF57
00FF6600FF6600FF6600FF7500FF7500FF7500FF8500FF9400FFA300FFA300FFB30094FF
0075FF00FFC200FFC200FFC200FFC200FFD100E1FF0019FF0094FF00E1FF00FFFF00FFFF
00E1FF0057FF00B3FF00F0FF00E1FF00F0FF00D1FF0085FF0038FF00D1FF00F0FF00FFF0
00FFE100FFD100FFD100FFD100FFC200FFC200FFC200FFB300FFB300FFB300FFB300FFB3
00FFB300FFA300FFA300FFA300FFA300FFA300FFA300FFB300FFB300FFB300FFC200FFD1
00FFF000A3FF00FFE100FFD100FFD100FFC200FFC200FFC200FFD100FFD100FFE100FFF0
00F0FF00D1FF0094FF0057FF00C2FF00D1FF00F0FF00FFFF00FFF000FFF000FFE100FFE1
00FFE100FFE100FFE100FFE100FFE100FFE100FFE100FFF000FFF000FFFF00FFFF00E1FF
00E1FF00C2FF00A3FF0085FF0028FF0028FF0500FF4200FF9E00FFFF0000FF001EFF0000
FF000FCC00FF0019FF0047FF0066FF5100FF0066FF0500FF0094FF0085FF00A3FF00E1FF
00F0FF00FFFF00FFFF00FFFF00FFFF00FFF000FFF000FFFF00FFFF00FFFF00FFFF00FFFF
00F0FF00F0FF00E1FF00E1FF00D1FF00B3FF000AFF0066FFDC00FF0038FF0094FF0085FF
0019FF000AFF0094FF00A3FF00B3FF00D1FF00E1FF00F0FF00F0FF00FFFF00FFFF00FFFF
00FFFF00FFF000FFF000FFF000FFFF00FFFF00F0FF000AFF0019FF0047FF0019FF0019FF
2300FF8F00FF0019FF5100FFAE00FF0038FF0075FF0094FF0094FF0057FF0057FF00E1FF
00FFFF00FFF000FFE100FFE100FFE100FFD100FFD100FFD100FFD100FFD100FFD100FFD1
00FFE100FFF000F0FFFF004C00FFF000FFD100FFC200FFB300FFB300FFB300FFB300FFB3
00FFB300FFB300F0FF00FFC200FFD100FFF000FFB300FFA300FFA300FF9400FF9400FF94
00FF9400FF9400FF9400FFA300FFA300FFA300FFA300FFA300FFB300FFB300FFC200FFC2
00FFD100FFD100FFE100FFF000FFFF00F0FF00C2FF0019FF1400FF0038FF8F00FF8F00FF
000AFF000AFFFF00000085FF00B3FF00D1FF00F0FF00FFFF0075FF0047FF00FFC200FFB3
00FFB300FFA300FF9400FF9400FF8500FF8500FF8500FF7500FF7500FF7500FF7500FF75
00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF66
00FF7500FF9400FF4700FF4700FF3800FF3800FF3800FF2800FF2800FF2800FF2800FF28
00FF2800FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A05FF0005FF0000FF0A05FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
00FF0A00FF1900FF1900FF1900FF1900FF1900FF1900FF2800FF1900FF2800FF2800FF28
00FF2800FF2800FF2800FF3800FF3800FF3800FF3800FF4700FF4700FF4700FF5700FF57
00FF5700FF6600FF7500FF9400FFC200C2FF00B3FFFF00B80500FF00FFF00038FF0094FF
0028FF00FF8500FF6600FF6600FF5700FF5700FF5700FF5700FF4700FF4700FF4700FF47
00FF4700FF4700FF4700FF4700FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF47
00FF3800FF3800FF4700FF4700FF4700FF4700FF4700FF4700FF5700FF5700FF5700FF57
00FF6600FF6600FF6600FF6600FF7500FF7500FF8500FF8500FF8500FF9400FFA300D1FF
00FFD100FFB300FFB300FFB300FFB300FFD1FF000000FFFF00D1FF00A3FF00FFE100FFE1
00FFFF00FFF000FFF000FFF000FFF000FFFF00F0FF0019FFEB00FF00B3FF0019FF00F0FF
00FFFF00FFE100FFD100FFD100FFD100FFC200FFC200FFC200FFB300FFB300FFB300FFB3
00FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFD100D1FF
0075FF00E1FF00FFF000FFE100FFD100FFD100FFD100FFD100FFD100FFE100FFE100FFF0
00B3FF00B3FF0094FF8F00FF0094FF0028FF00D1FF00F0FF00FFFF00FFF000FFF000FFE1
00FFE100FFE100FFE100FFE100FFE100FFF000FFF000FFF000FFF000FFFF00D1FF00D1FF
00B3FF0094FF0057FF0028FF6100FF0047FF000AFF4200FF8000FFFF0000FF007AFF003D
FF008A1400FF0038FF0075FF0085FF0094FF0094FF0094FF00B3FF00B3FF00C2FF00E1FF
00F0FF00F0FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F0FF
00F0FF00F0FF00E1FF00E1FF00D1FF00C2FF00B3FF0094FF1400FF3300FF0057FFFF00E6
0047FF3300FF00A3FF00C2FF00D1FF00D1FF00E1FF00F0FF00F0FF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F0FF00E1FF0047FF0085FF0028FF0075FF
0066FF000AFFFF0000FF0000FF001EAE00FF0028FF0075FF0038FF0500FF00C2FF00E1FF
00FFFF00FFFF00FFF000FFE100FFE100FFE100FFD100FFD100FFD100FFD100FFE100FFE1
00FFFF0028FF00C2FF0094FF00FFFF00FFE100FFC200FFC200FFB300FFB300FFB300FFB3
00FFC200FFD10085FF00FFFF7000FF00FFD100FFB300FFA300FFA300FFA300FFA300FFA3
00FFA300FFA300FFA300FFA300FFA300FFA300FFA300FFB300FFB300FFB300FFC200FFC2
00FFD100FFD100FFE100FFF000E1FF00C2FF00B3FF00A3FF0038FFFF00C7FF00E6DC00FF
6100FF0028FF0066FF0094FF00D1FF00F0FF00FFFF00FFF000FFE100FFD100FFC200FFB3
00FFA300FFA300FF9400FF9400FF8500FF8500FF7500FF7500FF7500FF7500FF6600FF66
00FF6600FF6600FF6600FF6600FF6600FF6600FF5700FF5700FF5700FF5700FF5700FF57
00FF5700FF5700FF4700FF3800FF3800FF3800FF3800FF2800FF2800FF2800FF2800FF28
00FF2800FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0042FF0042FF0042FF00
00FF1900FF1900FF1900FF1900FF1900FF1900FF2800FF1900FF2800FF2800FF2800FF28
00FF2800FF2800FF3800FF3800FF3800FF3800FF4700FF4700FF4700FF4700FF5700FF57
00FF5700FF6600FF7500FF8500FFF000FFE100FFE10085FF00E1FF00FFD100FFB300FFA3
00FF9400FF8500FF6600FF6600FF6600FF5700FF5700FF5700FF5700FF4700FF4700FF47
00FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF3800FF4700FF3800FF3800FF38
00FF4700FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF4700FF4700FF47
00FF3800FF4700FF4700FF4700FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF5700FF5700FF5700FF5700FF66
00FF6600FF6600FF6600FF6600FF7500FF7500FF7500FF8500FF8500FF8500FF9400FFA3
00FFA300FFA300FFA300FFA300FFB300FFB300FFC200FFC200FFD100FFF000FFD100FFD1
00FFD100FFD100FFD100FFE100FFE100FFF000FFFF00E1FF2300FF0038FF4200FFEB00FF
00E1FF00FFF000FFE100FFE100FFE100FFE100FFD100FFC200FFC200FFC200FFC200FFB3
00FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC200FFC200FFD100FFE1
00E1FFFF007A00F0FF0094FF00FFFF00FFF000FFE100FFE100FFE100FFE100FFF000FFFF
00E1FF0075FF0038FFFF00C7FF00E60038FF0094FF00A3FF00F0FF00FFFF00FFF000FFF0
00FFF000FFF000FFF000FFF000FFF000FFF000FFF000FFF000FFFF00F0FF00D1FF0066FF
000AFFFF002E1400FF0047FF0075FF0075FF0066FF0028FF5100FF9E00FF9E00FF7000FF
FF007AFF00F50038FF0085FF0094FF00A3FF00B3FF00B3FF00C2FF00D1FF00D1FF00E1FF
00F0FF00F0FF00F0FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F0FF
00F0FF00F0FF00E1FF00E1FF00D1FF00C2FF00B3FF00B3FF0094FF0075FF0500FF0066FF
0085FF00A3FF00B3FF00C2FF00D1FF00E1FF00E1FF00F0FF00F0FF00F0FF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00F0FF00F0FF00E1FF00D1FF00B3FF00A3FF0094FF
0085FF0028FF5100FFFF001EFF007AFF008AFF0000DC00FF000AFF0085FF00A3FF00C2FF
00D1FF00D1FF00FFFF00FFF000FFE100FFE100FFE100FFE100FFE100FFE100FFE100FFF0
0085FFDC00FF9E00FF5100FF00A3FF00FFF000FFD100FFC200FFC200FFC200FFC200FFC2
00FFE100FFE100E1FF00E1FF00FFF000FFC200FFB300FFB300FFA300FFA300FFA300FFA3
00FFA300FFA300FFA300FFA300FFA300FFA300FFB300FFB300FFB300FFC200FFC200FFC2
00FFD100FFD100FFE100FFF000C2FF0500FF0075FF0085FF0028FFFF00F5FF00008F00FF
DC00FF0019FF0085FF00B3FF00D1FF00F0FF00FFF000FFE100FFD100FFC200FFB300FFB3
00FFA300FFA300FF9400FF9400FF8500FF8500FF7500FF7500FF7500FF7500FF6600FF66
00FF6600FF6600FF6600FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF47
00FF4700FF4700FF4700FF3800FF3800FF3800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0014FF0014FF0014FF0014FF0005FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
00FF1900FF1900FF1900FF1900FF1900FF2800FF2800FF2800FF2800FF2800FF2800FF38
00FF2800FF3800FF3800FF3800FF3800FF3800FF4700FF4700FF4700FF4700FF5700FF57
00FF6600FF6600FF7500FF8500FF9400FFA300FFD100A3FF00D1FF00FFD100FFA300FF94
00FF8500FF7500FF7500FF6600FF6600FF6600FF5700FF5700FF5700FF5700FF4700FF47
00FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF47
00FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF47
00FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF4700FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF4700FF4700FF4700FF4700FF5700FF4700FF4700FF4700FF5700FF5700FF5700FF57
00FF5700FF6600FF6600FF6600FF6600FF7500FF7500FF7500FF8500FF8500FF8500FF94
00FF9400FF9400FF9400FFA300FFA300FFA300FFB300FFB300FFB300FFC200FFC200FFC2
00FFC200FFC200FFD100FFE100FFE100FFE100F0FF0085FF0075FFFF007A0047FF00C2FF
00F0FF00FFFF00FFF000FFFF00E1FF00F0FF00FFE100FFD100FFD100FFD100FFC200FFC2
00FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC200FFC200FFD100FFE1
00FFFF0085FF0085FF0028FF0075FF00E1FF00FFF000FFE100FFE100FFF000FFF000FFFF
00B3FF0085FF0075FFFF00000047FF0094FF0094FF00D1FF00F0FF00FFFF00FFF000FFF0
00FFF000FFF000FFF000FFF000FFF000FFF000FFF000FFF000FFFF00F0FF00E1FF00C2FF
0057FF0066FF0085FF0094FF0094FF0085FF0047FF0028FF8F00FF000AFF3300FFBD00FF
0019FF0028FF4200FF0085FF00A3FF00A3FF00B3FF00C2FF00C2FF00D1FF00E1FF00E1FF
00E1FF00F0FF00F0FF00F0FF00F0FF00F0FF00FFFF00FFFF00FFFF00F0FF00F0FF00F0FF
00F0FF00F0FF00E1FF00E1FF00D1FF00C2FF00C2FF00B3FF00A3FF0075FF2300FF0066FF
0094FF00B3FF00B3FF00C2FF00D1FF00E1FF00E1FF00E1FF00F0FF00F0FF00F0FF00F0FF
00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00E1FF00E1FF00D1FF00C2FF00B3FF00A3FF
0094FF0047FF000AFF3300FFAE00FFDC00FF0038FF0066FF0066FF7000FFFF00000028FF
FF00000028FF00D1FF00FFF000FFF000FFE100FFE100FFE100FFE100FFE100FFF000FFFF
00F0FF00C2FF0057FF0085FF0094FF00E1FF00FFE100FFD100FFD100FFD100FFD100FFE1
6100FF00F0FF0075FF0094FF00FFE100FFC200FFB300FFB300FFB300FFA300FFA300FFA3
00FFA300FFA300FFA300FFA300FFA300FFB300FFB300FFB300FFC200FFC200FFC200FFD1
00FFD100FFE100FFE100FFF000F0FF00C2FF0066FF2300FF8000FF5100FFCC00FFCC00FF
9E00FFDC00FF0057FF0094FF2300FF00D1FF00FFF000FFE100FFD100FFC200FFC200FFB3
00FFA300FFA300FF9400FF9400FF8500FF8500FF7500FF7500FF7500FF6600FF6600FF66
00FF6600FF6600FF5700FF5700FF5700FF5700FF5700FF5700FF4700FF4700FF4700FF47
00FF4700FF4700FF3800FF3800FF3800FF3800FF2800FF3800FF2800FF2800FF2800FF28
00FF2800FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0023FF0023FF00
23FF0023FF0023FF0014FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0042FF00
42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
00FF1900FF1900FF1900FF1900FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28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00FF1900FF1900FF1900FF2800FF2800FF2800FF2800FF2800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF4700FF4700FF4700FF4700FF4700FF5700FF5700FF57
00FF6600FF6600FF7500FF8500FF8500FFA300C2FF00B3FFFF000000C2FF00FFC200FF94
00FF8500FF7500FF7500FF7500FF6600FF6600FF6600FF6600FF5700FF5700FF5700FF57
00FF5700FF5700FF4700FF4700FF4700FF4700FF5700FF4700FF4700FF5700FF5700FF57
00FF5700FF6600FF6600FF5700FF5700FF4700FF4700FF5700FF4700FF5700FF5700FF75
00FF9400FF7500FFF000FFA300FF6600FF5700FF4700FF4700FF4700FF4700FF4700FF38
00FF3800FF3800FF4700FF3800FF3800FF3800FF3800FF4700FF3800FF4700FF4700FF47
00FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF5700FF5700FF5700FF5700FF57
00FF5700FF6600FF6600FF6600FF6600FF7500FF7500FF7500FF7500FF8500FF8500FF85
00FF8500FF8500FF9400FF9400FF9400FF9400FFA300FFA300FFA300FFB300FFB300FFB3
00FFB300FFC200FFC200FFC200FFD100FFD100FFE100FFFF00E1FF00D1FF0066FF0038FF
0038FF00C2FF00E1FF00D1FFFF00E600E1FF00F0FF0057FF00C2FF00C2FF00FFF000FFE1
00FFC200FFC200FFC200FFC200FFC200FFC200FFC200FFC200FFC200FFD100FFE100FFF0
00D1FF0057FFEB00FF3300FF00A3FF00E1FF00F0FF00FFFF00FFFF00FFFF00FFFF00F0FF
00E1FF00C2FF0094FFEB00FF0085FF00C2FF00D1FF00E1FF00F0FF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFF000FFF000FFF000FFFF00FFFF00FFFF00FFFF00F0FF00F0FF00E1FF
00D1FF00D1FF00C2FF00C2FF00B3FF00A3FF0094FF0085FF0075FF0047FF000AFF8F00FF
000AFF0057FF0075FF0085FF0094FF00B3FF00B3FF00C2FF00C2FF00D1FF00D1FF00E1FF
00E1FF00E1FF00E1FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00E1FF00E1FF
00E1FF00E1FF00E1FF00D1FF00D1FF00C2FF00B3FF0094FF0085FF0066FFDC00FF0057FF
0085FF00A3FF00B3FF00C2FF00D1FF00D1FF00E1FF00E1FF00E1FF00E1FF00E1FF00F0FF
00E1FF00F0FF00E1FF00E1FF00E1FF00E1FF00E1FF00D1FF00D1FF00C2FF00B3FF0094FF
0085FF0066FFAE00FFBD00FF0038FF0066FF0085FF00A3FF00B3FF00B3FF00C2FF00C2FF
00D1FF00F0FF00FFFF00FFFF00FFF000FFF000FFF000FFF000FFF000FFF000FFFF00F0FF
00A3FF00A3FFFF007A00B3FF00E1FF00FFFF00FFF000FFE100FFE100FFE100FFF000F0FF
00C2FF9E00FF000AFFBD00FF00FFFF00FFD100FFC200FFC200FFB300FFB300FFB300FFB3
00FFB300FFB300FFB300FFB300FFB300FFB300FFC200FFC200FFE100FFF000FFE100FFE1
00FFE100FFE100FFF000FFFF00E1FF00B3FF00B3FF0094FF0057FF3300FF4200FF8F00FF
FF006BFF0000000AFF0075FF0085FF0038FF00F0FF00FFE100FFE100FFD100FFC200FFC2
00FFC200FFB300FFA300FFA300FF9400FF8500FF7500FF7500FF6600FF6600FF6600FF66
00FF5700FF5700FF5700FF5700FF5700FF5700FF4700FF5700FF4700FF4700FF4700FF47
00FF3800FF3800FF3800FF3800FF3800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A05FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0042FF0042FF00
42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
00FF1900FF2800FF2800FF2800FF3800FF4700FF3800FF3800FF3800FF3800FF3800FF38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00FF2800FF2800FF2800FF3800FF4700FFA300FF4700FF4700FF3800FF3800FF3800FF38
00FF4700FF4700FF4700FF4700FF4700FF5700FF5700FF5700FF5700FF6600FF6600FF66
00FF7500FF7500FF7500FF8500FF9400FF9400FFB300FFFF0057FF00FFE100FFB300FF94
00FF9400FF8500FF8500FF7500FF7500FF7500FF6600FF7500FF6600FF6600FF6600FF66
00FF6600FF6600FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF6600FF75
0075FFBD00FF00FF8500FF6600FF6600FF5700FF5700FF6600FF6600FF6600FF7500FF85
00FFC200FFC200FF9400FF7500FF6600FF5700FF5700FF4700FF4700FF4700FF4700FF47
00FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF47
00FF4700FF4700FF4700FF4700FF4700FF4700FF5700FF5700FF5700FF5700FF5700FF57
00FF5700FF6600FF6600FF6600FF6600FF6600FF7500FF7500FF7500FF7500FF7500FF85
00FF8500FF8500FF8500FF8500FF9400FF9400FFA300FF9400FFA300FFA300FFA300FFB3
00FFB300FFB300FFB300FFC200FFD100FFD100FFE100FFF000FFFF00E1FF00A3FF0057FF
2300FF0057FF000AFFFF00D70057FF0028FF0066FF00A3FF00B3FF00F0FF00FFE100FFE1
00FFD100FFD100FFC200FFC200FFC200FFD100FFD100FFD100FFD100FFD100FFE100FFF0
00FFFF00F0FF00D1FF00B3FF1400FF4200FF0038FF00A3FF00D1FF00E1FF00E1FF00E1FF
00C2FF0057FF0500FFFA00FF5100FF00A3FF00D1FF00E1FF00F0FF00F0FF00F0FF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F0FF00F0FF00F0FF00E1FF
00E1FF00D1FF00D1FF00C2FF00B3FF00A3FF0085FF0075FF0066FF0057FF0019FFFF00E6
0500FF0038FF0057FF0028FF0038FF0094FF00B3FF00C2FF00C2FF00D1FF00D1FF00D1FF
00D1FF00E1FF00E1FF00E1FF00E1FF00E1FF00E1FF00E1FF00D1FF00D1FF00B3FF00C2FF
00D1FF00D1FF00C2FF00D1FF00C2FF00B3FF00A3FF0085FF000AFF0500FFFF008A5100FF
5100FF0057FF0075FF00A3FF00C2FF00C2FF00C2FF00D1FF00D1FF00D1FF00D1FF00D1FF
00D1FF00C2FF0094FF0057FF00C2FF00D1FF00D1FF00C2FF00C2FF00B3FF00A3FF0075FF
CC00FF0019FF5100FF3300FF0038FF0057FF0075FF00A3FF00B3FF00C2FF00D1FF00E1FF
00E1FF00F0FF00F0FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00E1FF
00B3FF0094FF1400FF0085FF00B3FF00F0FF00FFFF00FFFF00FFFF00D1FFFF00D700A3FF
0028FF6100FF00E1FF00E1FF00F0FF00FFF000FFD100FFC200FFC200FFB300FFB300FFB3
00FFB300FFB300FFB300FFC200FFC200FFC200FFD100FFD100FFFFFF00000094FF00F0FF
00FFFF00FFFF00FFFF00F0FF00E1FF00D1FF00B3FF0019FF0066FF0028FFAE00FFFF00E6
FF00F58000FFFF00B80057FF0075FF00D1FF00F0FF00FFFF00FFF000FFFF000AFF00D1FF
0094FF0057FF0085FF00FFFF00FFC200FF8500FF7500FF7500FF6600FF6600FF6600FF57
00FF5700FF5700FF5700FF5700FF5700FF4700FF4700FF4700FF4700FF4700FF4700FF38
00FF3800FF3800FF3800FF3800FF3800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF0A
00FF0A00FF0A00FF1900FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A05FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0014FF0014FF0014FF0014FF0014FF0005FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
00FF2800FF2800FF3800FF4700FFC200FFA300FF5700FF5700FF4700FF4700FF4700FF47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00FF2800FF3800FF3800FF5700FF850019FF00FF7500FF5700FF5700FF4700FF4700FF47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00FF3800FF3800FF4700FF6600FFE1FF000000FFD100FFB300FF5700FF5700FF5700FF57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00FF4700FF5700FF5700FF6600FFB3FF000000FFB300FF8500FF6600FF5700FF5700FF57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00FF7500FF6600FF6600FF7500FFC2FF00E600FFB300FF8500FF7500FF6600FF6600FF66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00D1FF00FFFF00FF8500FF8500FFC20085FF00B3FF00FF8500FF7500FF7500FF6600FF66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00D1FF00A3FF0085FF00FFB300C2FF00C2FF00FFB300FF9400FF8500FF7500FF7500FF75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00FF948F00FF00C2FF00D1FF00A3FF00FFD100FFA300FF9400FF8500FF8500FF8500FF94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00FF8500FFA300FFB300FFE10038FF00FFD100FFB300FFA300FF9400FFA300FFC200FFD1
00A3FF00FFC200FFC20094FF00F0FF00C2FF5100FF1400FF0500FF00B3FF00FFF00085FF
00FFB300FFA300FFA300C2FF00FF8500FF8500FF7500FF7500FF7500FF7500FF8500FF85
00FF9400FF9400FFA300FFB300FFD100E1FF0066FF2300FF1400FF00C2FF00F0FF00B3FF
00FFFF00FFC200FFC200FFE100FFD100FFC200A3FF00FFB300FFA300FFA300FFA300FFB3
00FFB300FFD100FFF000F0FF00A3FF5100FF00C2FF0047FF00FFE100FFD100FFD100FFA3
00FF9400FF8500FF8500FF7500FF7500FF6600FF6600FF6600FF6600FF6600FF5700FF66
00FF5700FF5700FF5700FF5700FF5700FF6600FF5700FF5700FF5700FF5700FF5700FF57
00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF66
00FF6600FF6600FF6600FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF85
00FF8500FF8500FF8500FF8500FF9400FF9400FF9400FF9400FFA300FFA300FFA300FFA3
00FFB300FFB300FFB300FFB300FFC200FFC200FFD100FFE100FFE100FFF000FFF000FFFF
00F0FF00E1FF00C2FF00B3FF0075FF4200FF0019FFFF008A00B3FF00B3FF0075FF1400FF
00B3FF00C2FF0028FF0038FF00D1FF00F0FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00F0FF00F0FF00F0FF00E1FF00E1FF00D1FF00D1FF00C2FF00B3FF0094FF0075FF
0057FF7000FF0038FF0028FF0066FF0094FF00A3FF00B3FF00C2FF00C2FF00C2FF00C2FF
00C2FF00A3FF0075FF00B3FF00B3FF00B3FF00A3FF2300FFFF005C0019FF0057FF0094FF
00A3FF00A3FF00A3FF00A3FF00A3FF0094FF0094FF0066FF0057FF0047FF0047FF000AFF
9E00FF5100FF000AFF0038FF2300FF0047FF0066FF0075FF0085FF0085FF0094FF0094FF
0094FF0085FF0075FF0057FF000AFFFF00F54200FF0028FF0038FF2300FF0500FF000AFF
0057FF0066FF0075FF0075FF0075FF0066FF0066FF0057FF0038FF000AFF2300FFFF0000
3300FF4200FF0038FF0047FF0057FF0057FF0057FF0057FF0047FF0047FF0028FF5100FF
8000FF1400FF0038FF0047FF0057FF0057FF0057FF0057FF0057FF0047FF0028FF000AFF
4200FFFA00FF6100FF000AFF1400FFFF00000066FF0075FF0085FF0085FF0085FF0066FF
2300FF1400FF0075FF0075FF2300FF8000FF0075FF0094FF00A3FF00A3FF00A3FF0094FF
0500FF0019FFFF0000000AFF0057FF00A3FF00C2FF00C2FF00D1FF00E1FF00F0FF00F0FF
00FFFF00FFFF00FFFF00FFF000FFF000FFF000FFF000FFF000FFF000FFF000FFF000FFF0
00FFF000FFFF00FFFF00FFFF00FFFF00FFFF00F0FF00D1FF00C2FF00B3FF0094FF0057FF
3300FFFF00E6FF00000019FF0057FF00B3FF00D1FF00E1FF00F0FF00FFF000FFE100FFE1
00FFD100FFD100FFD100FFC200FFC200FFD100FFD100E1FF00FFFFFF00F500F0FF0019FF
0057FF6100FF00FFFF00FFC200FFB300FFC200FF8500FF7500FF6600FF6600FF6600FF57
00FF5700FF5700FF5700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A05FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0042FF0042FF00
00FF8500FF9400FFB300FFD10094FF00FFFF00FFE100FFC200FFC200FFB300FFC200D1FF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00FF9400FFA300FFC200FFFF00A3FF00B3FF00B3FF0075FF00FFF000FFD100FFFF00E1FF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00FFB300FFB30028FF0066FF6100FFFF000F0057FF00D1FF00FFFF00FFFF0019FF0019FF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00FFE100FFD100FFF000C2FF0019FF5100FF000AFF0085FF00B3FF0047FF00B3FF00C2FF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00F0FF00B3FFFF008ABD00FF00B3FF0075FF2300FF0038FFFF00A800C2FF00FFF000FFD1
00FFD10500FF00FFC200FFA300FF8500FF8500FF9400FFB3BD00FF00FFA300FF8500FF85
00FF7500FF6600FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF66
00FF750094FF00B3FF00FFA300FF9400FFB31400FF00FFE100FFA300FFA300FFB300FFB3
00FFD100FFF000D1FFFF006B0047FF8000FF5100FF00B3FF00D1FF00C2FF00B3FFFF00B8
BD00FF0066FF5100FF00C2FF00F0FF00FFF000FFD100FFC200FFB300FFA300FFA300FF94
00FF9400FF8500FF8500FF8500FF8500FF7500FF7500FF7500FF7500FF7500FF7500FF75
00FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF85
00FFC200FFA300E1FF00FFC200FF9400FF8500FF7500FF7500FF7500FF7500FF7500FF75
00FF7500FF7500FF7500FF7500FF7500FF8500FF7500FF8500FF8500FF8500FF8500FF85
00FF8500FF9400FF9400FFA300FFB300D1FF00FFC200FFC200FFB300FFB300FFB300FFC2
00FFC200FFC200FFC200FFC200FFC200FFD100FFD100FFD100FFE100FFE100FFF000F0FF
00B3FF0085FFAE00FF5100FF0066FF0038FF6100FFFF0000FF00E6AE00FFDC00FF0066FF
0094FF00B3FF00C2FF00C2FF00D1FF00D1FF00E1FF00E1FF00E1FF00D1FF00E1FF00E1FF
00D1FF00C2FF0085FF0066FF00A3FF00A3FF00B3FF00B3FF00B3FF00A3FF0094FF0085FF
0066FF0038FF3300FF000AFF0047FF0047FF0075FF0085FF0094FF0094FF0094FF0094FF
0085FF0075FF0019FF2300FF0500FF0038FF0047FF0019FFFF00F50500FF0057FF0066FF
0075FF0075FF0075FF0075FF0075FF0075FF0066FF0047FF0038FF0028FF0019FF0500FF
3300FFDC00FF4200FF1400FF0019FF0028FF0038FF0047FF0057FF0057FF0066FF0066FF
0066FF0057FF0057FF0047FF0047FF0038FF0028FF2300FF8F00FFEB00FF3300FF000AFF
0028FF0028FF0500FFEB00FF1400FF4200FF5100FF1400FF0500FF1400FF8000FFFF00D7
FA00FF7000FF3300FF2300FF2300FF3300FF8000FFFF007A6100FFBD00FF9E00FF9E00FF
EB00FF7000FFAE00FF8F00FF8F00FFFA00FF4200FF2300FF1400FF4200FFBD00FFFF006B
8000FFFF0099000AFF0019FF0019FF000AFF1400FF0028FF000AFF1400FF0028FF0038FF
000AFF7000FFFF00002300FF0038FF0047FF0057FF0057FF0057FF0057FF0038FF0500FF
CC00FFAE00FF2300FF0057FF0085FF00A3FF00A3FF00B3FF00A3FF0085FF00C2FF00D1FF
00E1FF00E1FF00E1FF00F0FF00F0FF00F0FF00F0FF00E1FF00D1FF0075FF8F00FF0047FF
0085FFFF00F50094FF00B3FF00A3FF0085FF0057FF0047FF6100FF0066FF000AFF0057FF
0085FF00D1FF00E1FF00D1FF00A3FFFF00D70094FF00F0FF00FFF000FFE100FFD100FFC2
00FFC200FFB300FFB300FFB300FFB300FFA300FFA300FFA300FFA300FFA300FFA300FFA3
00FF9400FF9400FF9400FF8500FF8500FF8500FF7500FF7500FF6600FF6600FF6600FF57
00FF5700FF5700FF5700FF5700FF4700FF4700FF5700FF4700FF4700FF4700FF4700FF47
00FF4700FF4700FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A05FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0042FF0042FF0042FF0042FF0042FF0042FF00
4200FF9E00FF0075FF00FFFF00F0FF00C2FF0019FFAE00FF6100FF00B3FF00FFE100FFB3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000AFF00FFFF00FFE100FFD100E1FF00B3FF00C2FF0057FF00D1FF0066FF00FFC200FFA3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0019FF00E1FF00FFB300FFB300FFE100FFF000FFF000C2FF00F0FF00FFD100FFB300FF94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00FFC200FFC200FF9400FF9400FFA300FFB300FFC20066FF00E1FF00FFC200FFA300FF94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00FF8500FF8500FF8500FF8500FF9400FFA300FFC200FFF000B3FF00FFFF00FFC200FFA3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00FF7500FF7500FF7500FF8500FF9400FFA300FFFF8F00FF00FFD10085FF0057FF00FFE1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00FF6600FF6600FF6600FF7500FF8500FFD100A3FF00FFFF00FFA300FFB300F0FF8F00FF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00FF5700FF6600FF6600FF7500FF850028FF3300FF00A3FF00FF8500FF8500FF9400FFFF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00FF5700FF5700FF5700FF7500FF8500FFC200E1FF00FFA300FF7500FF6600FF7500FF85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00FF4700FF5700FF5700FF7500C2FF00FFFFAE00FF00FFC200FF6600FF5700FF5700FF57
00FF7500FF7500FF5700FF4700FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF4700FF4700FF4700FF4700FF4700FF5700FF5700FF6600FF6600FF7500FF7500FF85
00FF9400FFA300FFA300FFB300FFC200FFC200FFD100FFF00019FF0028FF0085FF00D1FF
00D1FF0057FF00A3FF00F0FF00FFFF00F0FF0019FF0075FF0075FF0066FF8F00FFFF0000
000AFF0085FF00F0FF00FFF000FFE100FFD100FFC200FFC200FFC200FFC200FFC200FFB3
00FFC200FFC200FFD100FFE100FFF00085FFFF009900E1FF00F0FF0085FFFF005C00A3FF
00F0FF0066FF00FFE100FFC200FFB300FFB300FFA300FFA300FFA300FFA300FF9400FF94
00FF9400FF9400FF9400FF9400FF9400FF9400FF9400FFA300FFA300FFA300FFB300FFD1
00FFC200FFC200FFC200FFC200FFD100FFD100FFE100FFF000F0FF9E00FF0094FF6100FF
0094FF00D1FF00E1FF00F0FF00F0FF00FFFF00FFFF00FFFF00FFFF00F0FF00F0FF00F0FF
00E1FF00E1FF00D1FF00D1FF00C2FF00C2FF00B3FF00A3FF0094FF0085FF0066FF0047FF
0019FFFF00008000FF7000FF6100FF0500FF0047FF0066FF0066FF0066FF0057FF0047FF
0047FF0028FF1400FF9E00FF3300FF000AFF0019FF0500FFFF00003300FF9E00FF1400FF
0500FF1400FFBD00FFAE00FFFF00B87000FF4200FF2300FF2300FF3300FF5100FFFF0000
5100FF3300FF2300FF2300FF3300FF7000FFFF00B88F00FF5100FF3300FF2300FF1400FF
2300FF3300FF6100FFFF00A8AE00FF4200FF2300FF2300FF1400FF1400FF2300FF3300FF
5100FF8000FFEB00FFFF00C78F00FF6100FF4200FF3300FF3300FF3300FF8F00FF6100FF
6100FF7000FFAE00FFFF0000FF0099AE00FFBD00FFEB00FFFF003DFF00D7FF0000FF006B
FF0000FF002EFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF000FFF0000FF0000FF007AFF00B8FF00D7
FF008AFF0000FF001EFF00E6FF00C7FF0099FF00C7FF00C7FF004CFF004CFF003DFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF001E
FF0000FF0000FF0000FF0000FF0000BD00FFFF00D72300FF4200FF2300FF0038FF0057FF
0066FF0066FF4200FF0057FFCC00FF0057FF0057FF000AFF000AFFBD00FFFF00002300FF
0038FF0066FF0094FF00A3FF00A3FF00A3FF0094FF000AFFBD00FF0075FF00C2FF00F0FF
00FFF000FFF000FFE100FFE100FFD100FFD100FFD100FFC200FFC200FFC200FFB300FFB3
00FFB300FFB300FFA300FFA300FFA300FF9400FF9400FF9400FF9400FF8500FF8500FF85
00FF8500FF8500FF8500FF7500FF7500FF7500FF7500FF7500FF6600FF6600FF7500FF66
00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF66
00FF6600FF6600FF757000FF00FFB300FFB300FFB3000AFF00FFB300FF9400FF9400FFFF
00FFFF0057FF00FFC200FFD100FFF07000FF00A3FF00FFC20500FF00FF3800FF2800FF28
00FF2800FF1900FF1900FF1900FF1900FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A05FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
00FF4700FF4700FF4700FF5700FF9400FFE100FFC200FF9400FF5700FF4700FF4700FF47
00FF5700FF4700FF4700FF3800FF3800FF3800FF3800FF3800FF2800FF3800FF2800FF38
00FF2800FF3800FF2800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF4700FF4700FF4700FF4700FF5700FF5700FF6600FF7500FF8500FF9400FF94
00FFA300FFC200FFE100FFC200FFE100FFE100FFE100FFFF0085FF0047FF00F0FF00FFFF
00E1FF00A3FF00C2FF00F0FF00FFF000FFF000FFFF00B3FF00D1FF00A3FF0038FFFF0000
0500FF0094FF00D1FF00D1FF00FFFF00FFE100FFE100FFE100FFD100FFE100D1FF00FFD1
00FFD100FFD100FFE100FFE100FFF000F0FFBD00FF00A3FF0085FF0066FF0500FF00F0FF
00FFF000FFE100FFD100FFC200FFB300FFB300FFA300FFA300FFA300FFA300FFA300FF94
00FFA300FF9400FF9400FFA300FF9400FFA300FFA300FFA300FFA300FFB300FFC28F00FF
00FFD100FFD100FFD100FFD100FFD100FFE100FFE100FFF000FFFF00E1FF00B3FF0057FF
0085FFBD00FF00D1FF00E1FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00E1FF
00D1FF00A3FF00C2FF00C2FF00B3FF00B3FF00B3FF00A3FF0094FF0085FFAE00FFFF003D
000AFFFF00F5FF00008000FF000AFF0028FF0047FF0057FF0057FF0057FF0047FFFF006B
0019FF0019FF0500FF6100FFFF00B8FA00FF1400FF1400FF4200FFCC00FF5100FF2300FF
2300FF2300FF4200FFFF0099FF004CAE00FF5100FF4200FF5100FF5100FF7000FFFF003D
8000FF5100FF5100FFBD00FF5100FF9E00FFFF00B8FA00FF6100FF4200FF3300FF3300FF
3300FF4200FF7000FFFF00006100FF4200FF3300FF2300FF2300FF2300FF3300FF4200FF
5100FFFF006BFA00FFFF0000FA00FFBD00FF5100FF5100FF6100FF6100FF8000FFCC00FF
8000FF8000FFFF0000FF005CFF00B8DC00FFFF00E6FF00D7FF007AFF003DFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF001EFF006BFF006BFF006B
FF0099FF0000FF0099FF00C7FF00A8FF001EFF007AFF002EFF003DFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF001EFF00C7CC00FF6100FF9E00FF4200FFFF00B80038FF
0057FF0057FF0028FF5100FFAE00FF0038FF0028FF2300FFAE00FF000AFF0500FF1400FF
7000FF9E00FF0094FF00B3FF00B3FF00B3FF00B3FF00A3FF0075FFFF00A84200FF00C2FF
00FFFF00FFF000FFE100FFE100FFD100FFD100FFD100FFC200FFC200FFC200FFC200FFB3
00FFB300FFB300FFA300FFA300FFA300FFA300FF9400FF9400FF9400FF9400FF8500FF85
00FF8500FF8500FF8500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF6600FF66
00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF66
00FF6600FF7500FF8500FFA30066FF00F0FF00FFE10028FF00FFC200FFB300FFF000FFF0
5100FF00FFD100FF9400FF8500FF8500FFE100FF6600FF5700FF4700FF3800FF2800FF28
00FF1900FF1900FF1900FF1900FF1900FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
05FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0023FF00
23FF0023FF0023FF0014FF0014FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
00FF3800FF3800FF4700FF5700FF6600FFB300FF9400FF5700FF4700FF4700FF3800FF38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00FF3800FF3800FF3800FF4700FF6600F0FF00C2FF00FF4700FF3800FF3800FF3800FF38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00FF3800FF3800FF3800FF3800FFB300FF5700FF4700FF3800FF3800FF3800FF2800FF28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00FF2800FF2800FF2800FF3800FF3800FF3800FF3800FF2800FF2800FF2800FF2800FF28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00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28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00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF1900FF1900FF28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00FF2800FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19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00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19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00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19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00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19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00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF0A00FF1900FF0A00FF0A00FF1900FF0A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00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF0A00FF0A00FF0A00FF0A
00FF1900FF0A00FF0A00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF2800FF1900FF1900FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF3800FF3800FF3800FF3800FF3800FF3800FF47
00FF4700FF4700FF5700FF6600FF940094FF00C2FF00FF9400FF8500FF7500FF7500FF75
00FF6600FF6600FF6600FF6600FF7500FF7500FF7500FF8500FF7500FF8500FF8500FF94
00FF9400FF9400FFA300FFB300FFB300FFC200FFC200FFD100FFE100FFF000E1FFFF0000
0085FF0038FFEB00FFFF0000DC00FFFF006B0500FF0047FF0066FF0075FF00B3FF00C2FF
00C2FF00D1FF00E1FF00E1FF00E1FF0075FF000AFF00C2FF00A3FF0038FF00A3FF0500FF
00FFFF00FFE100FFE100FFE100FFD100FFD100FFD100FFE100FFE100FFE100FFE100FFE1
00FFF000FFF000FFF000FFFF00FFFF00F0FF00F0FF00E1FF00E1FF00D1FF00C2FF00C2FF
00A3FF0094FF0075FF0057FF0500FFAE00FF5100FF0019FF0047FF0057FF0057FF0047FF
BD00FF0019FF000AFF9E00FFFF004CCC00FF7000FF1400FF1400FF3300FF5100FFFF007A
8000FF5100FF5100FF8F00FF8000FFFF002EAE00FFAE00FFBD00FFFF0000FF00C7FF00B8
FF0000FF001EFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF001EFF001EFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00D7DC00FFAE00FF8F00FF8000FF6100FF5100FF4200FF4200FF7000FF
FF000F2300FF0019FF0038FF0047FF0057FF0066FF0066FF0066FF0075FF0075FF0066FF
0038FF6100FF0028FF0066FF00A3FF00C2FF00C2FF00D1FF00D1FF00D1FF00E1FF00E1FF
00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00E1FF00C2FF00A3FF0038FF0038FF000AFF
00E1FF00FFFF00FFF000FFE100FFE100FFD100FFD100FFD100FFE100FFF000FFE100F0FF
00F0FF3300FF00C2FF00FFB300FFA300FF9400FF9400FF9400FF9400FF9400FF9400FF85
00FF8500FF9400FF9400FF9400FF9400FF9400FF9400FFA300FFB300FFC200FFD10094FF
00E1FF0075FF0085FF00B3FF00A3FF00FFFF00FFD100FFA300FF8500FF7500FF7500FF66
00FF6600FF5700FF5700FF4700FF4700FF4700FF4700FF3800FF3800FF3800FF3800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A05FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0023FF00
23FF0023FF0014FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A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00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A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00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A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00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A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05FF0000FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A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05FF0005FF0000FF0A05FF0005FF0000FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A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05FF0005FF0005FF0005FF0005FF0000FF0A05FF0005FF0000FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF4700FF4700FF4700FF4700FF4700FF47
00FF4700FF5700FF5700FF5700FF5700FF6600FF6600FF6600FF750066FF0075FF00FFE1
7000FF00E1FF0057FF00FFF000FFF000FFF000FFE100FFF000FFFF00E1FF0038FF00E1FF
00FFFF00FFF000FFF000FFFF00FFF000FFF000FFF000FFF000FFFF00FFFF00F0FF00E1FF
00D1FF00A3FF1400FF4200FFFF007AFF00A8FF003D0019FF2300FF0075FF0028FFFF00D7
0075FF00D1FF00E1FF00D1FF00C2FF0500FF0094FF00B3FF0019FF0075FF00B3FF00D1FF
00E1FF00E1FF00E1FF00E1FF00E1FF00D1FF0500FF00A3FF0094FF0085FF0066FF4200FF
0038FF0047FF0047FF1400FF0500FFDC00FF3300FF4200FFFF00A89E00FFFA00FFFF00B8
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF001EFF0000FF003DFF0000FF003DFF0000FF004CFF000FFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF003D
FF005CFF008AFF00C7FF00E6FA00FFCC00FFAE00FF8F00FF8000FF8000FF7000FF3300FF
2300FF1400FF0500FF0500FF0500FF000AFF000AFF1400FFFF00005100FFFF005C4200FF
000AFF9E00FF0019FF3300FF0047FF0047FF0047FF0085FF0094FF00A3FF00B3FF00B3FF
00B3FF00B3FF00B3FF00A3FF1400FF0094FF0094FF5100FFFF00000038FF8000FF8F00FF
4200FF1400FFDC00FF0075FF0094FF00A3FF000AFF00D1FF00F0FF00FFF000FFF000FFE1
00FFD100FFC200FFC200FFB300FFB300FFB300FFB300FFB300FFA300FFA300FFA300FFA3
00FFA300FFA300FFB300FFB300FFB300FFC200FFC200FFD100FFF000F0FFDC00FF1400FF
00FFFF0075FF0047FF00FFB300FFA300FF9400FF8500FF8500FF8500FF7500FF7500FF75
00FF6600FF6600FF6600FF6600FF6600FF6600FF5700FF5700FF5700FF6600FF7500D1FF
00FF7500FF7500FFD100FFB300FF7500FF5700FF5700FF5700FF6600FF858F00FF00FF85
00FF5700FF4700FF3800FF3800FF2800FF2800FF1900FF1900FF1900FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A05FF0000FF0A05FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0014FF0014FF00
14FF0005FF0014FF0014FF0014FF0005FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0023FF0014FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
05FF0005FF0005FF0005FF0005FF0000FF0A05FF0005FF0005FF0000FF0A00FF0A00FF0A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05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0000FF0A05FF0005FF00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05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0000FF0A05FF0005FF0005FF00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05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00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05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0000FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF2800FF1900FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF3800FF3800FF3800FF3800FF3800FF3800FF4700FF4700FF4700FF47
00FF4700FF4700FF4700FF4700FF5700FF5700FF5700FF5700FF6600FF6600FF6600FF75
00FF7500FF7500FF8500FF8500FF9400FFA300FFC25100FF00B3FF0094FF00FFFF00FFE1
00FFC200FFC200FFC200FFC200FFC200FFC200FFC200FFD100FFF000D1FF00A3FF00B3FF
00F0FF00E1FFFF00000038FF00D1FF00E1FF00E1FF00D1FF00D1FF000AFF00B3FF00B3FF
000AFF0028FF1400FF2300FFEB00FFFF0000FF00A88000FF9E00FF0075FF0094FF0075FF
0085FF0094FF0047FF00A3FF00A3FF00A3FF00A3FF0094FF0085FF0075FF0066FF0038FF
000AFF000AFF2300FF8000FFFA00FFFF000FFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF003DFF005CFF0000FF00E6DC00FFBD00FF9E00FF8F00FF
8000FF8000FFFF00F5FF00E6FF0000FF00F5DC00FFFF005C4200FF0500FF0019FF0028FF
0038FF0047FF0047FF0057FF0066FF0066FF0075FF0075FF0075FF0075FF0057FF0057FF
FF00B80047FF0047FF2300FFBD00FF0019FF0038FF000AFF0085FF00B3FF00C2FF00D1FF
00D1FF00E1FF00E1FF00F0FF00F0FF00FFFF00FFFF00FFF000FFF000FFE100FFE100FFE1
00FFD100FFD100FFD100FFD100FFD100FFD100FFD100FFD100FFE100FFE100FFE10094FF
00C2FF00FFF000FFE100FFE100FFE100FFF000FFF000FFFF00F0FF0047FF00D1FF00FFF0
00FFE100FFD100FFC200FFC200FFB300FFB300FFB300FFB300FFA300FFA300FFA300FFA3
00FFA300FFC20047FF00FFD100F0FF00FFF000FFB300FFA300FFA300FFB300FFD100FFC2
00FFF000A3FFAE00FF0038FF0028FF00A3FF00FFD100FFB300C2FF00FF7500FF6600FF57
00FF5700FF5700FF4700FF3800FF3800FF2800FF2800FF1900FF1900FF1900FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A05FF0005FF0000FF0A05FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0023FF00
23FF0014FF0023FF0023FF0023FF0023FF0023FF0023FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00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05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00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05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0000FF0A05FF0005FF0000FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF4700FF4700FF47
00FF4700FF4700FF4700FF5700FF5700FF5700FF5700FF5700FF5700FF6600FF6600FF66
00FF6600FF7500FF7500FF8500FFFF00A3FF0500FF00FFF000FFD100E1FF00FFB300FFB3
00FFA300FFB300FFA300FFA300FFB300FFB300FFB300FFB300FFC200FFC200FFC200FFD1
00FFE10066FF0057FF00FFFF00FFF000FFF000FFF000FFFF00FFFF00F0FF00E1FF00D1FF
00B3FF00A3FF0085FF0057FF5100FFFF00C75100FF1400FF2300FFFF0000FA00FFCC00FF
6100FF0038FF0057FF0066FF0075FF1400FF0047FF1400FF0047FF0057FF0047FF0019FF
2300FF3300FF7000FFFF00E6FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00B8FF00E6EB00FFFF00F5
FF006BFF0000EB00FF9E00FF8F00FF6100FF4200FF3300FF2300FF1400FF0500FF0500FF
2300FFFF006B2300FF0028FF0028FFEB00FF0038FF0047FF0047FF0047FF0038FF0019FF
7000FFFF00009E00FF000AFF0038FF0066FF0085FF0094FF00A3FF00B3FF00C2FF00D1FF
00D1FF00E1FF00E1FF00F0FF00F0FF00FFFF00FFFF00FFFF00FFF000FFF000FFF000FFF0
00FFF000FFE100FFE100FFE100FFE100FFE100FFF000FFF000F0FF0085FF0019FFFF00C7
00B3FF00D1FF00D1FF00A3FF0075FF1400FF0057FF00C2FF00E1FF00F0FF00D1FFEB00FF
BD00FF0085FF0066FF00D1FF00FFFF00F0FF00F0FF00B3FF00C2FF00FFFF00FFE100FFF0
0019FF00FFFF00F0FF0094FF000AFF00A3FF00C2FF0075FF0085FFFF00992300FF00D1FF
00FFFF0057FF00D1FF0094FF00FFE100FFC200FFA300FF7500FF6600FF5700FF4700FF47
00FF3800FF3800FF3800FF2800FF2800FF2800FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A05FF00
05FF0000FF0A05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0000FF0A05FF0000FF0A00FF0A00FF0A
00FF0A00FF1900FF1900FF1900FF1900FF1900FF1900FF2800FF3800FF2800FF0A00FF0A
05FF0005FF0005FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0000FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF4700FF47
00FF4700FF4700FF4700FF4700FF4700FF5700FF5700FF5700FF5700FF5700FF6600FF66
00FF6600FF6600FF7500FF8500FF8500FFA300FFC200FFC200FFB300FFB300FFA300FFA3
00FFA300FFA300FFA300FFA300FFA300FFA300FFB300FFB300FFB300FFC200FFC200FFC2
00FFD100FFD100FFE100FFE100FFE100FFE100FFF000FFF000FFFF00F0FF00E1FF00A3FF
0085FF0075FF0066FF0019FF0019FF0038FF000AFF0047FF0028FF2300FF1400FFFF0000
FF008A000AFF4200FF000AFF0047FF0019FF2300FF000AFF0038FF0038FF0038FF0028FF
000AFF2300FF7000FFEB00FFFF0000FF002EFF005CFF0000FF003DFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00C7FF00C7FF007A
FF006BFF00D7FA00FF8F00FF7000FF6100FF4200FF3300FF2300FF1400FF1400FF1400FF
FF003DBD00FF1400FF000AFF3300FF6100FF0028FF0038FF0038FF0038FF0500FF0500FF
4200FFFF00F5DC00FF4200FF2300FF0066FF0085FF0094FF00A3FF00B3FF00C2FF00C2FF
00D1FF00D1FF00E1FF00F0FF00F0FF00F0FF00F0FF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFF000FFF000FFFF00FFFF00FFFF00FFF000FFF000FFFF00F0FF00D1FF00B3FF0500FF
0075FF0057FF0085FF5100FF0047FF0094FF0500FF00E1FF00FFFF00FFF000FFFF00E1FF
00D1FF0066FFBD00FFCC00FF0057FF0075FF00A3FF0019FF1400FF00C2FF0094FF00D1FF
0075FF00C2FF00B3FF0028FF5100FF0047FF0057FF0075FF00FFFF00F0FFEB00FF00FFFF
00FFD100FFD100FFE100F0FF0085FFFF006B0085FF00FFB300FF6600FF5700FF4700FF47
00FF3800FF3800FF2800FF2800FF2800FF2800FF2800FF1900FF1900FF1900FF1900FF19
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A05FF0005FF0005FF0000FF0A05FF0005FF0005FF0005FF0005FF0005FF00
00FF0A05FF0005FF0005FF0005FF0000FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF1900FF3800FF5700FF2800FF2800FF2800FF3800FF470500FF00FFE100FF2800FF0A
05FF0005FF0005FF0005FF0005FF0014FF0005FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0000FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF0A00FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF4700FF4700FF4700FF47
00FF4700FF4700FF4700FF4700FF5700FF5700FF5700FF5700FF5700FF5700FF6600FF66
00FF6600FF6600FF7500FF7500FF8500FF8500FF9400FFA300FF9400FF9400FF9400FFA3
00FF9400FFA300FFA300FFA300FFA300FFA300FFA300FFB300FFB300FFB300FFB300FFC2
00FFC200FFD100FFD100FFD100FFE100FFE100FFE100FFF000FFFF00F0FF00C2FF8000FF
1400FF0057FF0057FF0019FF0066FF0075FF0075FF0085FF0075FF0057FF0028FFFF003D
6100FFBD00FFFF00002300FF3300FF0500FFEB00FF0500FF0019FF000AFF0500FF000AFF
9E00FF3300FF6100FFAE00FFFF00C7FF00D7FF00A8FF008AFF0000FF0000FF003DFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF005CFF004CFF0000FF00A8
FF00B8DC00FFFA00FF9E00FF7000FF7000FF7000FF4200FF3300FF2300FF2300FF2300FF
6100FFBD00FF3300FF4200FFEB00FF1400FF0019FF0028FF0028FF0019FF3300FF3300FF
FF00005100FF2300FF0500FFFF006B000AFF0085FF0094FF00A3FF00A3FF00B3FF00B3FF
00B3FF00D1FF00D1FF00E1FF00F0FF00F0FF00F0FF00F0FF00FFFF00FFFF00FFFF00F0FF
00F0FF00F0FF00E1FF00A3FF00F0FF00FFFF00FFFF00F0FF00E1FF00D1FF0075FF0038FF
CC00FF3300FF4200FF0038FF00C2FF00E1FF0057FF00FFF000FFE100FFE100FFE100FFF0
00F0FF0038FF00A3FF00E1FF00A3FF0094FF0057FFFF00000075FF0066FF000AFF0047FF
FF00C70019FF0038FFFF00A80028FF0066FF00FFFF00E1FF00FFD100FFD10066FF00FFF0
00FFB300FFB300FFC2BD00FF00FFD100FFA300FFB300FF8500FF6600FF4700FF4700FF38
00FF3800FF3800FF2800FF2800FF2800FF2800FF1900FF1900FF1900FF1900FF1900FF19
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A05FF0005FF0005FF0000FF0A05FF0005FF00
00FF0A05FF0005FF0000FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF19
00FF2800FF5700FFD100FF5700FF3800FF380075FF00F0FF00FF5700FF2800FF1900FF0A
00FF0A05FF0005FF0005FF0005FF0005FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0000FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF1900FF1900FF19
00FF1900FF1900FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF4700FF47
00FF4700FF4700FF4700FF4700FF4700FF5700FF5700FF5700FF5700FF5700FF6600FF66
00FF6600FF6600FF7500FF7500FF7500FF8500FF8500FF8500FF9400FF9400FF9400FF94
00FF9400FF9400FF9400FFA300FFA300FFA300FFA300FFB300FFB300FFB300FFB300FFB3
00FFC200FFC200FFC200FFD100FFD100FFE100FFE100FFE100FFF000F0FF00A3FF1400FF
00C2FF00B3FF0085FF0019FF0085FF0094FF00A3FF0094FF0085FF0047FF2300FF0500FF
0038FF0019FF6100FF0500FFEB00FFFF003DFF00006100FF3300FF8000FF3300FF2300FF
FF00008000FFEB00FFFF00C7FA00FFDC00FFFF00F5FF00C7FF00C7FF0099FF0000FF0000
FF000FFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF003DFF001EFF00E6
EB00FFCC00FFAE00FF9E00FF8F00FF8F00FFFF00006100FF5100FFFF005C3300FF4200FF
5100FFFF00B89E00FFFF006B5100FF0500FF0019FF0019FF0019FF0500FF5100FFFF000F
AE00FF2300FF0019FF0028FF0028FF0047FF0075FF0085FF0094FF0094FF0094FF0066FF
0066FF00B3FF00D1FF00D1FF00E1FF00E1FF00F0FF00F0FF00F0FF00F0FF00E1FF0094FF
00C2FF00E1FF00A3FF0047FF00D1FF00F0FF00E1FF00D1FF2300FF00B3FF0075FF0500FF
FF00000019FF0094FF00B3FF00F0FF00FFFF00FFF000FFE100FFD100FFD100FFD100FFE1
00FFFF00FFFF0094FF00FFF000FFFF00F0FF00C2FF0047FF00D1FF00E1FF00FFFF00E1FF
0019FF00F0FF000AFF00A3FF0085FF00F0FF00FFE100FFC200FFB300FFB300FFA300FF94
00FFA300FFA300FFB300E1FF00B3FF00FF9400FF7500FF6600FF5700FF4700FF4700FF38
00FF3800FF3800FF2800FF2800FF2800FF2800FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF19
00FF2800FF4700FFFF00FFA300FF5700FF7500FFF000FFD100FF5700FF2800FF1900FF0A
00FF0A05FF0005FF0005FF0005FF0005FF0005FF0005FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0005FF0005FF0014FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0000FF0A05FF0005FF0005FF0000FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF4700FF47
00FF4700FF4700FF4700FF4700FF4700FF5700FF5700FF5700FF5700FF5700FF5700FF66
00FF6600FF6600FF6600FF7500FF7500FF7500FF8500FF8500FF8500FF8500FF8500FF94
00FF9400FF9400FF9400FF9400FFA300FFA300FFA300FFA300FFA300FFB300FFB300FFB3
00FFC200FFC200FFC200FFD100FFD100FFE100FFE100FFE100FFF000FFF000FFFF00F0FF
00E1FF00C2FF0075FF0019FF00A3FF00B3FF00B3FF00A3FF0085FF0500FF0057FFEB00FF
0057FF0057FF0057FF0047FF0019FF8F00FFFF0000AE00FFFF00D7FF0000FF0000FF0099
FF004CFF0099FA00FF9E00FF9E00FF9E00FFBD00FFEB00FFFF00C7FF006BFF0000FF005C
FF004CFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF001EFF005CFF0099FF00C7FF00F5
FA00FFDC00FFBD00FFAE00FF9E00FFFF00F5FF008A8F00FFEB00FF8000FF5100FF5100FF
8000FFFF00D77000FF5100FF2300FF0500FF000AFF000AFF0500FF1400FFEB00FFFA00FF
8F00FF3300FF0028FF0038FF0057FF0066FF0075FF0085FF0085FF0085FF0075FF4200FF
0057FF00B3FF00B3FF00C2FF00B3FF00D1FF00E1FF00E1FF00E1FF00E1FF00E1FF0075FF
0028FF00A3FF0075FF0057FF00C2FF00D1FF00D1FFDC00FF0500FF0066FF0038FFDC00FF
FA00FF0047FF00A3FF00E1FF00FFFF00FFF000FFE100FFD100FFD100FFD100FFC200FFD1
00FFD100FFD100FFD100FFD100FFE100FFF000C2FF0085FF00E1FF00FFE100FFD10028FF
00FFE100FFE100FFF000F0FF0019FF00E1FF00FFE100FFB300FFA300FF9400FF9400FF85
00FF8500FF9400FFA300FFC2AE00FF0019FF00FF7500FF6600FF4700FF4700FF3800FF38
00FF3800FF2800FF2800FF2800FF2800FF2800FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF0A00FF0A00FF0A00FF1900FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF1900FF28
00FF2800FF3800FF5700FFE100FFB3FF000F00FFFF00FF5700FF4700FF2800FF1900FF0A
00FF0A00FF0A05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0014FF0005FF00
14FF0005FF0014FF0005FF0005FF0005FF0005FF0005FF00
05FF0014FF0014FF0014FF0014FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0000FF0A05FF0005FF0005FF0005FF0005FF0000FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF4700FF4700FF4700FF47
00FF4700FF4700FF4700FF4700FF5700FF5700FF5700FF5700FF5700FF5700FF6600FF66
00FF7500FF6600FF6600FF6600FF7500FF7500FF7500FF8500FF8500FF8500FF8500FF94
00FF9400FF9400FF9400FF9400FF9400FFA300FFA300FFA300FFA300FFB300FFB300FFB3
00FFB300FFC200FFC200FFD100FFD100FFD100FFD100FFE100FFE100FFF000FFF000FFFF
00F0FF00C2FFDC00FF0085FF00B3FF00C2FF00C2FF00B3FF0094FF0094FF0085FF0019FF
0075FF0075FF0066FF0047FF000AFF3300FF3300FF1400FF2300FFDC00FF3300FF3300FF
8F00FF8000FF6100FF6100FF7000FF9E00FFBD00FFFA00FFFF0099FF002EFF0099FF008A
FF001EFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF008AFF00B8FF00D7
FF0099FF00F5DC00FFCC00FFBD00FFDC00FFFA00FFFF00C7FF003D8000FF7000FF8000FF
FF00D7CC00FF5100FF3300FF2300FF1400FF0500FF1400FF3300FF4200FF8000FFFF005C
2300FF6100FF0028FF0047FF0057FF0066FF0075FF0075FF0075FF0075FF000AFF5100FF
0075FF0094FF00A3FF000AFF1400FF00B3FF00D1FF00D1FF00E1FF00E1FF00D1FF00B3FF
0047FF1400FFFF00D70094FF00B3FF00B3FF00A3FF0075FF6100FF0500FF0038FF0057FF
0057FFFF000000A3FF00B3FF00E1FF00FFF000FFD100FFD100FFC200FFC200FFC200FFC2
00FFC200FFC200FFC200FFC200FFD100FFFF0028FF00FFFFFF007A00FFE100FFC200FFC2
00FFC200FFC200FFE100F0FF00D1FF00E1FF8000FF0085FF00FF9400FF8500FF8500FF85
00FF8500FF8500FF9400FFFF00A3FF00FFD100FF7500FF5700FF4700FF4700FF3800FF38
00FF3800FF2800FF2800FF2800FF2800FF2800FF2800FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF1900FF1900FF28
00FF2800FF3800FF4700FF755100FF00FF8500FF5700FF4700FF3800FF1900FF1900FF0A
00FF0A00FF0A05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
14FF0014FF0014FF0014FF0014FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0000FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF4700FF4700FF47
00FF4700FF4700FF4700FF4700FF4700FF5700FF5700FF5700FF5700FF5700FF5700FF66
00FF6600FF6600FF6600FF6600FF7500FF7500FF7500FF7500FF8500FF8500FF8500FF85
00FF9400FF9400FF9400FF9400FF9400FF9400FFA300FFA300FFA300FFB300FFB300FFB3
00FFB300FFC200FFC200FFC200FFD100FFD100FFD100FFE100FFE100FFF000FFF000FFFF
00E1FF0085FF0094FF00B3FF00C2FF00D1FF00C2FF00C2FF00C2FF00B3FF00A3FF0094FF
0094FF0094FF0075FF000AFF1400FF1400FF000AFF0019FF1400FF0500FF0500FF0500FF
2300FF7000FF3300FF4200FFFF0000FF002EFF002EFF0000FF0000FF00E6FF00D7FF00B8
FF002EFF002EFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF001EFF00A8FF00A8
FF0000FF00C7FF0000EB00FFDC00FFFA00FFFF00B8DC00FFAE00FF8F00FF8F00FFCC00FF
FF003D9E00FF6100FF4200FF3300FF2300FF2300FF3300FFEB00FFBD00FFFF00B84200FF
1400FF0019FF0028FF0038FF0047FF0057FF0066FF0066FF0075FF0066FF0038FF2300FF
0066FF0075FF0066FF3300FF8000FF00B3FF00C2FF00D1FF00D1FF00D1FF00C2FF00B3FF
00A3FF0075FF3300FF0075FF0085FF0057FF0047FFFF003D1400FF0038FF00A3FF00C2FF
00C2FF0094FF0094FF0085FF0094FF00F0FF00FFD100FFC200FFC200FFB300FFC200FFB3
00FFB300FFB300FFB300FFB300FFC200FFF000D1FF00FFC200FFD100FFC200FFB300FFB3
00FFB300FFB300FFD10019FF00D1FF00FFC200FFC23300FF00FF9400FF8500FF7500FF75
00FF7500FF7500FF7500FF8500FF9400FFC200B3FF00FF5700FF4700FF4700FF3800FF38
00FF3800FF2800FF2800FF2800FF2800FF2800FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF1900FF1900FF2800FF28
00FF3800FF3800FF5700FF8500A3FF00FF7500FF5700FF3800FF2800FF1900FF1900FF19
00FF0A00FF0A00FF0A05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0000FF0A
14FF0014FF0014FF0014FF0014FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0000FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF4700FF4700FF4700FF4700FF47
00FF4700FF4700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF66
00FF6600FF6600FF6600FF6600FF7500FF7500FF7500FF7500FF7500FF8500FF8500FF85
00FF8500FF9400FF9400FF9400FF9400FFA300FFA300FFA300FFA300FFA300FFB300FFB3
00FFC200FFC200FFC200FFC200FFD100FFD100FFD100FFE100FFE100FFF000FFF000FFF0
00F0FF00E1FF00D1FF00D1FF00D1FF00D1FF00D1FF00D1FF00C2FF00C2FF00B3FF00A3FF
00A3FF0094FF0085FF0066FF0066FF8000FF0028FF0038FF0038FF0028FF0028FF0019FF
000AFF1400FF1400FF3300FF6100FF8000FFCC00FFEB00FFDC00FFEB00FFFF00E6FF00C7
FF008AFF003DFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF003DFF005CFF007AFF0000
FF003DFF0000FF00C7FA00FFFA00FFFF008AFF006BCC00FFAE00FFAE00FFBD00FFFF00D7
FF007A9E00FF7000FF8F00FF5100FF9E00FF4200FF4200FF7000FFFF00D7FF006BCC00FF
1400FF000AFF0028FF0028FF0019FF0047FF0057FF0057FF0057FF0057FF0028FF2300FF
0047FF0038FFFF00000057FF0085FF00B3FF00C2FF00C2FF00C2FF00C2FF00B3FF00B3FF
0094FF0057FF8F00FFEB00FF0028FFFF00D77000FF0085FF00A3FF0085FF00C2FF00E1FF
00D1FF00A3FF0094FF00F0FF00FFF000FFE100FFC200FFC200FFB300FFB300FFB300FFB3
00FFB300FFB300FFB300FFB300FFB300FFE100E1FF00FFB300FFA300FFA300FFA300FFA3
00FFA300FFB300FFD100E1FF00FFFF00FFB300FF9400FF9400FF8500FF7500FF7500FF75
00FF6600FF6600FF6600FF7500FF7500FF8500FF9400FF5700FF4700FF3800FF3800FF38
00FF3800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF1900FF1900FF1900FF2800FF2800FF38
00FF3800FF4700FF6600E1FF00C2FF4200FF00FF5700FF3800FF3800FF2800FF1900FF19
00FF0A00FF0A00FF0A00FF0A00FF0A05FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0000FF0A00FF0A00FF0A
14FF0014FF0014FF0014FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0000FF0A05FF0000FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF4700FF4700FF4700FF47
00FF4700FF4700FF4700FF4700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF66
00FF6600FF6600FF6600FF6600FF7500FF7500FF7500FF7500FF7500FF8500FF8500FF85
00FF8500FF8500FF9400FF9400FF9400FF9400FFA300FFA300FFA300FFB300FFB300FFB3
00FFC200FFC200FFC200FFC200FFD100FFD100FFD100FFE100FFE100FFE100FFF000FFF0
00FFFF00F0FF00F0FF00F0FF00E1FF00E1FF00D1FF00D1FF00D1FF00C2FF00B3FF00B3FF
00A3FF00A3FF0094FF0085FF0075FF5100FF0057FF0057FF0047FF0038FF0028FF0019FF
000AFF0500FF1400FF2300FF4200FF9E00FFFA00FFAE00FFBD00FFFF00F5FF005CFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000FFF002EFF000FFF0000
FF007AFF00B8FF00D7FF00E6FF00A8FF0000FF00E6EB00FFFF00E6FF006BDC00FFFF006B
FF00F5BD00FF8F00FFFF00009E00FFBD00FF6100FF7000FFFF007AFF00A88000FF8F00FF
4200FF0500FF000AFF1400FF8F00FF0028FF0500FF0028FF0047FF0038FF0028FF6100FF
FF004CFF00000038FF0066FF0094FF00A3FF00B3FF00B3FF00B3FF00A3FF0066FF0085FF
0085FF000AFF9E00FFFF00001400FF0066FF0047FF00B3FF00D1FF00D1FF00F0FF00F0FF
00F0FF00D1FF000AFF00E1FF00FFE100FFD100FFC200FFB300FFB300FFB300FFB300FFA3
00FFA300FFA300FFA300FFA300FFA300FFA300FFA300FFA300FFA300FF9400FF9400FF94
00FF9400FFA300FFB300FFFF00FFF000FFA300FF8500FF8500FF7500FF7500FF6600FF66
00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF4700FF4700FF3800FF3800FF38
00FF3800FF2800FF2800FF2800FF2800FF2800FF2800FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF1900FF0A00FF1900FF1900FF1900FF1900FF2800FF2800FF3800FF47
00FF4700FF5700FF7500FFB300E1FF00FFB300FF6600FF4700FF3800FF2800FF2800FF19
00FF1900FF0A00FF0A00FF0A00FF0A00FF0A05FF0000FF0A05FF0005FF0005FF0005FF00
05FF0005FF0000FF0A00FF0A00FF0A00FF0A00FF0A00FF19
14FF0014FF0014FF0005FF0014FF0014FF0014FF0014FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0000FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF4700FF4700FF4700FF4700FF4700FF47
00FF4700FF5700FF4700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF66
00FF6600FF6600FF6600FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF8500FF85
00FF9400FF8500FF9400FF9400FF9400FF9400FFA300FFA300FFA300FFB300FFB300FFB3
00FFC200FFC200FFD100FFC200FFD100FFD100FFD100FFE100FFE100FFE100FFF000FFF0
00FFFF00FFFF00FFFF00F0FF00F0FF00E1FF00E1FF00D1FF00C2FF00C2FF00C2FF00B3FF
00A3FF00A3FF0094FF0094FF0085FF0075FF0066FF0057FF0057FF0047FF0028FF0019FF
000AFF0500FF1400FF2300FF4200FF6100FF8000FF8F00FF9E00FFBD00FFFF00F5FF003D
FF00A8FF006BFF000FFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF008AFF0099FF00B8FF00B8FF008AFF0000FF006BFF00E6FF005CFF008AFF00E6FF000F
FA00FFEB00FFFF00D7EB00FFFF00F59E00FF8000FF9E00FFFF00F5FF00F57000FF4200FF
2300FF1400FF0500FF3300FFFA00FF1400FFFF005C000AFF0028FF000AFF4200FF1400FF
0038FF0047FF0066FF0085FF0094FF00A3FF00A3FF00A3FF0094FF0075FF5100FF0066FF
0066FF0028FFFF0099FF00002300FF0075FF00A3FF00C2FF00E1FF00F0FF00FFFF00FFFF
00FFFF00E1FF0057FF00D1FF00FFE100FFC200FFB300FFB300FFB300FFB300FFA300FFA3
00FFA300FFA300FFA300FFA300FF9400FFA300FF9400FF9400FF9400FF9400FF9400FF94
00FF9400FF9400FFA300FFB300E1FF00FF9400FF7500FF7500FF7500FF6600FF6600FF66
00FF6600FF6600FF5700FF5700FF5700FF5700FF5700FF4700FF4700FF3800FF3800FF38
00FF3800FF2800FF2800FF2800FF2800FF2800FF2800FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF1900FF0A00FF1900FF1900FF1900FF1900FF1900FF1900FF2800FF4700FFF000FF57
00FF5700FF6600FF7500FFC200FFF000FF8500FF6600FF4700FF4700FF2800FF2800FF19
00FF1900FF1900FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF1900FF28
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0000FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF4700FF4700FF4700FF4700FF4700FF47
00FF4700FF4700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF6600FF66
00FF6600FF6600FF6600FF6600FF6600FF7500FF7500FF7500FF7500FF7500FF8500FF85
00FF8500FF8500FF9400FF9400FF9400FF9400FFA300FFA300FFA300FFB300FFB300FFC2
00FFC200FFC200FFC200FFD100FFD100FFD100FFD100FFE100FFE100FFE100FFF000FFF0
00FFF000FFFF00FFFF00F0FF00F0FF00E1FF00E1FF00D1FF00D1FF00C2FF00C2FF00B3FF
00A3FF00A3FF0094FF0094FF0085FF0075FF0066FF0066FF0057FF0038FF000AFF2300FF
2300FF2300FF2300FF3300FF4200FF5100FF7000FF8F00FFAE00FFBD00FFFA00FFFF00E6
FF00C7FF006BFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF003D
FF005CFF0000FF004CFF008AFF005CFF000FFF0099FF00A8FF007AFF008AFF006BFF0000
FF00C7FF003DFF00D7FF0099EB00FFBD00FFBD00FFFF0000FF00F58F00FF6100FF4200FF
3300FF2300FF2300FF3300FFFF005C8000FF4200FF0500FF000AFF1400FFFF00993300FF
0047FF0057FF0075FF0085FF0085FF0094FF0094FF0094FF0085FF2300FF4200FF0028FF
6100FFFF0000FF00005100FF4200FF0075FF0094FF00B3FF00E1FF00FFFF00FFF000FFF0
00FFF000FFF000FFF00057FF00FFD100FFC200FFB300FFB300FFA300FFA300FFA300FFA3
00FFA300FF9400FFA300FFA300FF9400FF9400FF9400FF9400FF9400FF9400FF8500FF85
00FF8500FF8500FF9400FFA300FFA300FF8500FF7500FF7500FF6600FF6600FF6600FF66
00FF5700FF5700FF5700FF5700FF5700FF5700FF4700FF4700FF3800FF3800FF3800FF38
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF0A00FF0A00FF0A
00FF1900FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF2800FF2800FF4700FFA33300FF
00FF8500FF7500FF8500FFF00094FF0057FF00FF7500FF6600FFB300FF4700FF2800FF28
00FF1900FF1900FF1900FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF1900FF1900FF1900FF2800FF28
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0000FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF47
00FF5700FF4700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF6600FF66
00FF6600FF6600FF6600FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF8500FF85
00FF8500FF8500FF9400FF9400FF9400FFA300FFA300FFA300FFB300FFB300FFB300FFC2
00FFD100FFC200FFD100FFD100FFD100FFD100FFE100FFE100FFE100FFE100FFF000FFF0
00FFF000FFFF00FFFF00F0FF00F0FF00E1FF00E1FF00D1FF00D1FF00C2FF00B3FF00B3FF
00A3FF00A3FF0094FF0085FF0085FF0075FF0075FF0066FF0057FF0019FF9E00FFEB00FF
FF00007000FF6100FF4200FF5100FF8000FF8000FFAE00FFDC00FFCC00FFEB00FFFF00E6
FF00C7FF008AFF004CFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF002E
FF003DFF0000FF0000FF005CFF0000FF0000FF005CFF0000FF001EFF0000FF0000FF002E
FF000FFF001EFF003DFF0000FF0099FF00B8FF00F5FF000FFF005C8F00FF7000FF7000FF
5100FF5100FF4200FF4200FF8F00FF6100FF3300FF1400FF3300FFFF00B85100FF000AFF
0038FF0057FF0066FF0075FF0075FF0075FF0066FF0075FF0066FF0047FF6100FFEB00FF
000AFF0047FF0500FF8000FF0057FFFF00000038FF5100FF00B3FF00FFFF00FFF000FFE1
00FFE100FFE100FFE100FFD100FFC200FFB300FFB300FFB300FFA300FFA300FFA300FFA3
00FF9400FF9400FF9400FF9400FF9400FF9400FF8500FF8500FF8500FF8500FF8500FF85
00FF8500FF8500FF8500FF8500FF8500FF7500FF7500FF6600FF6600FF6600FF6600FF57
00FF5700FF5700FF5700FF5700FF4700FF4700FF4700FF4700FF3800FF3800FF3800FF38
00FF3800FF2800FF2800FF2800FF2800FF2800FF2800FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF0A00FF0A
00FF1900FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF0A00FF0A00FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF2800FF2800FF3800FF4700FF6600FFA3
00A3FF00FFA300FFA300FFF000F0FF00FFB300FF9400B3FF0085FF00FF4700FF3800FF28
00FF2800FF1900FF1900FF1900FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF1900FF1900FF1900FF3800F0FF00FF3800FF3800FF38
14FF0014FF0014FF0014FF0014FF0014FF0014FF0005FF0005FF0005FF0005FF0005FF00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14FF0014FF0014FF0014FF0014FF0014FF0005FF0005FF0005FF0005FF0005FF0005FF00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14FF0014FF0014FF0014FF0005FF0014FF0014FF0014FF0014FF0014FF0005FF0005FF00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14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0005FF00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14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0005FF0005FF00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14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0000FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF1900FF1900FF2800FF2800FF28
00FF2800FF2800FF2800FF3800FF3800FF3800FF3800FF3800FF4700FF4700FF4700FF57
00FF9400F0FF00FF8500FF6600FF6600FF5700FF5700FF5700FF5700FF5700FF5700FF66
00FF5700FF5700FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF66
00FF7500FF6600FF7500FF7500FF7500FF7500FF7500FF7500FF8500FF8500FF8500FF85
00FF8500FF8500FF9400FF9400FFA300FFB300F0FF00FFF000F0FF00B3FF0038FF6100FF
0094FF0019FF00D1FF0047FF00C2FF0019FF00E1FF00F0FF00FFFF00FFFF00FFFF00FFFF
00F0FF00F0FF00F0FF00F0FF00E1FF00E1FF00D1FF00D1FF00C2FF00A3FF0094FF0075FF
0028FF000AFFFF00000500FF0038FF0047FF0047FF0047FF0038FF0038FF0028FF0019FF
0500FF0500FF1400FF2300FF4200FF7000FF8000FF8F00FF9E00FFBD00FFFA00FFFF006B
FF00A8FF0099FF005CFF001EFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF003DFF005CFF007AFF008AFF008AFF0000
FF00A8FF00C7FF00A8FF0000FF004CFF0000FF0000FF0000FF0000FF0000FF0000FF00A8
EB00FF8F00FF6100FF5100FF000AFF0019FF0038FF0047FF0047FF0085FF00A3FF00A3FF
00C2FF00C2FF00D1FF00E1FF00F0FF00F0FF00FFFF00FFFF00FFF000FFE100FFE100FFD1
00FFD100FFD100FFC200FFC200FFB300FFB300FFB300FFA300FFA300FF9400FF9400FF94
00FF9400FF8500FF8500FF8500FF8500FF8500FF7500FF7500FF7500FF7500FF7500FF75
00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF5700FF5700FF5700FF5700FF57
00FF4700FF4700FF4700FF4700FF4700FF4700FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF28
00FF1900FF1900FF2800FF2800FF2800FF2800FF2800FF3800FF3800FF4700FF4700FF57
00FF6600FF7500FF9400FFE100B3FF2300FF0047FF00FFA300FF7500FF6600FF5700FF47
00FF4700FF3800FF3800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF3800FF38
00FF4700FF4700FF6600FF7500FF9400F0FF0028FF0028FF
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0000FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF1900FF1900FF2800FF2800FF2800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF4700FF5700FF5700FF5700FF66
00FF853300FF00FF9400FF7500FF6600FF6600FF6600FF6600FF5700FF5700FF6600FF66
00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF66
00FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF8500FF8500FF8500FF85
00FF8500FF9400FF9400FF9400FFA300FFB300FFC200FFC200FFE100D1FF0057FF0075FF
0038FF9E00FF6100FF0075FFFF004C00A3FF00E1FF00F0FF00F0FF00F0FF00F0FF00F0FF
00F0FF00F0FF00F0FF00F0FF00E1FF00E1FF00D1FF00C2FF00B3FF00A3FF0094FF0085FF
0066FF0038FF1400FF2300FF0028FF0038FF0038FF0038FF0038FF0028FF0019FF0019FF
0500FF0500FF1400FF2300FF6100FFFF0000FF00C7AE00FFAE00FFCC00FFFF0000FF0000
FF003DFF002EFF002EFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF001EFF0000FF005CFF002EFF0000
FF008AFF0000FF0000FF003DFF0000FF0000FF0000FF0000FF0000FF0000FF004CFF0000
CC00FFFA00FF3300FF1400FF0019FF0038FF0057FF0057FF0075FF0085FF0094FF00A3FF
00B3FF00C2FF00D1FF00E1FF00F0FF00F0FF00FFFF00FFFF00FFF000FFF000FFE100FFE1
00FFD100FFD100FFD100FFC200FFC200FFB300FFB300FFA300FFA300FFA300FF9400FF94
00FF9400FF8500FF8500FF8500FF8500FF8500FF7500FF7500FF7500FF7500FF7500FF75
00FF6600FF6600FF6600FF6600FF6600FF5700FF5700FF5700FF5700FF5700FF5700FF57
00FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF2800FF2800FF2800FF2800FF2800FF2800FF3800FF3800FF3800FF4700FF4700FF57
00FF6600FF7500FF8500FFB300FFE10019FF00FFC200FF9400FF7500FF6600FF5700FF47
00FF4700FF3800FF3800FF3800FF3800FF2800FF2800FF2800FF3800FF3800FF3800FF47
00FF4700FF5700FF6600FF8500FFA300FFE100B3FF8000FF
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0005FF00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14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00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14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00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14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0000FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF1900FF1900FF1900FF1900FF2800FF8500FF660047FF
0038FF00FF9400FF7500FF6600FF6600FF6600FF6600FF7500FF8500FFA30066FF00E1FF
0047FF00FFD100FFB300FF9400FF8500FF8500FF8500FF7500FF7500FF8500FF7500FF85
00FF8500FF8500FF9400FF9400FF8500FF7500FF7500FF7500FF7500FF7500FF7500FF75
00FF7500FF7500FF7500FF7500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF85
00FF9400FF9400FF9400FF9400FFA300FFA300FFB300FFB300FFC200FFD100FFD100FFE1
00FFF000FFFF00E1FF00D1FF0094FF5100FF1400FF0075FF00B3FF00C2FF00D1FF00D1FF
00E1FF00D1FF00D1FF00D1FF00D1FF00C2FF00B3FF0094FF0019FF0038FF0028FFFF00F5
000AFF5100FF0019FF0019FF0019FF1400FFFF004CFF00C7DC00FF6100FF6100FFFA00FF
8000FF5100FF5100FF5100FF6100FF8000FF9E00FFBD00FFDC00FFFF00F5FF00A8FF001E
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF005CFF00A8FF00E6
FF00D7FF006BFF00007000FF8000FF8F00FF1400FF0038FF0047FF0047FF000AFF0019FF
0066FF0094FF00B3FF00B3FF00D1FF00E1FF00F0FF00F0FF00FFFF00F0FF00FFFF00F0FF
00D1FF00D1FF00A3FFFF00B800B3FF00FFFF00FFF000FFD100FFA300FFA300FF9400FF94
00FF9400FF8500FF8500FF8500FF8500FF7500FF7500FF7500FF7500FF7500FF7500FF66
00FF6600FF6600FF6600FF6600FF6600FF5700FF5700FF5700FF5700FF5700FF5700FF57
00FF5700FF4700FF4700FF4700FF4700FF4700FF4700FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF3800FF3800FF3800FF3800FF3800FF4700FF4700FF57
00FF7500E1FF00FFF00500FF00B3FF0066FF8F00FF0066FF00FFF000FFF000FFD100FF85
00FF6600FF5700FF4700FF4700FF4700FF5700FF4700FF5700FF6600FFB300FFA300FFE1
00FFC200FFB30085FF0500FF00FFD100F0FF00FF8500FF66
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0005FF0005FF00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14FF0014FF0014FF0014FF0005FF0014FF0014FF0014FF0014FF0014FF0005FF0005FF00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14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00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14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00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14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00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14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0005FF00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14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0005FF0005FF0005FF00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14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0005FF00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14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF1900FF1900FF2800FF28
00FF2800FF2800FF3800FF3800FF4700FF475100FF00FFD100FFA300FF8500FFB300D1FF
00FFA300FF9400FF9400FF9400FF9400FFA300FFC200FFE100F0FF0057FF9E00FF2300FF
0028FF0085FF0066FF00FFF000FFE100FFE100D1FF00FFD100FFC200FFE100FFB300FFA3
00FFA300FFA300FF9400FF9400FF9400FF9400FF9400FF9400FF9400FFA300FFA300FFA3
00FFA300FFA300FFB300FFB300FFC200FFD100FFD100FFF000D1FF00F0FF00F0FF00C2FF
00C2FF0075FF00D1FF00D1FF00D1FF00C2FF00C2FF00C2FF00A3FF0066FF2300FF8000FF
2300FFFF0000FA00FF0019FF0038FF000AFF1400FF5100FF0038FF0047FF0057FF0057FF
0047FF0028FF0028FF0019FF1400FF8000FF8F00FF3300FF2300FF3300FF4200FF6100FF
FA00FFFA00FFAE00FFAE00FFBD00FFDC00FFFF0000FF007AFF00B8FF0099FF004CFF003D
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF000FFF0099FF0099FF00B8FF002EFF008AFF00004200FF
6100FFBD00FFEB00FFFF00000038FF0066FF0057FF0075FF00B3FF00B3FF00B3FF00A3FF
0057FF0066FF6100FFCC00FF0019FF4200FFFF002EAE00FF00C2FF00FFFF00FFE100FFD1
00FFC200FFA300FF9400FF9400FF8500FF8500FF8500FF8500FF8500FF8500FF7500FF85
00FF7500FF7500FF7500FF7500FF7500FF6600FF6600FF6600FF6600FF6600FF6600FF57
00FF5700FF5700FF5700FF5700FF5700FF5700FF4700FF5700FF4700FF4700FF4700FF47
00FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF47
00FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF47
00FF4700FF5700FF4700FF4700FF4700FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF4700FF3800FF4700FF3800FF4700FF4700FF4700FF4700FF4700FF5700FF5700FF57
00FF5700FF5700FF6600FF6600FF7500FF7500FF8500FF9400FFA300FFC23300FF00A3FF
FF00C700FFD100FFD100FFF03300FF00C2FF00FFF000FFD100FFF000FFD100FFA300FF75
00FF7500FF6600FF6600FF6600FF5700FF4700FF4700FF38
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00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14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00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14FF0014FF0014FF0014FF0014FF0014FF0014FF0005FF0005FF0005FF0005FF0005FF00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14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0005FF0005FF00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14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0005FF00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14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0005FF00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14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0005FF00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14FF0014FF0014FF0014FF0014FF0014FF0005FF0014FF0014FF0014FF0005FF0005FF00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14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0005FF0005FF0005FF0005FF00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14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0005FF0005FF0005FF00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14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0005FF0005FF00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14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0005FF0005FF00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14FF0014FF0014FF0014FF0014FF0005FF0014FF0014FF0014FF0005FF0005FF0005FF00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14FF0014FF0014FF0014FF0014FF0014FF0005FF0005FF0005FF0005FF0005FF0005FF00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14FF0014FF0014FF0014FF0014FF0014FF0014FF0005FF0005FF0005FF0005FF0005FF00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14FF0014FF0014FF0014FF0014FF0014FF0014FF0005FF0005FF0005FF0005FF0005FF00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14FF0014FF0014FF0014FF0014FF0014FF0014FF0005FF0005FF0005FF0005FF0005FF00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14FF0014FF0014FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0000FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF1900FF1900FF1900FF1900FF28
00FF2800FF3800FF3800FF3800FF4700FF4700FF4700FF5700FF5700FF5700FF6600FF85
00E1FF00FFD100FF9400FF8500FF9400FF9400FFA300D1FF00FFE10038FF00FFF000FFD1
00FFE100FFF000E1FF0019FFFF003D0028FF00C2FF00FFFF00FFF000FFE100FFD100FFD1
00FFD100FFD100FFD100FFE100FFF000F0FFFF00F51400FF0028FF00B3FF00D1FF00C2FF
0066FFFF00B800C2FF0094FF0085FF0038FF6100FFFF00006100FF8000FF2300FF0028FF
FA00FF0047FF0066FF0075FF0038FF2300FF0047FF0057FF0047FF8F00FF5100FF5100FF
FF00A8FA00FFFF005CFF0000FF002EFF007AFF002EFF00C7FF0000FF00B8FF00D7FF00A8
FF0000FF004CFF006BFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF003DFF00D7FF00C7BD00FF9E00FFAE00FF
9E00FFFF00A8CC00FF6100FF4200FF3300FF1400FF0500FF000AFF0019FF0019FF0500FF
7000FFAE00FF7000FF0500FF0038FF0047FF0057FF0066FF0075FF0085FF0094FF0094FF
00A3FF00A3FF0094FF0047FF1400FFFF00D70057FF0047FF000AFFFF00F5FF00B8FF0000
FF001E0047FF0085FF0094FF00B3FF00B3FF00B3FF0075FF00C2FF00D1FF00C2FF00B3FF
0075FF0075FF00B3FF00D1FF00F0FF00FFFF00FFFF00FFF000FFF000FFFF00FFFF00C2FF
0028FF00D1FF00D1FF00A3FFFF00E600A3FF00E1FF00FFFF00FFF000FFE100FFD100FFC2
00FFC200FFB300FFB300FFA300FFA300FFA300FFA300FFA300FFA300FFA300FFA300FFA3
00FFD14200FF00FFB300FFA300FFA300FFA300FFA300FFA300FFB300FFB300FFC200FFD1
00FFE100FFFF00A3FF7000FF00D1FF00FFF000FFD100FFC200FFB300FFB300FFA300FFA3
00FF9400FF9400FF9400FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF85
00FF8500FF9400FF9400FFA300C2FF0066FF0094FF00A3FF0047FF00F0FF00FFF000FFFF
00B3FF00A3FF00F0FF00FFF000FFF000FFF000FFF000F0FF6100FF00B3FF00A3FF9E00FF
5100FF00C2FF0085FF00C2FF8F00FF00F0FF00E1FF0094FF1400FF5100FF00A3FF00FFF0
00FFE100FFA300FF8500FF7500FF7500FF7500FF7500FF66
14FF0014FF0014FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00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14FF0014FF0014FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00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14FF0014FF0014FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00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05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00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05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00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05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00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05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0000FF0A05FF00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05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0000FF0A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05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00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05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00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05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0000FF0A05FF0005FF0005FF00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05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0000FF0A05FF0005FF00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05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0000FF0A00FF0A00FF0A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05FF0005FF0005FF0005FF0005FF0000FF0A05FF0005FF0005FF0000FF0A00FF0A00FF0A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05FF0005FF0005FF0005FF0005FF0000FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A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05FF0000FF0A00FF0A05FF0000FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A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00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A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00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A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00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A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00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A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00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A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00FF0A00FF0A00FF0A00FF0A00FF1900FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A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00FF0A00FF1900FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF0A
00FF0A00FF0A00FF1900FF0A00FF0A00FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF2800FF1900FF1900FF1900FF1900FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF3800FF3800FF3800FF3800FF3800FF3800FF4700FF47
00FF4700FF4700FF4700FF4700FF4700FF4700FF5700FF5700FF5700FF6600FF5700FF66
00FF6600FF6600FF6600FF6600FF6600FF7500FF7500FF7500FF7500FF7500FF7500FF85
00FF8500FF8500FF8500FF9400FF9400FF9400FFA300FFA300FFB300FFC200FFD100FFE1
00FFF000FFFF0038FF00B3FF0057FF1400FF00A3FF00C2FF00B3FF00A3FF0094FF0094FF
0085FF0066FF0057FF0047FF000AFF2300FF7000FFFF00E6FF007AFF0000FF0000FF0000
FF000FFF001EFF0000FF0000FF0000FF00A8FF00B8FF00D7FF001EFF00B8FA00FFFF003D
EB00FFFF006BFA00FFFF00F5FF0099FF0000FF00A8FF0000FF004CFF001EFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF002E
FF006BFF00A8FF00D7FF00F5DC00FFCC00FFFF00D7FF00E6EB00FF3300FF2300FF2300FF
2300FF6100FF7000FFEB00FF5100FF0019FF0047FF0066FF0066FF0066FF0075FF0075FF
0075FF0075FF0085FF0094FF0094FF0094FF0085FF0085FF0057FF6100FF0500FF0047FF
0057FF0047FFFF00F50500FF0066FF0075FF0057FF000AFF8F00FFFF0000000AFF0019FF
0019FFFF008ACC00FF7000FF2300FF0066FFCC00FF00B3FF00F0FF00FFE100FFD100FFC2
00FFB300FFB300FFA300FFA300FFA300FFA300FFA300FFA300FF9400FFA300FF9400FF94
00FFA300FF9400FFA300FFA300FFA300FFB300FFB300FFC200FFE100FFFF0500FF0066FF
00FFE100FFC200FFA300FFA300FF9400FF9400FF9400FFA300FFF000FF9400FF8500FF75
00FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF75
00FF8500FF8500FF8500FF9400FFA300FFB300FFC200FFD100D1FFFF00A800E1FF00FFE1
00FFE1FA00FF00B3FF2300FF00FFFF00FFF000FFB300FFA300FF9400FF8500FF8500FF75
00FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF8500FF8500FFA300F0FF
00F0FF0028FFFF00C700FFE100FFF000F0FF00B3FF00FFF000FFE100FFD100FFD100FFE1
00FFF000F0FF00B3FFCC00FF0066FF00B3FF0066FF00FFE100FFC200FFB300FFB300FFA3
00FFB300FFD100FFFF00FFF000FFFF00FFA300FF7500FF6600FF6600FF5700FF5700FF57
00FF5700FF5700FF5700FF5700FF5700FF5700FF6600FF75
00FF1900FF1900FF0A00FF0A00FF1900FF0A00FF0A00FF1900FF0A00FF0A00FF1900FF0A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00FF1900FF1900FF1900FF1900FF1900FF0A00FF1900FF1900FF0A00FF0A00FF1900FF19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00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19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00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19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00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19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00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19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00FF1900FF2800FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19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00FF2800FF2800FF1900FF2800FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19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00FF2800FF2800FF2800FF2800FF1900FF1900FF1900FF1900FF2800FF1900FF1900FF19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00FF2800FF2800FF2800FF2800FF2800FF2800FF1900FF1900FF2800FF1900FF1900FF28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00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF1900FF1900FF28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00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28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00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28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00FF3800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28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00FF3800FF3800FF3800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28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00FF3800FF3800FF3800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28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00FF3800FF3800FF3800FF3800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28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00FF3800FF3800FF3800FF3800FF3800FF3800FF2800FF2800FF3800FF2800FF2800FF28
00FF2800FF3800FF2800FF2800FF2800FF2800FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF4700FF4700FF4700FF5700FF6600FFF000FFF00094FF00FF9400FF85
00FF7500FF6600FF6600FF6600FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF57
00FF5700FF6600FF6600FF6600FF6600FF6600FF6600FF7500FF7500FF8500FF8500FF94
00FF9400FFA300FFB300FFD100D1FFFF00000075FF00D1FF00FFFF00FFD100FFD100FFC2
00FFC200FFC200FFC200FFC200FFC200FFD100FFE100FFE100FFF000D1FF0028FF00D1FF
00F0FF00F0FF00FFFF00F0FF00F0FF00E1FF00D1FF00A3FF0085FF0019FFFF0000FF007A
FF00009E00FF0019FF0094FF0094FF0047FF00B3FF00C2FF00C2FF00C2FF00C2FF00B3FF
0066FF5100FF0028FF0075FF0085FF0085FF0066FF5100FF6100FF0047FF0075FF0075FF
0075FF0075FF0075FF0066FF0066FF0057FF0057FF0047FF0038FF0500FF0500FF1400FF
8000FF9E00FFAE00FF7000FF8000FF8000FF3300FF1400FF1400FF2300FF2300FF3300FF
4200FF5100FF6100FF8000FFAE00FFFF000FFF00D7FF007AFF0000FF00C7FF00B8FF00C7
FF007AFF006BFF0000FF000FFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF001EFF0000FF0000
FF004CFF005CFF004CFF006BFF0000FF006BFF006BFF0000FF00B8FF00C7FF002EFF00C7
FF005CFF00B8EB00FF8F00FFFF008A3300FF1400FF0500FF0500FF0500FF0019FF0500FF
0057FF0066FF0075FF0075FF0085FF0085FF0094FF0094FF0094FF0094FF0085FF00A3FF
00B3FF00C2FF00C2FF00E1FF00E1FF00F0FF00F0FF00F0FF00FFFF00FFFF00FFFF00FFF0
00FFF000FFF000FFF000FFF000FFF000FFF000FFE100FFE100FFE100FFE100FFE100FFF0
00C2FF00FFF000FFE100FFD100FFD100FFD100FFD100FFD100FFFF00FFA300FF9400FF94
00FF9400FF8500FF8500FF8500FF8500FF8500FF7500FF7500FF7500FF7500FF7500FF75
00FF7500FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF5700FF5700FF5700FF57
00FF5700FF5700FF5700FF5700FF5700FF4700FF4700FF4700FF4700FF4700FF4700FF47
00FF4700FF4700FF4700FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF2800FF3800FF2800FF3800FF2800FF2800FF2800FF2800FF3800FF28
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF4700FF4700FF4700FF4700FF4700FF5700FF5700FF6600FF6600FF7500FFA34200FF
00FFF000FFD100B3FF00D1FF00FFD100FFC200FF9400FF8500FF8500FF8500FFA300FF94
00FFC200FFA300FFE100FFFF0075FF0075FF00B3FF00FFC200FFA300FF8500FF6600FF57
00FF5700FF4700FF4700FF3800FF2800FF2800FF1900FF19
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF2800FF3800FF38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00FF4700FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38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00FF4700FF4700FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38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00FF4700FF4700FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38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00FF4700FF4700FF4700FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF4700FF4700FF5700FF4700FF47
00FF5700FF5700FF5700FF5700FF5700FF6600FF7500FF9400FFF000F0FFFF0099FF00A8
00FFD100FFC200FFA300FF8500FF7500FF7500FF7500FF6600FF6600FF7500FF6600FF66
00FF6600FF7500FF7500FF7500FF7500FF7500FF8500FF8500FF9400FFB300E1FF00E1FF
00D1FF0066FFFF00F55100FF0066FF0075FF00B3FF00E1FF00FFFF00FFFF00FFF000FFF0
00FFF000FFF000FFF000FFF000FFF000FFFF00F0FF00E1FF00D1FF00A3FF0047FF000AFF
0028FF0028FF0057FF2300FF0028FF0047FF3300FF0094FF00C2FF00D1FF00D1FF00B3FF
0028FF00A3FF00C2FF000AFF0019FF00D1FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF
00F0FF00E1FF00E1FF00E1FF00D1FF00D1FF00C2FF00B3FF00B3FF00B3FF00B3FF00A3FF
00A3FF0094FF0094FF0085FF0057FF0028FF5100FF3300FF8F00FF8000FFFF00004200FF
1400FFEB00FF0019FF0028FF0028FF0038FF0028FF000AFF1400FF8F00FFFF0000DC00FF
7000FF9E00FF8000FF6100FF6100FF6100FF7000FF8000FF8F00FFAE00FFCC00FFFF00F5
FF00D7FF008AFF005CFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A8FF00E6FA00FF
FF00D7CC00FFAE00FFBD00FFDC00FFFF002EFF007AFF00D78000FF6100FF6100FF5100FF
2300FF2300FF3300FFEB00FFFF00D75100FFFF00D77000FF6100FFFF00A80500FF0019FF
0028FF5100FF0019FF0066FF0075FF0085FF0094FF00A3FF00A3FF00B3FF00B3FF00C2FF
00C2FF00D1FF00D1FF00E1FF00E1FF00E1FF00F0FF00F0FF00F0FF00FFFF00FFFF00FFF0
00FFF000FFE100FFE100FFE100FFE100FFD100FFD100FFD100FFC200FFC200FFC200FFC2
00FFC200FFB300FFB300FFB300FFA300FFA300FFA300FFA300FF9400FF9400FF9400FF94
00FF9400FF8500FF8500FF8500FF8500FF8500FF7500FF7500FF7500FF7500FF7500FF75
00FF7500FF6600FF6600FF6600FF6600FF6600FF6600FF5700FF5700FF5700FF5700FF57
00FF5700FF5700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF3800FF3800FF38
00FF4700FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF2800FF3800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF3800FF3800FF38
00FF3800FF3800FF4700FF4700FF5700FF6600FF7500FF7500FF7500FF8500FF9400F0FF
00FFFF0066FF00FFC200FFA300FF9400FF7500FF6600FF5700FF5700FF5700FF4700FF47
00FF4700FF5700FF5700FF5700FF6600FF6600FF7500FF8500FFB300FFE10066FF0066FF
7000FF00FFC200FFC200FFB300FF6600FF4700FF2800FF19
00FF4700FF4700FF4700FF4700FF4700FF3800FF3800FF3800FF3800FF3800FF3800FF38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00FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF3800FF4700FF3800FF3800FF38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00FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF47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00FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF47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00FF5700FF5700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF47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00FF5700FF5700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF47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00FF5700FF5700FF5700FF5700FF5700FF4700FF5700FF4700FF4700FF4700FF4700FF47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00FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF57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00FF5700FF6600FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF57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00FF6600FF5700FF6600FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF57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00FF6600FF6600FF6600FF6600FF6600FF5700FF5700FF5700FF5700FF5700FF5700FF57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00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF66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00FF7500FF7500FF6600FF6600FF6600FF6600FF6600FF7500FF7500FF7500FF7500FF75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00FF8500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF8500FF9400FF8500FF75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00FFA34200FF00FF8500FF8500FF7500FF7500FF8500FF9400FFD11400FF00FF9400FF85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00E1FF00FFB300FF9400FF8500FF8500FF8500FF9400FFB300C2FF00FFC200FF9400FF85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0085FF00FFE100FFA300FFA300FF9400FF9400FFB300FFF00057FF00FFC200FFA300FF94
00FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF9400FF9400FFA3
00FFA300FFA300FFB300FFB300FFC200FFF01400FF00C2FF00E1FF00B3FF7000FF0066FF
0047FFFF007A00A3FF0057FF0028FF00B3FF00E1FF00F0FF00F0FF00E1FF00B3FFEB00FF
0057FFFF00000085FF0057FF0047FFBD00FF0085FF00E1FF00FFFF00FFF000FFD100FFD1
00FFD100FFF000FFC200FFC200FFC200FFC200FFC200FFD100FFD100FFE100FFF000FFFF
00E1FF00B3FFEB00FF0066FF00D1FF00FFFF00FFF000FFE100FFD100FFC200FFC200FFB3
00FFB300FFB300FFA300FFA300FFA300FFA300FFA300FFA300FFA300FFA300FFA300FFA3
00FFA300FFB300FFB300FFB300FFC200FFD100FFF000C2FF0094FF00B3FF0057FF8F00FF
00B3FF00B3FF00A3FF8F00FF00E1FF00F0FF00F0FF00F0FF00E1FF00D1FF0066FF0057FF
6100FF0066FF0066FF00C2FF00D1FF00D1FF00E1FF00E1FF00E1FF00E1FF00E1FF00D1FF
00D1FF00B3FF0085FFFF00000047FF1400FF0094FF0094FF0085FF0075FF0057FF0028FF
5100FF000AFF0047FF0057FF0057FF0057FF0047FF2300FFFF00D7000AFF1400FF9E00FF
4200FF3300FF7000FFBD00FFDC00FFFF0099FF0000FF002EFF00E6FF0000FF00F5FF00B8
FF00D7FA00FFFF00E6FF000FFF00D7FF00F5FF007AFF00D7FF0000FF00D7FF00D7FF00B8
FF0000FF0000FF002EFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF001E
FF001EFF0000FF000FFF008AFF00B8FF00C7FF00D7FF00E6FF00F5FF00D7FF008AFF00B8
FF002EFF00C7EB00FFEB00FFFF001EAE00FF5100FF4200FF3300FF4200FF5100FFFF0000
8000FF7000FF4200FFAE00FF9E00FFFF00B8FF00F55100FF1400FF0019FF0028FF0038FF
0028FF0028FF0038FF4200FF000AFF0057FF0066FF0066FF0094FF00A3FF00B3FF00C2FF
00C2FF00C2FF00D1FF00D1FF00D1FF00D1FF00C2FF00C2FF00C2FF00B3FF00A3FF0094FF
0047FF3300FF9E00FF0066FF0094FF00B3FF00B3FF00B3FF00B3FF00B3FF0094FF0057FF
9E00FF000AFF6100FF0047FF0066FF5100FF0038FF6100FF0066FF00B3FF00D1FF00E1FF
00FFFF00FFFF00FFE100FFE100FFD100FFD100FFC200FFC200FFC200FFC200FFC200FFC2
00FFD100FFD100E1FF00B3FF00F0FF00B3FF00FFF000FFE100FFE100FFFF00FFF000FFFF
00D1FF0066FF00C2FF00FFFF00FFF000FFE100FFD10500FF00E1FF00FFE100FFD100FFE1
00FFF02300FF00FFFF00FFD100FFA300FF8500FF7500FF6600FF5700FF5700FF4700FF47
00FF3800FF3800FF3800FF2800FF2800FF2800FF2800FF1900FF2800FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF0A00FF0A00FF1900FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF1900FF1900FF19
00FF2800FF4700FF7500FF850047FF00FFFF00FFA300FFA300FF9400FFD100FFD100FFC2
0028FF00D1FF4200FF00FFE100FF9400FFB300FFFF00FFE100FF5700FF2800FF1900FF0A
00FF0A05FF0005FF0005FF0005FF0005FF0005FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0023FF00
9E00FF00C2FF00FFD100FFA300FFA300FFB300E1FF0075FF5100FF00F0FF00FFB300FF94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0057FF00FFFF00FFD100FFB300FFB300FFC200FFE10085FF00F0FF00FFFF00FFF000FFA3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0075FF0047FF00FFF000FFD100FFD100FFF000D1FF0047FF00FFF000FFD100FFB300FFA3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00B3FF0094FF00FFFF00FFE100FFF000F0FFDC00FF0057FF00E1FF00FFC200FFB300FFA3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AE00FF4200FF00E1FF00FFFF00B3FF0075FF0057FF00E1FF00C2FF00FFC200FFB300FFB3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00E1FF0075FF00B3FF00C2FF0047FF0066FF00D1FF00FFF000FFE100FFC200FFB300FFB3
00FFB300FFA300FFA300FFA300FFA300FFB300FFC200FFE100E1FF9E00FF0094FF00C2FF
00F0FF00FFFF00E1FF0019FF00A3FF0085FF5100FF5100FF00A3FF0075FF0075FF0085FF
0038FF1400FF0038FF3300FFFF00003300FF1400FF0038FF0047FF0075FF0075FF00FFF0
00FFD100FFC200FFC200FFC200FFE100C2FF00FFFF00FFB300FFA300FF9400FF9400FF94
00FF9400FF9400FF9400FF9400FF9400FF9400FFA300FFC200FFD100FFFF0047FF00F0FF
00FFE100FFC200FFB300FFB300FFB300FFE10075FF0047FF00A3FF00FFFFFF000F00FFA3
00FF9400FF9400FF9400FF9400FF9400FF9400FF8500FF9400FF9400FF9400FF9400FF94
00FF9400FF9400FFA300FFB300FFC200FFC200FFD100FFF000FFC200FFC200FFC200FFC2
00FFC200FFC200FFC200FFD100FFD100FFE100FFF000F0FF00E1FF00C2FF5100FF0057FF
0085FF0094FF00E1FF00F0FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00F0FF00F0FF00F0FF00F0FF00E1FF00E1FF00D1FF00D1FF00B3FF00A3FF00A3FF00A3FF
00A3FF00A3FF0094FF0094FF0085FF0085FF0075FF0066FF0057FF0047FF0038FF0028FF
FF005C2300FFAE00FFFF00006100FFAE00FF6100FF1400FF1400FF2300FF2300FF4200FF
6100FF8F00FFEB00FF9E00FF6100FF5100FF7000FFCC00FFFF00999E00FFFF00F5CC00FF
AE00FFAE00FFBD00FFDC00FFFA00FFFF00A8FF0000FF00A8FF00C7FF00B8FF006BFF0000
FF0099FF002EFF007AFF000FFF005CFF003DFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF006BFF007AFF00A8FF0000FF005CFF001EFF00C7BD00FFAE00FF9E00FF
8F00FF8000FF7000FF5100FF4200FF4200FF2300FF2300FF1400FF0500FF0500FF000AFF
0019FF0028FF0038FF0038FF0047FF0047FF0047FF0047FF0038FF0028FF2300FF4200FF
0500FF0057FF0075FF0085FF0094FF00A3FF00B3FF00B3FF00C2FF00D1FF00D1FF00D1FF
00E1FF00E1FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00E1FF00D1FF0094FF
00C2FF00F0FF00FFFF00FFFF00FFFF00FFF000FFF000FFF000FFF000FFF000FFFF00FFFF
00F0FF00E1FF00C2FF0500FF6100FF0047FF00B3FF00D1FF00E1FF00E1FF00E1FF00D1FF
00B3FF0066FF2300FFBD00FF0094FF0075FF00E1FF00E1FF0094FF0047FF0038FF0094FF
0075FF00F0FF00FFFF00FFFF0057FF00E1FF0094FF00FFE100FFC200FFC200FFC200FFD1
0066FF00F0FF00FFE10028FF00FFB300FFA300FF9400FF9400FFA300FFB300FFD100B3FF
00E1FF0094FF00FFA300FF8500FF8500FF8500FF8500FF8500FFB300D1FF00FF8500FF57
00FF4700FF3800FF2800FF2800FF2800FF1900FF1900FF1900FF1900FF1900FF1900FF0A
00FF0A00FF0A00FF1900FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A05FF0005FF0000FF0A
00FF0A05FF0005FF0000FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF1900FF1900FF1900FF1900FF1900FF1900FF2800FF2800FF38
00FF4700FF570094FF000AFF00FFB300FF5700FF3800FF2800FF1900FF1900FF0A05FF00
05FF0005FF0005FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0023FF0023FF00
14FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
00E1FF00C2FFCC00FF0038FF00A3FF00E1FF00FFFF00FFE100FFD100FFC200FFC200FFB3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00D1FF0085FF0057FF00D1FF00E1FF00FFFF00FFF000FFE100FFD100FFD100FFC200FFC2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1400FF0038FF0094FF00D1FF00F0FF00FFFF00FFF000FFE100FFE100FFD100FFD100FFC2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0047FFFF00001400FF00C2FF00F0FF00FFFF00FFF000FFF000FFE100FFE100FFD100FFD1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0019FF0057FF0085FF0085FF00E1FF00F0FF00FFFF00FFF000FFF000FFE100FFE100FFE1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FA00FF0019FF00A3FF00C2FF00E1FF00F0FF00F0FF00D1FF00FFFF00FFFF00F0FF00FFF0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0500FF0075FF0094FF00C2FF00D1FF00D1FF00B3FFFF001E00E1FF9E00FF00D1FF00F0FF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9E00FF0019FF0066FF0057FF00C2FF00C2FF0094FF0500FF00A3FF3300FF00C2FF00D1FF
00D1FF0028FF0057FF0057FF0019FFFF00C700C2FF00FFFF00FFE100FFD100FFD100FFE1
00E1FF0075FF00FFE100FFFFFF007A00FFD100FFB300FFA300FFA300FFA300FFB300FFB3
00FFB300FFC200FFC200FFD100FFF000F0FF0028FF00E1FF00FFFF00FFF000FFD100FFC2
00FFB300FFA300FF9400FF9400FF8500FF8500FF7500FF7500FF7500FF7500FF6600FF66
00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7500FF7500FF7500FF6600FF75
00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7500FF7500FF7500FF75
00FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF75
00FF7500FF8500FF8500FF8500FF8500FF9400FF8500FF8500FF9400FF9400FF9400FF94
00FF9400FFA300FFA300FFB300FFB300FFC20500FF00FFE100FFD100FFD100FFD100FFD1
00FFD100FFD100FFD100FFD100FFD100FFD100FFE100FFE100FFE100FFF000FFF000FFFF
00FFFF00F0FF00F0FF00E1FF00E1FF00D1FF00D1FF00D1FF00C2FF00C2FF00C2FF00B3FF
0094FFFF00C70019FF0057FF0066FF0057FF1400FF000AFF8000FFFF00F50019FF0019FF
8F00FF0500FF7000FF3300FF0057FF0066FF0066FF0066FF0066FF0057FF0057FF0057FF
0047FF0038FF0028FF0028FF0028FF0019FF000AFF0500FF2300FF7000FFAE00FFEB00FF
DC00FFFF00D7BD00FFAE00FF7000FF6100FF6100FF7000FF8F00FFFF0099FF00F5FF008A
FF003DFF00B8FF00F5FA00FFEB00FFFA00FFFF00F5FF00D7FF00C7FF00B8FF0099FF007A
FF004CFF000FFF000FFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF001EFF0000FF0099FF00D7FF00F5FA00FFCC00FFBD00FFAE00FF
8F00FF7000FF6100FF5100FF4200FF4200FF4200FF5100FF6100FFFF00E6DC00FFFF00F5
5100FF5100FF0047FF0057FF0066FF0075FF0075FF0075FF0085FF0085FF0085FF0094FF
0094FF00A3FF00A3FF00A3FF00A3FF00B3FF00C2FF00C2FF00D1FF00E1FF00E1FF00F0FF
00F0FF00F0FF00FFFF00FFFF00FFFF00FFFF00FFF000FFF000FFF000FFE100FFE100FFE1
00FFE100FFD100FFD100FFD100FFD100FFD100FFC200FFC200FFC200FFC200FFC200FFC2
00FFC200FFC200FFC200FFC200FFB300FFB300FFC200FFC200FFB300FFB300FFC200FFC2
00FFC200FFC200FFC200FFD100FFE100F0FF00E1FF0094FF0500FF0085FF00C2FF00F0FF
00FFD100FFC200FFB300FFA300FFA300FF9400FF9400FF9400FF8500FF8500FF7500FF75
00FF7500FF6600FF6600FF6600FF6600FF6600FF5700FF5700FF5700FF5700FF4700FF47
00FF4700FF4700FF3800FF3800FF3800FF3800FF3800FF3800FF2800FF2800FF2800FF28
00FF2800FF1900FF1900FF1900FF1900FF1900FF1900FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A05FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0000FF0A00FF0A
00FF0A00FF1900FF2800FF7500FF5700FF1900FF0A05FF0005FF0014FF0014FF0014FF00
14FF0014FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0033FF0033FF0033FF0023FF0033FF0033FF00
8000FF000AFF3300FF0075FF00A3FF00A3FF0094FF4200FF0047FF0066FF00B3FF00B3FF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DC00FF0019FF0057FF0075FF0094FF0085FF0085FF0057FF000AFF0075FF0094FF0085FF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8F00FF1400FF0500FF0057FF1400FF1400FF0057FF0019FF1400FF0057FF2300FF0038FF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7000FF1400FFBD00FF1400FF0500FF1400FF0028FFFF00E6BD00FF3300FF1400FFDC00FF
6100FF0085FF4200FF00FFFF00FFE100FFD100FFC200FFB300FFB300FFA300FFA300FF94
00FF9400FF9400FF9400FF8500FF8500FF8500FF8500FF8500FF8500FF9400FF9400FF94
00FFA300FFB300FFC200FFF00047FF0066FF00FFD100FFC200FFB300FFD100D1FF00F0FF
00B3FF0075FF00FFF000B3FF00FFA300FF8500FF7500FF6600FF6600FF6600FF6600FF57
00FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF57
00FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF6600FF6600FF6600FF6600FF66
00FF6600FF6600FF6600FF6600FF6600FF7500FF6600FF7500FF7500FF7500FF7500FF75
00FF7500FF7500FF7500FF7500FF8500FF8500FF8500FF8500FF9400FF8500FF8500FF94
00FF9400FF9400FF9400FF9400FFA300FFA300FFA300FFB300FFB300FFB300FFB300FFB3
00FFC200FFC200FFC200FFC200FFD100FFD100FFD100FFE100FFE100FFE100FFF000FFFF
00F0FF00E1FF0085FF0066FF8F00FF0019FF0085FF00A3FF00A3FF00A3FF0094FF0085FF
0075FF0057FF0028FFAE00FFFF0000FF0000FF00C70028FF0057FF0075FF0085FF0085FF
0085FF0094FF0094FF0094FF0094FF0085FF0085FF0085FF0075FF0075FF0075FF0066FF
0057FF0057FF0047FF0038FF0028FF000AFFFA00FF4200FF6100FFFF000F7000FF4200FF
7000FF6100FF8000FF4200FF2300FF2300FF2300FF3300FF4200FF5100FF7000FFFF00E6
CC00FF9E00FF9E00FF9E00FFAE00FFBD00FFDC00FFFF00C7FF0000FF00A8FF00B8FF0099
FF007AFF005CFF002EFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF006BFF00A8FF00C7FF00F5EB00FFEB00FF
FF0000AE00FF8000FF5100FF3300FF2300FF1400FF0500FF000AFF000AFF0019FF0028FF
0038FF0038FF0047FF0057FF0057FF0057FF0066FF0066FF0075FF0085FF0094FF0094FF
00A3FF00A3FF00B3FF00B3FF00C2FF00C2FF00D1FF00D1FF00E1FF00E1FF00E1FF00E1FF
00F0FF00F0FF00F0FF00FFFF00FFFF00FFFF00FFFF00FFF000FFF000FFF000FFE100FFE1
00FFD100FFD100FFD100FFC200FFC200FFC200FFC200FFB300FFB300FFB300FFB300FFB3
00FFB300FFA300FFB300FFA300FFA300FFA300FFA300FFA300FFA300FFA300FFA300FFA3
00FFB300FFB300FFB300FFB300FFC200FFD100FFE100FFF00075FF000AFF8F00FF00C2FF
00F0FF00E1FF00B3FF00FFD100FFC200FFA300FF9400FF9400FF8500FF8500FF7500FF75
00FF7500FF7500FF6600FF6600FF5700FF5700FF5700FF5700FF4700FF4700FF4700FF47
00FF3800FF3800FF3800FF3800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF19
00FF1900FF1900FF1900FF1900FF0A00FF0A00FF0A00FF1900FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A05FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0014FF0014FF0014FF0014FF0014FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0033FF0023FF0023FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
0047FF0047FF0038FF3300FFFF003DFF00D72300FFBD00FFFF0000FF0000FF005CAE00FF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0075FF0075FF0047FF000AFF8000FFFF00006100FFFF006BCC00FF1400FF4200FF8000FF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00B3FF0094FF0057FF4200FFFF00007000FF000AFF0019FFFF00C70047FF0028FF0066FF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00C2FF00A3FF0075FF1400FFFF003D2300FF4200FF0066FF0028FF0066FF00A3FF00A3FF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00A3FF000AFF6100FF0057FF0500FF0038FF0066FF0094FF0019FF0085FF0075FF00E1FF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1400FF00C2FFFF008A00A3FF0075FF0500FF0085FF00C2FF2300FF00C2FF00D1FF00FFFF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00FFFF00F0FF00C2FF00D1FF0094FF4200FF00B3FF00E1FF00E1FF00B3FF00FFF000FFE1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00FFE100FFF000FFFF00E1FF0085FF9E00FFFF00C700F0FF00FFFF00FFE100FFE100FFD1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00FFD100FFE100FFF000F0FF0019FFFF008A00A3FF00F0FF00FFF000FFE100FFD100FFC2
00FFD100FFE10075FF0038FF00FFE100FFB300FF9400FF8500FF7500FF7500FF6600FF66
00FF6600FF6600FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF6600FF6600FF66
00FF7500FF9400FFA300FFE100FFD100FF9400FF7500FF6600FF5700FF5700FF5700FF47
00FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF38
00FF4700FF3800FF4700FF3800FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF47
00FF4700FF4700FF4700FF4700FF4700FF4700FF5700FF5700FF5700FF5700FF5700FF57
00FF5700FF5700FF5700FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7500FF75
00FF7500FF7500FF7500FF7500FF7500FF8500FF8500FF8500FF8500FF8500FF8500FF94
00FF9400FF9400FF9400FFA300FF9400FFA300FFA300FFA300FFA300FFB300FFB300FFB3
00FFC200FFC200FFE17000FF00D1FF00C2FF00D1FF00FFFF00FFFF00FFFF00FFFF00F0FF
00E1FF00C2FF00C2FF00B3FF0047FF2300FF1400FF8000FF0057FF5100FF7000FF0047FF
6100FF000AFF0075FF0094FF00A3FF00B3FF00C2FF00D1FF00D1FF00D1FF00D1FF00D1FF
00D1FF00D1FF00D1FF00C2FF00B3FF0094FF9E00FFFF00990028FF0075FF0085FF0085FF
0085FF0075FF0057FF0038FF2300FF1400FF0019FF0047FF0057FF0057FF0057FF0057FF
0047FF0038FF000AFFFF00F58000FF1400FF1400FF2300FF3300FF6100FFFA00FF7000FF
7000FF8000FF8000FF8000FF8F00FF9E00FFAE00FFCC00FFFF00E6FF00A8FF00C7FF00A8
FF007AFF003DFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF002EFF008AFF00E6FA00FF
BD00FF9E00FF8000FF6100FF4200FF4200FF4200FFFF00001400FF0500FF000AFFFF00F5
5100FF1400FF000AFF000AFF0500FFBD00FF2300FF0019FF0038FF0038FF8000FF0500FF
000AFFFA00FFFF00006100FF7000FF000AFF0019FF0028FF0075FF0075FF0047FFFF00E6
0057FF0066FF0047FF00A3FF00B3FF0085FF00A3FFFF00B800E1FF00E1FF0085FF00B3FF
9E00FF00FFFF00FFF000D1FF00C2FF00FFC200FFB300FFA300FFA300FFA300FF9400FF94
00FF9400FF9400FF9400FF9400FF9400FF9400FF8500FF9400FF8500FF8500FF8500FF85
00FF8500FF9400FF9400FF9400FF9400FF9400FF9400FF9400FFA300FFA300FFA300FFB3
00FFC200FFC200FFF000FFFF00E1FF0075FF3300FF0019FF8000FF00C2FF00FFF000FFD1
00FFB300FFA300FF9400FF8500FF8500FF7500FF7500FF8500FFC200FF9400FF5700FF57
00FF4700FF4700FF3800FF3800FF2800FF2800FF2800FF2800FF1900FF1900FF1900FF19
00FF1900FF1900FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A05FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0023FF0023FF0023FF0014FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0033FF0033FF00
33FF0033FF0023FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
00FFC200FFE100FFFF00E1FF00B3FF0038FF0019FF00C2FF1400FF00FFD100FFC200FFC2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00FFC200D1FF3300FF0057FF0038FFFF004C0075FF0094FF00FFF000FFC200FFB300FFB3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00FFB300FFC200FFE13300FF00C2FFCC00FF00D1FF00E1FF0047FF00FFC200FFB300FFA3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00FFA300FFB300FFC200FFE100F0FF0057FF00D1FF00FFF000FFD100FFB300FFA300FFA3
00FF9400FF9400FF9400FF9400FF940075FF00FF9400FF7500FF6600FF6600FF5700FF57
00FF5700FF5700FF4700FF5700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF47
00FF5700FF5700FF7500FFE100FF6600FF5700FF5700FF4700FF4700FF3800FF4700FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF5700FF5700FF57
00FF5700FF5700FF5700FF5700FF6600FF6600FF6600FF6600FF6600FF7500FF7500FF75
00FF7500FF8500FF7500FF8500FF8500FF8500FF8500FF8500FF9400FF9400FF9400FF94
00FF9400FF9400FFA300FFA300FFA300FFA300FFA300FFA300FFB300FFB300FFB300FFC2
00FFC200FFD100FFE100FFF000F0FF00D1FF6100FF0075FF00B3FF00C2FF00B3FF00A3FF
0085FF0047FFFF005C7000FF0066FF00A3FF00C2FF00D1FF00D1FF00D1FF00B3FF3300FF
000AFF00A3FF00C2FF00A3FF2300FF0066FF00C2FF00E1FF00F0FF00F0FF00F0FF00F0FF
00F0FF00F0FF00E1FF00E1FF00E1FF00E1FF00D1FF00D1FF00C2FF00C2FF00C2FF00B3FF
0094FF0028FFFF00D70500FF0057FF0066FF0075FF0075FF0075FF0075FF0075FF0075FF
0066FF0066FF0057FF0057FF0047FF000AFF3300FF9E00FF3300FF1400FF1400FF1400FF
2300FF3300FF6100FFDC00FFFF00F5FF00C7FA00FFEB00FFFF00F5FF00C7FF00B8FF0000
FF002EFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF004CFF008AFF00B8FF00D7FA00FFBD00FF
AE00FFBD00FF9E00FF7000FF4200FF2300FF1400FF0500FF000AFF0019FF0028FF0047FF
0047FF0057FF0057FF0057FF0047FF0019FF0066FF0085FF0094FF0094FF0094FF0085FF
000AFFFF00000094FF0094FF00A3FF00A3FF00A3FF00A3FF0085FF0028FF0038FF0075FF
00B3FF00D1FF00E1FF00F0FF00F0FF00FFFF00FFF000FFF000FFE100FFE100FFD100FFD1
00FFC200FFC200FFB300FFB300FFB300FFA300FFA300FFA300FF9400FF9400FF9400FF94
00FF9400FF8500FF9400FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF85
00FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF9400FF9400FFA3
00FFB300FFD11400FF0085FFFF000000B3FF00F0FF00FFF000FFE100A3FF000AFF00E1FF
FF000F0085FF00A3FF00FFF000FFD100FFD100FFD100FFF000A3FFFF001E00A3FF00FFC2
00FF7500FF5700FF5700FF4700FF3800FF3800FF2800FF2800FF2800FF1900FF1900FF19
00FF1900FF1900FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A05FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0023FF0023FF0023FF0023FF00
23FF0014FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0042FF0042FF0042FF00
00FFA300FFB300FFC200FFD14200FF0047FF0038FF00FFE100FFD100FFB300FFA300FF94
00FF9400FF8500FF8500FF8500FF8500FF8500FF7500FF6600FF6600FF5700FF5700FF57
00FF5700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF47
00FF4700FF5700FFC200FF6600FF5700FF4700FF4700FF4700FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF5700FF5700FF5700FF57
00FF5700FF5700FF5700FF6600FF6600FF6600FF6600FF6600FF7500FF7500FF7500FF75
00FF8500FF7500FF8500FF8500FF8500FF8500FF8500FF9400FF9400FF9400FF9400FF94
00FF9400FFA300FFA300FFA300FFA300FFA300FFA300FFB300FFB300FFB300FFC200FFC2
00FFC200FFE10047FF0028FF00B3FF0094FF0057FF0075FF0094FF0047FF0057FF0075FF
0047FFFF00D70047FF0047FF0038FF2300FF00D1FF00E1FF00E1FF00D1FF00B3FF0075FF
0038FF00C2FF00D1FF00D1FF00C2FF0057FF00B3FF00F0FF00F0FF00F0FF00F0FF00F0FF
00F0FF00F0FF00F0FF00F0FF00E1FF00E1FF00E1FF00E1FF00D1FF00D1FF00C2FF00B3FF
0094FF0057FF6100FF3300FF0057FF0085FF0085FF0085FF0085FF0085FF0075FF0075FF
0075FF0066FF0066FF0057FF0047FF0038FF000AFF0500FF0500FF000AFF0500FF0500FF
1400FF2300FF3300FF5100FF8000FFBD00FFFF0099FF003DFF000FFF005CFF007AFF002E
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF003DFF007AFF00A8EB00FFBD00FF
9E00FF8F00FF7000FF5100FF4200FF3300FF2300FF3300FF3300FFFF00C70500FF0047FF
0057FF0057FF0066FF0066FF0066FF0066FF0085FF0094FF0094FF00A3FF0094FF00A3FF
0085FF0085FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF0085FF1400FFFF008A0066FF
00A3FF00B3FF00D1FF00F0FF00F0FF00FFFF00FFF000FFF000FFE100FFD100FFD100FFC2
00FFC200FFC200FFB300FFB300FFA300FFA300FFA300FF9400FF9400FF9400FF9400FF94
00FF9400FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF85
00FF8500FF8500FF7500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF9400FFA3
00FFC20085FF000AFF0047FF00FFE100E1FF0066FF00FFD100FFC200FFD100FFD100FFE1
00E1FF3300FF6100FF0500FF00FFFF00A3FF00D1FF00C2FF00FFFF00FFC200FFA300FF85
00FF7500FF5700FF5700FF4700FF4700FF3800FF3800FF2800FF2800FF2800FF1900FF19
00FF1900FF1900FF1900FF1900FF0A00FF0A00FF0A00FF0A00FF0A00FF0A05FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0023FF0023FF0023FF0023FF00
23FF0023FF0014FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0033FF0033FF0033FF0023FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0042FF0042FF0042FF0033FF0033FF0042FF0042FF00
00FFA300FFB300FFC200FFE100F0FF0057FF00C2FF00FFF000FFE100FFC200FFA300FF94
00FF8500FF8500FF7500FF7500FF7500FF7500FF6600FF6600FF5700FF5700FF5700FF57
00FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF47
00FF4700FF4700FF4700FF4700FF4700FF4700FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF2800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF5700FF57
00FF5700FF5700FF5700FF5700FF6600FF6600FF6600FF6600FF7500FF7500FF7500FF75
00FF7500FF8500FF8500FF8500FF8500FF8500FF9400FF9400FF9400FF9400FF9400FFA3
00FFA300FFA300FFA300FFA300FFA300FFA300FFB300FFB300FFB300FFB300FFC200FFC2
00FFD100FFE100F0FF0057FF00A3FF0085FF0094FF2300FF0038FF0047FF4200FF0038FF
EB00FF0047FF0085FF0085FF0075FF00C2FF00E1FF00E1FF00F0FF00E1FF00D1FF0038FF
0075FF00D1FF00F0FF00F0FF00E1FF00A3FF00F0FF00F0FF00FFFF00FFFF00F0FF00F0FF
00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00E1FF00E1FF00E1FF00D1FF00C2FF0094FF
0028FF0028FF0066FF0057FF0075FF0085FF0094FF0094FF0085FF0085FF0085FF0075FF
0075FF0066FF0066FF0057FF0057FF0047FF0038FF0028FF0019FF000AFF000AFF0500FF
1400FF2300FF3300FF8F00FFFF008AFF00B8CC00FFDC00FFFF00E6FF0099FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF005CFF0099FF002EFF0000CC00FF
9E00FF8F00FF7000FF6100FF5100FF4200FF6100FFBD00FF7000FF8000FF0019FF0047FF
0057FF0066FF0066FF0075FF0075FF0085FF0094FF0094FF00A3FF00A3FF00A3FF00B3FF
00B3FF00B3FF00C2FF00C2FF00C2FF00C2FF00C2FF00B3FF00A3FF2300FF0057FF2300FF
0075FF0057FF00B3FF00E1FF00F0FF00FFFF00FFF000FFF000FFE100FFE100FFD100FFD1
00FFC200FFB300FFB300FFB300FFA300FFA300FFA300FF9400FF9400FF9400FF9400FF85
00FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF7500FF7500FF75
00FF7500FF7500FF7500FF7500FF7500FF7500FF8500FF8500FF8500FF8500FF9400FF94
00FFB300E1FF0066FF00FFC200FFB300FFE10057FF00FFD100FFB300FFB300FFB300F0FF
0057FF00D1FF00D1FF0094FF0066FF0075FF0047FF0028FF00C2FF00FFC200FFA300FF85
00FF7500FF6600FF5700FF5700FF4700FF4700FF4700FF3800FF2800FF2800FF1900FF19
00FF1900FF1900FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A05FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0033FF0033FF0033FF0033FF0033FF0023FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
42FF0042FF0042FF0042FF0042FF0033FF0042FF0042FF00
00FFA300FFC200F0FF00F0FF00F0FF0075FF1400FF00E1FFFF00F500FFE100FFA300FF94
00FF8500FF7500FF7500FF7500FF7500FF7500FF6600FF5700FF5700FF5700FF5700FF47
00FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF2800FF3800FF2800FF2800FF2800FF2800FF3800FF2800FF2800FF2800FF2800FF38
00FF2800FF2800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF5700FF5700FF57
00FF5700FF5700FF5700FF6600FF6600FF6600FF7500FF7500FF7500FF7500FF7500FF85
00FF8500FF8500FF8500FF8500FF9400FF9400FF9400FF9400FF9400FFA300FFA300FFA3
00FFA300FFA300FFA300FFA300FFB300FFB300FFB300FFB300FFC200FFC200FFC200FFC2
00FFD100FFE100FFF000FFFF00E1FF00D1FF00B3FF0085FF000AFF7000FFCC00FFFF00C7
0019FF0075FF00A3FF00B3FF0094FF00E1FF00F0FF00F0FF00F0FF00F0FF00E1FF00C2FF
00A3FF00F0FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00F0FF00F0FF00F0FF00F0FF00F0FF00E1FF00E1FF00E1FF00D1FF00D1FF00C2FF
00A3FF0085FF00A3FF0094FF00A3FF0094FF0094FF0094FF0094FF0085FF0085FF0075FF
0075FF0066FF0066FF0057FF0057FF0047FF0038FF0028FF0028FF0019FF000AFF0500FF
1400FF2300FF3300FF5100FF7000FF8F00FF9E00FFFF00F5FF00C7FF007AFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF003DFF007AFF00B8FF00D7FA00FFCC00FF
CC00FFCC00FF9E00FFCC00FFFF00F57000FFFF00F55100FF1400FF000AFF0038FF0047FF
0057FF0066FF0066FF0075FF0085FF0085FF0094FF00A3FF00A3FF00A3FF00B3FF00B3FF
00C2FF00C2FF00C2FF00D1FF00D1FF00D1FF00C2FF00C2FF00C2FF00A3FF0085FF0028FF
6100FF0047FF0094FF00D1FF00E1FF00E1FF00FFFF00FFF000FFE100FFE100FFD100FFC2
00FFC200FFB300FFB300FFB300FFA300FFA300FFA300FF9400FF9400FF9400FF9400FF85
00FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF7500FF8500FF7500FF7500FF75
00FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF8500FF8500FF8500FF9400FFA3
00FFC200D1FF00FFC200FFA300FFA300FFB32300FF00FFB300FFA300FFA300FFA30075FF
00FFD100E1FF00FFE100FFFF0028FFFF00E6FF008AFF00E600A3FF00FFF000E1FF00FFA3
00FF8500FF7500FF6600FF6600FF5700FF6600FF6600FFB300FF3800FF2800FF1900FF19
00FF1900FF1900FF1900FF1900FF0A00FF0A00FF0A00FF0A00FF0A05FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0023FF0023FF0023FF0023FF0014FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0033FF0033FF0033FF0033FF0033FF0023FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
00FF9400FFD100FFF000B3FF1400FFEB00FF0066FF00C2FF00F0FF00FFC200FFA300FF85
00FF8500FF7500FF7500FF7500FF6600FF6600FF6600FF5700FF5700FF5700FF5700FF47
00FF4700FF4700FF4700FF4700FF4700FF3800FF4700FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF38
00FF2800FF2800FF3800FF2800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF4700FF3800FF3800FF4700FF4700FF4700FF4700FF4700FF4700FF5700FF5700FF57
00FF5700FF5700FF5700FF6600FF6600FF6600FF7500FF7500FF8500FF8500FF8500FF85
00FF8500FF8500FF8500FF9400FF9400FF9400FF9400FFA300FFA300FFA300FFB300FFB3
00FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC200FFC200FFC200FFD1
00FFD100FFE100FFE100FFFF00F0FF00E1FF00C2FF0057FF6100FFFF0000FF00D7FF0099
000AFF0085FF00C2FF00D1FF00E1FF00F0FF00FFFF00FFFF00FFFF00FFFF00FFFF0038FF
00F0FF00FFFF00FFFF00FFF000FFFF00FFF000FFF000FFF000FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00F0FF00F0FF00F0FF00F0FF00E1FF00E1FF00E1FF00D1FF00C2FF
00C2FF00B3FF00B3FF00B3FF00A3FF00A3FF00A3FF0094FF0094FF0094FF0085FF0075FF
0075FF0066FF0066FF0057FF0047FF0047FF0038FF0028FF0028FF0019FF0500FF6100FF
3300FF4200FF4200FF5100FF6100FF8000FF9E00FFFF00C7FF007AFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000FFF0000FF00D7FF00F5FF00C7
FF00F5FF004CEB00FFFF00E6FF007AFF002E9E00FF4200FF1400FF000AFF0028FF0047FF
0057FF0066FF0075FF0075FF0085FF0085FF0094FF00A3FF00A3FF00B3FF00B3FF00B3FF
00C2FF00C2FF00D1FF00D1FF00D1FF00D1FF00D1FF00D1FF00C2FF00A3FF0066FF0019FF
7000FF000AFF0094FF00B3FF00B3FF00A3FF00E1FF00FFFF00FFF000FFE100FFD100FFD1
00FFC200FFC200FFB300FFA300FFA300FFA300FF9400FF9400FF9400FF9400FF9400FF85
00FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF7500FF7500FF7500FF7500FF75
00FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF8500FF8500FFA3
00FFD100FFC200FF9400FF8500FF9400FF9400FFA300FF9400FF9400FF9400FF9400FFA3
00FFA300FFB300FFC200FFF00075FF0066FF0094FF0075FF00D1FF7000FF0094FF00FFD1
00FFD100FFD100FF9400FF7500FF7500D1FF00FFF000F0FF00FF5700FF2800FF2800FF19
00FF1900FF1900FF0A00FF0A00FF0A00FF0A00FF0A00FF0A05FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0014FF0014FF00
14FF0005FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0023FF0023FF0023FF0023FF0023FF0023FF0014FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
00FF8500FFA300FFC2FF000000F0FF0075FF00D1FF00FFF000F0FF0066FF00FFA300FF85
00FF7500FF7500FF7500FF6600FF6600FF6600FF5700FF5700FF5700FF5700FF4700FF47
00FF4700FF4700FF4700FF4700FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF4700FF4700FF4700FF4700FF4700FF4700FF5700FF5700FF57
00FF5700FF5700FF5700FF6600FF6600FF6600FF7500FF7500FF8500FF9400FF9400FF94
00FF8500FF9400FF9400FF9400FF9400FF9400FFA300FFA300FFB300FFC200FFF000FFC2
00FFB300FFB300FFB300FFB300FFB300FFC200FFC200FFC200FFC200FFC200FFC200FFD1
00FFD100FFE100FFF000FFFF00F0FF00C2FF00B3FF0075FFDC00FF3300FFAE00FFFF0000
0066FF0094FF00C2FF00E1FF00E1FF00F0FF00FFFF00FFF000FFF000FFF000FFF000FFF0
00FFF000FFF000FFF000FFF000FFF000FFF000FFF000FFF000FFF000FFF000FFF000FFFF
00FFFF00FFFF00FFFF00FFFF00F0FF00F0FF00F0FF00F0FF00E1FF00E1FF00E1FF00D1FF
00D1FF00C2FF00C2FF00B3FF00B3FF00B3FF00A3FF00A3FF0094FF0094FF0085FF0075FF
0066FF0057FF0057FF0047FF0047FF0038FF0038FF0028FF0019FF000AFF0500FF3300FF
8F00FF5100FF5100FF8F00FF8000FF9E00FFDC00FFFA00FFFF00B8FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF002EFF007AFF006BFF006BFF0000
FF005CFF0000CC00FFBD00FFCC00FF6100FF8000FFFF00008F00FF5100FF6100FF7000FF
0057FF0066FF0075FF0075FF0085FF0085FF0094FF00A3FF00A3FF00B3FF00B3FF00C2FF
00D1FF00D1FF00D1FF00D1FF00D1FF00E1FF00E1FF00D1FF00D1FF0066FF0085FF0038FF
0085FF0057FF7000FF0075FF0075FF0047FF0047FF00F0FF00FFFF00FFF000FFF000FFD1
00FFC200FFC200FFB300FFA300FFA300FFA300FF9400FF9400FF9400FF9400FF8500FF85
00FF8500FF8500FF8500FF8500FF8500FF7500FF7500FF7500FF7500FF7500FF7500FF75
00FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF85
00FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF94
00FF9400FFA300FFB300FFC200FFF00047FF00F0FF00FFFF00FFD100D1FF00FFFF1400FF
0057FF00F0FF00FFB300FF9400C2FF00E1FF00FFB300FF5700FF3800FF2800FF2800FF19
00FF1900FF1900FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A05FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
33FF0033FF0033FF0033FF0023FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
00FF8500FF9400FFB300FFD100FFE10038FF0057FF00FFD100FFC200FFB300FF9400FF85
00FF8500FF7500FF7500FF6600FF6600FF6600FF5700FF5700FF5700FF4700FF4700FF47
00FF4700FF4700FF4700FF4700FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF2800FF3800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF5700FF5700FF57
00FF5700FF5700FF6600FF6600FF6600FF6600FF7500FF8500FFA300FFC200FFA300FF94
00FF9400FF9400FF9400FF9400FF9400FFA300FFA300FFB300FFC200FFF000FFFF00FFD1
00FFC200FFC200FFC200FFC200FFC200FFC200FFC200FFC200FFC200FFD100FFD100FFD1
00FFE100FFF000FFFF00F0FF00E1FF0094FF0075FFFF00000066FF6100FF0047FF0057FF
FF004C00A3FF00C2FF00E1FF00F0FF00FFFF00FFFF00FFF000FFF000FFF000FFE100FFE1
00FFF000FFE100FFE100FFF000FFE100FFF000FFF000FFF000FFF000FFF000FFF000FFF0
00FFFF00FFFF00FFFF00FFFF00FFFF00F0FF00F0FF00F0FF00E1FF00E1FF00E1FF00D1FF
00D1FF00D1FF00C2FF00B3FF00B3FF00B3FF00A3FF00A3FF0094FF0094FF0075FF3300FF
0038FF0019FF0047FF0047FF0038FF0038FF0019FF0500FF000AFF0500FF1400FF7000FF
FF008A7000FF8000FFEB00FFAE00FFEB00FFFF0000FF0000FF007AFF007AFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF005CFF007AFF00E6
EB00FFFF00C79E00FF8000FF6100FF4200FF4200FF4200FFAE00FF2300FF3300FF0028FF
0047FF0066FF0066FF0075FF0075FF0075FF0085FF0094FF00A3FF00B3FF00B3FF00C2FF
00C2FF00D1FF00E1FF00E1FF00E1FF00E1FF00E1FF00E1FF00E1FF00D1FF00D1FF00B3FF
00B3FF0085FF0066FFFF003D8F00FF0085FF00C2FF00E1FF00F0FF00E1FF00D1FF00FFF0
00FFD100FFC200FFB300FFB300FFA300FFA300FF9400FF9400FF9400FF9400FF8500FF85
00FF8500FF8500FF8500FF8500FF8500FF7500FF7500FF7500FF7500FF7500FF7500FF75
00FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF75
00FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF8500FF85
00FF9400FFA300FFB300FFC200FFF00047FF00FFE100FFC200FFB300FFB300FFA300FFC2
0038FF00FFFF0094FF0075FF00A3FF00FF8500FF6600FF4700FF3800FF3800FF2800FF19
00FF1900FF1900FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A05FF0005FF0000FF0A
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
33FF0033FF0033FF0033FF0033FF0023FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0042FF0042FF0042FF00
33FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
00FF8500FF9400FFA300FFB300FFD100D1FF00D1FF00FFD100FFB300FFA300FF9400FF85
00FF7500FF7500FF6600FF6600FF6600FF5700FF5700FF5700FF5700FF4700FF4700FF47
00FF4700FF4700FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF2800FF2800FF2800FF2800FF2800FF3800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF4700FF4700FF4700FF4700FF4700FF5700FF5700FF57
00FF5700FF6600FF6600FF6600FF6600FF7500FF7500FF85FF00F500FFE100FFB300FFA3
00FFA300FFA300FFA300FFA300FFA300FFA300FFB300FFC200FFD13300FF0094FF00F0FF
00FFD100FFD100FFC200FFC200FFD100FFD100FFD100FFD100FFE100FFD100FFD100FFE1
00FFE100FFFF0075FF00D1FF00C2FF0085FFFF007A0066FF00A3FF00A3FF00B3FF0094FF
0038FF0057FF0094FF00B3FF00E1FF00FFFF00FFF000FFF000FFE100FFE100FFE100FFE1
00FFE100FFE100FFE100FFE100FFE100FFE100FFE100FFF000FFF000FFF000FFF000FFF0
00FFF000FFFF00FFFF00FFFF00F0FF00F0FF00F0FF00F0FF00E1FF00E1FF00E1FF00E1FF
00D1FF00D1FF00C2FF00C2FF00B3FF00B3FF00A3FF00A3FF0094FF0085FF0075FF0047FF
EB00FF000AFF0028FF0038FF0028FF0028FF000AFFFF007A1400FF1400FF2300FF6100FF
EB00FFFF0099CC00FFFF001EFF00C7DC00FFFF001EDC00FFFA00FFFF006BFF007AFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF004CFF00B8FF00E6EB00FF
CC00FFAE00FF8F00FF7000FF5100FF3300FF2300FF2300FF0500FF000AFF0019FF0038FF
0047FF0057FF0057FF0066FF0066FF0066FF0075FF0066FF0075FF00A3FF00B3FF00C2FF
00D1FF00D1FF00E1FF00E1FF00E1FF00E1FF00E1FF00E1FF00E1FF00E1FF00E1FF00D1FF
00C2FF00B3FF0094FF0028FF8F00FF5100FF0075FF0057FF00B3FF00B3FF00A3FF0019FF
00FFF000FFD100FFC200FFB300FFA300FFA300FF9400FF9400FF9400FF8500FF8500FF85
00FF8500FF8500FF8500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF75
00FF7500FF7500FF7500FF6600FF7500FF6600FF6600FF6600FF7500FF6600FF6600FF66
00FF6600FF7500FF7500FF6600FF6600FF6600FF6600FF7500FF7500FF7500FF7500FF85
00FF8500FF9400FFC200FFE10047FF00FFFF00F0FF00FFB300FF9400FF8500FF8500FFB3
00FFA300FF9400FF9400FFB32300FF00FF8500FF5700FF4700FF3800FF2800FF2800FF19
00FF1900FF1900FF0A00FF0A00FF0A00FF0A00FF0A00FF0A05FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0042FF0042FF0042FF0042FF00
42FF0033FF0042FF0042FF0042FF0042FF0042FF0042FF00
00FF8500FF9400FFA300FFA300FFD10038FF00B3FF00FFF000FFB300FFA300FF9400FF85
00FF8500FF7500FF6600FF6600FF6600FF5700FF5700FF5700FF5700FF5700FF4700FF47
00FF4700FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF3800FF2800FF3800FF3800FF38
00FF3800FF3800FF4700FF4700FF4700FF4700FF4700FF4700FF5700FF5700FF5700FF57
00FF5700FF6600FF6600FF6600FF7500FF7500FF8500FF9400FFB30075FF0028FF00C2FF
00FFB300FFA300FFA300FFA300FFB300FFB300FFE100FFFF00FFF000E1FF0085FF00FFF0
00FFE100FFD100FFD100FFE100FFE100D1FF00FFF000FFE100FFE100FFE100FFE100FFE1
00FFF000E1FF0094FF00A3FFFF000F3300FF0085FF0085FF00C2FF00D1FF00D1FF00A3FF
0028FF00A3FF0047FF0028FF2300FF00F0FF00FFF000FFE100FFE100FFE100FFE100FFD1
00FFD100FFE100FFE100FFE100FFE100FFE100FFE100FFE100FFF000FFF000FFF000FFF0
00FFF000FFFF00FFFF00FFFF00FFFF00F0FF00F0FF00F0FF00F0FF00E1FF00E1FF00E1FF
00D1FF00D1FF00C2FF00C2FF00B3FF00B3FF00A3FF00A3FF0094FF0094FF0075FF0066FF
0028FFFF007A000AFF0019FF0019FF000AFF8000FFCC00FF4200FF6100FF6100FFFF00F5
FF008AFF0000CC00FFBD00FFFF00E68F00FF8F00FFAE00FFBD00FFFF003DFF00D7FF00A8
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00D7FF003D
CC00FFAE00FF8F00FF8000FF8F00FF3300FF2300FF1400FF000AFF0019FF0028FF0038FF
0047FF0047FF0057FF0057FF0047FF0019FF0038FF0028FF0028FF0075FF3300FF00C2FF
00D1FF00D1FF00E1FF00E1FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00E1FF
00D1FF00B3FF0038FF0028FF0094FF0094FF0057FFFF00000066FF0038FF0094FF00E1FF
00FFF000FFE100FFD100FFC200FFB300FFA300FF9400FF9400FF9400FF8500FF9400FF85
00FF8500FF8500FF8500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF75
00FF7500FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF66
00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7500FF7500FF7500FF85
00FF8500FF9400FFD13300FF00FFD100FFB300E1FF00FFE100FF9400FF7500FF7500FF75
00FF6600FF6600FF7500FF943300FF00FFA300FF7500FF4700FF3800FF2800FF2800FF19
00FF1900FF1900FF0A00FF0A00FF0A00FF0A00FF0A00FF0A05FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0023FF0023FF0023FF0023FF0014FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0042FF0042FF0042FF0042FF0042FF00
42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
00FF8500FF9400FF9400FFB300FFC200F0FF00E1FF00FFD100FFB300FFA300FF9400FF85
00FF8500FF7500FF7500FF6600FF6600FF5700FF5700FF5700FF5700FF4700FF4700FF47
00FF4700FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF4700FF4700FF4700FF4700FF5700FF5700FF5700FF57
00FF6600FF6600FF6600FF6600FF7500FF7500FF8500FF9400FFB3FF000000A3FF00FFE1
00FFC200FFB300FFB300FFB300FFB300FFC200FFE100B3FF0075FF00A3FF00D1FF00FFFF
00FFF000FFF000FFF000D1FF00E1FFFF000000F0FF00FFF000FFF000FFF000FFF000FFF0
00FFFF00D1FF0085FF000AFF6100FF0038FF00C2FF00D1FF00E1FF00E1FF00E1FF00A3FF
0085FF00D1FF00E1FF0019FFFF008A00F0FF00FFF000FFE100FFE100FFD100FFD100FFD1
00FFD100FFD100FFD100FFE100FFE100FFE100FFE100FFE100FFE100FFF000FFF000FFF0
00FFF000FFFF00FFFF00FFFF00FFFF00F0FF00F0FF00F0FF00F0FF00E1FF00E1FF00E1FF
00D1FF00D1FF00C2FF00C2FF00B3FF00A3FF00A3FF0094FF0094FF0085FF0075FF0047FF
0019FF2300FF1400FF000AFF0500FF0500FF3300FFBD00FFEB00FFFF00A8FF00D7FA00FF
8000FFFF00008000FF7000FF6100FF6100FF8000FF8F00FFAE00FFDC00FFFF00F5FF007A
FF0000FF006BFF002EFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF004CFF007AFF007AFF00C7
FF0000BD00FFAE00FFFF00008000FF4200FF2300FF1400FF0500FF000AFF0019FF0028FF
0038FF0038FF0047FF0028FF0019FFDC00FF8F00FF0019FF0028FF0075FF0057FF00C2FF
00D1FF00E1FF00E1FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF
00E1FF0500FF0075FF00A3FF00B3FF00D1FF0085FF0094FF000AFFDC00FF9E00FF0066FF
0500FF00FFFF0085FF00FFF000FFB300FFA300FFA300FF9400FF9400FF8500FF8500FF85
00FF8500FF8500FF7500FF7500FF8500FF7500FF7500FF7500FF7500FF7500FF7500FF75
00FF7500FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF66
00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF75
00FF8500FFB300FFE100E1FF00FFA300FF9400FFD10075FF00FF8500FF6600FF6600FF57
00FF5700FF5700FF6600FF7500FFA30019FF0094FF00FF7500FF3800FF2800FF2800FF19
00FF1900FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A05FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0014FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0042FF0042FF0042FF0042FF00
42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
00FF9400FF9400FFA300FFC200FFD100FFFF00F0FF00FFD100FFB300FFA300FFA300FF94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00FF9400FFB300FFC200FFD100E1FF0500FF0094FF8000FF00FFE100FFD100FFB300FFA3
00FF9400FF8500FF7500FF6600FF6600FF6600FF5700FF5700FF4700FF4700FF4700FF47
00FF4700FF3800FF3800FF3800FF3800FF3800FF3800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF1900FF1900FF2800FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF2800FF1900FF1900FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF3800FF38
00FF3800FF3800FF3800FF4700FF4700FF4700FF5700FF5700FF5700FF5700FF6600FF66
00FF6600FF6600FF7500FF7500FF7500FF8500FFC200FFC200FFC200FFE100A3FF00FFFF
00FFE100FFD100FFD100FFE19E00FF00FFE100FFFF00F0FF0094FF000AFF0047FF00A3FF
00A3FF0085FF00A3FF0094FF4200FF000AFF0038FF00C2FF0047FF00C2FF00E1FF00E1FF
0085FF0047FF0075FF00B3FF0500FFDC00FF00F0FF00FFF000FFF000FFF000F0FF00A3FF
0047FF00F0FF00FFF000FFE100FFE100FFE100FFD100FFD100FFD100FFD100FFC200FFD1
00FFD100FFD100FFD100FFD100FFD100FFD100FFE100FFE100FFE100FFE100FFF000FFF0
00FFF000FFFF00FFFF00FFFF00F0FF00F0FF00F0FF00F0FF00E1FF00E1FF00E1FF00D1FF
00D1FF00D1FF00C2FF00B3FF0094FF0066FF0075FF0085FF0085FF0075FF0066FF0047FF
0028FF1400FF8F00FFFF00E6FF008AFF0000FF00C75100FFBD00FF4200FF1400FF1400FF
9E00FF2300FF8F00FF2300FF3300FF5100FFFF000FFF004CEB00FFFF00B8FF0099FA00FF
FF00E6FF00C7FF007AFF005CFF002EFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF004CFF0099FF00C7
FF00E6FF00D7FF0000DC00FFAE00FF8000FF5100FF5100FF9E00FF7000FF3300FF5100FF
4200FFFF002E1400FF7000FF0028FF0057FF0075FF0085FF00A3FF00B3FF00C2FF00D1FF
00E1FF00E1FF00F0FF00F0FF00F0FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00E1FF2300FF0075FF00D1FF00FFF0
00FFF000FFFF0019FF00FFF000FFB300FFA300FF9400FF9400FF9400FF8500FF8500FF85
00FF8500FF8500FF7500FF8500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF66
00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF57
00FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF6600FF5700FF5700FF6600FF66
00FF7500FF8500FFE100FFA300FF7500FF6600FF6600FF5700FF5700FF4700FF5700FF47
00FF4700FF4700FF4700FF5700FF6600FF7500FF7500FFB300FF6600FF3800FF2800FF19
00FF1900FF1900FF0A00FF0A00FF0A00FF0A00FF0A05FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0042FF0042FF0042FF00
42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
00FFA300FFD100D1FF0019FF00B3FF00FFE100FFD100FFFF9E00FF00E1FF00FFC200FFC2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00FFB300FFE12300FF0085FF00FFD100FFB300FFB300FFE17000FF0094FF0075FF00FFF0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00FFE100D1FF00D1FF0028FF00FFC200FFA300FFA300FFA300FFB300FFE100D1FFAE00FF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00E1FF00B3FF00FFD100FFB300FF9400FF9400FF8500FF9400FFA300FFD100E1FF4200FF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FA00FF00F0FF00FFC200FF9400FF8500FF8500FF8500FF8500FFA300D1FF00D1FF00FFE1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00F0FF00C2FF0075FF00FF9400FF7500FF7500FF7500FF7500FF8500FF8500FFB300FFB3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00FFC20094FF00FF9400FF7500FF7500FF6600FF6600FF6600FF6600FF7500FF8500FF94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00FFA300FFA300FF8500FF7500FF6600FF6600FF5700FF6600FF6600FF6600FF7500FF94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00FF8500FF7500FF6600FF6600FF5700FF5700FF5700FF5700FF6600FF6600FF7500FFC2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00FF8500FF7500FF6600FF5700FF5700FF4700FF4700FF5700FF5700FF5700FF850047FF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00FFA300FF7500FF5700FF5700FF4700FF4700FF4700FF4700FF4700FF5700FF6600FF75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00D1FF00FF8500FF5700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF57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00FF7500FF5700FF4700FF4700FF3800FF3800FF3800FF3800FF3800FF3800FF4700FF47
00FF5700FF6600FF6600FF8500E1FF00A3FF7000FF00FFD100FFA300FF9400FF9400FFB3
0094FF00FF9400FF7500FF3800FF2800FF2800FF2800FF1900FF1900FF1900FF1900FF19
00FF0A00FF1900FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF0A00FF0A
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF2800FF2800FF2800FF28
00FF3800FF3800FF3800FF4700FF5700FF5700FF6600FF7500FF9400FFC200F0FFEB00FF
00F0FF0075FF00E1FF0085FF00FFD100FFB300FFA300FF9400FF8500FF7500FF7500FF75
00FF7500FF7500FF7500FF7500FF6600FF7500FF7500FF7500FF7500FF7500FF7500FF75
00FF8500FF8500FF8500FF9400FF9400FFA300FFB300FFD100D1FF0019FF0066FFFF00F5
000AFF0028FF00C2FF00FFF000FFD100FFB300FFB300FFA300FFA300FFA300FFA300FF94
00FF9400FF9400FF9400FF9400FF9400FF9400FFA300FF9400FF9400FFA300FFA300FFA3
00FFA300FFB300FFB300FFC200FFD100FFE100F0FF0057FF0057FF0057FF00A3FF00E1FF
00F0FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F0FF00E1FF00E1FF00D1FFFF0000
0066FF8000FF0075FF00A3FF00C2FF00C2FF00D1FF00D1FF00D1FF00D1FF00D1FF00C2FF
00C2FF00C2FF00B3FF00A3FF0094FF0085FF0085FF0066FF0066FF0066FF0057FF0057FF
0047FF0038FF0028FF0019FF000AFF2300FF2300FF4200FFFA00FFFF00C7EB00FFFF0000
FF007AFF00A8FF0000FF000FFF000FFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF006BFF0099FF00C7FF00D7FF0000
FF00D7FA00FFDC00FFDC00FFFF001EFF00E6BD00FFAE00FFAE00FFFA00FFFF007A9E00FF
8000FFFF005C5100FF4200FF5100FFBD00FF5100FF0500FF0019FF0019FF4200FF2300FF
7000FFFF003D8F00FF0019FF0047FF0066FF0075FF0057FF9E00FF0085FF0057FF0094FF
00B3FF00B3FF00B3FF0094FFCC00FF0075FF00D1FF00E1FF00F0FF00FFFF00FFF000FFF0
00FFE100FFE100FFD100FFD100FFD100FFD100FFC200FFC200FFC200FFC200FFB300FFB3
00FFB300FFA300FFA300FFA300FFA300FFA300FF9400FF9400FF9400FF9400FF9400FF94
00FF8500FF8500FF8500FF8500FF8500FF7500FF8500FF7500FF7500FF6600FF6600FF66
00FF6600FF6600FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF4700FF47
00FF4700FF4700FF4700FF4700FF4700FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF2800FF2800FF3800FF2800FF2800FF2800FF2800FF2800FF2800FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A05FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
00FF6600FF4700FF4700FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF47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00FF5700FF4700FF3800FF3800FF3800FF2800FF2800FF2800FF3800FF3800FF3800FF47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00FF4700FF3800FF3800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF3800FF38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00FF3800FF3800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF38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00FF3800FF2800FF2800FF2800FF1900FF1900FF1900FF1900FF2800FF2800FF2800FF38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00FF3800FF2800FF2800FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF2800FF28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00FF2800FF2800FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19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00FF2800FF1900FF1900FF1900FF1900FF1900FF0A00FF0A00FF1900FF1900FF1900FF19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00FF1900FF1900FF1900FF1900FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF19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00FF1900FF1900FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF1900FF1900FF1900FF1900FF2800FF2800FF3800FF5700FF758000FF00FF7500FF57
00FF3800FF3800FF2800FF1900FF1900FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
05FF0005FF0000FF0A05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0000FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF1900FF1900FF19
00FF1900FF2800FF2800FF2800FF2800FF3800FFD100FF5700FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF4700FF4700FF4700FF4700FF5700FF5700FF5700FF6600FF6600FF75
00FF7500FF8500FF9400FFA300FFB300FFD100FFFF0094FF00A3FF00C2FF00F0FF0085FF
00F0FF00FFE100FFE100FFD100FFA300FF9400FF8500FF8500FF8500FF8500FF8500FF75
00FF8500FF7500FF7500FF7500FF7500FF7500FF7500FF8500FF8500FF8500FF8500FF85
00FF8500FF8500FF8500FF8500FF9400FF9400FF9400FF9400FF9400FFA300FFA300FFA3
00FFA300FFB300FFC200FFD100FFE100FFFF00B3FF000AFF00A3FF0028FF0094FF00F0FF
00FFFF00FFF000FFF000FFF000FFF000FFF000FFF000FFF000FFFF00FFFF00FFFF00FFFF
00F0FF00F0FF00F0FF00E1FF00D1FF00D1FF00B3FF0094FF0085FF0094FF0094FF0085FF
0085FF0075FF0066FF0057FF0028FFFF004C1400FF3300FFDC00FFFF0000FF003DFF00C7
FF00B8FA00FFDC00FFFF002EDC00FFDC00FFFA00FFFF00D7DC00FFBD00FFBD00FFEB00FF
FF00E6CC00FFAE00FFAE00FFBD00FFCC00FFEB00FFFF00D7FF000FFF0000FF00C7FF00D7
FF00B8FF0099FF006BFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF004CFF007AFF005CFF00D7FF00D7DC00FFFF00F5CC00FF6100FF4200FF
4200FF4200FF7000FFFF00D73300FF3300FF2300FF8000FF000AFF0038FF0047FF0047FF
0047FF0038FF0019FF7000FF0028FF3300FF0038FF4200FF6100FF3300FF0038FF00A3FF
00C2FF00C2FF00D1FF00D1FF00C2FF00D1FF00C2FF00C2FF00B3FF00A3FF0094FF0066FF
6100FF0066FF0085FF0094FF0094FF2300FF0047FF0057FFFF007A1400FF3300FF0066FF
0094FF00B3FF00B3FF00B3FF00B3FF0085FF4200FF4200FF0066FF0038FF00D1FF00F0FF
00FFF000FFE100FFD100FFD100FFD100FFD100FFD100FFD100FFD100FFE100FFF00028FF
0038FF0066FF00F0FF00FFD100FFC200FFB300FFA300FF9400FF9400FF9400FF8500FF85
00FF7500FF7500FF6600FF6600FF6600FF5700FF5700FF5700FF5700FF5700FF4700FF47
00FF4700FF4700FF4700FF4700FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A05FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0014FF0014FF00
14FF0014FF0005FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
42FF0042FF0042FF0042FF0042FF0042FF0051FF0051FF00
00FF1900FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF1900FF1900FF2800FF2800FF3800FF4700FF6600FFB300FFA300FF75
00FF5700FF3800FF2800FF1900FF1900FF0A00FF0A00FF0A00FF0A00FF0A05FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0000FF0A05FF0005FF0005FF0000FF0A05FF0005FF0005FF00
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF19
00FF1900FF1900FF1900FF2800FF2800FF3800FF3800FF3800FF2800FF2800FF2800FF28
00FF3800FF2800FF3800FF2800FF2800FF2800FF2800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF4700FF4700FF4700FF5700FF5700FF6600FF6600FF7500FF85
00FF8500FF8500FF9400FFA300FFB300FFD100B3FF2300FF00D1FF00FFFF00FFF000E1FF
3300FF00FFD100FFB300FFA300FF9400FF8500FF8500FF8500FF7500FF7500FF7500FF75
00FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF8500FF8500FF85
00FF8500FF8500FF8500FF8500FF8500FF9400FF9400FF9400FF9400FF9400FFA300FFA3
00FFA300FFB300FFD100FFF000D1FF00D1FF0085FF00E1FF00D1FF00C2FF00E1FF00F0FF
00FFF000FFF000FFF000FFF000FFF000FFF000FFF000FFF000FFF000FFFF00FFFF00FFFF
00F0FF00F0FF00F0FF00E1FF00E1FF00D1FF00C2FF00B3FF00B3FF00A3FF0094FF0094FF
0085FF0075FF0066FF0057FF0047FF0028FF000AFF3300FF9E00FFAE00FFDC00FFBD00FF
FF005C9E00FFBD00FFEB00FFAE00FF9E00FFEB00FFFF0000BD00FF9E00FFAE00FFFF005C
FF00F5CC00FF9E00FF9E00FFAE00FFCC00FFFA00FFFF0000FF0099FF00F5FF00F5FF00E6
FF00B8FF0099FF0000FF001EFF000FFF000FFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF004CFF005CFF00C7FF00D7FF00F5BD00FFCC00FF8000FF3300FF
3300FF3300FFFF00A8FF00C73300FF0500FF0019FF0028FF0028FF0047FF0057FF0057FF
0047FF0047FF0019FF8F00FF0038FF0057FF0066FF0075FF0057FF0028FFFA00FFFF0099
00C2FF00D1FF00D1FF00D1FF00D1FF00D1FF00D1FF00C2FF00B3FF0094FF0075FFFF00B8
0038FF0047FF0094FF00B3FF00B3FF00A3FF00A3FF0094FF0066FFBD00FFFF00000038FF
0066FF0094FF0057FF7000FF0085FF5100FF0066FF00A3FF00C2FF00D1FF00F0FF00FFFF
00FFF000FFF000FFE100FFE100FFE100FFD100FFD100FFD100FFE100FFE100FFF000F0FF
0500FF00C2FF00E1FF00FFD100FFC200FFB300FFA300FFA300FFA300FFA300FF9400FF94
00FF9400FF8500FF7500FF6600FF6600FF6600FF5700FF5700FF5700FF5700FF4700FF47
00FF4700FF4700FF4700FF4700FF4700FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A05FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0023FF0023FF0023FF0023FF0014FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
42FF0042FF0042FF0042FF0042FF0042FF0042FF0051FF00
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A05FF0005FF0000FF0A00FF0A00FF0A00FF0A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00FF0A00FF0A00FF0A05FF0005FF0000FF0A05FF0005FF0000FF0A05FF0005FF0000FF0A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00FF0A05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00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05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00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05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00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05FF0005FF0005FF0005FF0014FF0005FF0014FF0014FF0014FF0005FF0005FF0005FF00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05FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0005FF00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14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0005FF00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14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00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14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0005FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0005FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
05FF0014FF0014FF0014FF0014FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0000FF0A05FF00
05FF0000FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF1900FF0A00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF2800FF28
00FF2800FF2800FF3800FF3800FF4700FF4700FF5700FF5700FF6600FF756100FF00FFD1
0094FF0028FF00FFD100FFC200FFE10075FF00FFD100FFC20094FF0047FF00FF9400FF75
00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF5700FF6600FF6600FF6600FF66
00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7500FF7500FF75
00FF7500FF7500FF7500FF7500FF8500FF8500FF8500FF8500FF8500FF8500FF9400FF94
00FF9400FF9400FF9400FFA300FFA300FFA300FFA300FFB300FFB300FFB300FFB300FFC2
00FFC200FFC200FFD100FFD100FFD100FFE100FFE100FFE100FFF000FFFF00F0FF00E1FF
00C2FF0085FF7000FF0075FF0094FF0094FF0085FF0075FF0057FF0019FF8000FFEB00FF
BD00FF0028FF0057FF0085FF0094FF0094FF0094FF0094FF0094FF0094FF0085FF0066FF
0057FF000AFF0019FF0500FF6100FF0500FF0028FF0038FF0047FF0047FF0038FF0019FF
2300FF0019FF0019FF1400FFBD00FF5100FF1400FF0500FF1400FF2300FF3300FF4200FF
6100FF8000FFFF00F5FF00C7FF008AFF00E6FF005CFF00E6FF006BFF007AFF00C7FF00B8
FF0099FF000FFF0000FF003DFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF005CFF00B8FF00D7FF008AFA00FFBD00FF
AE00FFAE00FFFF00008000FF4200FF3300FF2300FF3300FFFF007A3300FF3300FF3300FF
7000FFFF00C7FF00995100FF1400FF000AFF000AFF4200FF0019FF0047FF0066FF0085FF
0094FF00A3FF00B3FF00B3FF00C2FF00C2FF00D1FF00D1FF00E1FF00E1FF00F0FF00F0FF
00FFFF00FFFF00FFFF00FFF000FFF000FFF000FFF000FFE100FFE100FFE100FFE100FFD1
00FFD100FFD100FFD100FFD100FFD100FFE100FFE100FFF000F0FF0085FF0066FF00E1FF
00F0FF00E1FF0085FF00A3FF00F0FF00FFFF00FFFF00FFFF00F0FF00E1FF00D1FF00B3FF
0075FF0500FFFF0000FF0000FF008A6100FFFF00D77000FF8000FF2300FF0047FF0075FF
00A3FF00F0FF00FFF000FFE100FFD100FFC200FFB300FFB300FFA300FFA300FF9400FF94
00FF8500FF8500FF8500FF8500FF7500FF7500FF7500FF7500FF7500FF6600FF6600FF66
00FF6600FF6600FF7500FF7500FF850085FF00FF8500F0FF00FF6600FF5700FF4700FF47
00FF4700FF3800FF3800FF3800FF3800FF3800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF0A00FF0A00FF0A00FF1900FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0014FF0014FF00
05FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
23FF0014FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0042FF0042FF0042FF0042FF0033FF0042FF0042FF0042FF0042FF00
42FF0042FF0042FF0042FF0042FF0042FF0051FF0051FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00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14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0005FF0005FF0014FF0014FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0000FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF0A
00FF0A00FF0A00FF1900FF0A00FF1900FF1900FF1900FF1900FF1900FF1900FF2800FF28
00FF2800FF3800FF3800FF4700FF5700FF6600FFA300FF8500FF9400FFA300FFF000FFF0
00FFF000FF9400FF8500FF9400FFD1000AFF00FFA300FF8500FF7500FF7500FF6600FF66
00FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF57
00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7500FF6600FF7500FF75
00FF7500FF7500FF7500FF7500FF8500FF8500FF8500FF8500FF8500FF9400FF9400FF94
00FF9400FF9400FF9400FFA300FFA300FFA300FFB300FFB300FFB300FFB300FFC200FFC2
00FFC200FFD100FFD100FFD100FFE100FFE100FFE100FFF000FFF000F0FF0085FF0038FF
0057FF0500FF0500FFCC00FF0028FF0038FF8000FF000AFF8000FF0019FF0038FF0066FF
0028FF0047FF0085FF00A3FF00B3FF00B3FF00B3FF00B3FF00A3FF0094FF0075FF0019FF
2300FF000AFF0028FF0047FF0019FF4200FF0038FF0047FF0057FF0066FF0057FF0057FF
0057FF0057FF0038FF000AFF0019FF0019FF0019FF000AFF0500FF4200FF5100FF6100FF
FF0000FF00E6FF00F59E00FF8F00FF8F00FFAE00FFDC00FFFF0099EB00FFFA00FFFF0000
FF00B8FF00A8FF00A8FF005CFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF000FFF006BFF006BFA00FFCC00FFBD00FF
8F00FF7000FF6100FF4200FF3300FF1400FF1400FF0500FF000AFF0019FF0019FF000AFF
FF00E65100FF2300FF3300FF9E00FFFF005CFF005C3300FF0019FF0047FF0066FF0085FF
0094FF0094FF00A3FF00B3FF00C2FF00C2FF00D1FF00D1FF00E1FF00E1FF00F0FF00F0FF
00FFFF00FFFF00FFFF00FFF000FFF000FFF000FFE100FFE100FFE100FFD100FFD100FFD1
00FFD100FFD100FFD100FFC200FFD100FFD100FFD100FFE100B3FF0028FF00FFF000FFE1
00FFE100FFE10019FF00E1FF00FFF000FFE100FFE100FFF000FFFF00C2FF0019FF0075FF
0019FF0066FF1400FF0500FF8000FF8F00FFFF00006100FFFF00D7FF00998F00FF0075FF
00B3FF00E1FF00FFFF00FFF000FFE100FFE100FFC200FFB300FFB300FFA300FFA300FFA3
00FF9400FF9400FF8500FF8500FF8500FF7500FF7500FF7500FF7500FF7500FF7500FF75
00FF7500FF8500FFB300FFD100FFE100F0FF00FF9400FF7500FF6600FF5700FF4700FF47
00FF4700FF4700FF3800FF3800FF3800FF3800FF3800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A05FF0005FF0000FF0A05FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0023FF0023FF0014FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
42FF0042FF0042FF0042FF0042FF0042FF0051FF0051FF00
23FF0014FF0023FF0023FF0014FF0023FF0023FF0014FF0023FF0023FF0014FF0023FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0000FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF28
00FF2800FF2800FF4700FF5700FF6600FF9400FFF000FFE100F0FF00FFE100FFFF00FFA3
00FFA300FF7500FF7500FF7500FF940066FF00FF8500FF7500FF6600FF6600FF5700FF57
00FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF57
00FF5700FF5700FF5700FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7500FF75
00FF7500FF7500FF7500FF8500FF8500FF8500FF8500FF8500FF8500FF9400FF9400FF94
00FF9400FFA300FFA300FFA300FFA300FFA300FFA300FFB300FFB300FFB300FFC200FFC2
00FFD100FFD100FFD100FFD100FFE100FFE100FFE100FFF000FFFF00F0FF00D1FF0066FF
0094FF0085FF0085FF0047FFFF000F2300FF7000FFFF00E6FA00FF0038FF0075FF0085FF
0066FFFF00E600A3FF00B3FF00C2FF00C2FF00C2FF00B3FF00A3FF0085FF0066FF0019FF
2300FF0038FF0066FF0066FF0028FFAE00FF0028FF0057FF0066FF0066FF0066FF0066FF
0066FF0057FF0057FF0047FF0038FF0028FF0028FF0019FF0500FF3300FFDC00FF8F00FF
BD00FFFA00FFEB00FF7000FF7000FF8000FFEB00FFFA00FFFA00FFBD00FFCC00FFDC00FF
FF0000FF00E6FF00D7FF00A8FF006BFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF001EFF007AFF008AFF001EFF0000FF0000FF00F5FF00C7
CC00FF7000FF6100FF4200FF3300FF2300FF0500FF000AFF0019FF0019FF0028FF0019FF
000AFF000AFF000AFF1400FFFA00FFFF00F5FF00005100FF0500FF0038FF0057FF0075FF
0075FF0066FFFF00B800A3FF00C2FF00C2FF00D1FF00D1FF00E1FF00E1FF00E1FF00F0FF
00F0FF00FFFF00FFFF00FFFF00FFF000FFF000FFE100FFE100FFE100FFD100FFD100FFD1
00FFD100FFC200FFC200FFC200FFC200FFC200FFD100FFD100FFD100FFD100FFD100FFD1
00FFD100FFD100FFE100FFE100FFE100FFE100FFE100FFE100FFF000F0FF00E1FF00C2FF
DC00FF00A3FF0094FF0057FFFF00F50028FF0500FF0028FFFF00C7000AFF000AFF000AFF
00A3FF00D1FF00F0FF00FFFF00D1FF00FFFF00FFD100FFC200FFB300FFB300FFA300FFA3
00FF9400FF9400FF9400FF8500FF8500FF8500FF8500FF8500FF8500FF7500FF7500FF85
00FF8500FFA300FFF000C2FFFF00A800FFC200FF9400FF7500FF6600FF5700FF5700FF47
00FF4700FF4700FF4700FF3800FF3800FF3800FF3800FF3800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF0A00FF0A00FF1900FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A05FF0005FF00
00FF0A05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0014FF0005FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
42FF0042FF0042FF0042FF0042FF0042FF0042FF0051FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0014FF0023FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0005FF0014FF0014FF0014FF0014FF0014FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0000FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF2800FF2800FF3800FF7500FFFF0066FF0057FF00FF9400FF9400FFF000FFA300FF85
00FF7500FF6600FF6600FF6600FF7500FFC200FF7500FF6600FF5700FF5700FF5700FF57
00FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF57
00FF5700FF5700FF6600FF5700FF6600FF6600FF6600FF6600FF7500FF7500FF7500FF75
00FF7500FF7500FF7500FF8500FF8500FF8500FF8500FF9400FF9400FF9400FF9400FF94
00FF9400FF9400FFA300FFA300FFA300FFA300FFA300FFB300FFB300FFB300FFC200FFD1
00FFD100FFE100FFE100FFE100FFE100FFF000FFF000FFF000FFFF00FFFF00E1FF00D1FF
00C2FF00A3FF0085FF0019FF1400FFFF0000FF001EFF00C7FA00FF0019FF0075FF0094FF
00A3FF0094FF00B3FF00C2FF00C2FF00C2FF00C2FF00C2FF00B3FF0075FF0019FF1400FF
0066FF0085FF0085FF0075FF3300FFFA00FFFF002E0066FF0075FF0075FF0075FF0075FF
0066FF0066FF0057FF0057FF0047FF0038FF0028FF0019FF0500FF9E00FF9E00FFFF0099
FF00008F00FF9E00FF5100FF5100FFCC00FFAE00FF9E00FFFF00E69E00FF9E00FFBD00FF
DC00FFFA00FFFF007AFF0099FF0000FF000FFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0099FF00C7FF00E6FF00C7FF00B8FF0000FF005C
BD00FFAE00FF7000FF4200FF3300FF2300FF1400FF0500FF0019FF0028FF0038FF0038FF
0038FF0038FF0028FF000AFF2300FF8000FF5100FF4200FFFF006B000AFF1400FF0038FF
0057FF0500FF0075FF0094FF00B3FF00C2FF00D1FF00D1FF00D1FF00E1FF00E1FF00E1FF
00F0FF00F0FF00FFFF00FFFF00FFF000FFF000FFE100FFE100FFD100FFD100FFD100FFD1
00FFC200FFC200FFC200FFC200FFC200FFC200FFC200FFC200FFC200FFC200FFC200FFC2
00FFC200FFC200FFC200FFD100FFD100FFD100FFD100FFE100FFE100FFF000FFFF00B3FF
00B3FF00C2FF0094FF0057FF0500FF0075FF0085FF0075FFBD00FF0075FF0094FF4200FF
0038FF0047FF7000FF00D1FFCC00FF00E1FF00D1FF0057FF00FFC200FFB300FFB300FFB3
00FFB300FFA300FF9400FF9400FF9400FF8500FF8500FF8500FF8500FF8500FF8500FF85
00FF9400FFA300FFD100E1FF0028FF00F0FF00FF9400FF7500FF6600FF6600FF5700FF57
00FF4700FF4700FF4700FF4700FF3800FF3800FF3800FF3800FF3800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A05FF0000FF0A05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0014FF0005FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0023FF0014FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0042FF0042FF0042FF0042FF00
42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0014FF0014FF0023FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0000FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF1900FF1900FF1900FF1900FF19
00FF2800FF2800FF3800FF4700FFB300FF6600FF6600FF6600FF7500FFB300FFB300FF75
00FF6600FF5700FF5700FF5700FF5700FF6600FF5700FF5700FF5700FF5700FF5700FF57
00FF5700FF4700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF57
00FF5700FF5700FF5700FF5700FF6600FF6600FF6600FF6600FF6600FF6600FF7500FF75
00FF7500FF7500FF7500FF8500FF8500FF8500FF8500FF8500FF9400FF9400FF9400FF94
00FF9400FFA300FFA300FFA300FFA300FFA300FFB300FFB300FFB300FFC200FFC200FFF0
00FFF000FFF000FFF000FFF000FFF000FFF000FFF000FFFF00FFFF00F0FF00E1FF00D1FF
00C2FF00B3FF0094FF6100FF6100FFFF0000FF004C9E00FF0028FF7000FF0085FF00A3FF
00B3FF00B3FF00C2FF00D1FF00D1FF00D1FF00D1FF00C2FF00B3FF0094FF2300FF0500FF
0085FF0094FF0094FF0075FF0047FF7000FF8F00FF0075FF0075FF0075FF0085FF0075FF
0075FF0066FF0057FF0057FF0047FF0038FF0019FF000AFF0500FF3300FF8F00FFFF002E
EB00FF8F00FF5100FF4200FF4200FF7000FF5100FF8F00FFCC00FF8000FF8F00FFBD00FF
CC00FFFF00F5FF00C7FF0000FF0000FF007AFF0000FF000FFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF002EFF007AFF00B8FF00E6FA00FFDC00FFEB00FFFF001EDC00FF
FF008AFF006B9E00FF6100FF8F00FF7000FF8F00FF4200FF0500FF0038FF0047FF0047FF
0047FF0047FF0038FF000AFF8F00FF5100FF0019FF000AFF000AFF8000FF6100FF0019FF
0028FFFA00FF000AFF9E00FF0085FF00B3FF00C2FF00D1FF00D1FF00D1FF00E1FF00E1FF
00E1FF00F0FF00F0FF00FFFF00FFFF00FFF000FFE100FFE100FFE100FFD100FFD100FFC2
00FFC200FFC200FFC200FFC200FFB300FFB300FFB300FFB300FFB300FFB300FFC200FFC2
00FFC200FFC200FFC200FFC200FFC200FFD100FFD100FFD100FFE100FFE100FFF000FFFF
00F0FF00D1FF00B3FF0047FF3300FF0094FF00B3FF0085FF0057FF0075FF00C2FF00C2FF
0075FF8000FF0075FF0066FF0057FF0500FF00D1FF00FFF000FFD100FFC200FFC200FFC2
00B3FF00FFB300FFA300FFA300FFA300FF9400FF9400FF8500FF8500FF9400FF8500FF94
00FF9400FFA300FFC28000FF00F0FF00FFD100FFB300FF7500FF6600FF6600FF6600FF57
00FF5700FF5700FF5700FF4700FF4700FF4700FF3800FF3800FF3800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A05FF0000FF0A05FF0000FF0A05FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0042FF0042FF0042FF0042FF0042FF00
42FF0042FF0042FF0042FF0042FF0042FF0042FF0051FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0014FF0023FF00
23FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0005FF0014FF0014FF00
14FF0014FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0000FF0A05FF0005FF0005FF0000FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF2800FF2800FF3800FF3800FF4700FF4700FF5700FF660047FF0075FF00FF66
00FF5700FF5700FF5700FF5700FF5700FF5700FF4700FF5700FF4700FF4700FF4700FF57
00FF4700FF4700FF4700FF4700FF5700FF4700FF5700FF5700FF5700FF5700FF5700FF57
00FF5700FF5700FF5700FF6600FF5700FF6600FF6600FF6600FF6600FF6600FF7500FF75
00FF7500FF7500FF8500FF8500FF8500FF8500FF8500FF9400FF9400FF9400FF9400FF94
00FFA300FFA300FFA300FFA300FFA300FFB300FFB300FFB300FFB300FFC200FFD100FFF0
00D1FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F0FF00E1FF00D1FF
00B3FF000AFF0075FF0028FF5100FF2300FF000AFF4200FF0019FF0066FF0094FF00A3FF
00B3FF00C2FF00D1FF00D1FF00D1FF00D1FF00D1FF00D1FF00C2FF0075FF0066FF0094FF
00B3FF00A3FF00A3FF0047FF0028FF0500FF0066FF0085FF0085FF0085FF0085FF0085FF
0075FF0066FF0057FF0057FF0047FF0038FF0500FF6100FF2300FF7000FFFF00997000FF
8000FF6100FF6100FF2300FF2300FF2300FF3300FF5100FF6100FF7000FF8F00FFFF007A
EB00FFFF0099FF002EFF00A8FF00C7FF00C7FF001EFF004CFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF007AFF0000FF0000BD00FFBD00FFCC00FF8F00FF
AE00FFEB00FFFF00D7FF00B88F00FF5100FF6100FFAE00FFFF00B80038FF0047FF0057FF
0057FF0047FF0038FF1400FF0500FF000AFF0019FF0057FF0038FF2300FF4200FFFF00E6
8F00FF0500FF0047FF0075FF0094FF00B3FF00B3FF00C2FF00C2FF00C2FF00C2FF00D1FF
00D1FF0094FF00E1FF00E1FF00FFFF00FFFF00FFF000FFE100FFE100FFD100FFC200FFD1
00FFC200FFC200FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB3
00FFB300FFC200FFC200FFC200FFC200FFC200FFD100FFD100FFD100FFE100FFF000FFFF
00FFFF00D1FF00A3FF8F00FF00A3FF00C2FF00C2FF0066FF00C2FF0057FF00E1FF00E1FF
00C2FF00A3FF0038FF6100FF0038FF00C2FF00F0FF00FFF000FFE100FFD100FFD1CC00FF
0038FF00FFD100FFC200FFD100F0FF00FFC200FF9400FF9400FF9400FF9400FF9400FF94
00FFA300FFD100FFFF0500FF00FFE100FFB300FF9400FF8500FF7500FF6600FF6600FF66
00FF6600FF6600FF6600FF6600FF5700FF4700FF4700FF3800FF3800FF3800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF1900FF2800FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A05FF0005FF00
00FF0A05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0014FF0014FF00
14FF0005FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0023FF0023FF0014FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0042FF0042FF0042FF0042FF0042FF00
42FF0042FF0042FF0042FF0042FF0042FF0051FF0051FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0014FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0014FF0023FF0023FF0023FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0005FF0014FF0014FF0014FF00
14FF0014FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0000FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF1900FF1900FF19
00FF1900FF2800FF2800FF2800FF3800FF3800FF3800FF4700FF5700FF9400FF8500FF57
00FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF47
00FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF5700FF5700FF5700FF57
00FF5700FF5700FF5700FF5700FF5700FF6600FF6600FF6600FF6600FF6600FF7500FF75
00FF7500FF8500FF8500FF8500FF8500FF8500FF9400FF9400FF9400FF9400FF9400FFA3
00FFA300FFA300FFA300FFA300FFB300FFB300FFB300FFB300FFC200FFC200FFD100F0FF
0066FF00A3FFFF000000E1FF00FFFF00FFFF00FFFF00F0FF00F0FF00E1FF00C2FF00C2FF
00B3FF0038FF0019FF5100FF0057FFFF00A8000AFF0047FFCC00FF0066FF0085FF00A3FF
00B3FF00C2FF00D1FF00E1FF00E1FF00E1FF00E1FF00D1FF00D1FF00B3FF00A3FF00C2FF
00C2FF00C2FF00B3FF0094FF0500FF5100FF0057FF0094FF0094FF0094FF0094FF0085FF
0075FF0066FF0047FF0047FF0038FF0028FF1400FF7000FF7000FFBD00FFEB00FF3300FF
3300FF1400FF1400FF0500FF1400FF2300FF2300FF3300FF5100FF6100FF8F00FFFF007A
FF001EFF0099FF00C7EB00FFFF00F5FF00C7FF0099FF003DFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF004CFF008AFF0099FF008ADC00FFAE00FF9E00FF8000FF7000FF
8000FF6100FF6100FFFF00F55100FF2300FF0500FF0019FF0028FF0047FF0057FF0057FF
0066FF0057FF0047FF5100FF0047FF0057FF0047FF0075FF0066FF0057FF0038FF4200FF
FF006B4200FF000AFF0075FF0094FF00A3FF00B3FF00B3FF00A3FF0085FF2300FF00B3FF
00B3FF000AFF0094FF00B3FF00F0FF00F0FF00F0FF00FFF000FFE100FFD100FFC200FFC2
00FFC200FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB3
00FFB300FFB300FFB300FFB300FFC200FFC200FFC200FFD100FFD100FFE100FFE100FFF0
00FFFF00E1FFDC00FF8000FF4200FF00E1FF00F0FF00C2FF00F0FF00FFFF00FFFF00FFFF
00F0FF00D1FF0085FF0028FF0028FF0085FF0075FF00F0FF00FFF000FFF000FFF000F0FF
0057FF00FFF000FFF00500FF00FFE100FFB300FFA300FF9400FF9400FF9400FFA300FFA3
00FFA300FFE10057FFFF000000D1FF00FFB300FF9400FF8500FF8500FF7500FF7500FF75
00FF8500FF7500FF8500FFE100FF6600FF5700FF4700FF3800FF3800FF3800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF1900FF1900FF2800FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF0A
00FF0A00FF1900FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0023FF00
23FF0014FF0023FF0014FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0042FF0042FF0042FF00
42FF0042FF0042FF0042FF0042FF0042FF0051FF0051FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00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23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00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23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00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23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0014FF0023FF0023FF00
23FF0023FF0023FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0000FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF0A00FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF47
00FF5700FF5700FF5700FF5700FF5700FF5700FF6600FF6600FF6600FF7500FF8500FFA3
00FFA300FFA300FFA300FFA300FFB300FFC2FF000000FFC200FFB300FFB300FFB300FFB3
00FFB300FFB300FFB300FFB300FFB300FFB300FFC200FFC200FFD100FFE100FFF000FFFF
00F0FF00E1FF00B3FF6100FF00A3FF00C2FF00C2FF00B3FF00A3FF0085FF0038FFFF007A
2300FF0075FF00B3FF00D1FF00D1FF00D1FF00C2FF0094FF000AFF00C2FF00E1FF00E1FF
00B3FF00D1FF00F0FF00FFFF00FFFF00FFFF00FFFF00FFFF00F0FF00F0FF00F0FF00F0FF
00F0FF00E1FF00E1FF00D1FF00D1FF00C2FF00C2FF00C2FF00B3FF00A3FF00A3FF0094FF
0085FF0028FF4200FF0500FF4200FFFF00E6FF0000FF00C70500FF000AFF0019FF0038FF
0038FF0038FF0028FF0500FF2300FFFF00008000FF6100FF8000FF8000FF6100FF6100FF
6100FF7000FF8F00FFAE00FFBD00FFDC00FFFF00F5FF008AFF006BFF000FFF0000FF0000
FF0000FF0000FF0000FF000FFF005CFF007AFF00D7FF00D7FF00F5FF00E68F00FF5100FF
3300FF2300FF1400FF0500FF000AFF000AFF000AFF0028FF0038FF0057FF0066FF0075FF
0075FF0085FF0085FF0094FF00A3FF00A3FF00A3FF00B3FF00A3FF0057FF00A3FF00A3FF
00A3FF00A3FF00A3FF0094FF0075FF9E00FF0085FF00A3FF00B3FF00B3FF00D1FF00D1FF
3300FF00B3FF00C2FF00E1FF00C2FF0066FF0094FF0028FF1400FF00FFFF00FFF000FFC2
00FFB300FFB300FFA300FFA300FFA300FFA300FFA300FFA300FFA300FFA300FFA300FFA3
00FFA300FFA300FFA300FFB300FFB300FFB300FFC200FFD100FFF000FFFF00E1FF0085FF
0066FF00E1FF00F0FF00A3FF0038FF00F0FF00FFE100FFD100FFC200FFC200FFC200FFC2
00FFC200FFC200FFC200FFC200FFD100FFE100FFF000F0FF0019FF8F00FFFF00F5FF00A8
0028FF0038FF00F0FF00FFF000FFE100FFD100FFD100FFD100FFD100FFE100FFD100FFD1
00FFD100FFE100FFFF0038FF00F0FF00F0FF6100FF00E1FF0075FF0057FF00F0FF00FFFF
00FFFF00FFE100FF9400FF6600FF6600FF5700FF4700FF4700FF4700FF3800FF3800FF38
00FF3800FF3800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF2800FF6600FFA300FF9400FF6600FF2800FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF4700FF2800FF1900FF1900FF0A
00FF0A05FF0005FF0005FF0005FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0023FF00
23FF0023FF0023FF0023FF0033FF0033FF0033FF0033FF0033FF0033FF0042FF0042FF00
42FF0042FF0042FF0042FF0042FF0042FF0042FF0051FF00
23FF0023FF0033FF0033FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00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23FF0033FF0033FF0033FF0033FF0023FF0033FF0033FF0033FF0023FF0023FF0023FF00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23FF0033FF0033FF0033FF0033FF0023FF0033FF0033FF0033FF0023FF0023FF0023FF00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33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0023FF0033FF00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33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0023FF0033FF0033FF00
33FF0033FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0014FF0023FF0023FF0023FF0023FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0000FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF19
00FF0A00FF0A00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF4700FF3800FF4700FF4700FF4700FF4700FF4700FF47
00FF4700FF4700FF5700FF5700FF5700FF5700FF5700FF6600FF6600FF6600FF7500FF85
00FF8500FF9400FFB34200FF0085FF00FFFF00C2FF0057FF3300FF0075FF00D1FF00FFF0
00FFE100FFD100FFD100FFD100FFD100FFD100FFD100FFE100FFE100FFF000FFF000FFFF
00F0FF00D1FF00C2FF0085FF0500FFFF00F5FF00A87000FF2300FF0057FF0085FF00C2FF
00D1FF00E1FF00F0FF00FFFF00FFF000FFF000FFF000FFE100FFE100FFE100FFE100FFE1
00FFE100FFE100FFE100FFE100FFE100FFF000FFF000FFF000FFF000FFFF00FFFF00FFFF
00F0FF00F0FF00E1FF00E1FF00D1FF00D1FF00C2FF00C2FF00B3FF0085FF0038FF4200FF
1400FF4200FF3300FFFF00000057FF0066FF0057FF0047FF0075FF0075FF0075FF0075FF
0075FF0075FF0066FF0066FF0057FF0047FF0028FF0019FF0019FF000AFF000AFF0500FF
2300FF3300FF4200FF6100FF8000FF9E00FFBD00FFFF00C7FF00A8FF002EFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF004CFF0000FF00C7FF007A
FF00B8FF0099FA00FF6100FF4200FF4200FFAE00FF0500FF0028FF0028FFFF00000500FF
FF00B85100FF3300FF4200FF0075FF0094FF00C2FF00D1FF00D1FF00D1FF00E1FF00E1FF
00E1FF00E1FF00D1FF00C2FF0066FFBD00FF000AFF0028FF00A3FF00D1FF00E1FF00FFFF
00FFF000FFE100FFE100FFD100FFC200FFC200FFC200FFB300FFB300FFB300FFA300FFA3
00FF9400FF9400FF9400FF9400FF9400FF9400FF9400FF9400FF9400FF9400FF9400FF94
00FF9400FF9400FF9400FFA300FFB300FFE10075FF00F0FF00D1FF0057FF00FFFF00FFD1
00FFB300FFA300FFA300FFB300E1FF0028FFCC00FF00FFE100FFB300FF9400FF9400FF94
00FF9400FF9400FF9400FF9400FFFF00E1FF00FFD100FFC200FFE1FF00A800FFF000FFD1
00FFD100FFE100FFF000E1FF00B3FF1400FF8F00FF0028FFEB00FF0057FF0057FF0085FF
FF000000A3FF00E1FF00FFFF00FFD100FFC200FFB300FFA300FF9400FF9400FF8500FF75
00FF7500FF6600FF6600FF5700FF5700FF5700FF4700FF4700FF4700FF4700FF3800FF47
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF2800FF3800FF28
00FF3800FF2800FF2800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF4700FF5700FF8500FF4700FF3800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF3800FF3800FF3800FF4700FF8500FF9400FFFF00D1FF00FF8500FF66
00FF5700FF4700FF5700FF6600FF8500FFD10085FF00F0FF00FF6600FF3800FF2800FF19
00FF1900FF0A00FF0A00FF0A00FF0A05FF0005FF0005FF0005FF0005FF0005FF0000FF0A
05FF0000FF0A00FF0A00FF1900FF3800FF4700FF5700D1FF00FF4700FF1900FF0A05FF00
14FF0014FF0014FF0023FF0023FF0023FF0023FF0023FF0023FF0033FF0033FF0033FF00
33FF0033FF0042FF0042FF0042FF0042FF0042FF0042FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00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33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0023FF0033FF0033FF0033FF0033FF0033FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0000FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF2800FF19
00FF1900FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF4700FF4700FF4700FF4700FF4700FF47
00FF4700FF4700FF5700FF5700FF5700FF5700FF5700FF6600FF6600FF6600FF7500FF75
00FF8500FF8500FF9400FF9400FFA300FFB300FFD100F0FF00D1FF0019FF00B3FF00C2FF
00FFFF00FFF000FFE100FFE100FFE100FFE100FFF000FFFF00F0FF00F0FF00F0FF00F0FF
00D1FF0057FF0085FF1400FFFF00E60066FF000AFF0028FF0085FF0028FF0075FF0075FF
2300FF00C2FF00E1FF00FFFF00FFF000FFE100FFE100FFE100FFD100FFD100FFD100FFD1
00FFD100FFD100FFE100FFE100FFE100FFE100FFF000FFF000FFF000FFFF00FFFF00F0FF
00F0FF00E1FF00E1FF00D1FF00D1FF00C2FF00C2FF00B3FF00A3FF0094FF0066FF0019FF
5100FF3300FF0019FF0047FF0075FF0085FF0094FF0094FF0094FF0094FF0094FF0085FF
0085FF0075FF0075FF0066FF0066FF0057FF0047FF0038FF0028FF0019FF000AFF2300FF
DC00FF6100FF8000FFCC00FFAE00FFFF00A8FF002EFF007AFF00A8FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF000FFF0000FF0000EB00FFAE00FF8F00FF7000FF7000FF
6100FF8F00FFFF00002300FF2300FF7000FF3300FF7000FF7000FF1400FF0028FF0047FF
0057FF0075FF0085FF0094FF00A3FF00A3FF00D1FF00E1FF00E1FF00E1FF00F0FF00F0FF
00F0FF00E1FF00F0FF00E1FF00E1FF00D1FF00C2FF0075FF9E00FF2300FF0038FF3300FF
00F0FF00FFF000FFE100FFD100FFC200FFB300FFB300FFA300FFA300FFA300FFA300FF94
00FF9400FF9400FF9400FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF85
00FF8500FF8500FF9400FF9400FF9400FFA300FFD100E1FF00D1FF00C2FFFF00B800FFB3
00FF9400FF9400FF9400FF9400FF9400FFA300A3FF00FFE100FF9400FF8500FF8500FF85
00FF8500FF8500FF8500FF8500FF8500FF9400FF9400FF9400FFA300FFB300FFB300FFB3
00FFC200FFD10038FF0057FF0047FF0500FF0038FFFF00D7FF00F5EB00FFFF006BFF00F5
8F00FF0038FF0028FF0094FF0085FF00FFE100FFB300FFA300FF9400FF9400FF8500FF75
00FF7500FF6600FF6600FF6600FF5700FF5700FF5700FF5700FF4700FF4700FF4700FF47
00FF4700FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF4700FF4700FF5700FF9400FF5700FF4700FF47
00FF5700FF6600FF9400FFFF00FF6600FF4700FF4700FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF4700FF5700FF5700FF7500FFE100C2FF00FFF000FF94
00FF7500FF7500FF8500FFD10038FF00FFA300FF7500FF6600FF5700FF3800FF2800FF19
00FF1900FF1900FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF1900FF2800FF851400FF00E1FF00FFFF00FFC200FF3800FF1900FF0A
05FF0005FF0014FF0014FF0014FF0014FF0014FF0023FF0023FF0023FF0023FF0033FF00
33FF0033FF0042FF0042FF0042FF0042FF0042FF0042FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0023FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0000FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF1900FF0A00FF0A00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF4700FF4700FF4700FF4700FF47
00FF4700FF4700FF5700FF5700FF5700FF5700FF5700FF6600FF6600FF6600FF7500FF75
00FF7500FF8500FF8500FF9400FFA300FFB300FFC200FFE100FFF000A3FFFF00000094FF
00F0FF00FFF000FFF000FFF000FFF000FFF000FFFF00E1FF00B3FF00E1FF00E1FF00E1FF
0094FF0500FF000AFFFF005C0500FF0094FF0094FF00B3FF00B3FF0085FF0075FF0075FF
0019FF2300FF0075FF00FFFF00FFF000FFE100FFD100FFD100FFD100FFD100FFD100FFD1
00FFD100FFD100FFD100FFE100FFE100FFE100FFE100FFF000FFF000FFFF00F0FF00F0FF
00E1FF00E1FF00C2FF00C2FF00C2FF00B3FF00B3FF00A3FF0094FF0038FF0047FFFF0000
0038FF0038FF0028FF000AFF0066FF0094FF00A3FF00A3FF00A3FF00A3FF0094FF0094FF
0085FF0075FF0075FF0066FF0066FF0057FF0047FF0038FF0019FF000AFF0500FFCC00FF
FF003DAE00FFAE00FFFF0000FF007AFA00FFEB00FFDC00FFFF00E6FF008AFF0000FF0000
FF0000FF0000FF0000FF0000FF002EFF00A8FF0099FF00C79E00FF8000FF6100FF4200FF
3300FFFF002E1400FF0500FF0500FFFA00FF1400FF0019FF000AFF8000FF0028FF0057FF
0075FF0085FF00A3FF00B3FF00C2FF00D1FF00D1FF00E1FF00E1FF00E1FF00F0FF00F0FF
00F0FF00F0FF00F0FF00F0FF00E1FF00E1FF00C2FF00A3FF000AFFFF00990075FF00C2FF
00F0FF00FFFF00FFF000FFD100FFC200FFB300FFB300FFA300FFA300FFA300FF9400FF94
00FF9400FF9400FF8500FF9400FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF85
00FF8500FF8500FF8500FF8500FF9400FF9400FFA300FFC200F0FF00FFFF00FFC200FFA3
00FF9400FF8500FF8500FF8500FF8500FF9400FFD100FF9400FF8500FF8500FF8500FF75
00FF7500FF7500FF8500FF8500FF8500FF8500FF8500FF9400FF9400FFA300FFA300FFB3
00FFB300FFC200FFF000FFFF0075FF00B3FF0085FF0047FF0500FF0019FF000AFF2300FF
FA00FFFA00FF0057FF00D1FF00F0FF00FFD100FFC200FFB300FFA300FF9400FF8500FF85
00FF7500FF7500FF6600FF6600FF6600FF5700FF5700FF5700FF4700FF4700FF4700FF47
00FF4700FF4700FF3800FF4700FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF4700FF3800FF3800FF4700FF4700FF4700FF5700FFD100FF9400FF6600FF5700FF57
00FF6600FFB300A3FF00FFD100FF7500FF5700FF4700FF4700FF3800FF3800FF3800FF38
00FF3800FF3800FF4700FF4700FF4700FF5700FF5700FF6600FFA300FFB37000FF00FFD1
00FF9400FF9400FFF05100FF00FFE100FFA300FF6600FF4700FF4700FF3800FF2800FF28
00FF1900FF1900FF1900FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF1900FF1900FF2800FF4700FF6600FFB300B3FF00FF8500FFB300FF2800FF0A
05FF0005FF0005FF0005FF0014FF0014FF0005FF0014FF0014FF0023FF0023FF0033FF00
33FF0033FF0033FF0033FF0042FF0042FF0042FF0042FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0023FF0033FF0033FF0033FF0033FF0033FF0023FF0023FF0033FF0033FF0033FF00
33FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0000FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF3800FF2800FF2800FF28
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF4700FF4700FF4700FF4700FF47
00FF4700FF4700FF5700FF5700FF5700FF5700FF6600FF6600FF6600FF6600FF7500FF75
00FF7500FF8500FF8500FF9400FFA300FFB300FFC200FFD100FFE100F0FF00B3FF0094FF
00E1FF00FFFF00FFFF00FFFF00FFFF00E1FF00E1FF00C2FF6100FF00C2FF00D1FF00C2FF
00B3FF0066FFFF00F53300FF0075FF00B3FF00D1FF00D1FF00C2FF0057FF0066FF00D1FF
00D1FF8F00FF00A3FF0057FF00FFE100FFD100FFD100FFD100FFD100FFD100FFD100FFD1
00FFD100FFD100FFD100FFD100FFE100FFE100FFE100FFF000FFFF00F0FF00F0FF00E1FF
00E1FF00C2FF0075FF0094FF00A3FF00A3FF0085FF0094FF0085FF0047FFFF00000057FF
0075FF0057FF0047FF0094FF0094FF00A3FF00B3FF00A3FF00A3FF00A3FF0094FF0094FF
0085FF0075FF0075FF0066FF0057FF0047FF0047FF0028FF0500FF3300FF2300FF4200FF
FF00C7FF0000CC00FFFF00F59E00FF8F00FF9E00FFBD00FFFA00FFFF008AFF006BFF0000
FF0000FF0000FF0000FF0000FF003DFF00B8FF00F5DC00FFBD00FFEB00FFFF00003300FF
2300FF1400FF0500FF0019FF0019FF0028FF0038FF0038FF0028FF1400FF4200FF1400FF
0066FF0085FF00A3FF00B3FF00C2FF00D1FF00E1FF00E1FF00F0FF00F0FF00F0FF00F0FF
00FFFF00FFFF00FFFF00F0FF00F0FF00E1FF00B3FF000AFF0028FF0085FFFF00B80094FF
000AFF00D1FF0066FF00FFE100FFD100FFB300FFB300FFA300FFA300FFA300FF9400FF94
00FF9400FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF85
00FF8500FF8500FF8500FF8500FF8500FF9400FFA300FFB300FFF000FFE100FFA300FF94
00FF8500FF8500FF8500FF7500FF7500FF7500FF8500FF8500FF7500FF7500FF7500FF75
00FF7500FF7500FF7500FF7500FF7500FF8500FF8500FF8500FF9400FF9400FF9400FFA3
00FFB300FFB300FFC200FFFFFF007A00E1FF00C2FF1400FF0066FF0500FFFF00000047FF
0028FF0500FF0047FFFF00B800FFFF00FFE100FFD100FFD10075FF00FFA300FF9400FF85
00FF7500FF7500FF7500FF6600FF6600FF5700FF5700FF5700FF5700FF4700FF4700FF47
00FF4700FF4700FF4700FF4700FF4700FF3800FF4700FF3800FF3800FF3800FF3800FF47
00FF3800FF3800FF4700FF4700FF4700FF5700FF6600FF8500FFF000FFB300FF7500FF66
00FF7500FF9400D1FF00FFD100E1FF00FF6600FF5700FF4700FF4700FF4700FF4700FF47
00FF4700FF4700FF4700FF4700FF5700FF5700FF6600FF6600FF7500FF940094FF00D1FF
00FFC200FFFF0019FF00FFC200FF940057FF00FF5700FF4700FF3800FF3800FF2800FF28
00FF1900FF1900FF1900FF1900FF1900FF1900FF0A00FF0A00FF0A00FF0A00FF1900FF19
00FF1900FF1900FF2800FF2800FF4700FF6600FFFF00E1FF00FF5700FF3800FF2800FF19
00FF0A00FF0A00FF0A00FF0A00FF0A05FF0005FF0000FF0A00FF2814FF0023FF0023FF00
33FF0033FF0033FF0042FF0042FF0042FF0042FF0042FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0023FF0033FF0033FF0033FF0033FF00
33FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0014FF00
14FF0023FF0023FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0000FF0A
05FF0005FF0005FF0000FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF3800FF3800FF3800FF3800FF4700FF3800FF4700FF4700FF4700FF4700FF4700FF47
00FF4700FF5700FF5700FF5700FF5700FF5700FF5700FF6600FF6600FF6600FF7500FF75
00FF7500FF8500FF9400FF9400FFB300FFB300FFC200FFD100FFF000FFFF00D1FF0057FF
00D1FF00F0FF00F0FF00F0FF00F0FF00B3FF0085FF00A3FFBD00FF00A3FF00B3FF00A3FF
0066FF4200FF0057FF0057FF00A3FF00C2FF00E1FF00E1FF00D1FF0085FF0057FF00E1FF
00FFFF00FFFF00FFF000E1FF00FFD100FFD100FFC200FFC200FFC200FFC200FFC200FFC2
00FFD100FFD100FFD100FFD100FFE100FFE100FFF000FFF000F0FF00B3FF00D1FF00D1FF
00D1FF2300FF0066FF0075FF0075FF0028FF0047FF0019FF0057FFFF00A80047FF0085FF
0094FF0094FF3300FF00A3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A3FF00A3FF0094FF
0085FF0066FF0057FF0057FF0038FF0038FF0038FF0028FFFF00B88000FF7000FFFF00E6
8F00FFFF00E67000FF6100FF6100FF7000FF8F00FFAE00FFDC00FFFF00F5FF00B8FF005C
FF0000FF0000FF0000FF0000FF0000FF000FFF006BFF0000FF006B9E00FF6100FF3300FF
1400FF0500FF000AFF0019FF0038FF0038FF0047FF0047FF0047FF8000FF2300FFFF00E6
FF00A80066FF0085FF00A3FF00C2FF00D1FF00E1FF00E1FF00F0FF00F0FF00F0FF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00F0FF00A3FF00C2FF0028FF00C2FF00A3FFBD00FF
1400FF0085FFFF003D6100FF00FFE100FFC200FFB300FFA300FFA300FFA300FF9400FF94
00FF9400FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF7500FF75
00FF8500FF7500FF8500FF8500FF8500FF8500FF9400FFB300A3FF00C2FF00FFB300FF85
00FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF75
00FF7500FF7500FF7500FF7500FF7500FF8500FF8500FF8500FF8500FF9400FF9400FFA3
00FFA300FFB300FFC200FFD100FFE100FFFF00B3FFFF00000094FF00C2FF00C2FF0075FF
0094FF00C2FF0066FFFF00B800C2FF00A3FF00FFF000F0FF00FFFF00FFC200FFC200FF94
00FF8500FF8500FF7500FF7500FF6600FF6600FF5700FF5700FF5700FF5700FF4700FF47
00FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF47
00FF4700FF4700FF4700FF4700FF4700FF5700FF6600FFE10085FF00FFE100FF9400FF85
00FF9400F0FF0047FF00FFA300FF7500FF6600FF5700FF5700FF4700FF4700FF4700FF47
00FF4700FF5700FF5700FF5700FF5700FF5700FF6600FF7500FF8500FF9400FFA300FFD1
0500FF00D1FF00FFB300FF9400FF7500FF6600FF5700FF4700FF3800FF3800FF2800FF28
00FF2800FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF2800FF2800FF3800FF4700FF9400FFE100FFB300FF6600FF3800FF2800FF19
00FF1900FF0A00FF1900FF2800FF3800FF2800FF2800FF3800FF3800FF0A05FF0023FF00
23FF0033FF0033FF0033FF0042FF0042FF0042FF0042FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0014FF0023FF00
23FF0023FF0023FF0023FF0023FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0000FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF4700FF4700FF4700FF47
00FF4700FF4700FF5700FF5700FF5700FF5700FF5700FF6600FF6600FF6600FF7500FF75
00FF8500FF8500FF9400FFA300F0FF00FFD100FFD100F0FF00FFFF00D1FF00A3FF000AFF
0094FF00B3FF00A3FF00D1FF00D1FF00C2FF000AFF0028FF0047FF0094FF0094FF0075FF
AE00FF0057FF00A3FF00B3FF0094FF00E1FF00F0FF00F0FF00E1FF00B3FF000AFF00D1FF
00FFFF00FFE100FFE100FFD100FFD100FFC200FFC200FFC200FFC200FFC200FFC200FFC2
00FFC200FFD100FFD100FFD100FFE100FFE100FFF000FFF000F0FF0075FF0085FF00C2FF
00B3FF0094FFBD00FF8000FFFF00000038FF0047FF0038FF0047FF0047FF0085FF00A3FF
00A3FF00B3FF00B3FF00C2FF00C2FF00C2FF00C2FF00C2FF00B3FF00A3FF00A3FF0085FF
0075FFFF005C0038FF6100FF0500FF000AFF0019FF000AFF4200FFFF00009E00FF4200FF
3300FF6100FFFF00E63300FF4200FF8000FFDC00FFEB00FFEB00FFFF00D7FF004CFF0000
FF0000FF0000FF0000FF0000FF004CFF00A8FF00D7FA00FFDC00FFFF00D7FF00A84200FF
2300FF1400FF000AFF0019FF0038FF0047FF0057FF0057FF0057FF0057FF0047FF000AFF
4200FF4200FF000AFF0075FF00B3FF00D1FF00E1FF00F0FF00F0FF00F0FF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F0FF00F0FF00E1FF00B3FF
4200FFFF000000A3FF00FFFF00FFE100FFC200FFB300FFA300FFA300FF9400FF9400FF94
00FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF7500FF7500FF7500FF75
00FF7500FF7500FF7500FF7500FF8500FF8500FF9400FFC200F0FF00FF9400FF9400FF85
00FF7500FF7500FF7500FF7500FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF66
00FF6600FF6600FF7500FF7500FF7500FF7500FF7500FF8500FF8500FF9400FF9400FF94
00FFA300FFB300FFB300FFC200FFE100F0FF00B3FF0075FF00C2FF00F0FF00C2FF0057FF
000AFF00F0FF00F0FF00C2FFCC00FF00B3FF00E1FF00C2FF0066FF0019FF00FFC200FFA3
00FF9400FF9400FF8500FF8500FF7500FF6600FF6600FF6600FF5700FF5700FF5700FF57
00FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF47
00FF4700FF4700FF4700FF4700FF5700FF5700FF6600FF8500FFB30028FF00D1FF00FFB3
00FFB300D1FF00F0FF00FF9400FF7500FF6600FF5700FF5700FF5700FF5700FF5700FF57
00FF5700FF7500FF6600FF6600FF6600FF6600FF7500FF7500FF8500FF9400FFB300FFE1
00C2FF00FFB300FF9400FF8500FF7500FF6600FF5700FF4700FF4700FF3800FF3800FF28
00FF2800FF2800FF2800FF2800FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF2800FF2800FF2800FF3800FF4700FF9400D1FF0047FF00FFB300FF4700FF2800FF28
00FF2800FF2800FF2800FF8500FF9400FF5700FF8500FFC200FF9400E1FF3300FF14FF00
23FF0033FF0033FF0033FF0042FF0042FF0042FF0042FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0000FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF4700FF4700FF4700FF4700FF47
00FF5700FF5700FF5700FF5700FF5700FF5700FF6600FF6600FF6600FF6600FF7500FF75
00FF8500FFA300FFB300FFC200E1FF00FFFF00F0FF0085FF0094FFFF00B80028FF00C2FF
0085FFBD00FF0085FF00B3FF00B3FF00B3FF0094FF0066FFAE00FF0057FFDC00FF0028FF
5100FF7000FF00C2FF00D1FF00F0FF00F0FF00FFFF00FFFF00F0FF00C2FF0038FF0038FF
00FFF000FFE100FFD100FFC200FFC200FFC200FFC200FFC200FFC200FFC200FFC200FFC2
00FFC200FFC200FFD100FFD100FFE100FFE100FFF000FFFF00F0FF00B3FFFF00000094FF
000AFF6100FF0038FF4200FF0085FF0094FF00A3FF0094FF0075FF0019FF0085FF00A3FF
00B3FF00C2FF00C2FF00C2FF00D1FF00C2FF00C2FF00C2FF00B3FF00A3FF0085FF0075FF
0057FF4200FF5100FFBD00FF5100FFBD00FFAE00FF9E00FF5100FF3300FFFF003D0500FF
0500FF0500FF1400FF2300FF3300FF8000FF8F00FFDC00FFFF00C7FF00D7FF0000FF008A
FF001EFF0000FF0000FF0000FF0000FF00A8FF00E6DC00FFAE00FF8F00FF6100FF4200FF
3300FF3300FF4200FF6100FF0019FF0047FF0057FF0066FF0066FF0066FF0066FF0038FF
0057FF0047FF2300FF0500FF0057FF00C2FF00E1FF00F0FF00F0FF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFF000FFF000FFF000FFF000FFF000FFF000FFFF00F0FF00D1FF
0085FF00A3FF0038FFFF000000F0FF0075FF00FFD100FFA300FFA300FF9400FF9400FF85
00FF8500FF8500FF8500FF8500FF8500FF8500FF7500FF7500FF7500FF7500FF7500FF75
00FF7500FF7500FF7500FF7500FF7500FF8500FF8500D1FF00FFA300FF8500FF7500FF75
00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF66
00FF6600FF6600FF6600FF7500FF7500FF7500FF7500FF8500FF8500FF9400FF9400FFA3
00FFA300FFB300FFC200FFD100FFE100E1FFDC00FF00A3FF00FFFF00FFF000D1FF00E1FF
00F0FF00FFF000FFE100F0FF00D1FF0038FF000AFF6100FF00F0FF00FFE100FFC200FFA3
00FFA300FF9400FFB300D1FF00FF9400FF7500FF7500FF7500FF6600FF5700FF5700FF57
00FF5700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF5700FF5700FF57
00FF5700FF5700FF5700FF5700FF5700FF6600FF6600FF8500FF940057FF00C2FF00FFFF
00FFF00094FF00FFB300FF9400FF7500FF7500FF6600FF6600FF6600FF6600FF6600FF66
00FF750094FF00FF8500FF7500FF7500FF7500FF7500FF8500FF9400FF9400FFC20066FF
00C2FF00FFB300FF9400FF8500FF7500FF6600FF5700FF5700FF4700FF3800FF3800FF38
00FF3800FF3800FF3800FF2800FF3800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF3800FF3800FF4700FF8500FFB30094FF00FF7500FF4700FF3800FF38
00FF3800FF5700FF4700FF6600FFD10038FF00FF8500FF3800FF1900FF0A05FF0014FF00
23FF0033FF0033FF0033FF0042FF0042FF0042FF0042FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
23FF0023FF0033FF0033FF0033FF0033FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0000FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF4700FF4700FF4700FF4700FF47
00FF4700FF4700FF5700FF5700FF5700FF5700FF5700FF6600FF6600FF6600FF7500FF75
00FF850075FF00FFF000F0FF0028FF9E00FF8000FF0500FF00B3FF0085FF00F0FF00F0FF
0066FF0057FF8F00FF0047FF0057FF0094FF0019FF0047FFAE00FF0500FFEB00FFDC00FF
0028FF00A3FF00C2FF00E1FF00F0FF00FFFF00FFF000FFF000FFF000FFFF00E1FF0085FF
00FFF000FFD100FFC200FFC200FFC200FFC200FFC200FFB300FFB300FFB300FFB300FFC2
00FFC200FFC200FFC200FFD100FFE100FFE100FFF000FFFF00E1FF0094FF0057FF2300FF
000AFF0066FF00A3FF0075FF00A3FF00C2FF00C2FF00B3FF0057FFFF00990066FF00B3FF
00C2FF00C2FF00D1FF00D1FF00D1FF00D1FF00D1FF00D1FF00C2FF00B3FF0075FF0038FF
5100FF0500FF0500FF0038FF0038FF0028FF0500FF1400FF0019FF000AFF0019FF0019FF
0019FF000AFF0500FF1400FF2300FF4200FF9E00FFFF00D7BD00FFDC00FFFF00E6FF00A8
FF002EFF0000FF0000FF0000FF003DFF005CFF007AFA00FFAE00FF8F00FF7000FF6100FF
5100FFFF00996100FF2300FF0038FF0057FF0066FF0066FF0075FF0075FF0085FF0085FF
0085FF0066FF0085FF00A3FF00A3FF00C2FF00E1FF00F0FF00F0FF00FFFF00FFFF00FFFF
00FFF000FFF000FFF000FFF000FFF000FFE100FFE100FFE100FFF000FFF000FFFF00A3FF
00D1FF0075FF00FFFF00F0FF00B3FF00FFF000FFC200FFA300FFA300FF9400FF9400FF85
00FF8500FF8500FF8500FF8500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF75
00FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF8500FF7500FF7500FF7500FF66
00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF66
00FF6600FF6600FF6600FF6600FF7500FF7500FF7500FF7500FF8500FF8500FF9400FFA3
00FFB300FFB300FFC200FFD100FFF000F0FF0047FFCC00FF00FFE100FFE100FFE100FFE1
00FFC200FFC200FFD100FFE100FFFF00B3FF0038FF4200FF00D1FF00FFF000FFD100FFB3
00FFB300FFB300FFE100E1FF00FFA300FF9400FF9400FF9400FF7500FF6600FF5700FF57
00FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF6600FF66
00FF7500FF6600FF6600FF6600FF6600FF6600FF7500FF8500FF9400FFA300FFD100F0FF
00E1FF00FFD100FFA300FF9400FF8500FF7500FF7500FF7500FF6600FF7500FFD100FF94
00FFA30066FF00FFC200FF8500FF8500FF8500FF8500FFD100FFC200FFB300FFC200E1FF
00FFFF00FFC200FFA300FF8500FF7500FF7500FF5700FF5700FF5700FF4700FF4700FF38
00FF3800FF3800FF4700FF4700FF3800FF3800FF4700FF5700FF3800FF3800FF3800FF28
00FF3800FF3800FF3800FF3800FF4700FF6600FFB300C2FF00FF9400FF5700FF4700FF57
00FF8500FFE100FF858F00FF00F0FF00FFE100FF6600FF1900FF0A05FF0014FF0023FF00
23FF0023FF0033FF0033FF0033FF0042FF0042FF0042FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0000FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF2800FF2800FF2800FF2800FF3800FF2800FF2800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF4700FF4700FF4700FF4700FF47
00FF5700FF5700FF5700FF5700FF5700FF5700FF6600FF6600FF6600FF6600FF7500FF75
00FF8500FFB300FFE100FFF000B3FF00E1FF00FFFF7000FF00F0FF00FFF000FFF000FFFF
00F0FF00C2FF0038FF4200FF7000FF0057FF0500FF000AFF7000FFFF00F5FF006B8F00FF
0047FF0094FF00A3FF00C2FF00FFFF00FFF000FFF000FFE100FFE100FFE100FFF0FF0000
00FFE100FFC200FFC200FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB3
00FFC200FFC200FFD100FFD100FFF000FFF000FFFF00F0FF00E1FF00B3FF0038FF1400FF
0075FF00B3FF00D1FF00D1FF00E1FF00E1FF00D1FF00B3FF0085FF8F00FF0085FF00A3FF
00C2FF00D1FF00D1FF00E1FF00E1FF00D1FF00D1FF00D1FF00C2FF00B3FF0075FFFF0000
0038FF0066FF0075FF0075FF0066FF0047FF2300FF000AFF0038FF0038FF0038FF0038FF
0019FF0019FF000AFF1400FF2300FF4200FF6100FF8F00FFAE00FFEB00FFFF005CFF002E
FF0000FF0000FF0000FF0000FF0000FF006BFF00B8FF00F5DC00FFFF00C7CC00FFFF006B
FF00006100FF1400FF000AFF0038FF0057FF0066FF0075FF0075FF0085FF0085FF0094FF
0094FF00A3FF00B3FF00C2FF00C2FF00D1FF00E1FF00F0FF00F0FF00FFFF00FFFF00FFF0
00FFF000FFF000FFF000FFF000FFE100FFF000FFE100FFE100FFE100FFE100FFF03300FF
00FFF000FFE100FFE100FFE100FFFF0019FF00FFB300FFA300FF9400FF9400FF9400FF94
00FF8500FF8500FF8500FF8500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF75
00FF7500FF7500FF7500FF6600FF6600FF7500FF6600FF7500FF6600FF7500FF6600FF66
00FF6600FF6600FF6600FF5700FF5700FF6600FF5700FF5700FF6600FF5700FF6600FF66
00FF6600FF6600FF6600FF6600FF6600FF7500FF7500FF7500FF8500FF9400FF9400FFB3
00FFB300FFC200E1FF00FFF000C2FF00C2FF00D1FF00FFF000FFD100FFC200FFC200FFB3
00FFB300FFB300FFC200FFE100D1FF0057FF00E1FF00E1FFFA00FF00D1FF00E1FF8000FF
00FFD100FFC200FFF000D1FF00FFC200FFD10094FF00FFB300FF8500FF6600FF6600FF57
00FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF6600FF6600FF7500FFD1
00FF9400FF7500FF6600FF7500FF6600FF7500FF7500FF8500FF9400FFA300FFC200F0FF
00C2FF00FFD100FFB300FFA300FF9400FF9400FF8500FF8500FF8500FF8500FFC200C2FF
00FFD100A3FF00FFA300FF9400FF9400FF9400FFB300FFC200D1FF00FFD100FFE10500FF
0085FF00FFD10047FF00FFA300FF8500FF7500FF6600FF6600FF6600FF5700FF5700FF47
00FF4700FF4700FF7500FF7500FF5700FF5700FF8500FF8500FF4700FF3800FF3800FF38
00FF3800FF3800FF4700FF4700FF4700FF6600FF9400F0FF00FF9400FF7500FF7500D1FF
00FFC200C2FF00FFE100FFF000FF6600F0FF00FF3800FF0A05FF0014FF0014FF0023FF00
23FF0023FF0033FF0033FF0033FF0042FF0042FF0042FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0000FF0A05FF0005FF00
05FF0005FF0005FF0005FF0000FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF3800FF3800FF3800FF3800FF3800FF3800FF4700FF4700FF4700FF4700FF4700FF47
00FF4700FF5700FF5700FF5700FF5700FF6600FF6600FF6600FF6600FF6600FF7500FF75
00FF8500FF9400FFA300FFB300FFD100FFFF00FFD100FFD100FFD100FFE100FFE100FFF0
00F0FF00D1FF00B3FF0075FF000AFF0500FF3300FF6100FF9E00FFFF00008F00FF0500FF
FF00D75100FF0066FF00C2FF00FFFF00FFF000FFE100FFE100FFD100FFD100FFD100FFE1
00FFD100FFC200FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB3
00FFB300FFC200FFC200FFD100C2FF1400FF00D1FF00E1FF0094FFBD00FF0038FF0094FF
0085FF0094FF00F0FF00F0FF00F0FF00E1FF00D1FF00B3FFFF0099FF006B000AFF0094FF
00C2FF00D1FF00E1FF00E1FF00E1FF00E1FF00E1FF00D1FF00C2FF3300FF7000FF0075FF
0075FF0094FF0094FF0085FF0066FF0038FFFF00F50019FF0047FF0047FF0047FF0047FF
0028FF000AFF2300FF2300FF3300FF4200FF6100FF8000FFAE00FFDC00FFFF00B8FF0099
FF003DFF0000FF0000FF0000FF0000FF001EFF003DFF003DFF0099FF0099DC00FFFA00FF
5100FF8000FFFF005CCC00FFBD00FF0047FF0066FF0075FF0085FF0085FF0094FF00A3FF
00A3FF00B3FF00B3FF00C2FF00D1FF00E1FF00E1FF00F0FF00F0FF00FFFF00FFFF00FFF0
00FFF000FFF000FFE100FFE100FFE100FFE100FFD100FFD100FFD100FFD100FFE100FFE1
00FFD100FFD100FFD100FFC200FFD100FFF000FFB300FFA300FF9400FF9400FF9400FF85
00FF8500FF8500FF8500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF75
00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF66
00FF5700FF6600FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF66
00FF5700FF6600FF6600FF6600FF6600FF7500FF7500FF8500FF8500FF9400FFA30028FF
00FFE100FFE100B3FF0019FF0066FF00F0FF0085FF00FFF000FFD100FFB300FFB300FFA3
00FFA300FFA300FFB300FFF000E1FF00FFFF00F0FF00FFE100FFF000C2FF2300FF00E1FF
00FFF000FFF000FFFF00B3FF00A3FF00D1FF00A3FF00FF9400FF8500FF7500FF6600FF66
00FF6600FF5700FF5700FF6600FF5700FF5700FF6600FF7500FF8500FF7500FF850066FF
00FFC200FF8500FF7500FF7500FF7500FF8500FF9400FF9400FFA300FFB300FFD100FFF0
0075FF00FFF000F0FF00FFD100FFB300FFF000FFC200FFD100FFA300FFA300FFB300FFE1
00B3FF00FFD100FFB300FFA300FFA300FFB300C2FF00F0FF0028FF00FFF000FFFF00B3FF
00B3FF00F0FF0094FF0057FF00FFB300FF8500FF8500FFD100FF8500FF9400FF7500FF57
00FF5700FF5700FF940019FF00FF7500FF7500FFF000FFB300FF5700FF4700FF3800FF38
00FF4700FF4700FF4700FF4700FF5700FF6600FF7500FFB300FFE100FFB300FFD10500FF
00FFF000FFB30028FF00FF4700FF4700FF6600FFA300FF0A05FF0014FF0014FF0023FF00
23FF0023FF0033FF0033FF0033FF0033FF0042FF0042FF00
42FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0014FF0014FF0023FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0000FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF2800FF2800FF2800FF2800FF2800FF2800FF38
00FF3800FF3800FF3800FF3800FF4700FF3800FF4700FF4700FF4700FF4700FF4700FF57
00FF5700FF5700FF5700FF5700FF5700FF5700FF6600FF6600FF6600FF6600FF7500FF75
00FF8500FF8500FF9400FFA300FFA300FFB300FFC200FFC200FFD100FFD100FFE100FFF0
00D1FF00B3FF00A3FF0066FF000AFFFF0000BD00FFFF0000FF00F5FF00E67000FF8F00FF
0085FF6100FF00A3FF00F0FF00FFF000FFE100FFE100FFD100FFD100FFD100FFD100FFC2
00FFC200FFB300FFB300FFB300FFB300FFB300FFA300FFA300FFB300FFB300FFB300FFB3
00FFB300FFB300FFC200FFD100FFE100E1FF0028FF00A3FF0047FF0038FF00C2FF00D1FF
00D1FF00F0FF00FFFF00FFFF00FFFF00F0FF00E1FF00C2FF0085FFFF004C0066FF0019FF
00D1FF00E1FF00E1FF00E1FF00E1FF00E1FF00E1FF00E1FF00D1FF00B3FF0047FF00B3FF
00B3FF00B3FF00A3FF0085FF0066FF4200FF1400FF0047FF0057FF0057FF0057FF0047FF
0028FF8000FFFF00D7FA00FF8000FF7000FFBD00FFFF00E6EB00FFFF00F5FF00D7FF008A
FF0000FF0000FF0000FF0000FF0000FF0000FF002EFF001EFF00E6CC00FF8F00FF6100FF
3300FF2300FF2300FF0500FF0028FF0047FF0066FF0075FF0075FF0085FF0094FF00A3FF
00A3FF00B3FF00C2FF00C2FF00D1FF00E1FF00E1FF00E1FF00F0FF00FFFF00FFFF00FFF0
00FFF000FFF000FFE100FFE100FFE100FFE100FFD100FFD100FFD100FFD100FFD100FFC2
00FFC200FFC200FFC200FFB300FFB300FFB300FFB300FF9400FF9400FF9400FF8500FF85
00FF8500FF8500FF8500FF8500FF7500FF7500FF7500FF7500FF7500FF7500FF6600FF66
00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF5700FF57
00FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF57
00FF5700FF5700FF6600FF6600FF6600FF7500FF7500FF8500FF8500FF9400FFA300FFE1
00D1FF0094FF5100FF00C2FF00FFE100FFE100B3FF00B3FF00FFD100FFB300FFA300FFA3
00FF9400FF9400FFA30094FF00FFB300FFC200FFD100FFC200FFE100C2FF00D1FF3300FF
00B3FF0085FF00A3FF00F0FF00FFE100FFD100FFA300FF9400FF8500FF7500FF6600FF66
00FF6600FF6600FF6600FF6600FF6600FF6600FF7500FF94000AFF00FFD100FFA300B3FF
00FFB300FF9400FF8500FF8500FF9400FFB300FFE100FFB300FFB300FFE10094FF00F0FF
0019FF00B3FF0066FF00FFF000FFD100FFF00094FF00FFE100FFC20075FF00FFD10057FF
0019FF00C2FF00FFE100FFF000FFD100FFC200FFE100D1FF0085FF00E1FF00C2FF0075FF
8000FF0066FF00A3FF00FFE100FFB300FFB300FFA300FFFF00FFC200D1FF00FF8500FF66
00FF6600FF6600FF8500A3FF00FFA300FFC200FFF000FF8500FF6600FF5700FF4700FF47
00FF4700FF5700FF5700FF5700FF6600FF6600FF8500FFC200FFE100FFB300FFA300FFD1
00FF6600FF7500FF6600FF3800FF2800FF1900FF1905FF0014FF0014FF0014FF0023FF00
23FF0033FF0033FF0033FF0033FF0033FF0042FF0042FF00
42FF0042FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0000FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF3800FF3800FF3800FF3800FF3800FF4700FF4700FF4700FF4700FF4700FF4700FF47
00FF5700FF5700FF5700FF5700FF5700FF6600FF6600FF6600FF6600FF6600FF7500FF75
00FF8500FF8500FF9400FF9400FFA300FFA300FFB300FFC200FFC200FFD100FFE100FFF0
00E1FF000AFF0047FF0038FF6100FFFF00008000FFFF008A4200FF8F00FF0038FF0500FF
00A3FF0094FF0057FF00B3FF00FFF000FFE100FFE100FFD100FFD100FFC200FFC200FFC2
00FFB300FFB300FFB300FFB300FFB300FFA300FFA300FFA300FFA300FFA300FFA300FFB3
00FFB300FFB300FFC200FFC200FFE10028FF0094FF6100FFFF00C700C2FF00F0FF00FFFF
00FFFF00FFF000FFF000FFF000FFFF00F0FF00E1FF00C2FF0085FFFF00D700A3FF00C2FF
00D1FF00E1FF00E1FF00F0FF00F0FF00F0FF00F0FF00E1FF00E1FF00E1FF00D1FF00D1FF
00C2FF00C2FF00A3FF0038FF0047FF8000FF0500FF0057FF0066FF0066FF0066FF0057FF
0500FF0500FF0500FF2300FF8000FFFF00D7EB00FFEB00FFFF00D7FF005CFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00C7EB00FFAE00FFFA00FF
3300FF1400FF000AFF0019FF0038FF0047FF0057FF0066FF0066FF0085FF0094FF00A3FF
00A3FF00B3FF00C2FF00C2FF00D1FF00D1FF00E1FF00E1FF00F0FF00F0FF00FFFF00FFFF
00FFF000FFF000FFE100FFE100FFE100FFD100FFD100FFD100FFC200FFC200FFC200FFC2
00FFB300FFB300FFB300FFB300FFA300FFA300FFA300FF9400FF9400FF9400FF8500FF85
00FF8500FF8500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF6600FF66
00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF5700FF6600FF5700FF5700FF57
00FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF57
00FF5700FF6600FF5700FF6600FF6600FF6600FF7500FF8500FF9400FFA300FFB300FFF0
0066FF0085FF00FFE100FFC200FFC200FFD100FFFF0085FF00FFF000FFB300FFA300FF94
00FF9400FF9400FF9400FF9400FF9400FF9400FFA300FFA300FFB300FFD100FFF000B3FF
CC00FF6100FF0038FF3300FF00FFD100FFB300FFA300FF9400FF8500FF7500FF7500FF75
00FF6600FF6600FF6600FF6600FF6600FF7500FF7500FF940085FF00A3FF00FFE100B3FF
00FFC200FFA300FF9400FFA3000AFF00FFF000FFFF00FFC200FFD100A3FF0075FF0066FF
0028FFFF00B88000FF0019FF0047FF0094FF9E00FF0075FF0057FFAE00FF00C2FF9E00FF
1400FF5100FF0038FF2300FF00C2FF0085FF00E1FF00A3FF2300FF0094FF9E00FF0057FF
000AFF0038FF0038FF00B3FF00FFF000E1FF00FFD100FFF000FFFF00FFB300FF9400FF85
00FF8500FF8500FF9400FFB300C2FF00E1FF00FFA300FF7500FF6600FF5700FF5700FF57
00FF5700FF660019FF00FF7500FF7500FF8500FFF00094FF00FFB300FF8500FF7500FF66
00FF4700FF4700FF3800FF2800FF1900FF0A00FF0A05FF0005FF0014FF0014FF0023FF00
23FF0023FF0033FF0033FF0033FF0033FF0033FF0042FF00
42FF0042FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0023FF0023FF0033FF0033FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0000FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF3800FF3800FF3800FF3800FF4700FF4700FF4700FF4700FF4700FF4700FF5700FF57
00FF5700FF5700FF5700FF5700FF6600FF6600FF6600FF6600FF6600FF7500FF7500FF75
00FF8500FF8500FF8500FF9400FF9400FFA300FFB300FFB300FFC200FFD100FFD100FFF0
00E1FF0028FF0075FF000AFFFF006BFF00E6CC00FF2300FFFF00A80038FFCC00FF0075FF
00B3FF00D1FF00E1FF00F0FF00FFF000FFE100FFD100FFD100FFC200FFC200FFC200FFB3
00FFB300FFB300FFB300FFA300FFA300FFA300FFA300FFA300FFA300FFA300FFA300FFA3
00FFB300FFB300FFC200FFC200FFD100FFFF00B3FF0038FF0038FF0028FF00F0FF00FFF0
00FFE100FFE100FFE100FFF000FFF000FFFF0094FF1400FF0057FF0038FF0094FF00C2FF
00D1FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00E1FF00E1FF00D1FF
00D1FF00C2FF00A3FF0057FFFF00000047FF0066FF0075FF0075FF0075FF0066FF0066FF
0057FF0038FF000AFF8000FFFF00994200FF6100FF8F00FFBD00FFFA00FFFF00A8FF001E
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000FFF0000FF00D7FF0000FF007A
6100FF2300FF0500FF0019FF0028FF0038FF0047FF0028FF0028FF0075FF0085FF0094FF
00A3FF00B3FF00B3FF00C2FF00D1FF00D1FF00E1FF00E1FF00E1FF00F0FF00F0FF00FFFF
00FFF000FFF000FFE100FFE100FFE100FFD100FFD100FFC200FFD100FFC200FFC200FFB3
00FFB300FFB300FFB300FFA300FFA300FFA300FF9400FF9400FF9400FF8500FF8500FF85
00FF8500FF8500FF7500FF7500FF7500FF7500FF7500FF7500FF6600FF6600FF6600FF66
00FF6600FF6600FF6600FF6600FF6600FF6600FF5700FF5700FF5700FF5700FF5700FF57
00FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF57
00FF5700FF5700FF5700FF5700FF6600FF6600FF7500FFA300FFB300FFB300FFC200F0FF
00B3FF4200FF00B3FF00FFA300FFA300FFB300E1FF3300FF0047FF00FFC200FF9400FF94
00FF8500FF8500FF8500FF8500FF8500FF8500FF9400FF9400FFA300FFB300FFD100F0FF
0066FF0057FF0019FF00B3FF00FFF000FFD100FFB300FF9400FF9400FF8500FF7500FF75
00FF7500FF7500FF7500FF7500FF7500FF8500FF8500FF9400FFB300FFD100E1FF00FFFF
00FFD100FFC200FFD100FFC200FFF000D1FF00B3FF00A3FF00F0FF00C2FF0047FF0038FF
EB00FF0066FF00C2FF00FFFF00FFFF00F0FF00D1FF00FFE100FFE100C2FF00E1FF00A3FF
00C2FF00B3FF00FFFF00A3FF00FFFF00B3FF7000FF1400FFCC00FF0028FF5100FF0085FF
0094FF00C2FF00FFFF00E1FF00D1FF0075FF0028FF0075FF0047FF00FFF000FFD100F0FF
0066FF00FFA300FFB300FFD10500FF00FFC200FF9400FF8500FF7500FF6600FF6600FF66
00FF7500FF85AE00FF00FFB300FF8500FF9400FFD15100FF00FFC200FF7500FF5700FF47
00FF3800FF3800FF2800FF1900FF1900FF0A00FF0A05FF0014FF0014FF0014FF0023FF00
23FF0023FF0033FF0033FF0033FF0033FF0033FF0033FF00
42FF0042FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0023FF0033FF0033FF0033FF0033FF0033FF0033FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0000FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF38
00FF3800FF3800FF3800FF3800FF4700FF4700FF4700FF4700FF4700FF5700FF5700FF57
00FF5700FF5700FF5700FF5700FF6600FF6600FF6600FF6600FF7500FF7500FF7500FF75
00FF8500FF8500FF9400FF9400FF9400FFA300FFA300FFB300FFC200FFD100FFE100FFF0
00F0FF00D1FF00A3FF0038FF3300FF0019FF1400FF0057FF0085FF0075FFFF00D70028FF
00B3FF00E1FF00F0FF00FFFF00FFF000FFE100FFD100FFD100FFC200FFC200FFB300FFB3
00FFB300FFA300FFA300FFA300FFA300FFA300FFA300FFA300FFA300FFA300FFA300FFA3
00FFA300FFB300FFB300FFC200FFE100FFFF0038FF00D1FF0094FF00F0FF00E1FF00FFE1
00FFE100FFE100FFE100FFE100FFF000FFFF00D1FFFF00001400FFAE00FFFF008A0066FF
00E1FF00F0FF00F0FF00FFFF00FFFF00FFFF00FFFF00F0FF00F0FF00F0FF00E1FF00E1FF
00D1FF00C2FF0047FF000AFF0038FF2300FF0085FF0085FF0085FF0085FF0075FF0066FF
0057FF0038FFFF007A3300FF2300FF2300FF6100FF9E00FFBD00FFFF0099FF007AFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A8AE00FF
7000FF6100FFAE00FF0500FFFA00FFAE00FF0028FF000AFF0019FFFF006B0057FF0085FF
0094FF0094FF00A3FF00B3FF00C2FF00D1FF00D1FF00D1FF00C2FF00C2FF00C2FF00FFFF
00FFF000FFF000FFE100FFE100FFD100FFD100FFD100FFC200FFC200FFC200FFB300FFB3
00FFB300FFB300FFA300FFA300FFA300FF9400FF9400FF9400FF9400FF8500FF8500FF85
00FF8500FF8500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF6600FF6600FF66
00FF6600FF6600FF6600FF6600FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF57
00FF5700FF5700FF4700FF5700FF4700FF4700FF4700FF4700FF4700FF4700FF5700FF57
00FF5700FF5700FF5700FF5700FF6600FF6600FF7500FFB30094FF00FFF000FFF04200FF
00FFE100FFD100FFA300FF9400FF9400FFA300FFC200F0FF00FFFF00FFB300FF9400FF85
00FF8500FF7500FF7500FF7500FF7500FF8500FF8500FF9400FFA300FFC200FFE100F0FF
7000FF00C2FF00A3FF0075FF0019FF00E1FF00FFC200FFD100FFA300FF9400FF8500FF85
00FF7500FF7500FF8500FF8500FFB300FF9400FF9400FFA300FFB300FFD100F0FF0057FF
0066FF00FFFFFF00F500B3FF0085FFFA00FF0047FF00B3FF00E1FF00A3FF0028FF000AFF
00A3FF00D1FF00F0FF00FFD100FFC200FFF000FFE100FFB300FFA300FFB300FFC200FFFF
00FFFF00FFC200FFC200FFB300FFC200FFE100D1FF0094FF0057FF0075FF2300FF00F0FF
00E1FF0047FF00FFE100FFC20028FF00FFD100E1FFAE00FF00A3FF00C2FF8000FF0028FF
0075FF00FFE10094FF00F0FF6100FF00A3FF00FFB300FF9400FF8500FF8500FF7500FF94
FF00B800FFB39E00FF00FFB300FFA300FFB300FFFF00FFFF00FFA300FF7500FF5700FF47
00FF3800FF2800FF2800FF1900FF1900FF0A05FF0005FF0014FF0014FF0014FF0023FF00
23FF0023FF0023FF0033FF0033FF0033FF0033FF0033FF00
42FF0033FF0033FF0042FF0042FF0042FF0042FF0042FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0005FF0014FF0014FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0000FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF2800FF2800FF2800FF2800FF2800FF2800FF38
00FF3800FF3800FF3800FF4700FF4700FF4700FF5700FF5700FF5700FF5700FF5700FF57
00FF5700FF5700FF6600FF6600FF6600FF6600FF6600FF6600FF7500FF7500FF7500FF75
00FF8500FF8500FF9400FF9400FF9400FFA300FFA300FFB300FFD100FFE100FFF000FFFF
00F0FF00D1FF0047FF1400FF0066FF0085FFFF00F50085FF00B3FF0057FF0500FFFF00E6
0094FF00C2FF00F0FF00FFF000FFF000FFE100FFD100FFD100FFC200FFC200FFB300FFB3
00FFA300FFA300FFA300FFA300FFA300FFA300FFA300FF9400FF9400FFA300FFA300FFA3
00FFA300FFB300FFB300FFC200FFF000F0FF00C2FF00FFF000FFF000FFE100FFD100FFD1
00FFD100FFD100FFD100FFE100FFF000FFFF00E1FF00B3FF9E00FF0094FF0038FF00D1FF
00F0FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F0FF00F0FF00F0FF00E1FF
00E1FF00D1FF00C2FF00A3FF00A3FF00A3FF00A3FF0094FF0094FF0085FF0075FF0066FF
0057FF0047FF0028FF0019FF0500FF2300FF4200FFCC00FFFF00C7FF0099FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF006BFA00FF
EB00FFFF001EFF00D7FF00009E00FF3300FF2300FF3300FF2300FF0028FF0066FF0075FF
0075FF000AFF0094FF0094FF00B3FF00C2FF00C2FF00C2FF4200FF0019FF00D1FF00F0FF
00FFFF00FFF000FFE100FFE100FFD100FFD100FFD100FFC200FFC200FFC200FFB300FFB3
00FFB300FFA300FFA300FFA300FFA300FF9400FF9400FF9400FF9400FF9400FF8500FF85
00FF8500FF7500FF7500FF7500FF7500FF7500FF7500FF6600FF6600FF6600FF6600FF66
00FF6600FF6600FF5700FF5700FF6600FF5700FF5700FF5700FF5700FF5700FF5700FF57
00FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF57
00FF4700FF5700FF5700FF5700FF5700FF6600FF7500FF8500FFC200A3FF4200FF00F0FF
00FFC200FFA300FF8500FF8500FF8500FF9400FFB300FFE100D1FF00FFD100FFA300FF85
00FF7500FF7500FF7500FF7500FF7500FF7500FF8500FF9400FFD100FFE15100FF00F0FF
00D1FF00FFE100FFD100C2FF00D1FF0066FF00E1FF00D1FF00D1FF00FFD100FF9400FF85
00FF8500FF8500FF9400FFB300FFFF00FFC200FFB300FFD100FFF000D1FF0085FF9E00FF
0028FFFF00000500FF00FFF000FFF000E1FF00F0FF00FFD100FFD10047FF00D1FF0075FF
7000FF00FFF000D1FF00FFA300FFA300FFB300FF9400FF8500FF8500FF9400FFE100A3FF
0075FF00FFB300FF9400FF9400FFA300E1FF00D1FF00FFFF00F0FF0500FF00F0FF00FFE1
00D1FF00FFE100FFE100FF9400FF9400FFA300FFE100A3FF00FFC200FFA300FFC20500FF
00F0FF0028FF0047FF000AFF8F00FF1400FF00FFE100FFE10094FF00FFA300FF9400FFA3
00C2FF00E1FF0094FF00FFD100FFC200FFE10085FF0094FF00FFA300FF8500FF6600FF47
00FF3800FF3800FF2800FF1900FF0A00FF0A00FF0A05FF0005FF0014FF0014FF0014FF00
23FF0023FF0023FF0023FF0033FF0033FF0033FF0033FF00
42FF0033FF0042FF0042FF0042FF0042FF0042FF0042FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0000FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF38
00FF3800FF3800FF3800FF4700FF4700FF5700FF5700FF5700FF5700FF5700FF5700FF57
00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7500FF7500FF7500FF7500FF75
00FF8500FF9400FF9400FF9400FFA300FFA300FFB300FFC200FFE1FF000000E1FF00F0FF
00D1FF0038FF7000FF3300FF00B3FF0094FF0075FF8000FF00C2FF00D1FF00C2FF0066FF
0500FF0075FF00F0FF00FFFF00FFF000FFE100FFD100FFD100FFC200FFC200FFB300FFB3
00FFA300FFA300FFA300FFA300FF9400FF9400FF9400FF9400FF9400FF9400FFA300FFA3
00FFA300FFB300FFC200FFE1EB00FF00F0FF00FFFF00FFD100FFC200FFC200FFC200FFC2
00FFC200FFC200FFD100FFE100FFFF00E1FF00D1FF0047FF0057FF00C2FF00D1FF00E1FF
00FFFF00FFFF00FFFF00FFF000FFFF00FFFF00FFFF00FFFF00FFFF00F0FF00F0FF00E1FF
00E1FF00D1FF00D1FF00C2FF00B3FF00B3FF00A3FF00A3FF0094FF0085FF0075FF0066FF
0057FF0047FF0038FF0019FF0500FF2300FF5100FF8F00FFFF00B8FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF002EFF0000FF00E6FF00E68F00FF
4200FFFF007A4200FF3300FFFF00D7FF00D7FF004CFF007ABD00FF0019FF0047FF0057FF
0057FFCC00FF0047FF4200FF0094FF00B3FF00B3FF00A3FF0047FF0085FF00D1FF00F0FF
00FFFF00FFF000FFE100FFE100FFD100FFD100FFD100FFC200FFC200FFB300FFB300FFB3
00FFB300FFA300FFA300FFA300FFA300FFA300FF9400FF9400FF8500FF8500FF8500FF85
00FF8500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF6600FF6600FF6600FF66
00FF6600FF6600FF6600FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF4700FF47
00FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF5700FF4700FF47
00FF4700FF4700FF5700FF5700FF5700FF6600FF6600FF8500FFB300FFE15100FF6100FF
4200FF00FF9400FF7500FF7500FF7500FF8500E1FF0057FF9E00FF0019FF00FF9400FF75
00FF7500FF6600FF6600FF6600FF6600FF7500FF7500FF8500FFE10085FF00FFC200FFD1
0500FF00FFC200FFB300FFC200FFD100E1FF3300FF0019FF00FFF000FFC200FFA300FF94
00FF9400FF9400FFB300FFFF0075FF00FFF000F0FF00D1FF0085FF000AFF4200FF0075FF
0038FF00FFE11400FF00FFB300FFC22300FF00E1FF00FFB300FFA300FFB300FFD100F0FF
0047FF00FFD100FFB300FF9400FF8500FF8500FF7500FF7500FF7500FF850094FF00FFA3
1400FF00FFF000FF8500FF8500FF9400FFB300FFFF00FFD100FFE10085FF0066FF00FFC2
00FFE100FFD100FF8500FF8500FF8500FFA300C2FF00FFB300FFD100FF8500FF9400FFA3
00FFB300FFFF00C2FF00C2FFDC00FF00FFFF0094FF2300FF0094FF00FFD100FFE100FFC2
00FFE100D1FF00FFFF00FFE100FFE100FFFF0094FF00FFFF00FFC2000AFF00FF8500FF57
00FF4700FF3800FF2800FF1900FF1900FF0A00FF0A05FF0005FF0014FF0014FF0014FF00
23FF0023FF0023FF0023FF0023FF0033FF0033FF0033FF00
42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0000FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF2800FF2800FF2800FF2800FF2800FF3800FF3800FF38
00FF3800FF3800FF4700FF5700FF7500FF6600FF6600FF6600FF6600FF6600FF6600FF66
00FF6600FF6600FF6600FF6600FF7500FF6600FF7500FF7500FF7500FF7500FF7500FF85
00FF8500FF9400FF9400FFA300FFA300FFA300FFB300FFC200FFE100F0FF0057FF00D1FF
00B3FF0019FF0028FF00C2FF00E1FF0075FF00B3FF00D1FF00E1FF00F0FF00D1FF0047FF
0066FF00A3FF00E1FF00F0FF00FFFF00FFF000FFE100FFD100FFC200FFC200FFB300FFB3
00FFA300FFA300FFA300FF9400FF9400FF9400FF9400FF9400FF9400FF9400FF9400FF94
00FFA300FFA300FFB300FFD100FFC200FFD10028FF00FFC200FFC200FFB300FFB300FFB3
00FFC200FFC200FFC200FFD100FFFF0075FF00A3FF0038FF0085FF00D1FF00F0FF00FFFF
00FFFF00FFF000FFF000FFF000FFF000FFF000FFFF00FFFF00FFFF00F0FF00F0FF00F0FF
00E1FF00E1FF00D1FF00C2FF00C2FF00B3FF00A3FF00A3FF0094FF0075FF0057FF0047FF
0047FF0038FF0500FF000AFF3300FF8000FFCC00FFFF007AFF00E6FF006BFF0000FF001E
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF006BFF00D7BD00FFBD00FF6100FF
2300FF1400FF000AFF0500FF1400FF000AFFAE00FF8F00FF2300FF8F00FF4200FF000AFF
0019FF6100FF0028FF0066FF0094FF0094FF0094FF0085FF2300FF0094FF00C2FF00C2FF
00D1FF00FFFF00FFF000FFE100FFD100FFD100FFD100FFC200FFC200FFB300FFB300FFB3
00FFB300FFA300FFA300FFA300FFA300FF9400FF9400FF9400FF8500FF8500FF8500FF85
00FF8500FF7500FF7500FF7500FF7500FF7500FF7500FF6600FF6600FF6600FF6600FF66
00FF6600FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF4700FF47
00FF5700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF47
00FF4700FF4700FF4700FF5700FF5700FF5700FF6600FF7500FF9400FFE100FFE100FFE1
00FF9400FF7500FF6600FF6600FF6600FF7500FF8500FFC200D1FF00FFB300FF8500FF75
00FF6600FF6600FF6600FF6600FF6600FF6600FF7500FF940085FF00FFB300FF9400FFB3
FF000000FFB300FFA300FFA300FFB300F0FF0038FF00C2FF0075FF00FFFF00FFC200FFB3
00FFB300FFFF00FFD100FFFF0075FF6100FF0085FF00F0FF00D1FF00FFF000C2FF4200FF
00FFF000FFC200FFA300FF9400FF9400E1FF00FF9400FF9400FF9400FF9400FFB300FFD1
0075FF00FFE100FFB300FF9400FF8500FF7500FF6600FF6600FF6600FF750028FF00FF75
00FF7500FF7500FF6600FF6600FF7500FF8500FF9400FFA300FFD10094FF00F0FF00FFB3
00FF9400FF8500FF7500FF6600FF6600FF7500FFA300FF7500FF6600FF6600FF6600FF75
00FF9400FFB300C2FF00FFF00075FF00FFB300FFD100B3FF00A3FF0094FF00A3FF00F0FF
00C2FF0094FF00D1FF00F0FF00E1FF0094FFCC00FF0019FF00E1FF00B3FF00FFE100FF75
00FF5700FF4700FF4700FF2800FF1900FF1900FF0A00FF0A05FF0005FF0014FF0014FF00
14FF0014FF0023FF0023FF0023FF0023FF0033FF0033FF00
42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0000FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF2800FF2800FF2800FF2800FF2800FF2800FF38
00FF3800FF3800FF4700FF570075FF00FF8500FF7500FF6600FF6600FF6600FF7500FF75
00FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF8500FF85
00FF9400FF9400FFA300FFA300FFB300FFB300FFC200FFD10094FF0066FF0057FF0075FF
0028FF0075FF0085FF00E1FF00FFFF00F0FF00FFFF00FFF000FFF000FFFF00FFFF00E1FF
00B3FF0066FFBD00FF00A3FF0028FF00E1FF00E1FF00FFF000FFD100FFC200FFB300FFB3
00FFA300FFA300FF9400FF9400FF9400FF9400FF9400FF9400FF9400FF9400FF9400FF94
00FF9400FF9400FFA300FFA300FFA300FFB300FFB300FFB300FFB300FFB300FFB300FFB3
00FFB300FFB300FFC200FFD100FFE10038FF0057FFFF00E600A3FF00D1FF00FFFF00FFF0
00FFF000FFF000FFF000FFF000FFF000FFF000FFFF00FFFF00FFFF00F0FF00F0FF00F0FF
00E1FF00E1FF00D1FF00D1FF00C2FF00B3FF00A3FF00A3FF0094FF0075FF2300FF8000FF
0028FF0019FF3300FF2300FF5100FFFF00008F00FF7000FFAE00FFFF007AFF0000FF00C7
FF006BFF0000FF0000FF0000FF0000FF0000FF005CFF000FFF00D7CC00FF7000FF4200FF
1400FF000AFF0028FF0038FF0038FF0028FF1400FF8000FF0038FF0038FF5100FF8000FF
FF000FBD00FF000AFF0057FF0075FF0075FF0066FF0066FFCC00FF0038FF1400FFFF0000
00A3FF00E1FF00FFF000FFE100FFE100FFD100FFD100FFD100FFC200FFC200FFB300FFB3
00FFB300FFA300FFA300FFA300FF9400FF9400FF9400FF9400FF9400FF8500FF8500FF85
00FF8500FF7500FF7500FF7500FF8500FF7500FF7500FF7500FF6600FF6600FF6600FF66
00FF6600FF6600FF5700FF5700FF5700FF5700FF5700FF5700FF4700FF4700FF4700FF47
00FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF47
00FF4700FF4700FF4700FF4700FF5700FF6600FF6600FF7500FF940075FF00FFA300FF85
00FF7500FF6600FF6600FF6600FF6600FF6600FF7500FF8500FFD100FFA300FF7500FF66
00FF6600FF5700FF5700FF5700FF6600FF6600FF6600FF7500FF7500FF7500FF7500FF94
00FFF000FF9400FF8500FF9400FFD100FFD10057FF00FFD100FFFFFF000000FFE100FFD1
00FFE10075FF0085FF0094FF0085FF00E1FF00FFD100FFC200FFC200FFB300FFD10066FF
0028FF00FFD100FF9400FF8500FF7500FF7500FF7500FF7500FF8500FF9400FFB300FFFF
00FFF00066FF00FFFF00FFB300FF8500FF6600FF5700FF5700FF5700FF5700FF5700FF57
00FF5700FF5700FF5700FF6600FF6600FF7500FF8500FF9400FFB300F0FF00FFF000FFA3
00FF8500FF7500FF6600FF6600FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF66
00FF9400FFD10094FF00FFD100FF9400FF940066FF00FFB300FFA300FFD100FFFF7000FF
0066FF0500FF00B3FF0094FFFF009900B3FF0075FF0047FFFF003D00FFFF00FFA300FF75
00FF6600FF7500FFA300FF4700FF3800FF1900FF1900FF0A00FF0A00FF0A05FF0005FF00
14FF0014FF0023FF0023FF0023FF0023FF0023FF0023FF00
42FF0042FF0042FF0042FF0042FF0042FF0042FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF2800FF2800FF2800FF2800FF2800FF2800FF3800FF38
00FF3800FF3800FF4700FF5700FF850094FF00FF9400FF7500FF7500FF8500FF8500FFB3
00FFA300FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF8500FF8500FF85
00FF9400FFA35100FF00FFC200FFC200FFC200FFC200FFD100FFF000F0FF00A3FF9E00FF
FF00B80019FF00D1FF00FFFF00FFF000FFE100FFE100FFE100FFE100FFF000FFFF00F0FF
0094FF00B3FF00C2FF0066FF0057FF0066FF0075FF00F0FF00FFE100FFD100FFC200FFB3
00FFA300FFA300FF9400FF9400FF9400FF9400FF9400FF9400FF9400FF8500FF9400FF94
00FF9400FF9400FF9400FF9400FFA300FFA300FFA300FFA300FFA300FFA300FFA300FFA3
00FFB300FFB300FFC200FFD100FFE100F0FF7000FF00B3FF0094FF0094FF00FFFF00FFF0
00FFE100FFE100FFE100FFE100FFF000FFF000FFF000FFFF00FFFF00F0FF00F0FF00E1FF
00E1FF00E1FF00D1FF00D1FF00C2FF00B3FF00A3FF0094FF0094FF0066FF0038FFFF0000
000AFF1400FF6100FFFF00007000FF8000FF7000FF3300FF6100FFAE00FFAE00FFFA00FF
FF0000FF006BFF000FFF0000FF0000FF000FFF008AFF00F5FF00D7FF007ACC00FF5100FF
5100FF3300FF0028FF0047FF0057FF0047FFFA00FF0047FF0057FF0066FF0057FF0038FF
4200FF9E00FFBD00FF1400FF0028FFFF00D70028FF000AFF0047FF0075FF0066FF00B3FF
00E1FF00F0FF00FFF000FFF000FFE100FFE100FFD100FFD100FFC200FFC200FFB300FFB3
00FFB300FFB300FFA300FFA300FF9400FF9400FF9400FF9400FF8500FF8500FF8500FF85
00FF8500FF7500FF7500FF7500FF7500FF7500FF7500FF6600FF6600FF6600FF6600FF66
00FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF4700FF4700FF4700FF4700FF47
00FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF47
00FF4700FF4700FF4700FF4700FF5700FF5700FF6600A3FF0057FF00C2FF00FF8500FF66
00FF6600FF5700FF5700FF5700FF5700FF5700FF6600FF8500FFC200FFB300FF7500FF57
00FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF6600FF6600FF6600FF6600FF75
00FF7500FF7500FF8500FF8500FF8500FF9400FFA300FFB300FFC200FFF00075FF00C2FF
0085FF00D1FF00FFF000FFD100FFFF00FFFF00FFC200FF9400FF9400FFA300D1FF00FFFF
00FFB30047FF00FF9400FF7500FF6600FF6600FF6600FF7500FF7500FF9400FFC20075FF
00FFB300FFA300FFF000C2FF00FFA300FF6600FF5700FF4700FF4700FF4700FF4700FF47
00FF4700FF4700FF5700FF5700FF6600FF6600FF7500FF9400FFB300FFF000FFD100FFA3
00FF8500FF7500FF6600FF5700FF5700FF4700FF4700FF4700FF4700FF4700FF5700FF75
00FFA300F0FF00FFA3AE00FF00FF9400FF7500FF7500FF7500FF8500FFA300FFD10047FF
0094FF000AFF0028FF00C2FF00C2FF00F0FF0094FF00E1FF0066FF8F00FF00FFE10066FF
00FF9400FF9400FFC200FFD100FF5700FF2800FF2800FF2800FF8500FF2800FF0A05FF00
05FF0014FF0014FF0014FF0014FF0023FF0023FF0023FF00
42FF0042FF0042FF0042FF0042FF0042FF0042FF0033FF0042FF0042FF0042FF0042FF00
42FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0005FF0014FF0014FF0014FF0014FF0014FF0014FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0000FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF38
00FF3800FF4700FF4700FF5700FF7500FFC200FFB300FFA300FF9400D1FF00FFB39E00FF
00FFA300FF8500FF8500FF8500FF7500FF7500FF7500FF8500FF8500FF8500FF8500FF94
00FF9400FFB30066FF00B3FF00FFE100FFD100FFD100FFE100FFFF00E1FF0094FF0057FF
0085FF0038FF0057FF00F0FF00FFE100FFD100FFD100FFD100FFE100FFE100FFFF00D1FF
0057FF00D1FF00FFFF00FFFF00E1FF0057FFFF008A00A3FF00FFFF0075FF00FFD100FFB3
00FFA300FF9400FF9400FF9400FF9400FF8500FF8500FF8500FF8500FF8500FF8500FF85
00FF8500FF9400FF9400FF9400FF9400FF9400FF9400FFA300FFA300FFA300FFA300FFA3
00FFA300FFB300FFC200FFD100FFF000D1FFFF002E00F0FF0085FF00FFF000FFF000FFE1
00FFE100FFE100FFE100FFE100FFE100FFF000FFF000FFF000FFFF00F0FF00F0FF00E1FF
00E1FF00D1FF00D1FF00C2FF00B3FF0075FF0094FF0085FF0085FF0066FF0019FF2300FF
8000FFAE00FF9E00FFFF00001400FF000AFF0500FF1400FF3300FF6100FFCC00FFFF0000
FA00FFFF00C7FF003DFF0000FF0000FF001EFF006BEB00FFAE00FF8000FF9E00FFDC00FF
3300FF0500FF0038FF0057FF0066FF0066FF0019FF0075FF0085FF0085FF0075FF0019FF
3300FF0047FF9E00FF0028FF7000FFFF00D78000FF2300FF0047FF0094FF00B3FF00D1FF
00E1FF00F0FF00FFFF00FFF000FFF000FFF000FFE100FFE100FFD100FFC200FFB300FFB3
00FFB300FFA300FFA300FFA300FFA300FF9400FF9400FF9400FF9400FF8500FF8500FF85
00FF8500FF8500FF8500FF7500FF7500FF7500FF7500FF7500FF6600FF6600FF6600FF66
00FF6600FF6600FF5700FF5700FF5700FF5700FF5700FF4700FF4700FF4700FF4700FF47
00FF4700FF4700FF4700FF4700FF4700FF3800FF4700FF3800FF3800FF3800FF3800FF47
00FF3800FF4700FF4700FF4700FF4700FF5700FF7500FFD1DC00FF00FF9400FFA300FF66
00FF5700FF5700FF5700FF4700FF4700FF5700FF5700FF9400FF6600FF6600FF5700FF57
00FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF6600FF66
00FF6600FF7500FF7500FF7500FF8500FF8500FF9400FF9400FFA300FFC200D1FF00FFF0
00FFD100FFD100FFB300FFA300FFF000FFA300FF9400FF8500FF8500FF9400FFD100FFE1
00FF8500FF8500FF7500FF6600FF6600FF5700FF6600FF6600FF7500FF8500E1FF0047FF
00FF9400FF8500FF9400FFFF00FFA300FF5700FF4700FF4700FF4700FF3800FF3800FF47
00FF4700FF4700FF4700FF5700FF5700FF6600FF7500FFD100FFF000FFF000B3FF00E1FF
00FFA300FF7500FF6600FF5700FF4700FF4700FF3800FF3800FF3800FF3800FF4700FF66
0038FF00FF8500FF7500FFFF00FFA300FF6600FF5700FF6600FF8500FFD10094FF00FFFF
00B3FF00D1FF0047FF00F0FF00FFD100FFE100D1FF00FFF000FFB300FFB300FFF09E00FF
00FFE100FFFF00FFE100FF8500FF5700FF4700FF3800FF4700D1FF00FF3800FF2800FF57
00FF1905FF0014FF0014FF0014FF0014FF0014FF0014FF00
42FF0042FF0042FF0042FF0042FF0042FF0033FF0042FF0042FF0042FF0042FF0042FF00
42FF0042FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0000FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF2800FF2800FF2800FF2800FF2800FF2800FF3800FF38
00FF3800FF3800FF4700FF5700FF9400F0FF00FFE15100FF00FFFF00FFF04200FF00FFD1
00FFA300FF9400FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF9400FF94
00FFA300FFC200D1FF3300FF00FFFF00FFE100FFE100FFFF0094FF00B3FF9E00FF00B3FF
00D1FF0057FF00F0FF00D1FF00FFD100FFD100FFC200FFC200FFD100FFE100FFF00075FF
8000FF00E1FF00FFF000FFE100E1FF00F0FF00F0FF0075FF3300FF0085FF0094FF00FFB3
00FFA300FF9400FF9400FF9400FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF85
00FF8500FF8500FF8500FF9400FF9400FF9400FF9400FF9400FF9400FF9400FFA300FFA3
00FFA300FFB300FFC200FFFF0094FF0028FF00FFF000FFE100FFE100FFE100FFD100FFD1
00FFD100FFE100FFE100FFE100FFE100FFE100FFF000FFFF00F0FF00F0FF00E1FF00E1FF
00D1FF00D1FF00D1FF00C2FF00B3FF0066FF5100FF0075FF0075FF0057FF0028FF3300FF
FF00008000FF000AFF9E00FF0028FF0028FF000AFF1400FF4200FFCC00FFFF00C7CC00FF
BD00FFFF00E6FF00A8FF0000FF0000FF000FFF00D7DC00FF9E00FF6100FF3300FF8F00FF
9E00FF0500FF0047FF0066FF0075FF0075FF0085FF0094FF0094FF0094FF0075FF000AFF
0066FF0057FF0085FF0047FF3300FFBD00FFFF001EFF005C1400FF0085FF00B3FF00C2FF
00E1FF00F0FF00F0FF00FFFF00FFFF00FFFF00E1FF00B3FF00FFD100FFC200FFC200FFB3
00FFB300FFA300FFA300FFA300FFA300FF9400FF9400FF9400FF9400FF9400FF8500FF85
00FF8500FF8500FF7500FF7500FF7500FF7500FF7500FF6600FF6600FF6600FF6600FF66
00FF5700FF5700FF5700FF5700FF5700FF5700FF4700FF4700FF4700FF4700FF4700FF47
00FF4700FF4700FF4700FF3800FF4700FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF4700FF4700FF4700FF4700FF7500FFA300FF6600FF6600FF6600FF57
00FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF5700FF5700FF5700FF4700FF47
00FF4700FF4700FF4700FF4700FF4700FF4700FF5700FF5700FF5700FF5700FF5700FF57
00FF6600FF6600FF6600FF7500FF7500FF7500FF8500FF9400FFA300FFC2FF004C00FFFF
00FFB300FFA300FF9400FF9400FF9400FF8500FF7500FF7500FF7500FF7500FF9400FFC2
00FF7500FF6600FF5700FF5700FF5700FF5700FF5700FF5700FF6600FF9400FFD100FFD1
00FF8500FF6600FF6600FF6600FFFF00FF5700FF4700FF3800FF3800FF3800FF3800FF38
00FF3800FF4700FF4700FF4700FF5700FF7500FF8500FFE10075FF00FFA300FFA300FFD1
00FFFF00FFC200FF6600FF5700FF4700FF3800FF3800FF2800FF2800FF3800FF4700FF75
00FF7500FF4700FF4700FF8500FF6600FF4700FF4700FF570066FF00FF9400FFB300FFD1
00FFC200FFFF00B3FF00FFE100FFB300FFD10094FF1400FF00FFA300FF8500FFB300FFB3
0500FF0019FFBD00FF00E1FF00FF7500FF6600FF5700FF5700FFC200FF6600FFA30057FF
00FF1905FF0005FF0005FF0014FF0014FF0014FF0005FF00
42FF0042FF0042FF0042FF0042FF0033FF0042FF0042FF0042FF0042FF0042FF0042FF00
42FF0042FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0000FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF1900FF0A00FF0A00FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF2800FF2800FF2800FF3800FF2800FF2800FF3800FF38
00FF3800FF3800FF4700FF5700FF7500FF8500FF9400FFC200E1FFDC00FF00FFFF00FFC2
00FFB300FFA300FF9400FF9400FF8500FF8500FF8500FF8500FF8500FF9400FF9400FFA3
00FFB300FFC200FFE100A3FF00D1FF00FFFF00FFFF00D1FF0038FFFF005C00D1FF00F0FF
00FFFF0085FF00FFF000FFD100FFC200FFC200FFC200FFC200FFC200FFD100FFF000D1FF
0085FF00FFFF00FFE100FFD100FFD100FFD100FFE100D1FF8F00FF00E1FF00FFD100FFB3
00FFA300FF9400FF9400FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF85
00FF8500FF8500FF8500FF8500FF9400FF9400FF9400FF9400FF9400FF9400FF9400FFA3
00FFA300FFA300FFB300FFC200FFD100FFFF00FFE100FFD100FFD100FFD100FFD100FFD1
00FFD100FFD100FFD100FFE100FFE100FFE100FFF000FFFF00E1FF00E1FF00C2FF00C2FF
00D1FF00C2FF00C2FF00B3FF00A3FF0075FFAE00FF0047FF0047FFAE00FF4200FF3300FF
0500FF4200FF0019FF0047FF0047FF0038FFAE00FFFF00007000FF8F00FF6100FF7000FF
9E00FFDC00FFFF008AFF000FFF0000FF0000FF002EFF006BCC00FF5100FF2300FF1400FF
0500FF5100FF0038FF0066FF0075FF0085FF0094FF00A3FF00A3FF00A3FF0094FF0094FF
00A3FF00A3FF0094FF0085FF2300FF4200FF1400FF4200FFEB00FF0038FF0038FF00B3FF
00C2FF00D1FF00E1FF00F0FF00F0FF00C2FF0019FF00FFFF00FFE100FFD100FFC200FFB3
00FFB300FFB300FFA300FFA300FFA300FF9400FF9400FF9400FF9400FF9400FF8500FF85
00FF8500FF8500FF8500FF7500FF7500FF7500FF7500FF7500FF6600FF6600FF6600FF66
00FF6600FF5700FF5700FF5700FF5700FF5700FF4700FF4700FF4700FF4700FF4700FF47
00FF4700FF4700FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF47
00FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF47
00FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF5700FF5700FF5700FF57
00FF5700FF6600FF6600FF6600FF7500FF7500FF8500FF9400FFB300FFE10500FF00FFE1
00FFB300FF9400FF8500FF8500FF7500FF7500FF6600FF6600FF6600FF6600FF7500FF75
00FF6600FF5700FF5700FF4700FF4700FF4700FF4700FF5700FF6600FFA300D1FF00A3FF
00FF7500FF5700FF4700FF4700FF5700FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF4700FF4700FF5700FFE100FFD10066FF00FFB300FF7500FF750094FF
00FFF000FFC200FF7500FF5700FF3800FF3800FF2800FF2800FF2800FF2800FF2800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF4700FF4700FF5700FF663300FF00FF94
00FF9400F0FF00B3FF00FFD100FF9400FFA300FFF000FF8500FF7500FF6600FF6600FF94
00FFD100FFC200FFB300FFF000FFF000FFF000FF8500FF9400FFC200FFB3BD00FF00FF38
00FF1900FF0A05FF0005FF0005FF0005FF0000FF0A00FF19
42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
42FF0042FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0000FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF3800FF38
00FF3800FF3800FF4700FF4700FF5700FF6600FF8500FFD100F0FF0085FF0038FF00E1FF
00FFC200FFB300FFA300FF9400FF9400FF9400FF9400FF9400FF9400FF9400FFA300FFB3
0094FF00B3FF00F0FF00D1FF00B3FF00E1FF00D1FF00C2FFFF00B80075FF0085FF00FFF0
00FFE100FFF000FFD100FFC200FFB300FFB300FFB300FFB300FFC200FFD1BD00FF00A3FF
BD00FFFF00A800FFD100FFC200FFB300FFC200FFE100FFF000FFFF0066FF00FFE100FFB3
00FF9400FF9400FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF85
00FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF9400FF9400FF9400FF9400FF94
00FF9400FFA300FFA300FFB300FFB300FFC200FFC200FFC200FFC200FFC200FFC200FFC2
00FFD100FFD100FFD100FFD100FFE100FFE100FFF000FFFF0038FF0085FF000AFF00A3FF
00B3FF00B3FF00B3FF00A3FF0075FFFF0000AE00FF000AFF0500FFBD00FF0500FF0047FF
0019FF0028FFFF00E60057FF0057FF0047FF000AFF0019FF5100FF5100FF3300FF8F00FF
BD00FFFF00E6FF00D7FF0000FF0000FF0000FF00C7CC00FF9E00FF6100FF2300FF0500FF
0019FF0038FF0057FF0066FF0075FF0085FF0094FF00A3FF00B3FF00C2FF00C2FF00C2FF
00C2FF00B3FF00B3FF0094FF0075FFFF006B0057FF0075FF0075FF2300FF2300FF0066FF
0066FF0066FF00B3FF00E1FF00D1FF0075FF00A3FF00FFFF00FFF000FFE100FFD100FFC2
00FFB300FFB300FFB300FFA300FFA300FFA300FF9400FF9400FF9400FF9400FF9400FF94
00FF8500FF8500FF8500FF8500FF7500FF7500FF7500FF7500FF7500FF6600FF6600FF66
00FF5700FF5700FF5700FF5700FF5700FF4700FF4700FF4700FF4700FF4700FF4700FF47
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF4700FF4700FF4700FF4700FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF4700FF47
00FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF5700FF57
00FF5700FF5700FF6600FF6600FF6600FF7500FF8500FF9400FFA300E1FF5100FF5100FF
00FFB300FF9400FF8500FF7500FF7500FF6600FF6600FF6600FF5700FF5700FF5700FF57
00FF5700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF5700FF6600FF9400FFA3
00FF5700FF4700FF3800FF3800FF3800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF3800FF3800FF4700FF5700FF9400FFF00094FF0047FF00FF6600FF5700FF66
00FF8500FFFF00FFF000FF7500FF3800FF2800FF2800FF2800FF1900FF1900FF1900FF28
00FF2800FF2800FF2800FF2800FF2800FF3800FF3800FF3800FF4700FF4700FF5700FF75
00FF9400FFD100E1FF00FFB300FF8500FF7500FFF000FF5700FF5700FF5700FF5700FF94
00FFB30028FF00FF7500FF7500E1FF00FFF00019FF00D1FF0094FF00FFC200FF5700FF38
00FF2800FF1900FF0A00FF0A00FF0A00FF0A00FF1900FF28
42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
42FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0000FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF2800FF2800FF2800FF2800FF2800FF3800FF3800FF3800FF38
00FF3800FF3800FF4700FF4700FF5700FF6600FF7500FFA300F0FF00FFD100B3FF0047FF
00FFFF00F0FF00FFFF00FFC200FFA300FF9400FF9400FF9400FF9400FFA300FFA300FFB3
00FFD100C2FF2300FF00A3FF5100FF00A3FF8000FF0057FF0094FF00D1FF00B3FF00FFE1
00FFD100FFC200FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC200FFFF00C2FF
00A3FF0028FF00FFC200FFB300FFA300FFA300FFB300FFB300FFC200FFE1000AFF00FFF0
00FF9400FF8500FF8500FF8500FF8500FF8500FF7500FF7500FF8500FF7500FF8500FF85
00FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF9400FF9400FF9400FF94
00FF9400FFA300FFA300FFA300FFB300FFB300FFB300FFB300FFB300FFC200FFC200FFC2
00FFC200FFD100FFD100FFD100FFD100FFE100FFF000FFFF00E1FF0066FF0057FF0028FF
0066FF00A3FF00A3FF0094FF0085FF0066FF1400FFFF0099FF00B80028FF0047FF0066FF
0047FF0066FF0066FF0075FF0075FF0066FF0057FF0038FFFF00D70500FF1400FF3300FF
FF00B89E00FFFF00E6FF0000FF0000FF0000FF00A8DC00FF8F00FF6100FF5100FF2300FF
0019FF0028FF0047FF0057FF0066FF0075FF0085FF00A3FF00C2FF00C2FF00C2FF00D1FF
00D1FF00C2FF00B3FF0094FF0047FF6100FF0085FF00A3FF00A3FF0085FF0066FF000AFF
FF008A0075FF00B3FF00C2FF00C2FF0075FF00B3FF00C2FF00B3FF0057FF7000FF00FFD1
00FFC200FFB300FFB300FFA300FFA300FFA300FFA300FF9400FF9400FF9400FF9400FF94
00FF9400FF8500FF8500FF8500FF8500FF7500FF7500FF7500FF6600FF6600FF6600FF66
00FF6600FF5700FF5700FF5700FF5700FF5700FF4700FF4700FF4700FF4700FF4700FF47
00FF4700FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF57
00FF5700FF5700FF5700FF6600FF6600FF7500FF8500FF9400FFA300FFD15100FF00FFE1
00FFC200FF8500FF7500FF7500FF6600FF6600FF5700FF5700FF5700FF5700FF5700FF47
00FF4700FF4700FF4700FF3800FF3800FF3800FF3800FF4700FF4700FF5700FF8500FFE1
00FF4700FF3800FF3800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF3800FF3800FF4700FF5700FF7500FFC200FFC200F0FF00FF5700FF4700FF47
00FF850038FF0066FF00FF6600FF3800FF2800FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF2800FF2800FF2800FF2800FF3800FF3800FF4700FF5700FF66
00FF7500FFFF0047FF00FFC200FF7500FF6600FF5700FF4700FF3800FF3800FF4700FFB3
00FF5700FF9400FF4700FF4700FF6600FF750066FF0094FF4200FF00E1FF00E1FF00FF66
00FF6600FF3800FF1900FF1900FF1900FF4700FF8500FF66
42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0000FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF1900FF1900FF1900FF1900FF1900FF28
00FF1900FF1900FF1900FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF3800FF38
00FF3800FF3800FF4700FF4700FF5700FF5700FF6600FF7500FFA300FFA300FFC200F0FF
FF008A00D1FF00FFF000FFB300FFA300FFA300FFA300FFA300FFA300FFA300FFB300FFB3
00FFD100FFE100FFFF00E1FF00A3FF5100FF4200FFFA00FF0085FF00F0FF00FFF000FFD1
00FFC200FFB300FFB300FFA300FFA300FFA300FFA300FFA300FFB300FFC200FFD100C2FF
0094FF00FFE100FFC200FFA300FFA300FF9400FF9400FF9400FFA300FFFF00FFD100FFA3
00FF9400FF8500FF8500FF7500FF7500FF7500FF7500FF7500FF8500FF7500FF7500FF75
00FF8500FF7500FF8500FF8500FF8500FF8500FF8500FF9400FF8500FF9400FF9400FF94
00FF9400FF9400FFA300FFA300FFA300FFA300FFB300FFB300FFB300FFB300FFC200FFC2
00FFC200FFC200FFD100FFD100FFD100FFE100FFE100FFF000FFFF00E1FF00C2FF0066FF
5100FF0085FF0094FF0075FF0066FF0038FFFF00C7CC00FFCC00FF0038FF0066FF0085FF
0094FF0094FF0085FF0085FF0075FF0075FF0066FF0047FF0028FF0019FF1400FF3300FF
6100FFFF0000EB00FFFF007AFF0000FF0000FF004CFF008AFF00B8FF0000FF00006100FF
3300FFEB00FF0028FF3300FF000AFF0019FF1400FF0094FF00C2FF00D1FF00D1FF00D1FF
00D1FF00D1FF00B3FF0028FF0057FF0094FF0500FF00C2FF00D1FF00D1FF00A3FF0038FF
0500FF8F00FF0075FF0047FF0085FF3300FF0057FF0075FF00C2FF00F0FF00FFE100FFD1
00FFC200FFB300FFB300FFB300FFB300FFA300FFA300FFA300FFA300FF9400FF9400FF94
00FF9400FF9400FF8500FF8500FF8500FF8500FF7500FF7500FF7500FF6600FF6600FF66
00FF6600FF6600FF5700FF5700FF5700FF4700FF4700FF4700FF4700FF4700FF4700FF38
00FF3800FF4700FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF4700FF4700FF4700FF4700FF4700FF4700FF47
00FF5700FF5700FF5700FF6600FF6600FF7500FF9400FFA300FFB300FFE1DC00FF00FFE1
00FFA300FF9400FF8500FF7500FF6600FF5700FF5700FF5700FF5700FF4700FF4700FF47
00FF4700FF4700FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF4700FFA300FF47
00FF3800FF2800FF2800FF2800FF2800FF2800FF1900FF1900FF1900FF1900FF2800FF28
00FF2800FF2800FF3800FF5700FFD100FF940085FF00FFE100FF6600FF4700FF3800FF38
00FF3800FF4700FF7500FF8500FF2800FF1900FF1900FF1900FF0A00FF0A00FF0A00FF0A
00FF1900FF1900FF1900FF1900FF1900FF2800FF2800FF3800FF3800FF4700FF5700FF66
00FF7500FFA300B3FF00FF8500FF6600FF5700FF4700FF3800FF3800FF2800FF3800FF38
00FF2800FF2800FF2800FF3800FF4700FF6600FF9400F0FF00FF9400FF9400FFD100C2FF
00FFC200FF8500FF3800FF2800FF3800FF667000FF3300FF
42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0033FF00
33FF0042FF0042FF0042FF0042FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0023FF0033FF0033FF00
33FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0000FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF1900FF0A00FF0A00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF3800FF3800FF38
00FF3800FF3800FF4700FF4700FF5700FF5700FF6600FF7500FF8500FF9400FFFF00E1FF
0094FF0094FF00FFE100FFC200FFB300FFB300FFA300FFA300FFA300FFB300FFB300FFC2
00FFD100FFE100FFF000F0FF0028FFEB00FFBD00FF6100FF00B3FF00F0FF00FFF000FFE1
00FFC200FFB300FFA300FFA300FFA300FF9400FFA300FFA300FFB300FFC200FFE100F0FF
0057FF00F0FF00FFF000FFA300FF9400FF9400FF9400FF9400FF9400FFB300FFA300FF85
00FF8500FF8500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF75
00FF7500FF7500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF9400FF94
00FF9400FF9400FFA300FFA300FFA300FFA300FFA300FFB300FFB300FFB300FFB300FFC2
00FFC200FFC200FFD100FFD100FFD100FFE100FFE100FFF000FFFF00E1FF00B3FF0094FF
2300FF0066FF0057FF0019FF0028FF3300FFDC00FF0047FF6100FF0019FF0047FF0094FF
00A3FF00A3FF0094FF0094FF0085FF0075FF0066FF0047FF0038FF0019FF2300FF7000FF
FF005CFF0000FF006BFF00D7FF0000FF0000FF003DBD00FF8000FF6100FFAE00FF3300FF
6100FFFF00B83300FF0500FF0038FF0057FF0038FF0047FF00C2FF00D1FF00E1FF00E1FF
00E1FF00D1FF00B3FFFF000000A3FF00C2FF000AFF00C2FF00E1FF00E1FF2300FF0094FF
00A3FF0075FF2300FF6100FF2300FF0075FF00B3FF00E1FF00F0FF00FFF000FFE100FFD1
00FFC200FFC200FFC200FFB300FFB300FFB300FFA300FFA300FFA300FFA300FFA300FF94
00FF9400FF9400FF9400FF9400FF9400FF8500FF8500FF7500FF7500FF7500FF6600FF66
00FF6600FF6600FF5700FF5700FF5700FF5700FF4700FF4700FF4700FF4700FF4700FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF2800FF2800FF38
00FF2800FF3800FF2800FF3800FF2800FF3800FF2800FF2800FF3800FF2800FF3800FF28
00FF2800FF3800FF2800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF4700FF4700FF4700FF4700FF4700FF47
00FF4700FF5700FF5700FF6600FF6600FF7500D1FF0094FF00FFE100FFF00047FF00FFF0
00FFD100FFE100FF8500FF7500FF6600FF5700FF5700FF5700FF4700FF4700FF4700FF47
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF2800FF2800FF2800FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF2800FF2800FF4700FFB300F0FF8F00FF00FFD100FFC200FF3800FF2800FF28
00FF2800FF2800FF8500FF3800FF1900FF1900FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF1900FF1900FF1900FF1900FF1900FF1900FF2800FF2800FF3800FF4700FF5700FF75
00FF9400E1FF00F0FF00FF9400FF7500FF5700FF4700FF3800FF2800FF2800FF1900FF19
00FF1900FF1900FF1900FF2800FF4700FFF000E1FF00C2FF00FF5700FF5700FF5700FF94
1400FF00FFFF00D1FF00FF5700FFC200FFB300FFB300FF66
42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0033FF0042FF00
42FF0042FF0042FF0042FF0042FF0042FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0000FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF3800FF38
00FF3800FF4700FF4700FF4700FF5700FF5700FF6600FF6600FF7500FF8500FFA300FFD1
00FFF00057FF00B3FF00FFD100FFC200FFB300FFB300FFB300FFB300FFB300FFC200FFD1
00FFD100FFE100D1FF00D1FF0075FF0066FF2300FF00A3FF0019FF4200FF0085FF000AFF
00FFD100FFB300FFA300FF9400FF9400FF9400FF9400FF9400FFA30066FF00D1FF0047FF
5100FF00A3FF00FFC200FF9400FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF85
00FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF75
00FF7500FF8500FF7500FF7500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF94
00FF9400FF9400FF9400FF9400FFA300FFA300FFA300FFA300FFB300FFB300FFB300FFC2
00FFC200FFC200FFD100FFD100FFE100FFE100FFE100FFF000F0FF0094FF1400FF2300FF
0066FF6100FF4200FF4200FFFF001E0500FF0057FF0075FF0038FF0085FF00A3FF00B3FF
00B3FF00B3FF00A3FF0094FF0085FF0066FF0057FF0047FF0028FF3300FF5100FFFF0000
8F00FF7000FF9E00FFFF0000FF000FFF0000FF00A8DC00FFFF00A83300FF2300FF000AFF
FF00000028FF1400FF0028FF0066FF0094FF00B3FF00C2FF00D1FF00E1FF00F0FF00F0FF
00F0FF00E1FF00D1FF6100FF00C2FF00F0FF00E1FF00F0FF00FFFF00F0FF00F0FF00E1FF
00D1FF0075FF0019FFCC00FFFF00003300FF00A3FF00E1FF00F0FF00FFF000FFE100FFD1
00FFC200FFC200FFC200FFC200FFB300FFB300FFB300FFB300FFB300FFB300FFA300FFA3
00FFA300FFA300FFB300FFD100FFA300FF9400FF8500FF8500FF7500FF7500FF7500FF66
00FF6600FF6600FF6600FF5700FF5700FF4700FF4700FF4700FF4700FF4700FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF2800FF3800FF2800FF2800FF28
00FF2800FF3800FF2800FF3800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF3800FF2800FF3800FF2800FF3800FF2800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF4700FF4700FF4700FF47
00FF4700FF5700FF5700FF6600FF6600FF7500FF9400FFC200B3FF0085FF4200FF00C2FF
0094FF00FFB300FF8500FF6600FF6600FF5700FF5700FF4700FF4700FF4700FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF2800FF2800FF3800FF5700FF8500E1FF00FF9400FF6600FF2800FF2800FF19
00FF1900FF1900FF2800FF1900FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF1900FF1900FF2800FF2800FF3800FF4700FF660500FF
00C2FF0047FF00FF940075FF00E1FF00FF6600FF4700FF3800FF2800FF1900FF1900FF0A
00FF0A00FF0A00FF1900FF1900FF5700FFE100FF4700FF9400FF5700FF2800FF3800FF94
00FF850047FF00FFA3000AFF00FF6600FF4700FF3800FF19
42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
42FF0042FF0042FF0042FF0042FF0042FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0000FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF2800FF2800FF2800FF2800FF2800FF2800FF3800FF3800FF3800FF38
00FF3800FF4700FF4700FF5700FF5700FF5700FF6600FF7500FF7500FF8500FF9400FFB3
00FFD10075FF00C2FF00FFF000FFD100FFC200FFC200FFC200FFC200FFD100E1FF00FFE1
00FFE100FFFF00A3FF0085FF0038FF00C2FF00E1FF00E1FF00A3FF00E1FF00FFFF00FFF0
00E1FF00FFA300FF9400FF9400FF9400FF9400FF9400FF9400FF9400FFA300FFB300FFE1
00A3FF00FFD100FFB300FF9400FF8500FF8500FF7500FF7500FF7500FF7500FF7500FF75
00FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF75
00FF7500FF7500FF7500FF7500FF7500FF8500FF8500FF8500FF8500FF8500FF8500FF94
00FF9400FF9400FF9400FF9400FF9400FFA300FFA300FFA300FFA300FFB300FFB300FFC2
00FFC200FFC200FFD100FFD100FFE100FFE100FFF000FFFF00F0FF00D1FF00B3FF00A3FF
0085FF0038FF6100FFFF004C8000FF7000FF0075FF0094FF0094FF00A3FF00B3FF00C2FF
00C2FF00B3FF00A3FF0094FF0038FF0047FF4200FF0019FF0500FFFF00007000FFFF0000
3300FF5100FFFA00FFFF0000FF008AFF0000FF00B8CC00FFDC00FF2300FF0500FF0028FF
0047FF0047FF0038FF5100FF000AFF0085FF00B3FF00D1FF00E1FF00E1FF00F0FF00F0FF
00F0FF00F0FF00F0FF6100FF00F0FF00FFFF00FFF000FFF000FFF000FFFF00FFFF00F0FF
00E1FF00B3FF0075FFBD00FF1400FF8000FF0066FF00A3FF00F0FF00FFFF00FFE100FFE1
00FFD100FFD100FFC200FFC200FFC200FFC200FFC200FFD100FFC200FFE100FFC200FFB3
00FFB300FFB300FFE100FFF000FFB300FFA300FFA300FF9400FF8500FF7500FF7500FF75
00FF6600FF6600FF6600FF5700FF5700FF5700FF4700FF4700FF4700FF4700FF4700FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF2800FF2800FF2800FF2800FF38
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF4700FF4700FF47
00FF4700FF5700FF5700FF5700FF6600FF7500FF8500FFC20038FF00FFFF0019FF00A3FF
00F0FF00B3FF00FFB300FF6600FF6600FF5700FF5700FF4700FF4700FF4700FF3800FF38
00FF3800FF3800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF2800FF3800FF570038FF00FF5700FF3800FF1900FF1900FF19
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A05FF0005FF0005FF00
00FF0A00FF0A00FF0A00FF0A00FF1900FF1900FF1900FF2800FF5700FF6600FF7500FFF0
0094FF00FF6600FF6600FFD17000FF00FFC200FF6600FF3800FF1900FF1900FF0A00FF0A
00FF0A00FF0A00FF0A00FF1900FF4700FF4700FF1900FF3800FF2800FF1900FF1900FF19
00FF2800FF3800FF5700F0FF00FF4700FF2800FF0A05FF00
42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
42FF0042FF0042FF0042FF0042FF0042FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF3800FF3800FF38
00FF3800FF4700FF4700FF5700FF5700FF6600FF6600FF7500FF8500FF9400FFA300FFB3
00FFC200FFFF0019FF00FFF000FFD100FFD100FFD100FFD100FFE100FFF0FF003D00F0FF
00FFFF00F0FF00B3FFAE00FF0075FF00E1FF00FFFF00FFFF00D1FF0028FF00FFD100FFC2
00FFA300FF9400FF9400FF8500FF8500FF8500FF8500FF9400FF8500FF9400FF9400FFB3
00FFF000FFD100FFA300FF8500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF75
00FF7500FF7500FF6600FF6600FF7500FF6600FF7500FF6600FF7500FF7500FF7500FF75
00FF7500FF7500FF7500FF7500FF7500FF8500FF8500FF8500FF8500FF8500FF8500FF85
00FF9400FF9400FF9400FF9400FF9400FFA300FFA300FFA300FFA300FFB300FFB300FFB3
00FFC200FFC200FFD100FFD100FFE100FFE100FFF000FFFF00FFFF00E1FF00D1FF00B3FF
0094FF1400FFFF00007000FF2300FF0047FF0085FF00A3FF00B3FF00C2FF00C2FF00C2FF
00C2FF00C2FF0094FF0066FF0019FF3300FFFF0000000AFF1400FF0500FF0019FF0019FF
0500FF2300FFAE00FFAE00FFFF007AFF0000FF0099CC00FF8000FF4200FFFF00F5AE00FF
0057FF0066FF0066FF0047FF000AFF000AFF0094FF00D1FF00E1FF00F0FF00F0FF00F0FF
00FFFF00FFFF00FFFF00FFFF00FFF000FFF000FFF000FFF000FFF000FFF000FFFF00F0FF
00C2FF0047FF0047FF0094FF00B3FF00A3FFCC00FF0066FF00C2FF0038FF00FFFF00FFF0
00FFE100FFD100FFD100FFD100FFD100FFD100FFF000B3FF00FFFF0075FF00FFD100FFC2
00FFC200FFC200FFF000D1FF00FFD100FFF00075FF00FFB300FF9400FF8500FF7500FF75
00FF7500FF7500FF6600FF6600FF5700FF5700FF4700FF4700FF4700FF4700FF3800FF38
00FF3800FF3800FF3800FF3800FF2800FF2800FF2800FF2800FF2800FF3800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF4700FF3800FF4700FF47
00FF5700FF5700FF5700FF5700FF6600FF6600FF8500FFA300FFB300FFE10085FF00FFFF
00FFC200FFA300FF8500FF6600FF6600FF5700FF5700FF4700FF4700FF3800FF4700FF38
00FF3800FF2800FF3800FF2800FF2800FF2800FF2800FF2800FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF0A00FF0A00FF1900FF0A00FF0A00FF0A00FF0A
00FF0A00FF1900FF1900FF2800FF2800FF4700FFB300FF6600FF2800FF1900FF0A00FF0A
00FF0A00FF0A00FF0A05FF0005FF0005FF0005FF0000FF0A05FF0005FF0005FF0005FF00
05FF0000FF0A00FF0A00FF0A00FF0A00FF1900FF1900FF2800FF570085FF00FFB300B3FF
00FF7500FF4700FF4700FF664200FF0066FF00FF6600FF4700FF2800FF0A00FF0A05FF00
05FF0005FF0005FF0005FF0000FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF1900FF2800FF660038FF00FF6600FF1900FF0A05FF00
42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
42FF0042FF0042FF0042FF0042FF0042FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0005FF0014FF0014FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF3800FF3800FF3800FF38
00FF4700FF4700FF4700FF5700FF6600FF6600FF7500FFB300FFA300FFA300FFC200FFC2
00FFE100FFF0FF000000FFFF00FFF000FFE100FFE100FFF00019FF00E1FF0038FF00D1FF
00E1FF0075FF0047FF00A3FF0038FF00FFFF00FFE100FFE100FFFF0047FF00FFFF00FFB3
00FFA300FF9400FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF9400FFA3
00C2FF00FFE100FFA300FF7500FF7500FF7500FF6600FF6600FF6600FF6600FF6600FF66
00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7500FF6600FF7500FF75
00FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF8500FF8500FF8500FF8500FF94
00FF8500FF9400FF9400FF9400FF9400FF9400FFA300FFA300FFA300FFB300FFB300FFB3
00FFC200FFD100FFE100FFE100FFF000FFF000FFF000FFFF00F0FF00E1FF00D1FF0094FF
0066FFBD00FF0019FF0028FF0500FF0057FF0094FF00A3FF00C2FF00D1FF00D1FF00D1FF
00D1FF00C2FF00A3FF6100FF0057FF0075FF0066FF3300FF0019FF0047FF0047FF0028FF
2300FF4200FFCC00FFFF00D7FF0000FF0000FF006BFA00FF9E00FF7000FF3300FF0028FF
0057FF0075FF0075FF0085FF0085FF0047FF0085FF00C2FF00E1FF00F0FF00FFFF00FFFF
00FFF000FFF000FFF000FFF000FFE100FFE100FFE100FFE100FFE100FFE100FFFF00E1FF
0075FF0094FF0094FF00A3FF00E1FF00C2FFFF00E64200FF0047FF0028FF00A3FF00FFFF
00FFE100FFE100FFE100FFF000FFFF00FFF000FFFF0094FF0038FF00F0FF00FFE100FFD1
00FFD100FFE100FFF03300FF00F0FF0047FF00B3FF00FFA300FF9400FF9400FF8500FF85
00FF8500FF8500FF7500FF6600FF5700FF5700FF4700FF4700FF4700FF3800FF3800FF38
00FF3800FF3800FF3800FF2800FF3800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF4700FF47
00FF5700FF5700FF5700FF6600FF6600FF6600FF7500FF9400FFA300FFD10057FF00FFF0
00FFB300FF9400FF7500FF6600FF6600FF5700FF5700FF4700FF4700FF3800FF3800FF38
00FF2800FF3800FF2800FF2800FF2800FF2800FF2800FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF1900FF1900FF1900FF2800FF8500FF6600FF4700FF1900FF0A00FF0A00FF0A
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0000FF0A00FF0A00FF1900FF1900FF1900FF2800FF7500B3FF00A3FF00FFB3
00FF6600FF3800FF3800FF3800FF5700C2FF00FFC200FFD100FF2800FF0A05FF0005FF00
05FF0014FF0014FF0014FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0000FF0A
00FF0A00FF1900FF3800FFA300FF6600FF2800FF0A05FF00
42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
42FF0042FF0042FF0042FF0042FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0000FF0A05FF0005FF0005FF00
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF3800FF3800FF38
00FF4700FF4700FF5700FF8500FF8500FF8500FFA300FFFF00FFC200FFD1FF003D00FFF0
00A3FF0500FF00C2FF2300FF00A3FF0057FF00FFFF00FFFF00D1FFAE00FF0047FF00B3FF
00B3FF0066FF3300FF00E1FF00FFFF00FFE100FFD100FFD100FFE100E1FF0085FF00FFB3
00FF9400FF8500FF8500FF8500FF8500FF8500FF7500FF7500FF7500FF8500FF8500FF94
00FFE100FF8500FF7500FF7500FF7500FF7500FF6600FF6600FF6600FF6600FF6600FF66
00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7500FF75
00FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF8500FF8500FF8500FF8500FF85
00FF8500FF9400FF9400FF9400FF9400FF9400FFA300FFA300FFA300FFB300FFB300FFC2
00FFC200FFFF00FFF000FFFF00FFFF00FFFF00FFFF00F0FF00E1FF00A3FF00B3FF0085FF
EB00FF0047FF0085FF0085FF0066FF0500FF0038FF0094FF00C2FF00D1FF00E1FF00E1FF
00E1FF00D1FF6100FF0094FF00A3FF0094FF0075FF3300FF0047FF0057FF0057FF2300FF
1400FF5100FF9E00FF8F00FFFF00B8FF0000FF005CDC00FF9E00FF2300FF2300FF000AFF
0057FF0075FF0085FF0094FF00A3FF00B3FF00C2FF00D1FF00F0FF00F0FF00FFFF00FFFF
00FFF000FFF000FFE100FFE100FFE100FFD100FFD100FFD100FFD100FFE100FFF000A3FF
0085FF00F0FF00E1FF0085FF00F0FF00FFFF00F0FF00C2FF9E00FF6100FF00C2FF00F0FF
00FFFF00FFFF00F0FF0075FF00D1FF00E1FF00D1FF0085FF0085FF00E1FF00F0FF0085FF
0075FF00FFFF00F0FF00A3FF00D1FF00FFF000FFC200FFB300FFA300FF9400FF9400FF94
00FFA300FFC200FFD100FF7500FF6600FF5700FF4700FF4700FF4700FF4700FF3800FF38
00FF3800FF3800FF3800FF2800FF2800FF3800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF3800FF3800FF3800FF3800FF3800FF4700FF47
00FF4700FF5700FF5700FF5700FF6600FF7500FF7500FF8500FFB300E1FF0094FF00F0FF
00FFC200FF9400FF8500FF7500FF6600FF5700FF5700FF4700FF4700FF3800FF3800FF38
00FF3800FF2800FF2800FF2800FF2800FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF1900FF194200FF00FF2800FF1900FF0A00FF0A00FF0A05FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0000FF0A00FF0A00FF1900FF2800FF3800FF4700FF8500FFFF00D1FF
00FF4700FF2800FF2800FF2800FF3800FF8500D1FF00FF9400FF5700FF0A05FF0005FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0005FF0005FF0005FF00
00FF0A00FF1900FF3800FF8500FFA30038FF00FF1905FF00
42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
42FF0042FF0042FF0042FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0023FF0033FF0033FF0033FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0000FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF0A00FF0A
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF3800FF3800FF3800FF3800FF38
00FF4700FF4700FF5700FF6600FFC200FFC200FFF00038FF00C2FF0094FF9E00FF0038FF
9E00FF00FFFF00FFFF00D1FFFF00A800B3FF00E1FF00E1FF00D1FF00A3FF9E00FF0075FF
8000FF2300FF00B3FF00F0FF00FFF000FFD100FFC200FFC200FFB300FFB300FFD100FFA3
00FF9400FF8500FF8500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF85
00FF8500FF7500FF7500FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF66
00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF66
00FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF8500FF8500FF8500FF85
00FF8500FF9400FF9400FF9400FF9400FFA300FFA300FFA300FFA300FFB300FFB300FFB3
00FFC200FFF00028FF0075FF00D1FF00F0FF00F0FF00F0FF00D1FF0085FF0075FF6100FF
0066FF0085FF00B3FF00B3FF0057FF0094FF0085FF5100FF00A3FF00E1FF00F0FF00F0FF
00F0FF00E1FF00D1FF00D1FF00C2FF00B3FF4200FF0019FF0075FF0075FF0066FF0057FF
0019FF8F00FF2300FFFF008AFF0000FF0000FF001EFA00FFDC00FF2300FF000AFF0038FF
0057FF0066FF0085FF00A3FF00B3FF00C2FF00D1FF00E1FF00F0FF00F0FF00FFFF00FFF0
00FFF000FFE100FFE100FFE100FFD100FFD100FFD100FFD100FFD100FFD100FFE100D1FF
00F0FF00FFF000FFF00085FF00FFF000FFF000FFFF00D1FF3300FF00C2FFFF000000C2FF
00E1FF0085FF9E00FF2300FF0500FF7000FF0019FFEB00FF8000FF000AFFAE00FF3300FF
0094FF00B3FF0066FF8000FF00B3FF00FFF000FFD100FFC200FFB300FFA300FFA300FFA3
00FFC2EB00FF00FFA300FF7500FF6600FF5700FF5700FF4700FF4700FF3800FF3800FF38
00FF3800FF3800FF2800FF3800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF1900FF2800FF2800FF1900FF2800FF2800FF19
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF3800FF3800FF3800FF3800FF3800FF3800FF47
00FF4700FF5700FF5700FF6600FF6600FF7500FF8500FF9400FFA31400FF0057FF00D1FF
0047FF00FFA300FF8500FF8500FF8500FF6600FF5700FF4700FF4700FF3800FF3800FF38
00FF2800FF2800FF2800FF2800FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF0A00FF0A05FF0005FF0005FF0005FF00
05FF0005FF0005FF0014FF0005FF0014FF0014FF0005FF0014FF0014FF0014FF0005FF00
05FF0005FF0005FF0005FF0000FF0A00FF1900FF2800FF4700FF5700D1FF00FFC200FF47
00FF2800FF1900FF1900FF1900FF2800FF3800FF5700FFFF00FF2800FF0A05FF0014FF00
14FF0014FF0014FF0023FF0023FF0023FF0023FF0014FF0014FF0014FF0014FF0014FF00
05FF0000FF2800FF940094FF000AFF00FF7500FF3805FF00
42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
42FF0042FF0033FF0042FF0042FF0042FF0042FF0042FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0014FF0023FF0023FF0023FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0000FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF3800FF3800FF3800FF38
00FF4700FF4700FF5700FF6600FFE100FFA300FFC200D1FF00FFF000FFE10085FF00FFE1
00FFD100FFD100FFE100F0FF00C2FFFF00F50019FF00B3FF00A3FF0047FF0019FF2300FF
8000FF3300FF00A3FF00D1FF00C2FF00FFD100FFC200FFB300FFA300FFA300FFA300FF94
00FF8500FF8500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF6600FF75
00FF7500FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF5700FF6600FF5700FF66
00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF66
00FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF8500FF8500FF8500FF85
00FF8500FF9400FF9400FF9400FF9400FF9400FFA300FFA300FFA300FFB300FFB300FFB3
00FFC200FFD100FFFF00A3FF6100FF0094FF00E1FF00D1FF00B3FF0075FFFF00B81400FF
00A3FF00C2FF00D1FF00C2FF0066FF00B3FF00D1FF00C2FF0038FF00F0FF00F0FF00F0FF
00F0FF00F0FF00E1FF00E1FF00D1FF00A3FF0500FF0075FF0094FF0085FF0075FF0066FF
0038FF0019FF1400FF5100FFAE00FFFF0000FF0000FF00F5AE00FF7000FF3300FFFF00A8
0028FFCC00FF0057FF0094FF00B3FF00C2FF00D1FF00E1FF00F0FF00F0FF00FFFF00FFFF
00FFF000FFE100FFE100FFE100FFD100FFD100FFC200FFC200FFC200FFD100FFE100FFE1
00FFD100FFD100FFD100FFE100FFD100FFD100FFE100FFF000FFF000FFFF00D1FF0075FF
0057FF0085FF00D1FF00A3FF00C2FF00F0FF00E1FF00B3FF00B3FF00F0FF00F0FF2300FF
00C2FF0085FFFF0000FF00F50075FF00D1FF2300FF00FFE100FFF00085FF00FFB300FFB3
00FFE1FF009900FFA300FF9400FF8500FF6600FF5700FF4700FF4700FF3800FF3800FF38
00FF3800FF3800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF2800FF1900FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF3800FF3800FF3800FF3800FF3800FF47
00FF4700FF5700FF6600FF6600FF7500FF8500FF9400FF9400FFB300FFD10500FF0094FF
00FFD100FFB300FFA300FFB300FFD100C2FF00FF5700FF4700FF4700FF3800FF3800FF28
00FF2800FF2800FF2800FF2800FF2800FF1900FF1900FF1900FF1900FF1900FF1900FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A05FF0000FF0A05FF0005FF00
05FF0005FF0005FF0005FF0000FF0A05FF0000FF0A05FF0005FF0005FF0005FF0005FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0005FF0014FF00
14FF0005FF0005FF0005FF0000FF0A00FF6600FF7500FF9400FF8500FFF000FF8500FF47
00FF2800FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF5700FFB305FF0014FF0014FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0014FF0014FF0014FF00
05FF0000FF0A00FF2800FF5700FFD100FF7500FF2800FF19
42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0005FF0014FF0014FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0000FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF3800FF3800FF3800FF3800FF3800FF38
00FF4700FF4700FF5700FF5700FF7500FF7500FFB300FFB300FFC200FFA300FFB300FFB3
00FFB300FFC200FFD100FFE100FFFF0085FF0038FF0066FF0019FFFF002E1400FFFF00B8
6100FF2300FF0500FF00A3FF00FFFF00FFD100FFB300FFB300FFA300FF9400FF9400FF85
00FF8500FF8500FF7500FF7500FF7500FF7500FF6600FF6600FF6600FF6600FF6600FF66
00FF6600FF6600FF6600FF6600FF5700FF5700FF5700FF5700FF5700FF6600FF5700FF57
00FF5700FF5700FF5700FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF66
00FF6600FF6600FF7500FF7500FF7500FF7500FF7500FF7500FF8500FF8500FF8500FF85
00FF8500FF9400FF9400FF9400FF9400FF9400FFA300FFA300FFA300FFB300FFB300FFC2
00FFC200FFD100FFF000F0FF00A3FF0057FF00C2FF00B3FF0094FFFF00A80019FF6100FF
0057FF00E1FF00E1FF00D1FF0038FF0057FF00F0FF00F0FF00F0FF00FFFF00FFFF00FFFF
00FFFF00F0FF00F0FF00F0FF00E1FF00D1FF00B3FF00B3FF00A3FF0094FF0066FF0057FF
0038FF000AFF8F00FFFA00FFFF00C7FF008AFF0000FF00E67000FF8000FF5100FFFA00FF
FF00002300FF0057FF0075FF0028FF00B3FF00D1FF00D1FF00E1FF00F0FF00F0FF00FFFF
00FFF000FFF000FFE100FFD100FFD100FFC200FFC200FFC200FFC200FFC200FFC200FFC2
00FFC200FFC200FFC200FFC200FFC200FFD100FFD100FFD100FFE100FFF000F0FF0028FF
00E1FF00FFFF00FFF000C2FF00FFF000FFE100FFF06100FF00A3FF00FFF000FFE100FFE1
00FFF000E1FF0047FF0094FF00D1FF0066FF3300FF00C2FF000AFF00FFFF00FFD100FFD1
00FFF000F0FF00FFE100FFE10047FF00F0FF00FF5700FF4700FF4700FF3800FF3800FF38
00FF3800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF2800FF1900FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF3800FF3800FF3800FF3800FF47
00FF4700FF6600FF8500FF8500FFC200FFB300FFB300FFB300FFB300FFFF00B3FF00C2FF
00FFFF00FFC200FFC20094FFBD00FF00FF7500FF5700FF4700FF4700FF3800FF3800FF28
00FF2800FF2800FF2800FF1900FF1900FF1900FF1900FF1900FF1900FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A05FF0000FF0A05FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0005FF0005FF0005FF0000FF0A00FF2800FF5700FFD100D1FF00FFF000FFB3
00FF2800FF0A05FF0005FF0005FF0005FF0000FF0A00FF5700FF0A14FF0014FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0014FF00
14FF0005FF0000FF0A00FF2800FFC200A3FF00FF6600FF28
42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0000FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF1900FF0A00FF0A00FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF3800FF3800FF3800FF3800FF38
00FF4700FF4700FF4700FF5700FF6600FF6600FF7500FF8500FF9400FF9400FF9400FFA3
00FFA300FFB300FFD100FFF000F0FF00D1FF0075FF5100FF1400FFFF00B8FF00E6FF0000
000AFF0066FF00B3FF0500FF00A3FF00FFD100FFB300FFA300FFA300FF9400FF9400FF85
00FF8500FF7500FF7500FF7500FF7500FF6600FF6600FF6600FF6600FF6600FF6600FF66
00FF6600FF6600FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF57
00FF5700FF5700FF5700FF5700FF5700FF6600FF6600FF6600FF6600FF6600FF6600FF66
00FF6600FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF8500FF8500FF8500FF85
00FF9400FF9400FF9400FF9400FF9400FFA300FFA300FFA300FFA300FFB300FFB300FFC2
00FFC200FFE100FFF000E1FF00B3FF000AFF0085FF0028FF0038FF0500FF0094FF0085FF
00D1FF00F0FF00F0FF00FFFF00D1FF00F0FF00FFFF00FFF000FFF000FFF000FFF000FFFF
00FFFF00FFFF00F0FF00F0FF00E1FF00E1FF00C2FF00C2FF00B3FF0094FF0066FF0500FF
000AFFDC00FF5100FF4200FF9E00FFFF007AFF0000FA00FF7000FF0500FF0028FF0028FF
1400FF000AFFDC00FF0028FF6100FF0085FF00C2FF00C2FF00D1FF00E1FF00D1FF00F0FF
00FFFF00FFF000FFE100FFD100FFC200FFC200FFC200FFB300FFB300FFB300FFB300FFB3
00FFB300FFB300FFB300FFC200FFC200FFC200FFC200FFD100FFE100FFF01400FF000AFF
00F0FF00FFF000FFE100FFD100FFD100FFC200FFE100F0FF00FFD100FFC200FFC200FFC2
00FFE100FFFF0066FF00F0FF00FFE100FFF000FFFF0075FF8000FF0066FF00D1FF00A3FF
0085FF00F0FF00FFF000FFC200FFA300FF7500FF6600FF4700FF4700FF3800FF3800FF38
00FF3800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF1900FF1900FF2800FF19
00FF1900FF2800FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF3800FF3800FF3800FF3800FF38
00FF4700FF5700FF94EB00FFDC00FFFF00B80094FF00FFF000FFD100F0FF1400FF0038FF
00D1FF00FFFF00E1FF00FFD100FF9400FF7500FF6600FF4700FF4700FF3800FF3800FF28
00FF2800FF2800FF2800FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A05FF0000FF0A05FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0005FF0005FF0000FF0A00FF1900FFC200FF5700FFF000FF7500FFC2
00FF1905FF0005FF0014FF0014FF0014FF0005FF0005FF0014FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0033FF0033FF0023FF0023FF0023FF0023FF0023FF0023FF00
14FF0005FF0000FF0A00FF1900FF4700FFB300D1FF00FF75
42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0014FF0023FF00
23FF0023FF0023FF0023FF0023FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0000FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF0A00FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF3800FF3800FF3800FF3800FF3800FF3800FF47
00FF4700FF4700FF4700FF5700FF5700FF6600FF6600FF7500FF8500FF8500FF9400FF94
00FFA300FFB300FFD10085FF0066FF00B3FF1400FF9E00FF5100FF9E00FF000AFF0028FF
8000FF00B3FF00E1FF00F0FF00FFFF00FFD100FFB300FFA300FFA300FF9400FF9400FF85
00FF8500FF7500FF7500FF7500FF6600FF6600FF6600FF6600FF6600FF5700FF5700FF57
00FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF57
00FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF6600FF6600FF6600FF6600FF66
00FF6600FF6600FF6600FF7500FF7500FF7500FF7500FF7500FF8500FF8500FF8500FF85
00FF8500FF9400FF9400FF9400FF9400FFA300FFA300FFA300FFA300FFB300FFB300FFC2
00FFC200FFE1FF008A0057FF0094FF0094FF0019FF1400FFFF00000019FF00A3FF00D1FF
00E1FF00FFFF00FFFF00FFF000FFF000FFF000FFF000FFE100FFF000FFF000FFF000FFF0
00FFFF00FFFF00FFFF00F0FF00E1FF00E1FF00D1FF00C2FF00A3FF0085FF0057FF3300FF
FF000F4200FF0019FF0500FF4200FFBD00FFFF0000FF00D7DC00FFFA00FF0047FF0057FF
0500FF0066FF0057FF8000FF3300FF0075FF00A3FF00A3FF0075FF00A3FF0038FF0066FF
00F0FF00F0FF00FFF000FFD100FFC200FFC200FFB300FFB300FFB300FFB300FFB300FFB3
00FFB300FFB300FFB300FFB300FFC200FFC200FFC200FFD100FFD100FFF000C2FF0038FF
00A3FF00FFE100FFD100FFC200FFC200FFB300FFC200FFB300FFB300FFA300FFB300FFB3
00FFD18F00FF00FFF000C2FF00FFC200FFC200FFE100F0FF00FFFF00D1FFFA00FF2300FF
0085FF00FFFF00FFB300FF9400FF8500FF7500FF6600FF5700FF4700FF3800FF3800FF38
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF2800FF1900FF19
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF3800FF3800FF3800FF38
00FF4700FF4700FF6600FF7500FFA300FFA300FFD100F0FF00C2FF8000FF0085FFDC00FF
7000FF00A3FF00F0FF00A3FF00FFD100D1FF00FF7500FF5700FF4700FF3800FF3800FF28
00FF2800FF2800FF2800FF1900FF1900FF1900FF1900FF1900FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A05FF0005FF0005FF0005FF0005FF0005FF0000FF0A05FF00
05FF0005FF0005FF0005FF0005FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0005FF0005FF0000FF0A00FF1900FF3800D1FF00FF4700FF19
00FF0A14FF0014FF0014FF0014FF0023FF0023FF0023FF0023FF0023FF0023FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0023FF0033FF0023FF0023FF0023FF00
14FF0005FF0000FF0A00FF2800FF4700FFA300A3FF00FFB3
42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0014FF0023FF0023FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0000FF0A05FF0000FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF3800FF3800FF3800FF3800FF4700FF47
00FF4700FF5700FF4700FF5700FF5700FF6600FF6600FF7500FF7500FF8500FF8500FF94
00FFA300FFB300FFC200FFF00094FF0019FF4200FFCC00FF1400FF0047FF0057FF0094FF
000AFF0057FF00E1FF00FFF000FFE100FFC200FFB300FFA300FFA300FF9400FF9400FF85
00FF8500FF7500FF7500FF7500FF6600FF6600FF6600FF6600FF5700FF5700FF5700FF57
00FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF57
00FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF6600FF6600FF6600FF6600FF66
00FF6600FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF8500FF8500FF8500FF85
00FF9400FF9400FF9400FF9400FF9400FFA300FFA300FFA300FFB300FFB300FFB300FFC2
00FFC200FFD100FFF000F0FF00E1FF00B3FF0019FFFF0000FF00000066FF00B3FF00D1FF
00F0FF00FFFF00FFF000FFE100FFE100FFE100FFE100FFE100FFE100FFE100FFE100FFF0
00FFF000FFFF00F0FF00F0FF00E1FF00E1FF00D1FF00C2FF0500FF0066FFCC00FFAE00FF
EB00FF0038FF0047FF8F00FFFF00F58000FFFF001EEB00FF3300FF3300FF0057FF0075FF
0094FF00A3FF0066FF0038FF0085FF0028FF0028FF000AFF8000FF0028FFFF00D79E00FF
FF00B80085FF0057FF00FFE100FFC200FFB300FFB300FFB300FFA300FFA300FFA300FFA3
00FFA300FFA300FFB300FFB300FFB300FFB300FFC200FFC200FFE100FFFF00E1FF1400FF
00F0FF00FFF000FFC200FFC200FFB300FFB300FFA300FFA300FFA300FFA300FFA300FFA3
00FFE1000AFF00FFB300FFE100FFB300FFA300FFB300FFB300FFD100FFFF00B3FF0038FF
7000FF00E1FF00FFF000FFA300FF8500FF7500FF6600FF5700FF4700FF4700FF3800FF38
00FF2800FF2800FF2800FF2800FF2800FF2800FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF3800FF3800FF38
00FF4700FF4700FF5700FF6600FF7500FF8500FFA300F0FF00FFF000FFF000B3FF8F00FF
0066FF00FFFF00FFC200FFE100FFF00066FF00FFF000FF7500FF4700FF3800FF3800FF38
00FF2800FF2800FF2800FF1900FF1900FF1900FF1900FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A05FF0005FF0000FF0A05FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0014FF0005FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0023FF0014FF0023FF0014FF0023FF0014FF0023FF0014FF0023FF00
14FF0014FF0014FF0014FF0014FF0005FF0005FF0000FF0A00FF2800FF9400FF3800FF0A
05FF0014FF0014FF0023FF0023FF0023FF0023FF0023FF0023FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0023FF0023FF00
14FF0005FF0000FF28000AFF00FF8500FF8500FF8500D1FF
42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
42FF0042FF0042FF0042FF0042FF0042FF0042FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0000FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF1900FF0A00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF47
00FF4700FF4700FF4700FF5700FF5700FF6600FF6600FF6600FF7500FF8500FF8500FF94
00FFA300FFB300FFC200FFF000F0FF00B3FFFF002E0028FF1400FF0094FF00B3FF00C2FF
4200FFFF008A00D1FF00FFFF00FFE100FFD100FFB300FFB300FFA300FF9400FF9400FF85
00FF8500FF7500FF7500FF6600FF6600FF6600FF6600FF5700FF5700FF5700FF5700FF57
00FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF57
00FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF6600FF6600FF66
00FF6600FF6600FF6600FF7500FF7500FF7500FF7500FF7500FF8500FF8500FF8500FF85
00FF9400FF9400FF9400FF9400FFA300FFA300FFA300FFA300FFB300FFB300FFB300FFC2
00FFD100FFD100FFE100FFFF00E1FF00B3FF0019FF000AFF0066FFFF00E60094FF00B3FF
00E1FF00FFFF00FFE100FFE100FFD100FFD100FFD100FFD100FFE100FFE100FFE100FFF0
00FFF000FFFF00FFFF00F0FF00E1FF00D1FF00C2FF00B3FF0500FFCC00FF000AFF0066FF
0057FF0075FF0075FF0047FF000AFF4200FFFF00D7FF00F56100FF0019FF0057FF0085FF
00A3FF00B3FF00C2FF00C2FF00B3FF0085FF0075FF00B3FF00B3FF00C2FF00A3FF00C2FF
0085FFFF00C700E1FF00FFE100FFC200FFB300FFB300FFA300FFA300FFA300FFA300FFA3
00FFA300FFA300FFA300FFA300FFB300FFB300FFB300FFC200FFE10094FF0094FFFF0000
0028FF00FFF000FFC200FFB300FFA300FFA300FFA300FF9400FF9400FF9400FF9400FF94
00FFC200FFB300FF9400FF9400FF9400FF9400FF9400FFA300FFB300FFD100C2FF00E1FF
00E1FF00D1FF0094FF00FFC200FFC200FF8500FF6600FF6600FF5700FF4700FF3800FF38
00FF2800FF2800FF2800FF2800FF2800FF2800FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF3800FF3800FF38
00FF3800FF4700FF4700FF5700FF6600FF8500FFD100A3FF00FFC200FFC200FFF000D1FF
00E1FF00FFE100FFB300FFA300FF9400FFA300FF7500FF6600FF4700FF3800FF3800FF38
00FF2800FF2800FF2800FF1900FF1900FF1900FF1900FF1900FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
23FF0023FF0023FF0023FF0014FF0023FF0023FF0023FF0023FF0023FF0014FF0023FF00
23FF0023FF0023FF0014FF0014FF0014FF0005FF0000FF0A00FF280075FF00FF9400FF19
14FF0014FF0023FF0023FF0023FF0023FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
23FF0005FF0000C2FF00FF0A00FF2800FF5700FF3800FF85
42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
42FF0042FF0042FF0042FF0042FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0000FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF2800FF1900FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF3800FF3800FF3800FF3800FF3800FF3800FF4700FF47
00FF4700FF4700FF4700FF5700FF5700FF6600FF6600FF6600FF7500FF8500FF8500FFA3
00FFB300FFC200FFD100FFE100F0FF0028FF0075FF00B3FF0094FF0066FF00D1FF00F0FF
00F0FF00B3FFAE00FF0085FF00FFE100FFD100FFC200FFC200FFB300FFA300FFA300FF94
00FF8500FF7500FF7500FF6600FF6600FF6600FF5700FF5700FF5700FF5700FF5700FF57
00FF5700FF4700FF5700FF4700FF5700FF4700FF5700FF4700FF4700FF4700FF4700FF57
00FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF6600FF6600FF6600FF66
00FF6600FF6600FF7500FF7500FF7500FF7500FF7500FF8500FF8500FF8500FF8500FF94
00FF9400FF9400FFA300FFA300FFA300FFA300FFB300FFB300FFB300FFB300FFC200FFC2
00FFD100FFE100FFF000FFFF00D1FF0047FF0038FF00A3FF00B3FF0085FF0094FF0028FF
4200FF00FFFF00FFE100FFE100FFD100FFD100FFD100FFD100FFD100FFE100FFE100FFE1
00FFF000FFFF00F0FF00E1FF00C2FF00C2FF00B3FF00A3FF0057FF0028FF000AFF0094FF
00A3FF0094FF0075FF0057FFAE00FFFA00FFFF00D7CC00FF0500FF0500FF1400FF2300FF
0094FF00D1FF00D1FF00D1FF00C2FF0085FF0047FF00C2FF00E1FF00F0FF00FFFF00FFFF
0047FF00D1FF0038FFFF006B00FFD100FFB300FFA300FFA300FFA300FFA300FFA300FFA3
00FFA300FFA300FFA300FFA300FFA300FFB300FFB300FFC200FFD100F0FF00C2FF0500FF
00D1FF00F0FF00FFC200FFB300FFA300FFA300FF9400FF9400FF8500FF9400FF8500FF85
00FF8500FF8500FF8500FF8500FF8500FF8500FF9400FF9400FFB300FFFF00E1FF00FFE1
00FFC200FFE100FFD1FF005C00FFFF00FF9400FF7500FF7500FF6600FF5700FF3800FF38
00FF2800FF2800FF2800FF2800FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF3800FF38
00FF3800FF4700FF4700FF5700FF6600FFA300D1FF00FFB300FFA300FFA300FFC200E1FF
00B3FF00FFE100FFA300FF9400FF8500FF7500FF6600FF5700FF4700FF3800FF3800FF38
00FF2800FF2800FF2800FF2800FF2800FF1900FF1900FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A05FF0005FF0000FF0A05FF0005FF0005FF0005FF0005FF0005FF0005FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0023FF0014FF00
23FF0023FF0014FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0014FF0014FF0005FF0000FF0A00C2FF00FF3800FF1900FF19
14FF0023FF0023FF0023FF0033FF0023FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0023FF0023FF0014FF0000FF1900FF0A00FF0A00FFA3
42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0014FF00
23FF0023FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0000FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF2800FF1900FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF4700FF47
00FF4700FF4700FF5700FF5700FF6600FF6600FF6600FF7500FF7500FF8500FF9400FFD1
00B3FF00FFE100FFE100FFFF00B3FF0038FF00C2FF00F0FF0075FF00D1FF0057FF00FFF0
00FFF00047FF00B3FF0075FF00FFFF00FFF000FFFF00FFE100FFFF00F0FF00FFA300FFA3
00FF9400FF8500FF7500FF6600FF6600FF5700FF5700FF5700FF5700FF5700FF5700FF47
00FF4700FF4700FF4700FF4700FF5700FF4700FF5700FF4700FF4700FF4700FF4700FF47
00FF4700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF6600FF66
00FF6600FF6600FF6600FF7500FF7500FF7500FF7500FF8500FF8500FF8500FF8500FF94
00FF9400FFA300FFA300FFA300FFB300FFB300FFB300FFB300FFC200FFC200FFC200FFD1
00FFD100FFE100D1FF00D1FF00B3FF6100FF0075FF00D1FF00E1FF0094FF00B3FF00F0FF
00FFFF00F0FF00FFD100FFD100FFD100FFC200FFC200FFD100FFD100FFD100FFE100FFE1
00FFF000E1FF00E1FF00D1FF0066FF0094FF0038FF0066FF0038FF0094FF000AFF00B3FF
00B3FF00A3FF0038FF7000FF0019FF0038FF7000FF2300FF0047FF0057FF0038FF00A3FF
00C2FF00E1FF00E1FF00E1FF00D1FF0085FFFF00C700A3FF00F0FF00FFF000FFF000FFE1
00FFE100FFD100FFE10094FF00FFB300FFA300FFA300FFA300FF9400FF9400FF9400FF94
00FF9400FF9400FFA300FFA300FFA300FFA300FFB300FFC200FFC200FFE100FFFF0075FF
00E1FF00FFF000FFC200FFB300FFA300FF9400FF9400FF8500FF8500FF8500FF8500FF85
00FF8500FF7500FF7500FF7500FF7500FF7500FF8500FF9400FFD100B3FF00FFC200A3FF
00FFA300FF9400FFB300C2FF00FFFF00FFD1FA00FF00FFF00075FF00FF6600FF3800FF38
00FF2800FF2800FF2800FF1900FF2800FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF2800FF1900FF1900FF2800FF2800FF2800FF2800FF2800FF2800FF3800FF38
00FF3800FF4700FF4700FF4700FF5700FF9400FF8500FF8500FF9400FF9400C2FF0085FF
1400FF00D1FF00FFA300FF8500FF7500FF6600FF5700FF5700FF4700FF3800FF3800FF38
00FF2800FF2800FF2800FF1900FF1900FF1900FF1900FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0014FF0014FF0005FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0014FF0014FF0000FF0A00FFA300FF0A14FF0014FF00
23FF0023FF0023FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
42FF0042FF0042FF0042FF0042FF0042FF0042FF0033FF0042FF0033FF0033FF0033FF00
33FF0033FF0023FF0023FF0023FF0014FF0014FF0000FF0A
51FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0000FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF2800FF1900FF2800FF19
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF3800FF28
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF4700FF4700FF47
00FF4700FF4700FF5700FF5700FF6600FF6600FF6600FF7500FF7500FF8500FF9400FFB3
00FFF000C2FF00FFFF00E1FFBD00FF0085FF00FFFF00FFF0DC00FF00FFF000F0FF00FFD1
00FFD100FFE100FFFF00C2FF000AFF1400FF0038FF0066FF4200FF00FFF000FFD100FFF0
00FFB300FF9400FF7500FF6600FF6600FF5700FF5700FF5700FF5700FF5700FF4700FF47
00FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF47
00FF4700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF6600FF6600FF66
00FF6600FF6600FF6600FF7500FF7500FF7500FF8500FF8500FF8500FF8500FF9400FF94
00FFA300FFA300FFC200FFB300FFB300FFB300FFC200FFC200FFC200FFD100FFD100FFD1
00FFE100FFF000E1FF7000FF0038FF0094FF00E1FF00F0FF00F0FF00D1FF00A3FF00FFF0
00FFE100FFD100FFC200FFC200FFC200FFC200FFC200FFC200FFD100FFD100FFE100FFE1
00FFFF00B3FF00A3FF0038FF3300FF0047FF0075FF0085FF0075FF00B3FF00C2FF00D1FF
00D1FF00A3FF0028FF0094FF8F00FF0075FF0057FF3300FF0066FF0094FF0066FF00A3FF
00E1FF00F0FF00F0FF00F0FF00E1FF00C2FF0075FF00A3FF00D1FF00FFF000FFE100FFD1
00FFC200FFC200FFC200FFC200FFA300FFA300FFA300FF9400FF9400FF9400FF9400FF94
00FF9400FF9400FF9400FF9400FFA300FFB300FFB300FFC200FFC200FFE100F0FF0047FF
0066FF00FFF000FFE100FFD100FFA300FF9400FF9400FF8500FF8500FF8500FF7500FF75
00FF7500FF7500FF6600FF7500FF6600FF7500FF7500FF8500FFFF00FFD100FF8500FFB3
00FF8500FF7500FF7500FF8500FF9400FFE100FFA300FF9400FF6600FF6600FF3800FF38
00FF2800FF2800FF2800FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF2800FF2800FF2800FF2800FF2800FF2800FF3800FF38
00FF3800FF3800FF4700FF4700FF5700FF5700FF6600FF7500FF7500FF9400FFA300FFE1
AE00FF00FFD100FFA300FF8500FF7500FF6600FF5700FF5700FF4700FF4700FF3800FF38
00FF3800FF3800FF2800FF1900FF1900FF1900FF1900FF0A00FF0A00FF0A00FF0A00FF0A
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0014FF0005FF0005FF0014FF0023FF0023FF00
23FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0042FF0033FF0042FF00
42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0033FF00
33FF0033FF0033FF0033FF0023FF0023FF0023FF0014FF00
51FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0023FF0033FF0033FF0033FF00
33FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0000FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF19
00FF1900FF1900FF1900FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF4700FF4700FF4700FF47
00FF4700FF5700FF5700FF5700FF6600FF6600FF7500FF7500FF8500FF8500FF9400FFD1
00E1FF3300FF00B3FF0075FF0094FF00A3FF00FFE100FFD100FFF000FFC200FFC200FFC2
00FFC200FFD100FFF03300FF00FFFF00FFF000FFFF00F0FF0085FF0075FF00C2FF00C2FF
0019FF00FFB300FF7500FF6600FF6600FF6600FF5700FF5700FF4700FF4700FF4700FF47
00FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF47
00FF4700FF4700FF4700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF6600FF66
00FF6600FF6600FF7500FF7500FF7500FF8500FF8500FF8500FF8500FF9400FF9400FF94
00FFA300FFC200E1FF00FFD100FFC200FFC200FFC200FFD100FFE100FFE100FFE100FFE1
00FFF000FFFF00E1FF0085FF0028FF0038FF00F0FF00FFF000FFF000F0FF2300FF00FFE1
00FFD100FFC200FFC200FFC200FFB300FFB300FFC200FFC200FFC200FFD100FFE100FFF0
00FFFF0075FFFF006B0057FF00B3FF00C2FF00D1FF00A3FF0028FF00B3FF00D1FF00E1FF
00E1FF00C2FF00D1FF00B3FF0075FF00A3FF0075FFEB00FF0066FF00B3FF00C2FF00C2FF
00F0FF00F0FF00FFFF00FFFF00F0FF00E1FF00A3FFAE00FF3300FF00FFFF00FFE100FFC2
00FFC200FFB300FFB300FFA300FFA300FF9400FF9400FF9400FF9400FF9400FF9400FF94
00FF9400FF9400FF9400FF9400FFA300FFA300FFB300FFC200FFD100FFF000F0FF00A3FF
0085FF00E1FF1400FF00FFD100FFA300FF9400FF8500FF8500FF8500FF7500FF7500FF75
00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF750085FF00FF7500FF6600FF66
00FF6600FF6600FF6600FF6600FF8500E1FF00FF9400FF6600FF4700FF4700FF3800FF28
00FF2800FF2800FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF0A00FF0A00FF1900FF0A00FF0A00FF0A00FF1900FF0A00FF0A
00FF0A00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF2800FF2800FF2800FF2800FF2800FF2800FF38
00FF3800FF3800FF4700FF4700FF4700FF5700FF6600FF6600FF7500FF8500FFA300FFD1
2300FF0085FF00FFB300FFB300FF8500FF6600FF6600FF5700FF4700FF4700FF4700FF38
00FF3800FF2800FF2800FF2800FF1900FF1900FF1900FF0A00FF0A00FF0A00FF0A00FF0A
05FF0005FF0005FF0005FF0005FF0005FF0005FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0042FF0042FF0042FF0042FF0042FF00
42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
33FF0042FF0033FF0033FF0033FF0033FF0023FF0014FF00
51FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0005FF0014FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0000FF0A05FF00
05FF0000FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF1900FF19
00FF1900FF2800FF2800FF3800FF3800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF3800FF2800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF4700FF4700FF4700FF4700FF47
00FF4700FF5700FF5700FF6600FF7500FF8500FF8500FF8500FF8500FF9400FFA300FFC2
00FFF000D1FF5100FFFF00A80028FF00FFF000FFD100FFC200FFB300FFB300FFB300FFB3
00FFB300FFD100FFFF4200FF00FFE100FFC200FFC200F0FF00E1FF00FFD100E1FFFF0099
00FFF000FFA300FF8500FF6600FF6600FF5700FF5700FF4700FF4700FF4700FF4700FF47
00FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF47
00FF4700FF4700FF4700FF4700FF5700FF5700FF5700FF5700FF5700FF6600FF6600FF66
00FF6600FF6600FF7500FF7500FF7500FF8500FF8500FF8500FF9400FF9400FFA300FFA3
00FFB300FFC200B3FF0500FF00FFD100FFD100FFD100FFF00038FF00F0FF00FFF000FFFF
00FFFF00F0FF0085FF0066FF00C2FF00B3FF00FFF000FFE100FFE100FFE100D1FF00FFD1
00FFC200FFC200FFB300FFB300FFB300FFB300FFB300FFC200FFC200FFD100FFF000F0FF
00E1FF00A3FF0075FF0038FF00E1FF00F0FF00E1FF00B3FF1400FF00A3FF00E1FF00F0FF
00F0FF00F0FF00F0FF00E1FF00D1FF00B3FF0075FF1400FF0047FF00B3FF00D1FF00E1FF
00F0FF00FFFF00FFF000FFF000FFFF0075FF00B3FF0085FF00A3FF00F0FF00FFF000FFC2
00FFB300FFB300FFA300FFA300FF9400FF9400FF9400FF9400FF9400FF9400FF9400FF85
00FF9400FF9400FF9400FF9400FF9400FFA300FFB300FFE12300FF000AFF00D1FF0075FF
6100FF0019FF0047FF00B3FF00FFC200FF9400FF8500FF8500FF7500FF7500FF7500FF66
00FF6600FF6600FF6600FF5700FF5700FF5700FF6600FF6600FF6600FF5700FF5700FF57
00FF5700FF5700FF5700FF5700FF7500FFC200FFD100FF5700FF4700FF3800FF2800FF28
00FF2800FF1900FF2800FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF0A00FF1900FF0A00FF0A00FF0A00FF1900FF0A00FF0A00FF0A00FF1900FF0A00FF0A
00FF0A00FF1900FF0A00FF0A00FF0A00FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF2800FF2800FF2800FF2800FF2800FF2800FF38
00FF3800FF4700FF4700FF4700FF5700FF5700FF5700FF6600FF7500FF9400FFC200FFD1
00C2FF0500FF00FFF000FFE100FF9400FF7500FF6600FF5700FF5700FF5700FF4700FF47
00FF4700FF3800FF2800FF2800FF2800FF1900FF1900FF0A00FF0A00FF0A00FF0A00FF0A
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0033FF0023FF0023FF0033FF0033FF00
33FF0033FF0033FF0023FF0033FF0033FF0023FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
42FF0042FF0042FF0033FF0033FF0033FF0033FF0023FF00
42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0000FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF1900FF1900FF1900FF19
00FF2800FF2800FF3800FF9400FF5700FF3800FF3800FF3800FF3800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF4700FF4700FF4700FF4700FF4700FF4700FF47
00FF5700FF5700FF6600FF6600FF850075FF00FFB300FFA300FF9400FFA300FFA300FFC2
00FFE100D1FF0075FF00B3FF0094FF0057FF00FFE100FFB300FFA300FFA300FFA300FFA3
00FFB300FFC200E1FF000AFF00FFF000FFB300FFA300FFA300FFA300FFB30047FF00FFE1
00FFFF00FFF000A3FF00FF8500FF6600FF5700FF5700FF4700FF4700FF4700FF4700FF47
00FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF47
00FF4700FF4700FF4700FF4700FF4700FF5700FF5700FF5700FF5700FF5700FF6600FF66
00FF6600FF6600FF7500FF8500FF8500FF8500FF9400FF9400FF9400FF9400FFA300FFA3
00FFC200FFD10085FF00D1FF00FFF000FFE100FFF000D1FF1400FF00D1FF00E1FF0066FF
00D1FF00D1FF0019FF0066FF00FFFF00FFF000FFE100FFD100FFD100FFC200FFC200FFC2
00FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC200FFC200FFF03300FF
00A3FF0047FF00E1FF00E1FF00FFF000FFF000F0FF00A3FF9E00FF00B3FF00F0FF00FFFF
00FFFF00FFFF00F0FF00F0FF00D1FF00C2FF0066FFFF003D0057FF00A3FF00D1FF00E1FF
00FFFF00FFF000FFF000FFF000FFF000FFF000FFFF00E1FFFF00990085FF00D1FF00FFC2
00FFB300FFA300FFA300FF9400FF9400FF9400FF9400FF8500FF8500FF8500FF8500FF85
00FF8500FF9400FF9400FF9400FF9400FF9400FFA300FFE100FFF000FFFF0075FF00B3FF
8F00FF00B3FF00FFFF0075FF00FFC200FF9400FF9400FF8500FF7500FF7500FF6600FF66
00FF6600FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF47
00FF4700FF4700FF4700FF5700FF660500FF00FFE100FF6600FF3800FF3800FF2800FF28
00FF2800FF2800FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF0A00FF0A
00FF0A00FF1900FF0A00FF0A00FF0A00FF1900FF0A00FF0A00FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF2800FF2800FF2800FF2800FF38
00FF3800FF3800FF4700FF4700FF4700FF5700FF5700FF6600FF7500FFB300F0FF00C2FF
000AFF0500FF3300FF0028FFAE00FF00FFC200FF7500FF6600FF5700FF6600FF5700FF66
00FF6600FF5700FF3800FF2800FF1900FF1900FF1900FF0A00FF0A00FF0A00FF0A00FF0A
05FF0005FF0005FF0005FF0005FF0005FF0014FF0014FF0005FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0033FF0033FF0023FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
42FF0042FF0042FF0042FF0042FF0042FF0033FF0033FF00
42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
42FF0042FF0042FF0042FF0042FF0042FF0042FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
14FF0014FF0014FF0014FF0014FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0000FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF1900FF1900FF1900FF19
00FF2800FF3800FF4700FFF000FF6600FF4700FF3800FF3800FF3800FF3800FF3800FF28
00FF2800FF3800FF2800FF2800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF57
00FF5700FF5700FF6600FF6600FF8500FFC20085FF00FFC200FFB300FFB300FFC200F0FF
00FFFF2300FF00E1FF00FFFF0085FF00FFE100FFFF00FFA300FF9400FF9400FF9400FFA3
00FFA300FFC200FFF00066FF00FFE100FFB300FF9400FF9400FF8500FF9400FF9400FF94
00FF9400C2FF00FF9400FF7500FF5700FF5700FF4700FF4700FF4700FF4700FF4700FF47
00FF3800FF4700FF3800FF3800FF4700FF3800FF4700FF4700FF4700FF4700FF4700FF47
00FF4700FF4700FF4700FF4700FF4700FF5700FF5700FF5700FF5700FF5700FF5700FF66
00FF6600FF7500FF7500FF9400FFA300FF9400FF9400FF9400FFA300FFA300FFA300FFB3
00F0FF00C2FF00D1FF00D1FF00F0FF00D1FF00D1FF0094FF5100FFFF008A0075FF1400FF
00A3FF00A3FF00A3FF00F0FF00FFF000FFE100FFD100FFD100FFC200FFC200FFB300FFB3
00FFB300FFB300FFA300FFA300FFA300FFA300FFA300FFB300FFB300FFC200FFE100C2FF
7000FF00A3FF00FFFF00FFE100FFE100FFF000FFFF0057FF000AFF0085FF00F0FF00FFF0
00FFF000FFF000FFFF00F0FF00D1FF00C2FF00A3FF0047FF0047FF0094FF00B3FF00B3FF
00FFFF00FFF000FFE100FFE100FFE100FFE100FFF000F0FF0085FF0057FF00FFFF00FFD1
00FFB300FFA300FF9400FF9400FF9400FF9400FF8500FF8500FF8500FF8500FF8500FF85
00FF8500FF8500FF8500FF9400FF9400FF9400FFA300FFA300FFB300FFE100D1FF00FFFF
00A3FF1400FF00FFF000FFD100FFB300FFA300FF9400FF8500FF7500FF7500FF6600FF66
00FF6600FF5700FF5700FF5700FF5700FF4700FF4700FF4700FF4700FF4700FF4700FF47
00FF4700FF4700FF4700FF4700FF4700FF6600FFC20028FF00FF3800FF3800FF2800FF28
00FF2800FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF0A00FF0A00FF1900FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF2800FF2800FF2800FF2800FF2800FF28
00FF3800FF3800FF4700FF4700FF4700FF5700FF5700FF6600FF7500FF8500FFE100D1FF
00B3FF0047FF00FFFF00FFD100FFB300FF8500FF7500FF7500FF7500FF7500FFD100FFC2
00B3FF00FFE100FF5700FF2800FF1900FF1900FF1900FF0A00FF0A00FF0A00FF0A00FF0A
05FF0005FF0000FF0A05FF0005FF0005FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
42FF0042FF0042FF0042FF0042FF0051FF0042FF0042FF0051FF0042FF0051FF0042FF00
42FF0042FF0042FF0042FF0042FF0042FF0042FF0033FF00
42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0014FF0014FF00
14FF0014FF0014FF0014FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0000FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF1900FF1900FF1900FF1900FF28
00FF3800FF6600FFA300D1FF00FF6600FF4700FF4700FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF4700FF47
00FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF5700FF4700FF57
00FF5700FF5700FF6600FF7500FF8500FFA300FFF00057FF00FFD100FFC200F0FF0075FF
0075FF00F0FF00FFE100FFD100C2FF00FFC200FFA300FF9400FF9400FF9400FF9400FF94
00FFA300FFE100F0FF5100FF0047FF00FFB300FF9400FF8500FF7500FF7500FF7500FF75
00FF7500FFB300FF8500FF5700FF5700FF4700FF4700FF4700FF4700FF4700FF3800FF47
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF4700FF4700FF47
00FF4700FF4700FF5700FF4700FF4700FF4700FF5700FF5700FF5700FF6600FF6600FF66
00FF6600FF7500FF8500FF9400FFF000FFB300FFB300FFB300FFB300FFB300FFB300FFC2
00FFE100FFFF00C2FF0085FF1400FF0066FF0038FF0085FF00A3FF00B3FF00F0FF00F0FF
00FFFF00E1FF000AFF00C2FF00FFF000FFE100FFD100FFC200FFC200FFB300FFB300FFB3
00FFB300FFA300FFA300FFA300FFA300FFA300FFA300FFA300FFB300FFC200FFD100C2FF
0075FF000AFF00FFE100FFD100FFD100FFE100FFFF00D1FF1400FF00E1FF00FFF000FFF0
00FFF000FFF000FFF000F0FF0057FF0038FF0085FF0500FF8000FF0500FF0066FF00D1FF
00FFFF00FFE100FFE100FFD100FFD100FFD100FFE10057FF00FFFF00FFFF0085FFFF00A8
00FFB300FFA300FF9400FF9400FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF85
00FF8500FF8500FF8500FF8500FF8500FF9400FF9400FFA300FFA300FFC200FFD100FFE1
00E1FF0066FF00F0FF00FFD100FFB300FFB300FFA300FF9400FF8500FF7500FF6600FF66
00FF5700FF5700FF5700FF5700FF4700FF4700FF4700FF4700FF4700FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF4700FF476100FF00FF4700FF3800FF2800FF2800FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF1900FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF0A00FF0A00FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF2800FF2800FF2800FF2800FF38
00FF3800FF3800FF4700FF4700FF4700FF5700FF5700FF6600FF7500FF8500FFC200FFC2
00FFE100A3FF0028FF00FFC200FFA300FF9400FF8500FF7500FF7500FF8500FFB3FF004C
00FFA300FF5700FF3800FF2800FF2800FF1900FF1900FF1900FF0A00FF0A00FF0A05FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0033FF0023FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0042FF0033FF0042FF00
42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
42FF0042FF0051FF0051FF0042FF0051FF0051FF0051FF0051FF0042FF0051FF0042FF00
51FF0042FF0051FF0042FF0042FF0042FF0042FF0042FF00
51FF0051FF0051FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0014FF00
14FF0014FF0014FF0005FF0005FF0005FF0000FF0A05FF0005FF0005FF0005FF0005FF00
00FF0A05FF0000FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF1900FF0A00FF1900FF1900FF1900FF1900FF1900FF2800FF28
00FF3800FF4700FF7500E1FF00FF7500FF5700FF4700FF4700FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF4700FF4700FF4700FF47
00FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF5700FF5700FF5700FF57
00FF5700FF6600FF6600FF7500FF9400FFA300FFD10019FF00FFE100FFE100FFFF00A3FF
0085FF00A3FF00FFC200FFB300FFB300FFB300FF9400FF8500FF8500FF8500FF8500FF85
00FF9400FFB33300FF0085FF00FFF000FFC200FF8500FF7500FF7500FF6600FF6600FF66
00FF6600FF7500FF6600FF5700FF4700FF4700FF4700FF4700FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF4700FF3800FF47
00FF4700FF4700FF4700FF4700FF5700FF4700FF5700FF5700FF5700FF5700FF6600FF66
00FF6600FF7500FF8500FF9400FFD10066FF00FFFF00FFC200FFB300FFB300FFC200FFD1
00FFE100F0FF0075FFFF00F58000FF00C2FF00C2FF00FFFF0085FF00F0FF00FFE100FFE1
00FFF000FFFF00A3FF00C2FF00FFFF00FFE100FFD100FFC200FFC200FFB300FFB300FFA3
00FFA300FFA300FFA300FFA300FFA300FFA300FFA300FFA300FFA300FFC200FFF000C2FF
00FFF000FFD100FFC200FFC200FFC200FFD100FFF00047FF0057FF0094FF00FFF000FFE1
00FFE100FFE100FFF000F0FF00B3FF00A3FF0047FF0028FFAE00FF0085FF2300FF00B3FF
00FFFF00FFE100FFD100FFE100FFD100FFD100FFC200FFC200FFC200FFD100FFFF00FFD1
00FFA300FF9400FF9400FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF85
00FF8500FF8500FF8500FF8500FF8500FF9400FF9400FF9400FFA300FFB300FFB300FFE1
00D1FF000AFF0066FF00C2FF00FFC200FFC200C2FF00FFF000FF8500FF7500FF6600FF66
00FF5700FF5700FF5700FF4700FF4700FF4700FF4700FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF2800FF2800FF2800FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF2800FF2800FF2800FF2800FF38
00FF3800FF3800FF4700FF4700FF4700FF5700FF5700FF6600FF7500FF8500FF9400FFA3
00FFC200E1FF00E1FF00FFD100FFC200FFA300FF9400FF8500FF9400FFFF0057FF00FFB3
1400FF00FF4700FF3800FF2800FF2800FF1900FF1900FF1900FF0A00FF0A00FF0A00FF0A
05FF0005FF0005FF0005FF0005FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0042FF0042FF0042FF0042FF0042FF00
42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0051FF00
51FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF00
51FF0051FF0051FF0051FF0042FF0051FF0051FF0042FF00
51FF0051FF0051FF0051FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0014FF0014FF0014FF00
14FF0014FF0005FF0005FF0005FF0000FF0A00FF1900FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF1900FF1900FF1900FF1900FF1900FF2800FF2800FF28
00FF3800FF4700FF7500FFD100FFA300FFFF00FF6600FF5700FF4700FF4700FF4700FF47
00FF4700FF4700FF3800FF3800FF4700FF4700FF4700FF4700FF4700FF4700FF5700FF57
00FF5700FF5700FF4700FF4700FF4700FF4700FF5700FF5700FF5700FF5700FF5700FF57
00FF6600FF6600FF7500FF8500D1FF00E1FF00D1FF0057FF00D1FFBD00FF00A3FF00A3FF
00FFFF00B3FF00FFB300FFA300FF9400FF8500FF8500FF8500FF7500FF7500FF8500FF85
00FF8500FFA300FFC200E1FF0075FF00FFB300FF9400FF7500FF6600FF6600FF5700FF57
00FF5700FF5700FF5700FF4700FF4700FF4700FF4700FF3800FF4700FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF47
00FF4700FF4700FF4700FF4700FF4700FF4700FF5700FF5700FF5700FF5700FF6600FF66
00FF6600FF7500FF7500FF9400FFB300FFFF00D1FF00FFE100FFC200FFD100FFE1EB00FF
00F0FF4200FF0047FF0500FF0066FF00F0FF00FFF000FFD100FFE100FFD100FFC200FFD1
00FFD100FFFF00D1FF0038FF8F00FF00FFF000FFD100FFC200FFB300FFB300FFA300FFA3
00FFA300FFA300FFA300FFA300FF9400FF9400FF9400FFA300FFA300FFC200E1FF00FFD1
00FFD100FFB300FFB300FFB300FFB300FFC200FFE100B3FF00E1FF00FFF000FFD100FFD1
00FFD100FFD100FFE100FFF000FFFF0066FF00B3FF0094FF1400FF00B3FF00D1FF00E1FF
00FFFF00FFE100FFD100FFD100FFC200FFC200FFC200FFB300FFB300FFB300FFC200FFB3
00FFA300FF9400FF9400FF8500FF8500FF8500FF8500FF8500FF7500FF7500FF7500FF75
00FF8500FF7500FF7500FF8500FF8500FF8500FF8500FF9400FF9400FFA300FFB300FFC2
00F0FF00C2FF0038FF00FFFF00FFE100FFF000D1FF00FFA300FF8500FF7500FF6600FF66
00FF5700FF5700FF5700FF4700FF4700FF4700FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF0A00FF0A00FF0A00FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF2800FF2800FF3800FF38
00FF3800FF3800FF4700FF4700FF5700FF5700FF6600FF6600FF7500FF8500FF9400FFB3
00FFD100F0FF0094FF00FFFF00E1FF00FFF000FFB300FFA300FFA300FFF000FFFF00FF85
00FF6600FF5700FF3800FF3800FF2800FF2800FF1900FF1900FF0A00FF0A00FF0A00FF0A
05FF0005FF0005FF0005FF0005FF0005FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0033FF0033FF0033FF0023FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0051FF0051FF0051FF00
51FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF00
51FF0051FF0051FF0051FF0051FF0051FF0051FF0042FF00
51FF0051FF0051FF0051FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00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51FF0051FF0051FF0051FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00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51FF0051FF0051FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00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51FF0051FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0014FF0014FF0014FF0014FF00
14FF0005FF0005FF0000FF0A00FF1900FF470085FF00FF4700FF3800FF2800FF2800FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF2800FF2800FF2800FF4700FF6600FF5700FF5700FF57
00FF5700FF6600FF8500FFE10075FF0075FF00FF8500FF6600FF6600FF5700FF5700FF57
00FF5700FF5700FF5700FF5700FF6600FFA300FF9400FF8500FF8500FFA30038FF00FFD1
00FF9400FF7500FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7500FF75
00FF7500FF7500FF8500FF9400FFB300FFC20085FF0500FF00E1FF00FFF000FFE100D1FF
00FFF000FFC200FFD100E1FF00FF7500FF6600FF6600FF6600FF6600FF6600FF6600FF66
00FF6600FF6600FF7500FF8500A3FF00FFFF00FF8500FF6600FF5700FF4700FF4700FF47
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF2800FF3800FF3800FF2800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF4700FF4700FF4700FF4700FF5700FF5700FF5700FF6600FF6600FF75
00FF7500FF7500FF8500FFA300FFB300FFD100FFF000B3FF9E00FFFF00000028FF00FFFF
00FFE100FFC200FFB300FFA300FFA300FFA300FF9400FF9400FF9400FF9400FFA300FFA3
00FFD1000AFF00B3FF0094FF9E00FF0075FF00E1FF00FFD100FFC200FFA300FFA300FFA3
00FF9400FF9400FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF85
00FF8500FF9400FF9400FF9400FF9400FF9400FF9400FFA300FFA300FFA300FFB300FFB3
00FFB300FFC200FFD100FFE100FFFF00F0FF00E1FF00C2FF0066FF0075FF00C2FF00D1FF
00B3FF00B3FF00FFE100FFC200FFB300FFB300FFA300FFA300FFA300FF9400FF9400FF94
00FF8500FF8500FF8500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF75
00FF6600FF7500FF7500FF7500FF7500FF7500FF8500FF8500FFA300FFE19E00FF0075FF
00F0FF0047FF00F0FF0066FF0019FF00F0FF00FFC200FFA300FF9400FF8500FF7500FF66
00FF6600FF5700FF4700FF4700FF3800FF3800FF3800FF3800FF3800FF2800FF2800FF28
00FF2800FF2800FF2800FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF0A
00FF0A00FF1900FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF1900FF1900FF1900FF1900FF1900FF2800FF3800FF3800FF47
00FF5700FF6600FFB300E1FF00FFD100FFD100C2FF00FFFF0019FF00FFD100FFC200FFFF
00D1FF1400FF00B3FF6100FF0028FF000AFF00D1FF00FFE100FFB300FFA300FFA300FFD1
00FFFF00FFB300C2FF00FF8500FF6600FF6600FF3800FF1900FF1900FF0A00FF0A00FF0A
00FF0A05FF0005FF0005FF0005FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0042FF0033FF00
42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
42FF0042FF0042FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF00
51FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF00
61FF0051FF0061FF0061FF0051FF0061FF0061FF0061FF00
42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00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51FF0051FF0051FF0051FF0051FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00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51FF0051FF0051FF0051FF0051FF0051FF0042FF0042FF0042FF0042FF0042FF0042FF00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51FF0051FF0051FF0051FF0051FF0051FF0042FF0042FF0042FF0042FF0042FF0042FF00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51FF0051FF0051FF0051FF0051FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00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51FF0051FF0051FF0051FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00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51FF0051FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00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51FF0051FF0051FF0051FF0051FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00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51FF0051FF0051FF0051FF0051FF0051FF0042FF0042FF0042FF0042FF0042FF0042FF00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51FF0051FF0051FF0051FF0051FF0051FF0042FF0042FF0042FF0042FF0042FF0042FF00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51FF0051FF0051FF0051FF0051FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00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51FF0051FF0051FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00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51FF0051FF0051FF0051FF0051FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00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51FF0051FF0051FF0051FF0051FF0051FF0042FF0042FF0042FF0042FF0042FF0042FF00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51FF0051FF0051FF0051FF0051FF0051FF0042FF0042FF0042FF0042FF0042FF0042FF00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51FF0051FF0051FF0051FF0051FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
42FF0042FF0033FF0033FF0033FF0033FF0033FF0033FF0023FF0033FF0033FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0005FF0005FF0005FF0000FF0A00FF0A00FF19
00FF2800FF4700FF948000FF00FFA300FFB300FFF000FFFF00F0FF00E1FF00E1FF00E1FF
00FFE100FFB300FF9400FF9400FF8500FF9400FF8500FFA300FFB300FF9400FF9400FFA3
00FFD100FFD10085FF9E00FFFA00FF0047FF00F0FF00FFC200FF9400FF8500FFA300FF85
00FF7500FF7500FF7500FF8500FF9400FFB300FFFF00FFE100E1FF0019FF00FFFF00FF85
00FF6600FF5700FF5700FF4700FF4700FF4700FF4700FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF4700FF4700FF4700FF4700FF4700FF5700FF5700FF6600FF66
00FF7500FF8500FF9400FFC200C2FF00D1FF00FFD100FFB300FFB300F0FF00FFE100FF66
00FF5700FF5700FF4700FF4700FF4700FF4700FF3800FF3800FF3800FF2800FF2800FF38
00FF2800FF2800FF2800FF2800FF1900FF1900FF2800FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF2800FF2800FF2800FF3800FF3800FF4700FF6600FF6600FF9400FFA300FFFF
00FF8500FF6600FF5700FF4700FF4700FF4700FF4700FF4700FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF4700FF4700FF4700FF5700FF6600FF85
00FFE100FFF000E1FFBD00FF00A3FF0066FF0085FF0028FF00E1FF00FFFF00FF7500FF66
00FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF57
00FF5700FF5700FF5700FF6600FF6600FF6600FF7500FF7500FF8500FF8500FF9400FF94
00FFB300FFC200E1FF7000FF00F0FF00FFF000FFF00085FF00D1FF0047FF0094FF0066FF
00C2FF0047FF00FFF000FFE100FFD100FFD100FFFF00FFFF00FFF09E00FF3300FF0057FF
0057FF00FF8500FF7500FF6600FF5700FF5700FF5700FF5700FF5700FF4700FF4700FF47
00FF4700FF4700FF4700FF4700FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF47
00FF4700FF6600D1FF00B3FF00FF5700FF3800FF2800FF1900FF1900FF1900FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A05FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0014FF0014FF0005FF0005FF0005FF0014FF0014FF0014FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0000FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF1900FF1900FF1900FF2800FF2800FF28
00FF2800FF3800FF3800FF4700FF5700FF9400FFC200FF9400FF9400FFB3000AFF0094FF
00E1FF00FFC200FFA300FF9400FF9400FF8500FF7500FF7500FF7500FF7500FF8500FFD1
00FFF000FF9400FF6600FF4700FF3800FF2800FF2800FF1900FF1900FF0A00FF0A05FF00
05FF0014FF0014FF0014FF0023FF0023FF0023FF0023FF0023FF0023FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
42FF0042FF0042FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF00
51FF0051FF0051FF0051FF0061FF0061FF0051FF0061FF0061FF0061FF0061FF0061FF00
61FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF0070FF0070FF00
61FF0061FF0070FF0070FF0070FF0070FF0070FF0070FF00
51FF0051FF0051FF0051FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00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51FF0051FF0051FF0051FF0051FF0042FF0042FF0042FF0042FF0042FF0042FF0033FF00
42FF0033FF0033FF0033FF0033FF0033FF0033FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0014FF0023FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0005FF0005FF0005FF0005FF0000FF0A00FF0A00FF0A
00FF1900FF2800FF3800FF4700FF4700FF5700FF6600FF6600FF7500FF8500FF9400D1FF
0500FF00C2FF00FFD100FFB300FFC200FFF000C2FF0500FF00FFFF00FFC200FFD100FFF0
AE00FF1400FF00FFE100FFE100FFD100D1FF000AFF00FFD100FF8500FF6600FF6600FF57
00FF5700FF5700FF6600FF6600FF9400E1FF00FFFF00FF8500FF7500FF8500FFB30500FF
00FF9400FF5700FF4700FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF4700FF4700FF4700FF5700FF6600FF94
00FFF000FFC200FFD100FFD100A3FFFF00990094FF0038FF00F0FF00FFC200FF9400FF75
00FF6600FF5700FF4700FF4700FF3800FF3800FF3800FF3800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF0A00FF1900FF1900FF0A00FF0A00FF0A
00FF1900FF0A00FF0A00FF1900FF1900FF0A00FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF2800FF2800FF3800FF4700FF5700FFC20047FF00FF9400FF7500FF94
00FFF000FF6600FF4700FF4700FF3800FF3800FF2800FF2800FF2800FF2800FF2800FF38
00FF2800FF2800FF2800FF3800FF3800FF3800FF3800FF3800FF4700FF4700FF5700FF66
00FF8500FF9400E1FF0085FF00FFB300FFB300F0FF00FFF000FF7500FF6600FF5700FF57
00FF5700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF5700FF57
00FF5700FF5700FF5700FF5700FF5700FF6600FF6600FF6600FF7500FF7500FF8500FF94
00FFB300D1FF0075FF00FFE100FFD100FFC200FFC200FFE100FFE100FFFF00B3FF9E00FF
00A3FF00FFFF00FFE100FFD100FFC200FFB300FFB300FFA300FFB300FFA300FFA300FF94
00FFA300FF8500FF6600FF6600FF5700FF5700FF5700FF4700FF4700FF4700FF4700FF47
00FF4700FF4700FF4700FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF2800FF2800FF3800FF2800FF2800FF2800FF2800FF2800FF28
00FF3800FF3800FF4700FFFF00FF4700FF2800FF1900FF1900FF1900FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0014FF0014FF00
14FF0005FF0005FF0014FF0014FF0014FF0014FF0005FF0014FF0014FF0014FF0014FF00
14FF0005FF0014FF0014FF0014FF0014FF0005FF0014FF0014FF0014FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0000FF0A05FF0005FF00
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF1900FF1900FF2800FF2800FF28
00FF2800FF3800FF3800FF4700FF4700FF5700FF6600FF6600FF8500FF8500FFA300FFD1
00B3FF00E1FF00FFF000F0FF00FFF00075FF00FFE100FF9400FF9400FF9400FFA300FFFF
00FFB300FF8500FF7500FF6600FF6600FF5700FF6600FFC200FF8500FF4700FF6600FF28
00FF0A05FF0014FF0014FF0023FF0023FF0023FF0023FF0023FF0023FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
42FF0042FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF00
51FF0051FF0051FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF00
61FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF0070FF0070FF0070FF00
70FF0070FF0070FF0061FF0070FF0070FF0070FF0070FF00
51FF0051FF0051FF0051FF0051FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00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51FF0051FF0051FF0051FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0033FF00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51FF0051FF0051FF0051FF0051FF0042FF0042FF0042FF0042FF0042FF0042FF0033FF00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51FF0051FF0051FF0051FF0051FF0042FF0042FF0042FF0042FF0042FF0042FF0033FF00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51FF0051FF0051FF0051FF0051FF0042FF0042FF0042FF0042FF0042FF0042FF0033FF00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51FF0042FF0051FF0051FF0042FF0042FF0042FF0042FF0042FF0042FF0033FF0033FF00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51FF0051FF0051FF0051FF0051FF0051FF0042FF0042FF0042FF0033FF0033FF0033FF00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51FF0051FF0051FF0051FF0051FF0042FF0042FF0042FF0042FF0042FF0033FF0033FF00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51FF0051FF0042FF0051FF0051FF0042FF0042FF0042FF0042FF0042FF0042FF0033FF00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51FF0051FF0051FF0051FF0051FF0051FF0042FF0042FF0042FF0042FF0042FF0033FF00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51FF0051FF0051FF0051FF0051FF0042FF0042FF0042FF0042FF0042FF0042FF0033FF00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51FF0051FF0042FF0051FF0051FF0042FF0042FF0042FF0042FF0042FF0042FF0033FF00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51FF0051FF0051FF0051FF0051FF0051FF0042FF0042FF0042FF0042FF0042FF0033FF00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51FF0051FF0051FF0051FF0051FF0051FF0042FF0042FF0042FF0042FF0042FF0042FF00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51FF0051FF0051FF0051FF0051FF0051FF0042FF0042FF0042FF0042FF0042FF0042FF00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51FF0051FF0051FF0051FF0051FF0051FF0051FF0042FF0042FF0042FF0042FF0042FF00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51FF0051FF0051FF0051FF0051FF0051FF0042FF0042FF0042FF0042FF0042FF0042FF00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51FF0051FF0051FF0051FF0051FF0051FF0051FF0042FF0042FF0042FF0042FF0033FF00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51FF0051FF0051FF0051FF0051FF0051FF0051FF0042FF0042FF0042FF0042FF0042FF00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51FF0051FF0051FF0051FF0051FF0051FF0042FF0042FF0042FF0042FF0042FF0042FF00
42FF0033FF0033FF0033FF0023FF0023FF0014FF0014FF0005FF0005FF0000FF0A00FF0A
00FF1900FF2800FF4700FF5700FF94AE00FF00FF9400FF6600FF5700FF4700FF4700FF47
00FF4700FF5700FF5700FFA300FF9400FF7500FF7500FF8500B3FF0028FF0500FF00FFE1
00FFA300FF9400FF9400FFC200FFD100FF8500FF9400FF7500FF4700FF2800FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF2800FF4700FF7500FFB300FFB300FF8500FF38
00FF1900FF0A00FF0A05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0005FF0014FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0000FF0A
00FF0A00FF0A00FF0A00FF0A00FF1900FF1900FF1900FF2800FF2800FF2800FF3800FF47
00FF4700FF5700FF6600FF6600FF7500FFA30038FF0028FF00F0FF0047FF00FFA300FF75
00FF6600FF5700FF5700FF4700FF4700FF3800FF3800FF3800FF2800FF2800FF1900FF19
00FF1900FF1900FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A05FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0000FF0A05FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0000FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF1900FF0A00FF0A00FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF38
00FF3800FF4700FF4700FF5700FF850075FF00A3FF00FFB300FFF000F0FF00E1FF00FFF0
00B3FF0075FF0057FF00A3FF00E1FF00FFE100FFD100FFE100FFFF00F0FF00B3FF00B3FF
0066FF5100FF4200FF0047FF0075FF0075FF0085FF8000FF0038FF0094FF0038FF00E1FF
00FFE100FFC200FFB300FFA300FF9400FF8500FF7500FF6600FF6600FF5700FF5700FF47
00FF4700FF3800FF3800FF3800FF3800FF2800FF2800FF2800FF2800FF2800FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0000FF0A00FF0A00FF1900FF6600FFE100FF6600FF3800FF28
00FF1900FF1900FF1900FF1900FF1900FF1900FF2800FF2800FF3800FF4700FF5700FF66
00FF7500FF9400F0FF00E1FF0075FF0066FF00B3FF00FFE100FF9400FF7500FF6600FF57
00FF4700FF3800FF3800FF2800FF2800FF2800FF2800FF2800FF3800FF4700FFC20094FF
1400FF00FF7500FF2800FF1900FF0A05FF0014FF0014FF0014FF0023FF0023FF0023FF00
33FF0033FF0033FF0042FF0042FF0042FF0042FF0051FF0051FF0051FF0051FF0051FF00
51FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF00
61FF0061FF0061FF0061FF0061FF0070FF0070FF0070FF0070FF0070FF0070FF0070FF00
70FF0070FF0070FF0070FF0070FF0070FF0070FF0070FF00
51FF0051FF0051FF0051FF0051FF0051FF0051FF0042FF0042FF0042FF0042FF0042FF00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51FF0051FF0051FF0051FF0051FF0051FF0051FF0042FF0042FF0042FF0042FF0042FF00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51FF0051FF0051FF0051FF0051FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00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51FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0042FF0042FF0042FF0033FF00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51FF0051FF0051FF0051FF0051FF0051FF0051FF0042FF0042FF0042FF0042FF0042FF00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51FF0051FF0051FF0051FF0051FF0051FF0051FF0042FF0042FF0042FF0042FF0042FF00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51FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0042FF0042FF0042FF0042FF00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51FF0051FF0051FF0051FF0051FF0051FF0051FF0042FF0042FF0042FF0042FF0042FF00
33FF0033FF0033FF0033FF0023FF0014FF0014FF0005FF0000FF0A00FF0A00FF1900FF19
00FF1900FF1900FF2800FF2800FF3800FF4700FF7500FFA300FFA300FFD100C2FF8F00FF
0057FF0047FFFF000000D1FF0075FF0094FF00E1FF00FFD100FFA300FFA30066FF00FF85
00FF4700FF3800FF2800FF1900FF1900FF1900FF0A00FF0A05FF0005FF0005FF0005FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0014FF0023FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0005FF0005FF0005FF0000FF0A
00FF0A00FF1900FF1900FF1900FF2800FF3800FF4700FF3800FF3800FF4700FF4700FF47
00FF5700FF5700FF6600FF7500FF8500FFA3FF00F50075FF00B3FF00FFB300FF9400FF85
00FF7500FF6600FF5700FF4700FF4700FF3800FF3800FF3800FF2800FF2800FF2800FF19
00FF1900FF1900FF0A00FF0A00FF0A00FF0A00FF0A05FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0000FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF2800FF1900FF2800FF2800FF2800FF2800FF28
00FF3800FF3800FF3800FF3800FF3800FF4700FF4700FF5700FF5700FF6600FF8500FFA3
00E1FFFF00000094FF00FFC200FFB300FFA300FFA300FFA300FFA300FFB300FFC200FFD1
00FFF000FFFF00B3FF3300FF00E1FF00FFF000FFD100FFC200FFB300FFA300FF9400FF94
00FF9400FF8500FF8500FF8500FF8500FF8500FF8500FF7500FF6600FF6600FF5700FF57
00FF4700FF4700FF4700FF3800FF3800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF0A00FF0A00FF0A00FF1900FF0A
00FF0A00FF0A00FF0A00FF0A05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0014FF0023FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0005FF0005FF0005FF0005FF0005FF0005FF0000FF0A00FF0A00FF0A00FF1900FF19
00FF1900FF2800FF2800FF3800FF3800FF4700FF6600FF9400FFA300FFC200E1FF4200FF
0075FF0057FF00FFFF00FFE100FFC200FFC200E1FF00A3FF00FFFF00FFB300FFA300FF57
00FF5700FF4700FF3800FF3800FF4700FF2800FF1900FF1900FF1900FF2805FF0014FF00
23FF0023FF0033FF0033FF0042FF0042FF0042FF0042FF0051FF0042FF0051FF0051FF00
51FF0051FF0051FF0061FF0051FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF00
70FF0070FF0070FF0070FF0070FF0070FF0070FF0070FF0070FF0070FF0070FF0070FF00
70FF0070FF0070FF0070FF0070FF0070FF0070FF0080FF00
51FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0042FF0042FF0042FF0042FF00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51FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0042FF0042FF0042FF0042FF00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51FF0051FF0051FF0051FF0051FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00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51FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0042FF0042FF0042FF0042FF00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51FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0042FF0042FF0042FF0042FF00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51FF0051FF0051FF0051FF0051FF0051FF0042FF0042FF0042FF0042FF0042FF0042FF00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51FF0051FF0051FF0051FF0051FF0051FF0051FF0042FF0042FF0042FF0042FF0042FF00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51FF0051FF0051FF0051FF0042FF0051FF0051FF0042FF0042FF0042FF0042FF0042FF00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51FF0051FF0051FF0051FF0051FF0051FF0042FF0042FF0042FF0042FF0042FF0042FF00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51FF0051FF0051FF0051FF0051FF0051FF0051FF0042FF0042FF0042FF0042FF0042FF00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51FF0051FF0051FF0051FF0051FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00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51FF0051FF0051FF0051FF0051FF0051FF0042FF0042FF0042FF0042FF0042FF0033FF00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51FF0051FF0051FF0051FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0033FF00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51FF0051FF0051FF0051FF0051FF0042FF0042FF0042FF0042FF0042FF0033FF0033FF00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51FF0051FF0051FF0051FF0042FF0042FF0042FF0042FF0042FF0033FF0033FF0033FF00
33FF0033FF0023FF0023FF0023FF0014FF0014FF0000FF0A00FF1900FF3800FF4700FF66
00FFD1FA00FF00F0FF00FFFF00FF7500FF5700FF3800FF1900FF0A05FF0005FF0005FF00
05FF0005FF0005FF0005FF0000FF0A00FF1900FF3800FF5700FFD100FF7500FF7500FF28
05FF0014FF0014FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0033FF0033FF00
33FF0033FF0033FF0033FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
42FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0014FF0014FF0014FF0014FF0014FF0014FF00
05FF0005FF0005FF0000FF0A00FF0A00FF0A00FF1900FF1900FF2800FF2800FF3800FF38
00FF4700FF855100FF00FFFF00FFD100A3FF00FFFF00FFB300FFA300FF7500FF5700FF57
00FF4700FF4700FF5700FF5700FF6600FF8500FFF0CC00FF00FF9400FF5700FF3800FF19
00FF0A00FF0A05FF0005FF0005FF0005FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0023FF0023FF0023FF0014FF0023FF0023FF0023FF0023FF0014FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0014FF0023FF0023FF0023FF00
23FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0000FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF4700FF4700FF4700FF4700FF4700FF57
00FF5700FF5700FF6600FF6600FF8500FFE100C2FF5100FF00FFFF00FFE100FFD100FFD1
00FFD100FFD100FFF000E1FF00C2FFFF00A800B3FF000AFF00FFFF00FFF000FFE100FFF0
00C2FF0094FF00FFD100FFB300FFA300FF9400FF9400FF9400FF8500FF7500FF6600FF66
00FF5700FF5700FF5700FF5700FF5700FF4700FF4700FF4700FF4700FF4700FF5700FF57
00FF5700FF6600FF6600FF6600FF6600FF6600FF7500FF8500FFA300FFF000FFD100FF94
00FF8500FF7500FF8500FFD100FF7500FF7500D1FF00FF5700FF3800FF1900FF0A00FF0A
05FF0005FF0014FF0014FF0014FF0014FF0014FF0014FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0033FF0033FF0033FF00
33FF0023FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0023FF0023FF0023FF00
23FF0023FF0014FF0014FF0014FF0005FF0005FF0000FF190094FF000AFF00FF7500FF66
00FFA300D1FF00FF7500FF5700FF9400FF2800FF2800FF1900FF2800FF3800FFA300FFF0
0038FF00FFB300FF4700FF1900FF1900FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF1900FF1900FF2800FF4700FF6600FFA300C2FF00C2FF00A3FF00FF7500FF4700FF28
00FF1900FF0A05FF0005FF0014FF0014FF0014FF0014FF0000FF0A00FFE100FF2800FFC2
05FF0014FF0005FF0000FF7523FF0042FF0051FF0051FF0061FF0061FF0061FF0061FF00
61FF0070FF0070FF0070FF0070FF0070FF0070FF0070FF0070FF0070FF0070FF0070FF00
70FF0070FF0070FF0070FF0080FF0080FF0080FF0080FF00
51FF0051FF0042FF0051FF0042FF0042FF0042FF0042FF0033FF0033FF0033FF0033FF00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51FF0051FF0051FF0042FF0042FF0042FF0042FF0033FF0033FF0033FF0033FF0033FF00
23FF0023FF0023FF0023FF0014FF0014FF0005FF0005FF0000FF0A00FF1900FF3800FFE1
0057FF00FF7500FF6600FF7500FF9400FF4700FF4700FF8505FF0005FF0014FF0014FF00
14FF0014FF0014FF0014FF0005FF0000FF0A00FF2800FFFF00FF8500FF8500FF38FF0000
14FF0023FF0023FF0023FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0042FF00
33FF0042FF0033FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
42FF0033FF0042FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
23FF0023FF0023FF0023FF0023FF0023FF0014FF0014FF0014FF0014FF0014FF0014FF00
05FF0000FF0A05FF0000FF0A00FF0A00FF0A00FF0A00FF1900FF1900FF2800FF3800FF38
00FF4700FF575100FF00FFB300FFE100B3FF00FFD10028FF00FF9400FF6600FF4700FF47
00FF3800FF3800FF3800FF3800FF4700FF5700FF4700FF4700FF4700D1FF00FF4700FF19
00FF0A05FF0005FF0005FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0023FF0023FF0023FF0023FF0014FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0000FF0A00FF0A00FF0A00FF0A00FF1900FF0A00FF1900FF1900FF1900FF1900FF19
00FF2800FF1900FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF4700FF4700FF4700FF4700FF4700FF5700FF57
00FF5700FF5700FF6600FF6600FF7500FF8500FFA300FFB300A3FF00C2FF00A3FF00B3FF
00FFF000FFF000E1FF000AFF0038FFFF00D70500FF0085FF00C2FF00E1FF00D1FF00D1FF
0028FF00F0FF00FFFF00D1FF00F0FF00D1FF1400FF00FFD100FFA300FF8500FF7500FF66
00FF6600FF6600FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF6600FF7500FF85
00FF8500FFF000FFE100FF8500FF8500FF94FF000000FFB32300FF00B3FFFF003D8000FF
00B3FF00E1FF00FFA300FFF000FF7500FF6600FFB300FFA300F0FF00FF3800FF1900FF0A
05FF0005FF0005FF0014FF0014FF0014FF0014FF0014FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0023FF0023FF00
23FF0023FF0023FF0014FF0014FF0014FF0005FF0000FF1900A3FF00FFC200FF9400E1FF
00FFF000FF7500FF4700FF2800FF1900FF0A00FF0A00FF0A00FF0A00FF1900FF2800FF57
00FFD100FF8500FF5700FF2800FF0A05FF0005FF0005FF0005FF0005FF0005FF0005FF00
00FF0A00FF1900FF6600FF8500FFA300FF9400FF7500FF5700FF7500D1FF0028FF00FF85
00FFA300FF7500FF1900FF0A00FF0A00FF2800FF6600FF3800FF5700FF7500FFFF3300FF
00FF9400FF7500FF2800C2FF00FF2833FF0042FF0051FF0051FF0061FF0061FF0061FF00
61FF0070FF0070FF0070FF0070FF0070FF0070FF0070FF0070FF0070FF0070FF0080FF00
80FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF00
51FF0051FF0042FF0042FF0042FF0033FF0033FF0033FF0033FF0033FF0023FF0023FF00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51FF0042FF0042FF0042FF0042FF0033FF0023FF0014FF0023FF0023FF0023FF0023FF00
23FF0014FF0014FF0014FF0005FF0005FF0000FF0A00FF0A00FF2800FF7500FF9400FFD1
00FF5700FF3800FF2800FF3800FFD100FF4705FF0014FF0014FF0014FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0014FF0014FF0005FF0000FF190094FF00FF1905FF00
23FF0023FF0033FF0033FF0033FF0033FF0042FF0042FF0042FF0042FF0042FF0042FF00
42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
42FF0042FF0042FF0042FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0023FF0023FF0023FF0023FF0023FF0014FF0014FF0014FF0014FF0014FF0005FF00
05FF0005FF0005FF0005FF0000FF0A00FF0A00FF0A00FF1900FF2800FF2800FF3800FF47
00FF5700FF6600FF7500FFB300FFE100FFE100FF9400FF7500FF6600FF5700FF4700FF38
00FF3800FF2800FF2800FF2800FF2800FF1900FF1900FF1900FF1900FF2800FF3800FF0A
05FF0005FF0005FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0000FF0A00FF0A00FF0A00FF0A00FF1900FF1900FF2800FF1900FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF3800FF3800FF3800FF3800FF3800FF4700FF38
00FF3800FF3800FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF5700FF5700FF57
00FF5700FF6600FF6600FF7500FF7500FF9400FFA300FFB300FFC200FFE100F0FF2300FF
2300FF000AFF00A3FFFF007A0047FF3300FF5100FF0019FF2300FF0028FF0094FF00C2FF
00F0FF00F0FF00F0FF00FFFF00FFFF00FFD100FFC200FFA300FF9400FF8500FF7500FF75
00FF7500FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7500FF8500FFC2
00E1FF0075FF00FFE100FFD10028FF00A3FF0066FF00FFFF00FFD100FFF00019FF00FFD1
00FF9400FF6600FF5700FF4700FF3800FF3800FF3800FF7500FF4700FF5700FF4700FF0A
05FF0005FF0014FF0014FF0014FF0014FF0014FF0014FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0042FF0042FF0042FF0033FF0033FF0033FF0042FF0042FF0042FF0042FF0042FF00
33FF0033FF0042FF0042FF0042FF0042FF0033FF0033FF0042FF0042FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0023FF00
23FF0023FF0023FF0023FF0014FF0014FF0005FF0000FF0A00FF1900FF4700FFD100FF94
00FF6600FFA300FF2800FF0A05FF0005FF0005FF0005FF0005FF0000FF0A00FF1900FF57
00FF7500FFA300FF5700FF3805FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
05FF0000FF2800C2FF00FF1900FF1900FF2800FF6600FF1900FF1900FF2800FFC200FFFF
00FF850075FF00FF6600FF476100FF00FFFF00F0FF00FF7500FF3800FF3800FFB300FF57
00FF0A23FF0023FF0023FF0023FF0014FF0042FF0051FF0061FF0061FF0061FF0061FF00
70FF0070FF0070FF0070FF0070FF0070FF0070FF0070FF0070FF0070FF0070FF0080FF00
80FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF00
51FF0042FF0042FF0042FF0033FF0033FF0014FF0000FF6605FF0014FF0014FF0014FF00
14FF0005FF0005FF0000FF0A05FF0000FF0A00FF0A00FF1900FF2800FF750075FF00FFFF
00FFA300FF1900FF1900FF1900FF1900FF4705FF0014FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0014FF0005FF0000FF1900FF7500FF8500E1FF
23FF0033FF0033FF0033FF0033FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
42FF0042FF0042FF0042FF0042FF0042FF0033FF0033FF0033FF0033FF0033FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0014FF0014FF0014FF0014FF0005FF00
05FF0005FF0005FF0000FF0A00FF0A00FF0A00FF1900FF1900FF2800FF4700FF6600FF66
00FF6600FF6600FF8500C2FF2300FF0094FF00FFA300FF7500FF6600FF4700FF3800FF38
00FF2800FF2800FF2800FF1900FF1900FF1900FF1900FF1900FF1900FF0A00FF0A00FF0A
05FF0005FF0005FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
00FF0A00FF0A00FF0A00FF1900FF1900FF2800FF1900FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF3800FF3800FF3800FF3800FF3800FF3800FF4700FF47
00FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF5700FF5700FF5700FF57
00FF5700FF6600FF7500FF7500FF9400FFA300FFC200FFF000F0FF00E1FF0038FF00C2FF
00B3FF0047FF0057FF5100FF7000FF9E00FFFF00B80019FF0066FF1400FF00D1FF00F0FF
00FFFF00FFF000FFE100FFD100FFD100FFB300FFA300FF9400FF8500FF8500FF8500FF75
00FF7500FF6600FF6600FF6600FF6600FF6600FF6600FF7500FF7500FF8500FF9400FFA3
00FFD100E1FF00A3FF0066FF00D1FF00FFD100FFE100FFC200FF9400FF9400FFD100FFC2
00FFFF00FFC200FF4700FF3800FF2800FF2800FF2800FF2800FF2800FF2800FFA300FF0A
05FF0005FF0014FF0014FF0014FF0014FF0014FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0033FF0033FF0033FF0033FF0023FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0042FF0042FF0042FF0042FF0033FF0033FF0042FF0042FF0042FF0042FF0042FF00
33FF0042FF0042FF0042FF0042FF0042FF0033FF0042FF0042FF0042FF0042FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
23FF0023FF0023FF0023FF0014FF0014FF0005FF0000FF0A00FF2800FFF000FFD100FF47
00FF3800FFB300FF0A05FF0014FF0014FF0014FF0014FF0014FF0005FF0005FF0000FF19
00FF3800FFFF00FF2800FF0A05FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0005FF0005FF0005FF0005FF0000FF0A00FF1900FF0A00FF0A00FF1900FF1900FF38
00FF3800FF6600FFF0AE00FF00FF8500FF4700FF6600FF3800FF0A00FF0A00FFE105FF00
23FF0033FF0033FF0033FF0042FF0042FF0051FF0051FF0061FF0061FF0061FF0061FF00
61FF0070FF0070FF0070FF0070FF0070FF0070FF0070FF0070FF0070FF0070FF0070FF00
80FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF00
51FF0042FF0042FF0033FF0033FF0023FF0005FF001400FF00FF2805FF0005FF0005FF00
05FF0000FF0A00FF3800FF2800FF1900FF1900FF1900FF2800FF3800FF9400FF9400FF85
00FF3800FF0A00FF0A05FF0005FF0005FF0014FF0023FF0023FF0023FF0033FF0033FF00
33FF0023FF0023FF0023FF0023FF0023FF0023FF0014FF0000FF5700FF2814FF0023FF00
23FF0033FF0033FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
42FF0042FF0042FF0042FF0042FF0042FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0023FF0023FF0023FF0023FF0023FF0014FF0014FF0014FF0014FF0014FF0005FF00
05FF0005FF0005FF0000FF0A00FF0A00FF0A00FF1900FF1900FF2800FF4700FFA300F0FF
00FF9400FF8500FF9400FFB30085FF00FFD100FFA300FF7500FF6600FF4700FF3800FF38
00FF2800FF2800FF1900FF1900FF1900FF1900FF1900FF0A00FF0A00FF0A05FF0005FF00
05FF0005FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
00FF0A00FF0A00FF0A00FF0A00FF1900FF1900FF280038FF00FF3800FF3800FF3800FF28
00FF2800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF4700FF4700FF4700FF47
00FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF5700FF5700FF5700FF5700FF57
00FF6600FF6600FF6600FF7500FF9400C2FF0028FF000AFF2300FF00B3FF00D1FF00FFFF
00F0FF00D1FF00B3FF0075FF0066FF0019FF8F00FF0019FF0075FF00B3FF00D1FF00F0FF
00FFF000FFE100FFD100FFC200FFC200FFB300FFA300FF9400FF9400FF8500FF8500FF85
00FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF8500FF9400FF9400FFA32300FF
00FFE1FF00A81400FF000AFF00FFC200FF9400FF9400FF7500FF7500FF850057FF00FFA3
00FF6600FF5700FF3800FF2800FF2800FF1900FF1900FF1900FF1900FF0A00FF0A05FF00
05FF0005FF0014FF0014FF0014FF0014FF0014FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
42FF0042FF0042FF0042FF0042FF0042FF0033FF0042FF0042FF0042FF0042FF0042FF00
33FF0042FF0042FF0042FF0042FF0042FF0033FF0042FF0042FF0042FF0042FF0033FF00
42FF0042FF0042FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0023FF00
33FF0023FF0023FF0023FF0014FF0014FF0005FF0000FF0A00FF2800FF7500FF9400FF28
00FF0A00FF0A05FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0005FF0000FF0A
00FF2800D1FF00FF2805FF0014FF0014FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0014FF0014FF0014FF0014FF0014FF0005FF0005FF0005FF0005FF0000FF0A00FF0A
00FF1900FF3800FF9400FF5700FF2800FF1900FF1905FF0005FF0005FF0005FF0023FF00
33FF0033FF0042FF0042FF0042FF0051FF0051FF0051FF0061FF0061FF0061FF0061FF00
70FF0070FF0061FF0070FF0070FF0070FF0070FF0070FF0070FF0070FF0070FF0070FF00
70FF0070FF0080FF0080FF0080FF0080FF0080FF0080FF00
42FF0042FF0042FF0033FF0033FF0023FF0005FF0000FF9400FF4700FF1900FF0A00FF0A
00FF1900FFD100FFA300FF4700FF3800FF5700FF5700FF4700FF5700FFD100FF4700FF38
00FF1900FF0A05FF0014FF0014FF0014FF0023FF0023FF0023FF0033FF0023FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0023FF0023FF0000B3FF14FF0023FF0033FF00
33FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
42FF0042FF0042FF0042FF0042FF0051FF0042FF0042FF0051FF0051FF0042FF0042FF00
42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
42FF0042FF0042FF0042FF0042FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
23FF0023FF0023FF0023FF0023FF0014FF0014FF0014FF0014FF0014FF0005FF0005FF00
05FF0005FF0000FF0A00FF0A00FF0A00FF1900FF1900FF1900FF2800FF3800FF5700FF94
8000FF00FFB300FFB300A3FF6100FF00A3FF00FF9400FF8500FF7500FF6600FF4700FF38
00FF2800FF1900FF1900FF1900FF0A00FF0A00FF0A00FF0A00FF0A05FF0005FF0005FF00
05FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0014FF0023FF0023FF0023FF0023FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0000FF0A
00FF0A00FF0A00FF0A00FF1900FF1900FF2800FF380047FF00FF5700FF4700FF3800FF38
00FF3800FF3800FF3800FF3800FF4700FF3800FF4700FF4700FF4700FF5700FF5700FF57
00FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF66
00FF6600FF6600FF7500FF7500FF8500FFB30075FF00D1FF00FFF000FFF000FFE100FFF0
00FFFF00E1FF00C2FF00A3FF0066FF5100FFFF006B1400FF0047FF0094FF0057FF00B3FF
00FFF000FFE100FFD100FFC200FFC200FFB300FFA300FF9400FF9400FF8500FF8500FF85
00FF8500FF7500FF7500FF7500FF7500FF7500FF8500FF940066FF00FFC200FFC200C2FF
5100FF00D1FF00F0FF00F0FF00FFD100FF9400FF7500FF6600FF6600FF6600FFA300FFE1
00FF5700FF3800FF2800FF2800FF1900FF1900FF1900FF0A00FF0A00FF0A00FF0A05FF00
05FF0014FF0014FF0014FF0014FF0014FF0014FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0042FF0042FF0042FF0042FF0033FF0033FF00
42FF0042FF0042FF0042FF0042FF0042FF0033FF0042FF0042FF0042FF0042FF0042FF00
42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
42FF0042FF0042FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0023FF0023FF0023FF0014FF0005FF0000FF1900FF2800FF4700FFD100FF3800FF0A
05FF0014FF0014FF0014FF0023FF0023FF0023FF0023FF0023FF0023FF0014FF0005FF00
00FFB300FF2800FF2805FF0014FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0014FF0014FF0014FF0014FF0014FF0005FF0005FF0000FF0A
00FF1900FF3800FFF000FF5700FF2800FF0A05FF0014FF0014FF0023FF0023FF0033FF00
33FF0042FF0042FF0042FF0051FF0051FF0051FF0061FF0061FF0061FF0061FF0061FF00
70FF0070FF0070FF0070FF0070FF0070FF0070FF0070FF0070FF0070FF0080FF0080FF00
80FF0080FF0080FF0070FF0080FF0080FF0080FF0080FF00
42FF0042FF0033FF0033FF0023FF0005FF0000FF0A00FF3800FF9400FF2800FF1900FF28
00FF2800FF574200FF00FF8500FFF000D1FF00FFE10019FF00F0FF00FF6600FF3800FF19
00FF0A05FF0014FF0014FF0014FF0023FF0023FF0023FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0023FF0033FF0033FF0033FF00
33FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0051FF00
42FF0051FF0051FF0051FF0051FF0051FF0051FF0042FF0051FF0051FF0051FF0042FF00
51FF0051FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
42FF0042FF0042FF0042FF0042FF0042FF0042FF0033FF0033FF0033FF0033FF0033FF00
33FF0023FF0023FF0023FF0014FF0014FF0014FF0014FF0014FF0005FF0005FF0005FF00
05FF0000FF0A00FF0A00FF0A00FF0A00FF1900FF1900FF2800FF2800FF3800FF5700FF85
00FFB300FFF000FFF000D1FFCC00FF00FFFF00FFB300FFD100A3FF00E1FF00FF5700FF38
00FF2800FF1900FF1900FF0A00FF0A00FF0A00FF0A00FF0A05FF0005FF0005FF0005FF00
05FF0014FF0014FF0014FF0014FF0014FF0014FF0023FF0023FF0023FF0014FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0014FF0023FF0023FF0023FF0023FF0023FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0005FF0005FF0005FF0005FF0005FF0005FF0000FF0A
00FF0A00FF0A00FF0A00FF1900FF1900FF2800FFD100FFF000FF7500FF5700FF4700FF47
00FF3800FF3800FF4700FF4700FF4700FF4700FF4700FF5700FF6600FFA300FF7500FF66
00FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF6600FF66
00FF6600FF6600FF7500FF7500FF8500FF9400FFA300FFB300FFC200FFD100FFD100FFE1
00FFF000D1FF0075FF0085FF0066FF000AFFAE00FF5100FF0500FF0019FF0094FF00E1FF
00FFFF00FFF000FFD100FFC200FFC200FFB300FFB300FFA300FF9400FF9400FF9400FF85
00FF8500FF8500FF8500FF8500FF8500FF8500FF9400D1FF00FFF000FFFF0085FF0057FF
00E1FF00FFC200FFD100FFFF00FFC200FFD100FF6600FF5700FF5700FF5700FF6600E1FF
00FF5700FF2800FF2800FF1900FF1900FF0A00FF0A00FF0A00FF0A05FF0000FF0A05FF00
05FF0014FF0014FF0014FF0014FF0014FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0042FF0042FF0042FF0042FF0042FF0033FF00
42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
42FF0042FF0042FF0042FF0042FF0042FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0023FF0023FF0023FF0014FF0005FF0000FF3800FF9400FFB300FF4700FF6600FF0A
14FF0014FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0014FF0005FF00
0019FF05FF0014FF0014FF0023FF0023FF0023FF0023FF0033FF0033FF0033FF0033FF00
23FF0023FF0023FF0023FF0023FF0023FF0014FF0014FF0014FF0014FF0005FF0000FF0A
00FF1900FF4700FFD100F0FF00FF2800FF0A05FF0014FF0023FF0023FF0033FF0033FF00
42FF0042FF0042FF0051FF0051FF0051FF0051FF0061FF0061FF0061FF0061FF0061FF00
61FF0070FF0070FF0070FF0070FF0070FF0070FF0070FF0070FF0080FF0080FF0080FF00
80FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF00
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQ
ooooo`007_ooool2o`0000Cooooo00?o0000ooooooooool00_ooool3o`0000?ooooo0ol0000Ioooo
o`;o00001?ooool00ol0003oooooooooo`02ooooo`?o00001?ooool2o`0000?ooooo0ol0000Eoooo
o`;o00001?ooool00ol0003oooooooooo`02ooooo`?o00001?ooool2o`0000?ooooo0ol0000Foooo
o`;o00001?ooool00ol0003oooooooooo`02ooooo`?o00001?ooool2o`0000Cooooo0ol0000Doooo
o`;o00001?ooool00ol0003oooooooooo`02ooooo`?o00001?ooool2o`0000;ooooo1Ol0000Koooo
o`;o00001?ooool00ol0003oooooooooo`02ooooo`?o00000oooool001gooooo00Co0000oooooooo
oooo00002Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01Oooooo00Co0000oooo
oooooooo00002Oooool00ol0003oooooooooo`02ooooo`06o`000?ooooooooooo`000?oooooo0000
0oooool00ol0003oooooooooo`0Aooooo`04o`000?ooooooooooo`0000Wooooo00?o0000oooooooo
ool00_ooool01_l0003oooooooooool0003oooooo`0000?ooooo00?o0000ooooooooool04_ooool0
1?l0003oooooooooool00009ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo0000
1?ooool00ol0003oooooooooo`0Booooo`04o`000?ooooooooooo`0000Wooooo00?o0000oooooooo
ool00_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0001[ooooo00Co0000
oooooooooooo00002Oooool00ol0003oooooooooo`02ooooo`005_ooool5o`0000;ooooo00Co0000
oooooooooooo00002Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo013ooooo1Ol0
0002ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool00_ooool01_l0003ooooo
ooooool0003oooooo`0000?ooooo00?o0000ooooooooool02_ooool5o`0000;ooooo00Co0000oooo
oooooooo00002Oooool00ol0003oooooooooo`02ooooo`06o`000?ooooooooooo`000?oooooo0000
0oooool00ol0003oooooooooo`0;ooooo`Go00000_ooool01?l0003oooooooooool00009ooooo`03
o`000?oooooooooo00;ooooo00Go0000oooooooooooo0000ooooo`05o`0000cooooo1Ol00002oooo
o`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0
0003ooooo`03o`000?oooooooooo01?ooooo1Ol00002ooooo`04o`000?ooooooooooo`0000Wooooo
00?o0000ooooooooool00_ooool001gooooo00Co0000oooooooooooo00002Oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo01Oooooo00Co0000oooooooooooo00002Oooool00ol0003o
ooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo0ol0000Dooooo`04o`000?oooooooooo
o`0000Wooooo00?o0000ooooooooool00_ooool01Ol0003oooooooooool0003ooooo00Co00005Ooo
ool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo00;ooooo00Ko0000oooooooooooo
0000ooooool00002ooooo`03o`000?oooooooooo01;ooooo00Co0000oooooooooooo00002Oooool0
0ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool06Ooo
ool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo00;ooooo000Mooooo`04o`000?oo
ooooooooo`0000Wooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Gooooo`04o`00
0?ooooooooooo`0000Wooooo00?o0000ooooooooool00_ooool01_l0003oooooooooool0003ooooo
o`0000?ooooo00?o0000ooooooooool04Oooool01?l0003oooooooooool00009ooooo`03o`000?oo
oooooooo00;ooooo00Ko0000oooooooooooo0000ooooool0000Hooooo`04o`000?ooooooooooo`00
00Wooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooo
000001Cooooo00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`02ooooo`06o`000?oo
ooooooooo`000?oooooo00000oooool00ol0003oooooooooo`0Hooooo`04o`000?ooooooooooo`00
00Wooooo00?o0000ooooooooool00_ooool001gooooo00Co0000oooooooooooo00002?ooool2o`00
00Cooooo0_l0000Iooooo`04o`000?ooooooooooo`0000Sooooo0_l00004ooooo`06o`000?oooooo
ooooo`000?oooooo00000oooool00ol0003oooooooooo`0Aooooo`04o`000?ooooooooooo`0000So
oooo0_l00004ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool05Oooool01?l0
003oooooooooool00008ooooo`;o00001?ooool01?l0003oooooooooool00003ooooo`;o00005?oo
ool01?l0003oooooooooool00008ooooo`;o00001?ooool01_l0003oooooooooool0003oooooo`00
00?ooooo00?o0000ooooooooool06?ooool01?l0003oooooooooool00008ooooo`;o00001?ooool0
01kooooo0_l0000:ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool06?ooool2o`00
00[ooooo00?o0000ooooooooool00oooool2o`0000?ooooo0ol0000Eooooo`;o00002_ooool00ol0
003oooooooooo`03ooooo`;o00001?ooool2o`0001Kooooo0_l0000:ooooo`03o`000?oooooooooo
00?ooooo0_l00005ooooo`03o`000?oooooooooo01?ooooo0_l0000:ooooo`03o`000?oooooooooo
00?ooooo0_l00003ooooo`?o00007?ooool2o`0000[ooooo00?o0000ooooooooool00_ooool00?oo
oooo8Oooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool0027ooooomol00008oooo
o`008Oooool01Ol0003ooooooooooooooooo000000_ooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool01Ol0
003ooooooooooooooooo000000Sooooo0008ooooo`;o00001?ooool00ol0003oooooooooo`02oooo
o`;o00000oooool5o`0000Cooooo00?o0000ooooooooool0loooool00ol0003oooooooooo`06oooo
o`001oooool01?l0003oooooooooool0000:ooooo`05o`000?ooooooooooooooool000000_ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo0??ooooo00?o0000ooooooooool01_ooool0
00Oooooo00Co0000oooooooooooo00002oooool01Ol0003ooooooooooooooooo000000Kooooo0_l0
003cooooo`;o00002?ooool000Oooooo00Co0000oooooooooooo00002?ooool4o`0000Cooooo00?o
0000ooooooooool00oooool03Ol0003oooooooooooooool0<ol003_o000oo`00@_l0043o0012o`00
?ol004;o000oo`001@12o`001P0mo`00@_l004;o0012o`00>ol003oo00<0@_l04@0co`000`0Wo`00
8ol002?o000402?o0003023o000So`006?l000<05?l001<01Ol000;o2@00obD00?n1003U[000dJl0
0<K:002Po`0E/O@00=WX00f3o`0SW^H00>Fg003oQ@00og80@<2Q003o^`00ofL00?mK00H00?mG0240
0?mS003oJP00ogX00?mm003oQ@00oiD00;3S002Xo000ol<00?ng003o/`00ol<00?CX003]o00EOol0
0:3o04Y<e@00`ol00;oo042B`000olX00?n_003oX`00oi`00?nH003oT@00ohX0@<1T003oKP00oel0
0?mG003oD`00od/00P00odL00`00od000?lk003o>002003o>0D00?lX00<00?lS003o6@00oaT00P00
oaT00`00oa800?l:003o2P02003o2P0300?o1@05o`001Ol000<01Ol000<03Ol001Co000Do`001P0D
o`0302?o0003023o000So`008ol001408ol01@0Do`001009o`001Ol000;o2000o`X2003o4P0>003o
6@00oa`00?lX003o=000of<00?n=003oX000^ol004Oo00EXo`00okL00=Ve003o?000obP3003o8@07
003o9@00ofL02L1j003o8@00hcd00>EN023o000203?o000303_o0012o`00@_l00080@_l000<0Col0
057o001Ao`001@1Ao`001@1Io`00DOl0067o001Qo`00GOl000`0HOl01?ooool00ol0003ooooooooo
o`06ooooo`001oooool01?l0003oooooooooool00007ooooo`07o`000?ooooooooooooooool0003o
ooooo`000003ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooooooo0`0co`000`0g
o`00?Ol003oo000204;o000403_o0012o`00@_l003oo00<0@_l000D0?ol004;o0012o`00@_l003Oo
000204;o000303oo000co`00<ol000l0<ol000<0;ol002?o000So`001@0So`000`0Po`005?l001Co
000201Co000A00Go0003o`<00?lB003o<000ogd00?o2003oS@00n;/00?mn003oS@00o<h00=C5003o
O@00of<00?mO003oI`00oe/00P00odl01@00odL00?m;003oA`00od/00?mC00800?mG02<00?mS003o
JP00ofX00?me003oR@00l=T00?o6003oY`00oj<00?nW003o/`00ol<00?SY003Fn000hOl0=C[o003B
o`00oo400?oI003o_`00oj/00?nP003oU000ohd00?n5003oN000og800?mV003oG`00oeL00?mC003o
B`00odL00?m4003o?003003o>003003o:000ob`00?lX00800?lX00<00?lU003o7000oaT00P00oaT0
0`00oa800?l>003o2P02003o2P0300?o1@05o`001Ol000<01Ol000<03Ol001Co000Do`001`0Do`02
02?o0003023o000Lo`008ol001008ol00P0Ho`0401Co000500Wo0005o`000ol5003o>@00oc000`00
ob403P00obH00?l/003o>000odl00?m^003//`00eO002Ikh003hf@00eMd00?m^003o<000ob400?lI
0`00oa801P00ob800?lB00?o1@0:o`004Ol002?o0080<ol01@12o`000`1Ao`00C_l0057o0007057o
000505ko001Eo`00HOl0067o001Mo`002P1Qo`04ooooo`03o`000?oooooooooo00Kooooo0007oooo
o`04o`000?ooooooooooo`0000Oooooo00Oo0000ooooooooooooooooo`000?oooooo000000?ooooo
00?o0000ooooooooool00_ooool01Ol0003oooooooooooooool0;ol000D0<ol000<0?ol004;o000g
o`000P12o`001@0ko`00?ol004;o000mo`00=ol00080@_l000<0>ol003?o000co`003`0co`0202oo
0080<ol000<0:ol002?o000So`001P0So`0401Co000@00Go0003o`<00?lB003o<@00hLH00?mZ003o
@000od`00?mC003oNP0QNO0009kF003oT@00oe/00?m?003oB`P00?m700T00?m;003oE`00oeL00?mK
003oIP00ofX00?mi003oU000ohd00P00oi@04`00oj000?n[003o^`00olX00?oQ003`o`00P?l06IWo
003ol000om400?nk003oZ`00oi`00?nD003oQ@00oh400?me003oJP00ofH00P00oeL01@00odl00?m7
003oA`00od@00?ll00800?lh00<00?l`003o;000obP00P00obP00`00obD00?lI003o6@03003o6@80
0?l>1000o`X00`04o`801Ol000Go000200Go000400Wo000Do`004Ol0017o00L05?l000<07?l001Co
000So`000P0So`00100Lo`008ol002?o000Po`0502?o000401ko000So`008ol001co00808?l01@0D
o`006P0=o`001Ol000?o1@00oa800?m400W0T000od@00?m0003o=000ocD00?lh003oA000of<00?mf
0230_`10H<000?c>003oR@00hLX00>1f003o9@00oaT00?l>003o2P02o`P01?l30P05o`00100Do`00
5ol0023o000Wo`0203?o000303oo0012o`00@_l00080@_l000<0AOl0057o001Ao`002@1Ao`0205go
000305Wo001Qo`00GOl000P0HOl01?ooool00ol0003oooooooooo`06ooooo`002?ooool2o`0000Wo
oooo0ol00003ooooo`?o00001Oooool01Ol0003oooooooooooooool0:ol000P0<ol000T0=ol003_o
000co`00=ol004;o000ho`00<ol003Oo000ko`003P0co`000`0_o`00<ol003?o000203?o000302oo
000So`008ol000L08ol000<08?l001So000Do`000`0Do`0200Go0003003o2P00o5l00?mC00<00?l`
00H00?m0003U/`00j:/00?n7003oU000od/2003oA0800?ll00@00?lh003o?000od000?m50`00odL0
1`00odl00?mG003oE`00oe/00?mV003oJP00ogP00P00ohD04P00oi400?nD003oX`00ok<00?o:003o
f@00^ol0AROo02Q`o`00b_`00?oM003obP00okl00?nL003oU000ohD00?mi003oL`800?mV0P00oeL0
1000od/00?m7003oA`00od03003o>003003o;000obP00?lX00800?lX00<00?lU003o7@00oaT00P00
oaT00`00oa800?l:003o2P03003o2P0300Co0`05o`001Ol000@01Ol000<02Ol001Co000Do`002@0D
o`00100Lo`008ol001ko000Lo`0202?o000501co000So`008ol002?o000Lo`000P0So`000`0Po`00
8ol001co000701Co00801Ol001H00ol5003o4P00ogH01L2T003daP00ojP00?m?003o@P00od@00?mC
003UX000hLX00>GQ003Ah@0=`:@00?mW003oH`00h6<00?lQ003o5P00o`X00_l80P05o`001P09o`00
5?l001Co000Qo`008ol002oo0080<ol000<0>ol003oo0012o`000P12o`000`15o`00DOl004ko000;
057o000805Go001Io`00EOl0067o001Io`00HOl005ko001Io`03067o00Cooooo00?o0000oooooooo
ool01_ooool0027ooooo00Ko0000oooooooooooooooo02?o000[o`0T03?o000302Wo000So`008ol0
00@08ol000@08Ol002?o000So`007?l0100Do`003@0:o`001Ol0007o2@00o`d00?lD003o5`00oa`0
0?lS003o;P00of/00?lk003o?@00od000P00ocP2003o=PD00?lh00D00?m0003oA`00odL00?m:003o
C@02003oE`0G003oG000ofH00?m`003oM@00oh000?n5003oU`00okD00>gA003oi000oo000>ko03YV
o013L?400<oo003`nP0QN_d00:k[003oZ`00oi@00?n5003oP000ogD00P00ofH00`00oeX00?mG003o
DP02003oA`04003o@P00ocP00?lh003o=PD00?lX00<00?lL003o6@00oaT00P00oaT00`00o`l00?l=
003o2P03003o2P03007o2@03o`<01Ol000@01Ol000@03Ol001Co000Do`003ol02@0Do`003P0Io`00
5?l001Wo000So`008Ol001Oo000Qo`008ol0027o000Go`008Ol001co000Do`005ol01P0Do`00700?
o`002_l000Go0005o`000Ol9003o4P00ob400?m/01K8`013ZZ800?2Y003oGP00oeX00?mY003o[P00
d_008eko00V_h`00l:400?mG003o@P00ob`00?lI003o4P00o`X00ol300Go000:o`0201Co000301co
000Qo`008ol000<0<ol000<0=_l003go0012o`001012o`000`1:o`00DOl004co000?057o000505?o
001Do`00E_l0057o001Fo`001?ooool00ol0003oooooooooo`06ooooo`008Oooool01?l0003ooooo
ooooooooool202?o000302Oo000co`00<ol001d0<ol000@0;_l002oo000co`00<ol0200So`000`0P
o`006?l001Co000401Co000400Wo0005o`001Ol000;o20800?l:00D00?l>003o6@00oaT00?lM003o
8@04003o:0800?l/0P00oc03003o>003003o?000od000?m700800?m700<00?mC003oE`00oeL00P00
ofH2003oM@0E003oQ@00oi400?C606ANgP10On80@:G?002co`1G3=D0K`?o04Poo`05J?l00<;o003h
k000gLh00?nP003oR@00ogd00?me003oJP00ofH00?mS00800?mG00H00?m;003oA`00od@00?ll003o
>000oc04003o:003003o7@00oaT00?lI00<00?lI00<00?l>003o2P00o`X00`00o`X00`03o`D01Ol0
00Go000600Go000300Wo000Do`005?l000l05?l000<07?l001Co000Do`002@0Do`00700Ao`005?l0
00Go0005o`000_l8003o2P00oaH00?lQ003o?000of<00<[M003`h@00oh000?mb003oS@00oj@02Foo
016Qn000c]H00?o3003oE`00oc`00?lX003o6@00oa800_l800Go0009o`0201Co000401So000Po`00
8ol002Oo00@0<ol02012o`001@1:o`00DOl004ko001Ao`00C_l00100DOl01?ooool00ol0003ooooo
ooooo`06ooooo`008Oooool01?l0003oooooooooooooool302?o000302Oo000co`00<ol001d0<ol0
3@0So`0601Co00<01Ol00`00o`X01@00o`h00?lF003o6@00oaT00?lN00800?lU1P00obP4003o>004
003oA000odL00?m7003oC`800?mG0P00ofH07000ogD00?mi003oQ@00oi400?nP003o``00o?00EEKe
04EFc`1A5MD0Q0[e00EIo`00f_l008Go01Uco`0PH?@00?nk003oT@00ohD00?mh003oM@00ofh00?mV
003oH`00oeL00?mC003oA`00od@2003o>003003o=000obP00?lX00800?lX00<00?lU003o7@00oaT0
0P00oaT00`00oaH00?l>003o2P04003o2P0400;o2003o`D01Ol000Co0`D01Ol07@0Do`000`0Ao`00
5?l000Go000200Go000H00;o2000o`h00?lI003o:000od000?mC003oNP00ZnP00?n[003oX00oT^P0
@<2Y032Io`00l=d00?nH003oMP00oe<00?m4003o<`00ob400?lB00?o1@05o`002Ol00P0Do`00100H
o`008ol002?o000So`0503?o000303oo0012o`00@_l000D0@_l000@0B_l004Ko001Ao`00C_l0101A
o`000`1:o`00DOl0057o0009057o00Cooooo00?o0000ooooooooool01_ooool0027ooooo00Go0000
oooooooooooooooo023o000302?o000302So000co`00;ol001P0<ol000@0;ol003?o000co`00<ol0
2P0So`000`0Po`008ol0023o000501Co0005017o0005o`001Ol000Co0`05o`000`00o`X00`00o`h0
0?lF003o6@02003o6@03003o7@00ob400?lX00<00?lX00<00?l/003o:000ocP00P00ocP01P00od00
0?m7003oA`00odl00?mG003oF`800?mV0P00ogD04`00ohD00?n=003oW000olh00W3o002To`00hOl0
3XSo06@g`00XT_l00?cl003ok@00omd00?o3003oY`00oi@00?n5003oPP00ogd00P00ogD2003oKP03
003oF`00od/00?m700800?lh00<00?ld003o:000obP00P00obP00`00oad00?lI003o6@02003o6@03
003o5P00o`X00?l:00D00?l:00<01?l200Go0005o`001@05o`000`09o`004Ol000go000E01Co0003
017o000Do`005?l000805?l001d04Ol000Wo0005o`001Ol000;o2000o`X00?lM003o:@00ocP00?m^
003oJ`00oi@06L3I002^j`00gND0G6ge041L`010Pl000?oB003o[`00ogH00?mS003oD`00of/00?mW
003o6P03o`D01Ol000go000201Co000401co000So`008ol002_o00D0<ol000<0@_l003oo0012o`00
2@12o`00101:o`00Aol004Ko001:o`0204Ko0080B_l00`16o`001@17o`00B_l004[o001:o`00A_l0
00Cooooo00?o0000ooooooooool01_ooool0027ooooo00Go0000oooooooooooooooo01So000402?o
000302_o000_o`00<ol00100<ol000<0<?l003?o000co`00100co`0202_o000303?o000`o`008ol0
00X08ol000<06?l001Co000Do`001@0Do`001@0:o`001Ol000Go0005o`001?l300800?l:00<00?l>
003o2P00oa801000oaT00`00ob400?lU003o:002003o:005003o;000oc000?lh003o>000oc`00P00
odL06000odl00?mG003oF`00ofH00?m[003oM@00ogT00?n5003oS@00oi`00>c2003oh@00onD00?oh
0032o`10;^X009co003`n000omd00?o:003o/`00oj<00?nH003oU0800?n=00L00?nL0430WP00oi@0
0?C6003oMP00oeL00?m700800?lh00<00?l`003o:000obP00P00obP2003o8@@00?lI00<00?lF003o
3P00o`X01000o`X:00Go000400oo000Do`005?l0017o01H05?l000P03Ol0017o0005o`001?l300Go
0002o`P00?lB003oD`800?n501@00?CF042d^000^nd00>SB003hbP00/oP0?QKo009Ao`00[?l00>7o
002Pk000oiP00?mf003oV000e]T03JV[003o=000o`X01Ol000go00805?l000D07?l002?o000So`00
8ol002oo000503?o000303oo0012o`00@?l00180@_l000<0?ol004;o0012o`000`12o`04ooooo`03
o`000?oooooooooo00Kooooo000Qooooo`06o`000?ooooooooooooooo`0Ho`008?l0100So`001@0W
o`00;ol002_o000co`00;ol00080<ol000<0;ol003?o000co`002`0co`001@0[o`00<ol003?o000c
o`00:ol000/08ol000@08?l002?o000So`008ol01P0Do`000`0Ao`001Ol000Go000200Go000300Co
0`02o`P00?l:00800?l:00<00?l>003o5000oaT00P00oaT00`00oad00?lI003o:003003o:004003o
;@00ocP00?lh003o?0800?m70P00oeL2003oIP0N003oL`00ogD00?n1003oQ@00oi400?nP003oZ`00
ok/00?o>003lk@0PI?l0V0>801aXo`05[Ol00?oI003obP00okL00?n[003oX`00oi`00?nI003oY000
j=800<[o003:m000`]T00?36003oIP00odL00?m00P00ocP01@00oc000?lX003o:000obP00?lM00D0
0?lI1`00o`X00`01o`P00_l800Go000700Go000300oo000Do`002Ol001805?l000H04Ol001Co000D
o`004Ol001Co000=o`0300Go000J00Co0P00o`X00?lB003o:@00oi`00<Zk0820e@00ojP00?nP003o
O@00oi800;Od002Ho`0;6?l0@C3C04DNo`0=ZOP00?no003oZ000X>400?N^003o?000oad00?l:00Go
0009o`0201Co0005023o000So`008ol002?o000[o`001@0co`0203Oo0140@_l000D0>ol003?o000[
o`00:ol003_o000304;o00Cooooo00?o0000ooooooooool01_ooool0027ooooo00Ko0000oooooooo
oooooooo01Co000Lo`0602?o000302Oo000[o`009ol00080<ol000<0:ol003?o000[o`001@0co`00
100_o`00<ol003?o000`o`0203?o000502_o000Wo`00<ol003?o000[o`00300So`000`0No`008ol0
023o000701Co000300[o0005o`001Ol000801Ol000<00ol5003o2P00o`X00P00o`X00`00o`l00?lI
003o6@04003o6@<00?lX00/00?l]003o>000ocP00?m4003oA`00od/00?mG003oH`00ofX00?mm003o
P002003oQ@0K003oS@00oi@00?nP003oZ`00ok/00?o>003oj@00g?l0ACO302R>o`00m?l00?o]003o
h@00olH00?ng003oZ`00oj<00?n`003hg@00__@0@8KZ002gm000ohd00?m^003oF`00odL00?m40080
0?lh00P00?l/003o:000ob`00?lX003o9@00oad00?lI003o70800?lI00<00?lF003o3P00o`X01@00
o`X;00Go000400go000Do`005?l0017o01805?l00P0=o`0400Go000700?o0`00o`X00?lB003o7@00
oc000?mG003XQ@02003oG`0A003oH`00oh800?SB003`l000k?`0@7C^024Ho`0TV_`0:8?l07YUm000
oj@00?mI003o<000oaT00?l:00Go000=o`000P0Do`001`0Lo`008ol002?o000So`00:ol003?o000_
o`001@0co`00100mo`00>ol004;o000oo`0704;o00<0>ol000P0=ol003?o000co`00:ol001?o:@07
ob004_lJ02oo00<0<ol01?ooool00ol0003oooooooooo`06ooooo`008Oooool2o`0000;ooooo0P0D
o`000`0Lo`008ol002?o000602?o00809ol000@0:ol0033o000[o`00<ol00P0_o`000`0co`00;ol0
02_o000203?o000502So000co`00<ol002_o000So`000P0Wo`0=02?o0003027o000Do`005?l000H0
5?l000<03Ol000So0005o`001005o`000`02o`P00?l:003o2P02003o2P03003o4P00oaT00?lI0080
0?lI00<00?lM003o9@00obP00P00obP2003o>00S003o@000od/00?mG003oH`00ofh00?n5002gdP00
ohl00?n=003oU000oiP00?nL003oX`00ojl00?o:003ok000oo`00=Co040go`0m7_l0=jGo003]o`00
[ol00?c/0036h@00okl00?nk003oc@00SOl0@8k0003/e@00b]d00?n1003oIP00oeL00P00odL2003o
>0800?l/0P00obP00`00obD00?lI003o6@03003o6@03003o5P00o`X00?l:00D00?l:0P03o`D00`04
o`<01Ol000Go000700Go000301Co000Ao`003Ol000805?l000@04Ol001Co000Do`004Ol01`0Do`00
1P0Ao`005?l001Co0009o`005?l000go00@01Ol001/01?l300?o1@00o`X00?l>003o6@00obD00?l/
003o?000od@00?m?003oF`00ofh00?nA003o^`00b_`08V7o03=oo000n>T00?nH003o``00U?l00?ND
003oD000obT00?lB00?o1@05o`000`0Do`001@0Po`008ol002?o000So`009ol000L0<ol000<0=ol0
03_o000ko`000P0oo`001@0ko`00@_l003Oo000ko`00=_l000@0<ol000P0;ol002Oo000Po`001ol=
003oIP0;o`<08ol002_o0080<ol00oooool2o`0000Sooooo000Qooooo`04o`000?oooooooooooooo
o`<05?l000<08?l0027o000So`002P0So`001P0[o`008ol002Oo000[o`009ol002?o0080;ol000<0
8ol002Oo000[o`003P0So`001@0Po`008ol002?o000So`007?l000P05?l000<02?l000Go0005o`00
0P05o`000`04o`<00_l8003o2P03003o2P03003o4P00oaT00?lI00<00?lI00L00?lM003o:000obP0
0?lX003o=000ocP00?m700800?mj00L00?mm003oR@00m=T07;CU003oZ`00ojl00>bn00800?nW01`0
0?n_003o]`00omH00:Co003:o`0EYol01C[o00E2o`00[ol00;oo00e`o`02K?l00>Gd003odP00olX0
:lKL002Io`00l?`00?n_003oS@00ogD00?mV003oE`00od/00?m7003o?@00ocP00?l`1000obP00`00
ob400?lI003o6@02003o6@03003o5P00o`h00?l>00H00?l:00<00ol500Go0005o`002P05o`001009
o`005?l001Co000=o`0;01Co000301;o000Do`001Ol000H01Ol000@01?l3007o2000o`X00?l>0P00
oaT05P00obP00?l`003o>000odL00?mC003oL`00oiD00=GI00e_o`00n>T00?o6003oU@00ogT00?mf
003X^`0>X^400>7U003oH`00n5/00_l800Go000Ao`0201Co0007023o000So`008ol002?o000Wo`00
<ol002oo000>03?o000<033o000[o`008?l001So000Po`008ol001So000=o`000?m0003oR@05ob40
6?l00`0So`04ooooo`03o`000?oooooooooo00Kooooo000Qooooo`04o`000?ooooooooooooooo`@0
5?l000<07?l002?o000So`008`0So`00100Lo`008ol002?o000Ho`0801Co000300[o0005o`001Ol0
00<01Ol000<01?l3003o2P00o`X00`00o`X01`00oa800?lI003o6@00oaT00?lM003o6@00obD00P00
obP03000oc000?lh003o@010`4D00/3>0032cP00c]T00Z7h003:n00MeNP00<[o003Xh@<00?nk01T0
0?o6042d^000TOl007Ko0020o`00Bol0GAK;02Q5o`1c:?T01d?o003:o`00lO`00?Ch003dl003[?d0
0>Gd003o``00oi`00?n9003oM@00ofX00?mO003oD`00odL00?m000800?lh1000obP00`00ob400?lI
003o6@04003o6@L00?l:00<00_l800Go0003o`D02`05o`002@09o`001Ol000Wo000Do`003ol0017o
000Do`004Ol000go000201Co000500go000Do`004Ol000So0009o`002005o`02003o2P03003o4P00
oaT00?lI00800?lX00X00?lh003o@000oe<09MG502c0bP00o>D0<F;o003/eP00oi400?mb0P00oel0
2000ofH00?n2003Q]`00oh400?RE003o5P05o`003Ol00P0Do`000`0Lo`008ol002?o000302?o0003
03?o000_o`00<ol000`0<ol000d0:ol001Go0002ocH01olI017o000Do`003Ol000?o2@0o`8D00<kQ
003oL`0=o`006?l000807?l01?ooool00ol0003oooooooooo`06ooooo`008Oooool01Ol0003ooooo
ooooooooool02_l000804_l00P0Do`0201Wo000301ko000So`008ol001<08ol000<08Ol002?o000S
o`001`0So`001@0Qo`008ol002?o000So`006Ol000P05?l000<04_l000go0005o`001005o`000`03
o`<00ol5003o2P03003o2P03003o3@00oa@00?lI00<00?lI02l00?lL003o9P00obP00?lX003o;P00
ocP00?lm003oC@00og/02MF[003h/`0[/NL00<c[02f4l`1`BMP00;Gm00BEn000om`00?oA003oi000
n?X00<3o02hSkP1m4><0>@ko0;h0L@1>1?l0c0320;04Y005@_l04E7o05ENd00AMOl019co003]l000
n]H00?nf003oWP00ohX00?n7003oN000of400?mJ003oBP00oc/00?lh003o<`03003o:003003o9P00
oah00?lI00@00?lI00<00?lB003o3`00o`X01P00o`X00`02o`L01Ol000Co0P0>00Go000900So000:
o`002?l000So000?o`002?l000Go000:o`002?l000P01Ol000D01?l2003o2P00o`X00?l:003o4P02
003o6@0F003o9P00ob/00?lh003o@000oe800=VP003[n00/SoT0=DCo003Dj@06eLD00?m[003oDP00
odL00?m0003oB`00ocP00?lX003o8@01o`h01Ol000So00<05?l000<08?l002?o000So`000P0So`02
02Ko0003037o000^o`00<ol000P0<ol000l0<Ol002Ko000Po`002OlR003eO@0CeGl00OmT00;o6@02
o``00?lI003mU`04O>H00?lS00;o1`0:o`000P0=o`04ooooo`03o`000?oooooooooo00Kooooo000Q
ooooo`04o`000?ooooooooooooooo`801Ol000<04Ol001Co000Bo`00100Do`0201co0005023o000S
o`008?l0027o000Po`006`0So`000`0Lo`005?l001Co000401Co0004017o000Do`005?l001Co00H0
1Ol000<01?l3003o2P00o`X01000o`X5003o6@04003o8@00obP00?lX003o:0800?lh02H00?m4003o
D`00oe/00?m^003oR@00oiP00?Ze01c0dP00eO@009So042>kP00k?`00:Co03M`o`19@l00AA;o0>T0
a@2L0?d0oP1809@0o@2l0?L0T@370029o`00__l00;_o003ll@00l_0007[o041ko@00`_`00?3l003o
aP00l>`00?oJ003oR@0c`:P00?ma003oA0800?lh00H00?l/003o:000obP00?lX003o8@00oa`5003o
6@03003o4P00o`X00?lB00L00?l:00H00ol500Go0005o`001?l300Go0004o`<I00Go000300Co0`00
o`X00?l:00800?l:01T00?lB003o7@00oaT00?lX003o<000ocP00?m4003oC`00ogP00?nT081]M@00
Y?@00=gF003oeP00of<00?m7003o>000oc000?lV003o8@00oaH00?l>00?o1@05o`002Ol000<05?l0
00<06Ol0023o000So`001@0So`0202Oo000502ko000_o`00:ol002oo000co`000P0Wo`0302?o000?
01Wo0008o`<00?AV032eh@09[MT00?mC003o?000ocP0;;S6003oU@00od800?l:00;o2003o`D00_l8
00Cooooo00?o0000ooooooooool01_ooool0027ooooo00Co0000oooooooooooooooo0`05o`000`09
o`003ol001Co000601Co00806?l000D07_l0023o000So`008ol0023o000=02?o0003023o000So`00
8ol000D08ol000<06?l001co000Lo`00200Do`000`0Ao`003Ol000Wo000600Go000700Co0`00o`X0
0?l:003o2P00o`l00?lB003o5P05003o6@04003o7@00obP00?lX003o:0800?lh02T00?ll003oA`00
oe<00?mK003oKP00ogT00?n=003oY000ok/00?o`002Po`0TMol0BCOG0029o`00POl07Qco0<L0^P0:
4Ol0S03^01XHo`1Q4^X03ago002Ho`00`_l00?oY003ocP00oll00<;X00:lm011D/L087Oo002/o`1Q
<L/00W3o003Qm000eMT00?n:003oB`00oc`00?lh003o<004003o:0P00?lI00<00?l>003o2P00o`X0
1P00o`X01003o`D00_l800Go0004o`8I00Go00801?l31000o`X06P00oaH00?lI003o9@00ob`00?lh
003oA000od/00?mK003oL000oj`00ZWh003`eP00oiD00?mn003oF`00od000?ld003o:000ob400?lI
003o3P00o`X01?l300Go0009o`004Ol00`0Do`000`0Lo`008ol002?o000?02?o000@023o000Do`00
1Ol0003o8@00m7T00=6[002Xn000/kL00?mR003QcP00ogT00?l[003o6@00oaH00?lJ0170F`Cooooo
00?o0000ooooooooool01_ooool0027ooooo00Co0000oooooooooooooooo0P04o`<400Go000300go
0009o`004Ol000H05?l00P0Ho`000`0So`008?l002?o000=02?o0004023o000So`008ol0023o00<0
8ol000<07?l001Co000Do`002@0Do`000`0Ao`001Ol000Go000400Go000300Co0`00o`X00?l:00D0
0?l:1@00oaT01@00ob400?lX003o:000obP00?ld00800?lh02T00?m7003oB`00oeL00?mV003oKP00
ohD00?nT003ocP0EV_l05Igo003ok@00iO000?oh003Qo`00V?l0CBkV001Wo`1H7<<00Tgo002=o`00
[ol0<5co003>o000omH00?no003o^000ok/00?oM002An000omh0@<2Q03>Bn000m>D00?nL003oT@00
n;<00?mG003o@000ocP00?ld003o;003003o:003003o9P00oad00?lI00D00?lI0P00oaH9003o2P80
0ol500@01Ol000Co0`05o`001?l34`05o`000`04o`<01Ol000?o1@04003o2P05003o4P00oaT00?lI
003o:000oc`00P00oel03P00of/00?mV003oP00=R_l0EDOG003`k@00ohT00?mV003oC`00od@00?l`
003o:000oaT00?lF0P00o`X00`04o`<01Ol000Go0002017o00<05?l000<06?l002?o000Po`000P0S
o`000`0Po`008ol002?o000802?o000A01co000Do`003ol000Go0000o`h00?lM003oKP00fL800>GM
003o_`09`;h00?mK003o>`00oc000?lh01W0Q@00ojl01?ooool00ol0003oooooooooo`06ooooo`00
8Oooool01?l0003oooooooooooooool2003o2P0300;o2003o`D00ol500800ol50P05o`0200go0003
017o000Do`004Ol000@05?l00P0Ho`0@02?o000501co000Po`008ol002?o000Ho`00200Do`00100A
o`005?l001Co000Do`0700Go000300?o1@00o`X00?l:00<00?l:00<00?lF003o6@00oaT00`00oaT0
4@00oad00?lX003o:000obP00?l`003o>000oc`00?m4003oA`00oeL00?mO003oLP00oi800?c602QT
o`00U?l00>G]00800?o:01X00?oU002Ao`0ALol00;Go002/o`0G6_l06DGo002Lo`00hOl01GCo003Q
l000ol<00?n_003oYP00oj<00>Rn003o[000oi`00?n_01iFo000l;/00?mi003oLP00oel00?m;003o
@0800?lh1@00obP00`00oad00?lQ003o6@06003o6@03003o5000o`X00?l:00P00?l:00@00ol500;o
2005o`001?l32005o`000`04o`<01Ol000Go000800Go00800ol500H00_l8003o2P00o`X00?l:003o
3@00oaH2003o6@0B003o:000od000=W:00j0f@00ojl00?n1003oS`00olh009Wo01Flj@00oj000?m^
003oF`00od/00?ld003o:000oaT00?lF0P00o`X01004o`<01Ol000Go0009o`0601Co000501co000H
o`008ol002?o000Po`000P0So`001P0Lo`008?l001co000Ho`007?l001So00<05?l000l02_l000Go
0000o`X00?lI003o;000oc`00?mG003oR@09Q^P00?n5003oJ`00of800?mG003oU010_<l01?ooool0
0ol0003oooooooooo`06ooooo`008Oooool01Ol0003oooooooooooooool00?l>00800?l:00H00?l>
003o;P00od@00?lU00;o2004o`<500Go000300[o0009o`005?l000<05?l00P0Ho`0202?o0003027o
000So`007?l000H08ol000@07?l002?o000So`008ol00P0Do`000`0Ho`005?l001Co000801Co0003
017o000=o`001Ol000D01Ol000<01?l300?o1@00o`X01@00o`X00`00oa800?lI003o6@02003o6@80
0?lQ0`00obP07`00ob`00?lh003o>000od000?m7003oE`00of<00?mi01gEf@00j?002HOo05EJn@00
olH00?ng003o^`00j=800?cX042YkP00i_l0<j7o04@Xo`0>?ol00<[o003oo000ond00?oM003o]`00
ojL00?nL003oU000oi400`00ohd01`00ok<00?mi003oJP00oe/00?mB003oA`00od@00P00ocP00`00
oc@00?lX003o:003003o:003003o8@00oad00?lM00L00?lI00@00?lB003o3P00o`X00?l>2@00o`X0
1`03o`D00_l800Go0003o`D01Ol000?o0`04o`<00`05o`000`03o`D01Ol000Go000200Go000500Co
0P05o`000ol500Go0003o`D01P00o`X2003o6@0C003o9@00obP00?ll003oF`10`9H009co003Qh@00
ok/00;Od02Qgo`00olX00?nH003oS@00n:L00>bc003o?000obP00?lL003o4P02003o2P0500?o1@05
o`001Ol000Go0009o`003`0Do`00100=o`005?l001Co000Do`02017o000?00Go0004o`<00?l:003o
5P00ob400?ld003oB`00og800<[E0430Z@09cN400?nD00W0Z000n=80097o00Cooooo00?o0000oooo
ooooool01_ooool0027ooooo00Co0000oooooooooooooooo0`00oaT03P00oad00?m0003`X000obd0
0?l>003o2P02o`P00ol500;o2000o`h00_l<00?o1@04o`<02Ol01@0Do`0201So000301ko000So`00
6?l000808ol000@08?l001co000So`008ol00P0Lo`000`0So`007?l001Co000=01Co000300Wo0005
o`001Ol000D01Ol000<00ol5003o2P00o`X00`00o`X00`00oa800?lF003o6@04003o6@05003o8@00
obP00?lX003o:000oc@00P00ocP09P00od@00?m7003oF`00ogh00?nE00JYj`0oLol00?CQ0330cP00
oj/00?nS003oZ`00ok<00?no003oeP00on/00?3o002Lo`15Ao400;_o003om000omT00?o2003o/`00
oj<00?nG003oT@00ohT00?n5003oO@00ogT00?mb003oJP00of<00?mG003oC000odL00?m00`00ocP0
0`00ob`00?lX003o:004003o:003003o8@00oad00?lM00L00?lI00<00?lB003o2P00o`X03000o`X0
1`02o`P00_l700;o2005o`000ol500Go0003o`D00P05o`001004o`<01Ol000?o0`05o`08003o2P0F
003o4P00oaT00?lI003o8@00obP00?lh003oB`00ofX00?nH042Ug`0EY?806RSo0021o`00a_l00=WM
0162g@00^n400?mW003o@000obP00?lI003o4P800?l:00<00_l800Co0`05o`000P05o`000`09o`00
4_l001Co000401Co0003017o000Do`005?l000805?l000L04Ol000Co0`03o`D00?lU00Co0`05o`00
2Ol000801Ol000l01?l2003o2P00o`h00?lI003o:000oc@00=Ui003`Z`00ok/009So04/Tg`1=P<l0
0=g`00Uol000o<h01?ooool00ol0003oooooooooo`06ooooo`008Oooool03_l0003ooooooooooooo
ool00?lU003o8@00obD00?l/003mS@00e]800?ll003o7@00oaH00?lB0P00oaH01P00oc`00?mG003o
A@0=`4l01?l300Wo00H05?l000L05ol001So000Do`008?l002?o000Ho`005?l000808?l03`0Do`00
0`0=o`005?l001Co000600Go00800ol500<00_l8003o2P00o`X00`00o`X00`00oa800?lI003o6@03
003o6@06003o8@00obD00?lX003o:000ob`00?ld0P00ocP07000od000?m7003oG`0T_<800<KM01?0
j`00W?l00?nk003oW000oi@00?nL003oX000oj<00?nc003o`P00omh0097o001Ko`2W0?T006_o003E
o000omT00?o6003o[`00oj000?nD003oQ@00oh42003oM@03003oLP00ofH00?mV00800?mG00<00?m<
003oA`00od000`00ocP00`00oc@00?l/003o:007003o:004003o9@00ob400?lQ003o70@00?lI00<0
0?lF003o4P00o`h04000o`X00`03o`D00?l:00?o1@0200;o200300?o1@00o`X00?l:00L00?l:01L0
0?lB003o5`00oaT00?lI003o8@00obP00?lh003oC`00oiP00<[B003Yl000l^H006?o014jo`1L@o40
0=;o003dm000oj@00?mW003oB000oc000?lQ003o6@03003o2P0300Co0`05o`001Ol000801Ol000@0
2?l0017o000Do`003Ol00`0Do`0200go000800Wo0005o`001Ol000;o3000of<00?mZ003o4P03o`D2
00Go000@00?o1@01o`P00?l>003o7@00obD00?l/003o?000oel00>S3042a``0XM?l07XCo003Qm000
ok<00=fP003oKPCooooo00?o0000ooooooooool01_ooool0027ooooo00Co0000oooooooooooooooo
0P00oc001P00oc@00?m0003[`000k=80@<23003o<0800?lQ00T00?lh003oA000oe/00>Vn0032Z@00
ob400ol500Go000=o`007P0Do`0900Go00H00?l:00<00?l?003o5P00oaT01000oaT00`00oad00?lX
003o:002003o:00;003o<000ocP00?lh003oA000odL00?mC003oJP00n;<00?nE003oX000oi400P00
ohT05000oi400?nD003oX000ojl00?no003of@00eO`00:_o048IiP00[ol00?So003oj@00o>D00?oB
003oY`00ohl00?n5003oN@00ogD00?mb0P00ofH00`00oe/00?mG003oE`02003oA`03003oA000oc`0
0?lh00800?lh00<00?ld003o:000obP02P00obP00`00obD00?lQ003o6@04003o6@05003o4P00o`h0
0?l=003o2P00oa806P00o`X01000o`h00?lI003o6@00oad2003o:00B003o>000ogh00?o6002<f@00
oj@00?n^003Bl00`Mol007Ko003oaP00b/H07:gd003Mi@0L`:@00?lh003o7P00oaT00?l>0P00o`X0
0`02o`P01?l300Go000500Go00802Ol00`05o`002@03o`D00_l800;o1`00o`X00?lN003dZ`00ofh0
0?lQ003o3P03003o2P0?003o3`00obT00?m^003o@000oc`00?m8003oMP00Ynd00?cQ003Eo006V_D0
0?ng003oR@00oel00?m800Cooooo00?o0000ooooooooool01_ooool0027ooooo0_l00002ooooo`0A
003o@000oc`00?ll003oB`00ojh01L3B003oE`00od000?lh003oB000dJL00?nI016acP00n8400?l^
003o4P03o`D00P05o`0J01Co00804Ol00P0Do`000`09o`001Ol000Go000400Go00800ol51P00o`X0
0`00oa@00?lI003o6@03003o6@03003o7@00obD00?lX00800?lX02800?l/003o>000ocP00?lh003o
?000odL00?m?003oF`00ofL00?m^003oM@00ogT00?mm003oP@00ohD00?nA003oW000ok<00?oJ003o
j`00n?l009So00dmo`0`L?l0=jWo003Uo`12KL000?C]003oZ`00ohl00?n5003oN@00ogD00?mZ0P00
ofH2003oE`05003oD`00odX00?m7003oA000oc`01@00ocP00`00obd00?lX003o:003003o:009003o
;000oc000?l`003o=000oc<00?l`003o;000obD00?lQ00D00?lI00<00?lG003o6@00oaH01@00oaH2
003o4P03003o3@00o`X00?l:00d00?l:00<00?l>003o2P00oa800`00oaT05@00oad00?lX003o:000
ocP00?mC003oIP00ofh00?mf003oU`00omd00:So003odP00oiP00?n1003oQ@00a]H00?m^003oG`00
ob<00?lI003o5P03003o2P0300;o2004o`<01Ol000L01Ol001d01?l300;o2000ob400=VD003o6@00
ob400?lh0430^000n<X00?mG003o7@00oaH00?lB003o5P00oah00?lh003:cP00m9D00?m?003oE`00
ofh00?nD003o^`00d_P08:;m003hh@00m>d00?mK003o=003ooooo`;o00002?ooool0027ooooo01Go
0000oooooooooooooooo003oQ@00oeD00?m?003oG000o:L00=CS003oL000oe`00?n7003oTP0P[>/0
@gKW003`^P00odd00?lN003o3`02o`L00`05o`000`0Do`003ol001Co000G01Co000300oo000:o`00
2_l000H01Ol000<01?l200?o0`00o`X00`00o`X00`00o`l00?l=003o5`04003o6@03003o7000oah0
0?lS00@00?lX00D00?l[003o=P00ocP00?lh003o?@02003oA`0H003oE@00oeX00?mQ003oIP00ofh0
0?me003oN000oh000?n8003oV@00j=@00;3j01bVj`0PUOl08Q?o0=D0N@2F0<T016co005io`0[[=l0
0??N003o/`00ohl00?n50P00ogD2003oIP04003oI000oeL00?mG003oE`<00?m700<00?m2003o>`00
ocP01000ocP01000ocH00?lh003o=P00ocH2003o>009003o@000oe`00?n0003oF@00ohl02MF7003o
<000ob/00?lS00P00?lI1@00oah01000ob400?lK003o5`00o`l2003o3@X00?l:00@00?l=003o2P00
oaL00?lG0P00oaT05000oa`00?lS003o:000obP00?lh003o@000odX00?mJ003oIP0JhiT00<;e021Z
o`00hOD00?nO003oJ`00oe`00?m?003o@P00oc<00?lU0P00oaT00`00o`l00?l:003o2P02003o2P04
007o2@02o`L00_l500;o1`800ol301l00ol500;o1`00o`d00?lD003[I000iZ@00>1j003o>000odl0
0<OG003XYP00od800?l[003o8@00oah00?lS003oF`01eIh00?3:003oY000ogD00?nN003o/`00n<`0
0LGV003Bo`13ENL0<J?/003K`P00kGP00?lc00Cooooo00?o0000ooooooooool01_ooool0027ooooo
01Go0000oooooooooooooooo003oP@00ofh00?mb003oNP00oi@00>cU003o]`09/M406IKd00::l000
oj/00?mn003d`P00od@00?lL003o3P00o`X01005o`0G01Co000300oo000Do`004Ol000L01Ol000<0
1?l200?o1@00o`X00`00o`X00`00o`h00?lB003o6@04003o6@03003o7@00oaT00?lQ00@00?lX00<0
0?l[003o;000ocP00P00ocP01P00oc`00?m7003oA`00odL00?mG003oFP800?mV01D00?mZ003oM@00
ogd00?n5003oS@00oj000?no006nn000c_l008go06`Uo`00H_l00<[o003ho000eOP0>g?o003Ag@00
oi@00?n5003oN@00ogD00`00ofH3003oE`06003oC000odL00?m7003oA`00od@00?m02000ocP02P00
oc`00?m4003oC`00og800<kB003ma@09`;<00?m?003o>000ob`2003o:009003o9@00ob400?lI003o
7000oad00?lU003o:000ob`00?m800800?l`00<00?m<003oF`00ocX00P00oaT00`00oaH00?l>003o
2P03003o2P07003o4P00o`X00?l>003o2P00o`h00?l:003o4P04003o6@03003o7000oaT00?lX0080
0?lX0P00ocP03P00odL00?m?003oIP00ohD00<K601FJo`00okh00?n5003oIP00oeL00?m7003o>000
oc000?lX1000oaT2003o3PT00?l:00/00?lF003o8@00odL00=WI00^EiP00ogd00?mj003:i@00oh80
0?m?003o>002003o<00@003o?000odd00?bP003/e@00d^T00?SB003>l00=Pol0@:Ge01b3n000Iol0
6USo002gl000ohd00?mO003oA0Cooooo00?o0000ooooooooool01_ooool0027ooooo01?o0000oooo
oooooooooooo003o/`00o;<00=gB003o[000b]h00>SU003le@00k>T00?n/003Mg@00ofh00?m?003o
F`00ocP00?lI00800?l:1@05o`000`09o`005?l001;o000201Co0003017o000Do`005?l000/05?l0
00D04Ol001Co000Do`002_l000Wo000800Go000300?o1@00o`X00?l:00800?l:00<00?l>003o5P00
oaT01000oaT00`00oad00?lI003o:004003o:003003o;000ob/00?lh00<00?lh00@00?m0003oA`00
odL00?m70P00oeL00`00oel00?mV003oIP02003oM@0C003oP@00ohd00?nH003laP0[[m800?od003]
o`00SOl0;E;o003Jo`00onT00?oI003oa`00ojl00?nG003oQ@00ogT00?me003oLP02003oIP04003o
F`00oeL00?mG003oC`@00?m700<00?m4003o@000ocP00`00ocP2003o?00;003o@000odL00?m?003o
F`00ofh00?nc023E^000ofX00?m?003o?000oc@02000obP02@00oc000?m4003`]`00og800?m^003o
eP10`7L00?le003o7@04003o6@08003o3P00oaH00?l:003o4P00o`X00?lF003o2P00oaH7003o6@@0
0?lX0P00ocP03@00odL00?mG003oQ@00nZh0@<3C00e=o`00gM800?n/003oU000oe<00?m7003o>000
oc000P00obP4003o6@L00?lB00d00?lF003o4P00oaH00?lI003o8@00oc000?mG003j]@00iO@00?3B
003`eP00ofh00?mC00800?m;01400?mG003oH`00of@00?n903nhg@10?]h0@9;a02bBm005V_P00?nT
003oW005_>`00?o8002kg@05`?@00?n1003oJP04ooooo`03o`000?oooooooooo00Kooooo000Qoooo
o`0Ho`000?ooooooooooooooo`05V^d00?SQ0033o`00iN`01Zoe003>`P00ohD00?mj003oKP00og80
0?m;003o?000oc000?lU003o5`00o`h00?l:00?o1@05o`001?l30`05o`0200go000301Co000Ao`00
5?l000X05?l000L04Ol001Co000Do`003Ol0017o000Do`002_l000P01Ol000<01?l3007o2000o`X0
0P00o`X00`00oa800?lI003o6@04003o6@800?lU1P00obP01`00ob`00?lc003o>000ocP00?ll003o
>000od000`00odL00`00oe<00?mG003oF`02003oIP800?me00l00?n1003oS@00oi@00?nW003oa@00
omD06L3l001Oo`1J9Mh00;oo003oh@00olX00?ng003oY`00oi@00P00ohD2003oM@03003oJP00ofH0
0?mO00<00?mG1P00odL2003oA003003o@P00od@00?m400800?m700`00?mC003oIP00ofh00?n104Do
b`00j:h00?mO003oC`00od@00?lh003o=000ob`4003o:00<003o;000oc@00?ll003oC`00n:000?c2
003hdP0AR^D00?mK003o<`00obP00?lM1@00oaT00`00oaH00?lI003o5009003o6@05003o7P00obP0
0?lX003o:000oc000P00ocP02`00odL00?mG003IX000ZN/00<[d031=o`00__@00;[/003oR@00oe/0
0?m700800?lh00@00?l[003o:000obD00?lM1P00oaT01000oa`00?lQ003o8@00oad2003o6@0M003o
8@00obP00?ld003oA`00ofH00?nE016]g@00ok/00?mm003oJP00oel00?Rg003o[`00n;l00?:L003h
j@00eO@0@57;003Im000oj@00<jT003oKP00oh40<l2j003KTP00o9P00?bk003]f@00b^T01?ooool0
0ol0003oooooooooo`06ooooo`008Oooool04ol0003oooooooooooooool0@5Gm00eXo`1o3_l004So
01Rnh@00oi@00?mb003oIP00oeL00?m;003o@000oc@00?lX003o7@00oaL00`00o`X00`04o`<01Ol0
00Go000300Go000300[o000Do`004Ol000805?l000<04Ol001Co000Do`001P0Do`001P0=o`005?l0
01Co000=o`001Ol000go00L01Ol000<00ol500Go0003o`D00`00o`X00`00oaH00?lI003o7@0<003o
:007003o;000oc000?lh003o>000oc`00?lh003o?003003oA`06003oB`00oe<00?mG003oG`00ofH0
0?mZ0P00ogD05000ohD00?n9003oU000oj<00?ne003obP00onT00=;o028ho`00k?l00?oY003obP00
okL00?nS003oV@00oi400?n5003oP@00ogD00?mb0P00ofH01000oel00?mG003oE`00oeL:003oA`0<
003oB`00oe<00?mO003/]`00oj/00?nP06U0_000ok<00?mZ003oE`00odL00?ll0P00ocP04000oc@0
0?l`003o<000ocD00?lh003o@000od/00?mG003oOP00m>400?nL003oI`00odP00?lc003o:000obD@
003o6@0F003o8@00obH00?lX003o:000ob`00?ld003o>000od000?m7003oC`00ofh00lSD003dk000
L_l06K7h00W0i@00om800<jE003oC`00od000?lh003o<0<00?lX00@00?lU003o8@00obD00?lQ0P00
obP01000obd00?m^003oKP00ob`3003o:00D003o<000oc`00?m7003oG`00oh400?CB002[l000hMD0
0?SM003oR@00oiP00<K/003UfP0@Yn/008gl003]i@00U?`00>7Q003oR@00ofL3003oD`05003oC`00
oe<00?mf002_f@00ofL01?ooool00ol0003oooooooooo`06ooooo`008Oooool04ol0003ooooooooo
ooooool00?c]003:o`00M_l0Gago04eho@00n:l00?m^003oF`00odl00?m0003o>000ob`00?lX003o
7@00oaT00`00o`X00`03o`D01Ol000Go000500Go000400Wo000Do`004Ol000go00805?l000@03Ol0
01Co000Do`003Ol00P0Do`00100=o`004Ol001Co0009o`0:00Go000;00;o2000o`X00?l:003o2P00
oa800?lI003o7@00oc`00?mZ003o=000oc002000obP2003o=0D00?lh00<00?m0003oA`00odL00P00
odL2003oE`0D003oH`00ofH00?mZ003oM@00ogT00?n5003oR@00oi@00?nS003o]@00o>T08;Sl0036
o`0I?Ol00;?o00:Fo`10`</00?nk003o[`00oj43003oU006003oT@00ogT00?m^003oIP00of<00?mK
0`00oeL00`00od/00?m7003oA`05003oA`0>003oB`00oeL00?mK003oKP00oj000:Cl003leP00_ol0
0?g:0032`P00ofL00?m?003oA`00od04003o>00;003o>`00odP00?n9003oIP00ogH00?3E0650jP00
ogH00?mG003oA000ocD00P00obP00`00ob400?lI003o7@0<003o6@800?lU0P00obP05@00ob`00?l`
003o>000ocP00?ll003oA`00odl00?mW003V]@00ok/0@8?a01blj000oj000?n5003oJP00odl00?m7
003o?000ocP00?l`003o;003003o:00W003o;000ocP00/21003o@000odX0C7cM0032P@00oc`00?ld
003o<000oc@00?m0003oC`00oe<00?m[003M_P00omh0097o01F6o`00iO000?CB01Vdl000SOl0757o
003ja`00kMD00?n5003oX000hN`00;_I003oP@00od000?ld003o<000oc<00?m4003oS@15JLl00?mZ
00Cooooo00?o0000ooooooooool01_ooool0027ooooo00oo0000oooooooooooooooo003lm000Gol0
@2?0002go`00cOX0CH38003oMP00oeL00?m?003o@000ocP00P00obP2003o6@05003o3P00o`X00?l:
003o2P04o`<02@05o`002@09o`005?l0017o0009o`005?l001;o0005o`005?l0017o000<00Go0006
00Co0`03o`D00?l:003o2P00o`d00?l>0P00oaT01000ob`00?m^003oOP00od@2003o>004003o<000
ob`00?l/003o<0800?ld1P00ocP00`00oc`00?lh003oA`03003oA`0N003oB`00oeL00?mJ003oIP00
ofX00?me003oN@00ohD00?n9003oU000oiP00?nS003o]@00n>4009So01ETo`293Xl0ACOm01UTo`10
U]X00?3M003o]`00ok000?n[003laP00o=T00?CQ003oT@00ogD00?mZ0P00ofH4003oE`800?m?0`00
odL07`00odX00?m?003oE`00oeL00?mW003oZ000[md0>k7l05]Ro`1M5_T0=TkO00Vli@00k:/00?m^
003oB`00odL00?m4003o@000oc`00?m0003oBP00oe/00?nW003UbP00oiT0<8?/003ocP00ohD00?mC
003oA`00ocP00`00obP00`00obD00?lI003o7@06003o6@05003o7@00oaT00?lM003o8@00obD01000
obP04000oc000?lh003o>000ocP00?m4003oA`00odl00?mO003oM@00oj@00:_/003Uh@00oi`00?mb
003oH`00oeL2003oA`03003o>`00ocP00?lh00@00?lh01P00?m<003M/`00bYP00?ma003lg@00hKL0
0?m;003oA000od000?m7003oH`00oiT00?mZ003oO@00/n400TWo05```00LCOl009Co0029o000VOl0
3KcU00:Ym000oi@2003oG`0<003oW000oj/00?R5003hP@00ob`00?lU003o8@00obP00?lh003oIP0I
MnP00?nD1?ooool00ol0003oooooooooo`06ooooo`008Oooool05Ol0003oooooooooooooool06Hko
068NiP09Nol00>7l003oc@00oj@00?mj003oH`00oe<00?m4003o>000oc000?lX003o8@00oaT00?lF
003o3P03003o2P0300Go0003o`D01Ol000X01Ol000<02Ol000So0005o`003005o`000`04o`<01Ol0
00Go0004003o2P09003o5P00oaT00?lU003o<000ogT0@:WO003AR@00od@00?ll00d00?lh1000odL0
2@00od/00?mC003oE`00oeX00?mV003oMP00oi400?n=003oU002003oW00G003oX`00ojL00?nk003U
i@1<H_l00:Oo04<RkP00O_l00=Ko003`o000omT00?o6003o_@00olh0Y42001F>o`00ok<00?n=003o
O@00ogD00?m^003oIP00of@01P00oeL00`00oe<00?m?003oE`02003oE`0=003oG`00ofh00?nA003l
aP00olH01J7d001Vo`00dNP00?cF003/aP00ogH00?mG003oB`04003oA`0=003oF@02`;l00?no00:d
k000hN4009Co003o^`00ogX00?mW003oB`00ocP00?l`003o;003003o:0800?lQ1000oaT01000ob40
0?lI003o8@00obD5003o:005003o<000ocP00?lh003o>000od000P00odL03P00oeL00?mO003oL`00
olh00:Cl03>No`00^]T00?mi003oIP00oeL00?mC003oB`00odL00?m;0`00od@08@00od000?m7003o
D`00oi`009cY003e[P00fNT00?mj003oF`00odl00?mC003oO@00oi400YKM003oR@00ohl00?oF03>h
o010G<00<Dko003ln000olL00?n`003oW000o=800?f7003oA`00od/00?n=002n/`00ocP00?lY003o
7@02003o6@05003o7000oc000?n1003Ih@00d^D01?ooool00ol0003oooooooooo`06ooooo`008Ooo
ool04_l0003oooooooooooooool0P5Z^00hAo`10EL00097o013Ee`00oi`00?n1003oNP00o8T00?m;
003o?000oc000?l/003o9@800?lI00<00?l>003o2P00o`X00P00o`XI00Go000300Co0`05o`001Ol0
00800_l80`00o`X02P00o`d00?lI003o7@00ob`00?ll003oJP00`o`00?mf003oD`00odL4003o@003
003oA000ocP00?lh00800?lh00<00?ll003o>`00od001000odL09000od/00?m7003oE`00oeL00?mO
003oIP00ogd0@;S0003o/`00olH00?3Q003o]`00ok<00?ng003o`000omT00?cl003:o`20;800@4;V
003Io`00ooP00?oM003od@00ol`00<[]00eco`00d_P00?nk003oT@00ohD00?mi003oM@00ofh00?mY
003oH`X00?mG01h00?mV003oKP00ogd00?n=003o[`0E/O@0033o003bg000oiP00?n1003oKP00oe/0
0?mG003oC`00oe<00?m?003oE`00oel00?nP003obP00]o00<R;o041k``00olh089KU003o[`00odl0
0?lm003o>000ob`5003o:004003o8@00obD00?lQ003o8@H00?lX00<00?l/003o<000ocD00`00ocP0
7@00od000?m7003oA`00odl00?mG003oG`00og000?nX003oh@0cS_P00?n_003oO@00og800?mS003o
F`00oeL00?mJ003oJ`00of<00?n9003oF`00oe<00?mG003oH`00ogd00?o:002mj`00o;L00?mm00<0
0?m^01H08<2W003/k009_>D00?nc003oc`00m>D00>Gl00Lco`0cR_l00?3h02Blf@00oh400?mb003o
/`00odd00?ld003o<000ocP00=VH003o8@00oaH00?l>0P00o`X01@00oa@00?lM003oB000oiP01K3E
00Cooooo00?o0000ooooooooool01_ooool0027ooooo01?o0000oooooooooooooooo00:hn015E//0
0<Kh032Fo`00Uol00>SM003oX005S]T00?nD003oE`00odL00?lh003o;000obP00?lQ00800?lI1@00
o`X00`03o`D01Ol000Go000F00Go000300?o1@05o`000_l800@00?l:00X00?lB003o6@00ob400?mR
003/Q@00oi@00?oB003oOP00of<00?mK1000odl00`00od/00?m7003oA`02003o@003003oA000odD0
0?m700<00?m700<00?m;003oA`00oe<00P00oeL06`00of400?mZ003oO@00b]d00=Ko04e]`000j?P0
0?oF003ocP00olX00?o<003og@00oo`00>7o001jo`00H_l00<ko042e`000o?@00?oY003oiP02YOl0
@6_0003og@00ojl00?nP003oT@02003oS@05003oT@00ogD00?mV003oIP00oe/01P00oeL03`00oe/0
0?mS003oIP00ofh00?mm003oS@00oj/00>7Y040W`003`=`00?nL003oO@00ofh00?mV003oF`03003o
E`0>003oG`00of/00?n1003oX000j>4007Ko041EjP00e_l00?SI003oOP00oel00?m7003o>000oc@>
003o:003003o;000oc@00?lh00800?lh01000?ll003oA000odL00?m7003oC`00oeL00?mO003oIP00
og000?n=003hd@00a_l00?nc003oR@00ogd00?mf0P00ofh08000og<03KcM003oY010Pmh00?mf003o
H`00ofX00?mb003oP@00oj@00>K]003oaP00oj000=f_003he@00oi@00?n_003Xh@0Z8_l00h3l0025
o`00V?l01F3o05/Po`0l;ol00<;o003o^`00ofh00?mK003oB`00ocX00?lX0P00ob400`00oad00?lB
003o2P04003o2P04003o4P00ob400?lh003XZ0Cooooo00?o0000ooooooooool01_ooool0027ooooo
01Co0000oooooooooooooooo003oY000k/`00?Zm003o^00GYOP01:Cj04fNi000g_D00=WF02;E_@00
ofH00?m0003o=P00oc000?lV003o8@800?lI00@00?l?003o3@00o`X00?l:0P01o`T00`04o`401Ol0
00Go000@00Go000500Co0P05o`000ol300Go0002o`L01P00o`X04@00oaL00?lL003o:000od800?mm
003cW000fK/0483]003m]@00og/00?>X003oO@00n8D00?nQ01SEQ`00oeD00?m:00L00?m70P00odX0
9000oeD00?mG003oE`00oeL00?mS003oJ@00ogP00?n?003ca@00U?P08ZOj0450i`00^?d00?oV003o
h`00n_D008Oo002^o`00JOl0NQ3W0025o`0kDOh009Co003So`00kO`017Wo003Qo`00omh00?o:003m
bP00mML00>7N003Ge`00ln400?ZZ003oL`800?mV00H00?mT003oG`00oel00?mG003oFP00oel2003o
IP0=003oJ`00ogD00?n5007E^000mLD00?oS035UfP00i>@02MG5003oS@00ogD00?m[003oIP02003o
H@0>003oIP00ofh00?n?003oU`00fm803YSm002Oo`00n]@00?nk00BdgP13M^h00>6c003oF000ocd2
003o>003003o;@00obP00?lX00L00?lX00L00?l[003o;@00ocH00?lh003o@000oe`00?m<00<00?m7
0P00odl0<@00oeX00?mQ003oJ`00og000?n5003oW000olL017km003Ng000g/X00?Ro003Ge`00jMh0
0?nL01;SY@00lm@00=Ce003o_`00oi800?n:003o_@00kM800?nV02_8`00=N?l0@6KQ00Bkl`00W_00
?g[j003Lj@00XOl04HWm03YSo`00i^H00??@003`c`0@Iod06kCh02iho`00olX00?fa003oJ@00oe80
0?m0003o;@00oa`00?lG003o3`00o`X00P03o`D02005o`001?l200Go0004o`400ol5003o5000odD0
:mF;1?ooool00ol0003oooooooooo`06ooooo`008Oooool2o`0000;ooooo00d00?mZ003oI`00og80
0?n9003o`P0=EOl01DGo003Bg@00oi`00?mi003oG`00od/00?m400800?m000D00?l`003o:000oaT0
0?lI003o5P05003o2P0300Go0004o`<01Ol000l01Ol000<01?l300Go0003o`D01`00o`X2003o6@0A
003o7@00obP00?l`003o@000oeL00?n1003]f@00X?@00?o602^^b`00olH00:_/003:d@00og800?mO
003oE`00odl01000odL2003oB`03003oA`00oeL00?mG00<00?mG02400?mV003oKP00ogD00?n5003o
V000okL00?oI003Fo01l6^X0>jWo003jo@00`ol0@4WJ02POo`0S3_l0DP3o07`:fP1M2^X04FSo03Mk
o`15<ol0087o041/`002YOl00:3o003:o`14E_l0`2E4003/k@00ok<00?n?003oN@00ofh02@00ofH0
3@00og800?mi003oS@00m<X0K6WK003Bo`0f8_l0CG;L02BYm000a]D00?nA003oM@00og800P00ofh0
3P00ogD00?n502_8]000ol800?CY001jo`10/<l00?n/003oS@00ohD00?n9003oKP00oe@00?m40`00
ocP00`00oc000?lX003o:003003o:0800?l/00X00?ld003o>000ocP00?lh003oA`00oel00?n_003o
I000oeL00?m?0P00oeL0<P00oel00?mV003oW000oj@00?n=003j_@00j?00@7??003of@00l=d008go
002@o005Lol097_o002kk01NGk`0@9;005`om@00Y?@01Eco003Ih@02YOP04Jgh0036n000a_`01b3o
02U]o`00c_000=gX0029o`00okL00=Vo003o_`00iOl00?C2003oPP00oi`00?nc003h]`00m>402G_d
003oU@00ogH00?mW003oB000oc<00?lI003o3P00o`X00ol50`05o`001`09o`003Ol000So0005o`00
0_l800;0KP00oc400oooool2o`0000Sooooo000Qooooo`0Jo`000?ooooooooooooooo`00odl00?mC
003oH`00oiP00k7S04A3o`05Nol00;o`003o[`00oh400?mW003oE`00odl00?mC003oPP00of800?l`
003o9@00oad00?lI003o5P00o`h4003o2P0300?o1@05o`000ol500801Ol000<01?l300Go0004o`<0
1`05o`000`03o`D01Ol000?o1@08003o2P<00?lI00l00?lM003o:000oc000?m0003oC`00ofh00?nL
0036m000V?l0LTfn003Mk000gLX00?nT003oKP00ofH00`00oeL2003oC`03003oB`00oe<00?mC00D0
0?mG02000?mO003oIP00ofh00?mm003oQ@00oiP00?n[003o_`00on400=go01U`o`00Uol009So001G
o`3;0<T0a`2i0</0S03R0;d0iP2001lBo`0LCOl009Co003]o`00W?l06Goo041[iP00Zol07;Sl03mo
o`0/`=D00?nL003oRP800?me0P00ofH00`00ofX00?mV003oIP02003oIP800?mZ00`00?me003oO@00
ohd00?n_0036n000d_l03FSo02b9dP00on400>76003oS@00oh42003oM@0@003oN@00ohT00>SB06aV
b`0A^?P0<7_o003Am000ok<00?nE003oP@00og800?mV003oF`00od`00?m7003o?0@00?lh0P00oc@0
0`00oc000?lc003o>003003o>007003o?000od@00?m?003oMP00l<h00?n5003oH`03003oG`0a003o
JP00ogh00?n`002Ll000ojl00>?L028Mo`00k>D00?nT003oX000ojP00?nk00V3o`00l>T00>g`01ZT
o@12<od0947o003Fn01PKN80<:g`01aPo`0PS_`00:oh00UXo`1>9=L0@9;J003oaP00oj`00<k6003o
U000ogH00?nk003l_`00eLh00?m[003oH`00ofX00?mi003oU@00/nD00>cU04eaZ@00T?000?mm003o
IP00oad00?l:00Co0`0200Go000300Wo000Ao`005?l000805?l000@04Ol000go0004o`<01?l31?oo
ool00ol0003oooooooooo`06ooooo`008Oooool06?l0003oooooooooooooool00?m0003oA000oe/0
H82l01>nbP00ok/00?cX04Ue`00=`=400?o:003oQ@00ofX00?mS003oP@00cmh00?mC003o>000ob`0
0?lX003o7@800?lI1P00o`X00`02o`P01Ol000Co0`0200Go000300?o1@05o`001Ol000801Ol000H0
0ol500Go0005o`000?l:00?o1@02o`P7003o2P0D003o4P00oaT00?lI003o6@00obD00?lX003o<000
od000?mb003oZ`00c[l00=gX05X>`00ZK?l00?nk003oW000ohD00?mb003oIP00oel:003oE`0S003o
F`00oel00?mV003oJ@00ogD00?n1003oT@00oj@00?o>003oeP00m?P03Hko015_o`0^@]D0Lc?Z07LX
c`3o07/0i`2E0>/0G`2^0?l0j`1b02d`o`00/ol00>go003on000oo000?o]0033o000n>T00?oB003>
h@00okh00?nD003oQ@00ogT00P00ogD00`00ofh00?mV003oJP02003oIP0?003oJ@00og800?me003o
M@00oh400?n=003M`P00j=d00?oQ002go`0[H_H00?o:003oZ`00oiP00?n900<00?n500l00?nD003o
/`00j?00`02001EEo`00onT00?ng003oT@00ogT00?m^003oH`00oeL00?m?003oA`00od@02`00ocP0
:@00od000?m7003oB`00oe/00?mm016Mk00Ed>/00?n5003oJP00ofH00?mZ003oMP00k<800=gh003B
o000l>`0EFCQ003`j000m<X00?n9003oO@00oh400=Vo003o`P00dK/00?nL003o]@00SO@00=Wd003o
]`00ok<00?n/01V]k@00`]X00?nc00:Qn000T_d00=WM003oW000oh400?mb00800?mO00<00>bT003o
OP00oe/00P00odl02`00oe/00?mZ003oZ000`^`00?nD003o[`00olH077oX003mV@00obd00?l:0080
1Ol000<03Ol001Co000Do`001`0Do`04ooooo`03o`000?oooooooooo00Kooooo000Qooooo`0Eo`00
0?ooooooooooooooo`00oc000?ld003o?000odl00?n8003oQ@00oiD00>GF00f:o`00iO`0@<22003o
Q@00ogd00>Fc00^^d@00of<00?m;00800?m000D00?ld003o9@00oaT00?lF003o3P05003o2P0600;o
2000o`X01?l300Go0002o`P01Ol00P03o`D01005o`000ol500;o2003o`D8003o2P03003o3P00oa80
0?lI00800?lI01<00?lN003o:000obP00?lh003o@000ofL00?nc00:dj@00_o`0@SoZ02^Ti000m=T0
0?nP003oQ@00ogD00?m^003oIP00oel00?mK00H00?mG0`00oe/2003oIP0P003oJ`00ogT00>F_003o
^`00n<h04Igl031/o00kFOl0>eCo003`o`00k_l00<Oo002=o`171l00N0?008d0hP0Z3_l0H0gZ030^
o`0IEOl00>Sj003oi@00omT00?oE003odP00olH00?ng003o[`00oj@00?nD003oQ@00ogT3003oM@05
003oLP00ofh00?mb003oLP00og<00`00ogD02P00ohD00?n=003oW000ojl00?o3003Um00[T^H00?3/
003o]`00oj02003oU00?003oT@00oiP00?n_003o_`00g_P0;DOo02AAo`0=T_l00=[o0430X@00ogD0
0?mV003oG`00oeL00?m<00800?m700<00?m0003o>000ocP01@00ocP05`00oc`00?m0003oA`00od/0
0?mC003oE`00of<00?n5003ocP0[`lP00?n=003oN@00ogD00?mi003oP@00oi`00?o:0025o`1=:<00
0=k]003oY000ohd00?mi00800?m^01H00?mb003oKP00og800?mi003oX@09R_000<K/003oX000ogd0
0?n1003oU000oj000?n9003oY00VTn400?oF003oT@00og800?mO003oC`00od/00?m?0`00od003P00
odL00?m?003oI`00eL800:OQ003oJP00odl00?mC003UX000lXD00?la00;o2005o`003Ol0100Do`00
1P0Ho`007?l0023o000Lo`008ol0023o00Cooooo00?o0000ooooooooool01_ooool0027ooooo01?o
0000oooooooooooooooo003o:000ob`00?l`003o?000odl00?mS003oV000m?0008go00Ukn000olH0
0?nX003oX000olX00>fm00800?mf00L00?n=003oMP00oh`00?m0003o9@00oaT00?lF00X00?l:00<0
0_l7003o2P00o`X02P00o`X00`00o`h00?lB003o5P03003o6@0B003o7@00obH00?lX003o:000ocP0
0?m0003oC`00oh4008gQ003o_`00om80:gCk003:o`00b/H00?nA003oP@00ogD00?m^0P00ofH01000
oel00?mG003oE`00oe/2003oE`800?mK0`00ofH08000og000?mm003oX000l?`05S?o03TPo`10T^H0
0:Oo003ln000onT00?gh00fJo`09GOl005Oo01I7o`0>;?l01Bko002=o`00V?l006;o003hl000omd0
0?oA003oaP00okl00?nc003o[`00oj<00?nH003oU000ohD00?n12P00ogD07000oh400?n5003oS@00
oiP00?nW003obP00l?P0:5ko01I;o`00fO000?nc003oX000oi`00?nT003o_`05]?@00?oY05U:o`00
a_`00?c`002co`00olh00?n=003oM@00ofH00?mO003oE`00odl3003oA`04003o@000ocP00?ll003o
?0800?lh00l00?m0003oA000odL00?m?003oQ@00oiP00?mb003oMP00ohT00>SE00>Om`00oj000?n=
003oQ@00ohd00P00ok<02000m>d077oo01DWo`00bNd00?Rg003oO@00ofX00?mV1000oel01P00ofX0
4=Fc003oaP00ojP00?bk003oI`800?mS00T00?mZ003oLP00ohd00=CL002Dj@10`;`00?nH003oG`00
odL00P00ocP2003o=0800?lh00`00?m4003oMP00iM803FC/003oMP00oc`00?l`003o8@00ob@00?lJ
00Go0009o`0301Co000301co000So`008?l000D08ol01?ooool00ol0003oooooooooo`06ooooo`00
8Oooool06_l0003oooooooooooooool00?lI003o9@00obP00?ld003o@P00oe/00?mb003d^`00omD0
09co02Bdn002R_l00?cU003>m000fNH05X3Q002[f@00]oP00>bj003oR@00gGd00?lX0P00oaT00`00
o`l00?l:003o2P0C003o2P03003o3P00oa800?lI00<00?lI01@00?lM003o8@00obP00?lX003o<000
ocP00?m0003oC`0I`9@00?nL003oT@00hKl00EGo00F`o000olH00?n[003X]`00ohd00?mi003oLP80
0?mV00@00?mT003oG`00of<00?mO0P00of<3003oIP09003oJP00og<00?mm003oW000ok/00?oQ042N
_000on400?oM00800?oI01000?oV003Yo000Z?l02H?o002To`05=_l0Eaco001no`00d_l00<ko003[
l000omD00?o:003o`P00okL00?nc0P00oj<2003oU003003oR000ohD00?n500P00?me01d00?mm003o
Q@00ohD00?n=003oU000oj<00?o>0032n00YCol0;9Ko003oi@00okl00?n_003oZ`00okl00=gh002g
o`0EL?l0:hca003li@00olH00?oQ001^o`0=`:l00?me003oIP00oel00?mG003oDP05003oA`800?m4
00h00?m0003oA000odL00?m7003oC`00oe/00?nH003oeP00j<h00?nT003oW000olH00<;]003oZ`80
0?nL00/00<;E003Qo`00m>D0097o002[o`00hNP00=ke05F0a`00ogH00?mS003oF`04003oE`0B003o
F`00j:<00?n1003oG`00of/00?mC003oC`00oe<00?mK003oJP00ojP00<oI003oS@00gM800>7o003o
IP00od000?l`0`00obP03@00ob/00?l`003o?000oe<00?nT032Ff@00ofX00?ld003o7@00oaH00Ol;
00Co0`09o`000`0Do`000`0Lo`008ol002?o000402?o000302Oo000[o`3ooooo00?ooooo00?o0000
ooooooooool01_ooool0027ooooo01ko0000oooooooooooooooo003o5P00oaT00?lX003o=000odD0
0?mK003oKP00ohd00?c:003/m000Iol0DQK00029o`00j=D00?[2003Qh@00okl00>SE003dS@00odP0
0?lh003o:000oad00?lI003o5`00oa8B003o2P04003o3@00o`h00?lI003o7@<00?lI0P00obD2003o
:00B003o;000ocP00?lh003o@000odl00?mO003oJP00ogd00?nE003XdP0l<ol00?3d003oeP00__P0
0?nT003oS@00oh400?me2@00ofH07P00ofX00?mb003oM@00ogd00?n9003oV000ojL00?ng003o^`00
okl00?o2003obP00omT00?oY003ho000hOl00<[o0021o`2H7[800:So003Mo`00n?l00?o[003oe@00
olX00?o2003o/`00oj/00?nS003oX0800?nD00X00?n8003oQ@00ohD00?n5003oO@00ogD00?mm003o
N@00ogD00?mj1000ohD2003oU00?003oX`00okL00>7Y003Nn00eD_l00=Wh003oeP00olH00?o:003`
i@00iOP0>E;o054oiP00n>/00?nk00800?n[00D00?nT003/[`00ogD00?mV003oG`02003oE`800?m;
2000odL02`00od/00?mG003oG`00ogX04KSI00VJo`00ROl01Jg`003hk00E]^d00?nk00800?ng00`0
0?CU002@o`10K>h00:_h003Me@00ok<00>7[003oP@00ofH00?mO003oD`00odl2003oA`800?m?00<0
0?mO003oC`00od/01000odL02`00oeL00?mS003oW00Rb/L00?mS003oI`00ogd00=61003o=000obP0
0?lU00800?lQ00`00?lV003o:000oc@00?m?003oP@00m?P00>bc003oB`00oaH00?l:00Co0P09o`03
01Co000301co000So`008ol000<08ol000@09ol002_o000co`00<ol01?ooool00ol0003ooooooooo
o`06ooooo`008Oooool06ol0003oooooooooooooool00?l>003o6@00obD00?ld003oE`00ofh00?mm
003oT@00d]d00:Co040ZhP0=@_l00<[o003o^P00ohl00?n1003oKP00ogH00?mC003o?000oc000?lX
003o7@02003o6@03003o5P00oa800?l:00`00?l:00D00?l>003o2P00o`h00?l:003o4P04003o6@03
003o9@00obP00?lX00800?lX01@00?l]003o=000ocP00?lh003oA`00odl00?mG003oIP00ogd00?nL
003oc`09U_l0=eWo003:o`0=G?P0@9[K002Em000ok/00?mm003oLPP00?mV01`00?m^003oM@00ogD0
0?n1003oQ@00oi400?nH003oX`00oj/00?nc003o^`00ol800?o?003oh@00oo@00?So002[o`09DOl0
P@j0034do`00^ol00?So003ol000omd00?o:003o_`00ok<00?n[0P00oj<2003oU003003oS`00ohT0
0?n500T00?n501P00?n9003oT@00oi@00?nH003oX`00ojl00?no003ej00oKol08VWo003ol@00onD0
0?3h05QN`00=G?l00Vco01Eco`00fOP00?n_003oV000oi400?n9003oN@00ofh2003oIP<00?mG00H0
0?m?003oA`00odL00?m7003oB`00odL2003oB`0H003oBP00oe<00?mG003oIP00ofh00?nL003o]`00
a_`0;:W/01FYm00PUOd00?oX002_m000o>d0>jWh001Ko`0Y=?l02Jgd003oZ000oi400?nN003oN@00
oel00?mC1000odL00`00od@00?m0003o@002003o@00@003o>000od000?lh003o@000odL00?mZ003o
aP0H`ll00?m?003o@000oc`00?ld003o9@00oad00?lI003o7@800?lI00X00?lM003o<000dJ000?nk
002cf@00m<X07<1Z003o4P03o`D02?l00`0Do`000`0Po`008ol002?o000302?o000302ko000[o`00
<ol00080<ol01?ooool00ol0003oooooooooo`06ooooo`008Oooool06ol0003oooooooooooooool0
0?l:003o6@00obD00?mC003[YP0=`=800<[E003o/`00a^d0Obc^00Tbo`00Y?l04KSd003o/`00oh00
0?mZ003oF`00oe<00?m4003o>000oc@00?lX003o9@04003o6@03003o2P00oa800?l:00`00?l:00<0
0?l>003o4P00oaT00P00oaT00`00oad00?lX003o<002003o>0800?ld0`00ocP04`00od@00?m7003o
C`00oeL00?mV003oQ@00fN407J;j0415l@290>H0@7_0003dm00c_>`0>l3M003oV000oh400?me003o
L`00ofX01000ofH00`00ofX00?m^003oM@02003oM@0G003oQ@00ohT00?nA003oU000oi`00?nS003o
Z`00ok<00?o2003oc`00onT00?oh003do`00b_l0;5So01<>o`00H_l00:oo003Uo`0Cb?l00:ol003o
e@00ol800P00ok<00`00ojL00?nS003oW002003oU003003oS@00ohT00?n500L00?n501T00?n9003o
U000oi@00?nD003oW000oj<00?n_003o_`00om@00?3l021Eo`00c_l00;oo001Oo`0k:ol00=Ko003l
k@00a_P0:m35003oX000oi400?n5003oP@00ogD00?m^00800?mV00P00?mK003oE`00oeL00?mG003o
D`00odl00?m;003oC`800?m;01P00?mC003oE000oeL00?mK003oIP00ofh00?n1003oU@00oj@00?ng
003odP00Sod009co001fo`00/?l03FCo01F3o`00jO`00<kX003oV000oh400?m`003oH`00oeL2003o
A`03003oA000oc`00?lh00D00?lh0P00oc@3003o>007003oB`00ogH00>JQ003o@000ob`00?lX003o
8@03003o6@0=003o5P00oa800?lD003o6@00ob400?l`003oF`00ofL00=GE003o@000oa800ol500go
000201Co000301co000Po`008ol000<08ol000<0;ol0033o000co`000`0co`04ooooo`03o`000?oo
oooooooo00Kooooo0002ooooo`;o00001?ooool00ol0003oooooooooo`02ooooo`;o00000oooool5
o`000003ooooool0003o000000?o00001?ooool07?l0003oooooooooooooool00?l:003o4P00ob40
1=E^003oR`00hi800?>^00VOn000hM400;S`0032m@0aDO<00=kX003o^`00n8d00?mT003oE`00odX0
0?m0003o>000obh00?lX003o9P00oa`4003o6@0?003o5000o`l00?l?003o2P00o`d00?l:003o3000
o`X00?l=003o2P00o`l00?l=003o4P00oa@00?lG00<00?lI00H00?lQ003o:`00ocH00?mh003oJ`00
odL2003o?@0D003o?`00odD00?m5003oA`00od`00?mE003oFP00ofH00?mh02_EQP00e_006j3j00iR
o`00b_l00?oD003o^000oj<00?n?003oQ@00ogP2003oM@800?mc00<00?m`003oL`00ogD00`00ogD0
6`00ogX00?n5003oQ@00ohl00?nD003oV@00oj<00?nV003o/`00okd00>kT022ao@00g?l00=oo0037
o`00P?l0GQSk0012o`09O?l00;go03Meo000g_d00?oN003obP00ok/00?nc003oZ`02003oX`03003o
W000oi@00?nD00800?nB00L00?n?003oS@00ohd00?n=003oS`00oi400?nB00800?nD01L00?nG003o
W000oj<00?nY003o/`00ok/00?o>003okP00aOl09V?o0030o@00hoP01<?h003jgP00olD00?o2003o
^@00oiT00?n:003oQ@00ogd00?me003oL003003oIP03003oFP00oeL00?mG00L00?mG01T00?mI003o
G`00of@00?mY003oL`00ogd00?n=003oW000oj/00?oG00bbo@1^4>l0P03o00]3o`00^?l00?[[003o
`P00i[d00?n:003oM@00ofH00?mG003oBP00odL00?m500<00?lh00@00?lf003o<000obd00?l[0P00
obP03@00ob/00?lX003o:000obd00?lh003oI00LfV800?lX003o7P00oaT00?lG003o5000o`l00`00
o`X03@00o``00?l:003o3`00oa@00?lN003o;P00iZH00?mY003o;P05o`004Ol001Co000Lo`00100S
o`000`0Vo`00;_l002ko000503?o00Cooooo00?o0000ooooooooool01_ooool00005ooooool0003o
ooooooooool000002_ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo
00000_ooool00ol0003oooooooooo`02ooooo`0<o`000?ooooooooooooooo`00o`X00?l>003o6@00
oad00?lc003oE`00l;h00=7B0P00oi402`00ok<00>c`071>a`00QOl00?Ff003oJP00oeL00?m7003o
@000ocP00?ld00<00?lX1`00oaT02000oa800?lI003o2P00oa@00?l:003o5P00oa800?lF1P00oaT0
1`00oad00?lX003o=000od@00<JE01VFi@00of<00`00odl04@00oe<00?mG003oE`00oeL00?mK003o
IP00ofX00?me003oT@00ojh00>7M041```00M_l00?cQ003o/`00oi`00?nD00800?n500<00?mh003o
M@00ogD01`00ogD3003oQ@800?nD01L00?nL003oX`00oj<00?nc003o^`00n>P00:_o05`Ro`10Kl00
09So05PBo`380;X0b02Z07`F``0T>_l007So003>o`00gO`00?3Y003oaP00okL00?nc003oZ`03003o
X`03003oW000oi@00?nD00<00?nD00<00?nH003oX000oih00P00oi`04`00oj000?nS003oX`00oj<0
0?nc003o]`00olH00?oI003Mo`0XLol00<[o003ok@00omD00?o:003o_`00okL00?nW003oW000oi@0
0P00ohD3003oM@05003oJP00ofH00?mV003oI000oel01000oeL2003oF`0H003oG`00of<00?mV003o
IP00ofX00?mb003oM@00oh400?nA003oX000ojl00?oF02^9l`0=;_l0Z03000hLo`10DN800=Wd003o
^`00oi`00?n9003oN@00ofH00?mG0P00odL3003o>003003o<000obP00?lX00D00?lX0P00obD2003o
:004003o<000obP00?lQ003o6@800?l>2P00o`X01`00oaH00>6H003o;@04o`<03Ol001Co000Ho`00
1@0So`000`0[o`00<ol003?o000403?o000303_o0?oooooooooo00;ooooo00?o0000ooooooooool0
1_ooool00005ooooool0003oooooooooool000002oooool01Ol0003ooooooooooooooooo000000Go
oooo00?o0000ooooooooool01?ooool06Ol0003oooooooooooooool00_l8003o2P00oa800?lI003o
;@00of<0=kcd003oU000ofh00?mf003de@00k?`0@3[m003dk000ojH00?m^003oG`00od/00?m4003o
>000oc@00`00obP00`00oah00?lI003o6@0A003o6@0=003o7P00obP00?l/003oA000iHT00?nE02RQ
d@00ogH00?m^003oOP00og<00?nH003oI`02003oG`800?mV00h00?mb003oM@00ohD00?nS003obP00
eOP0MdkV003oj@00olh00?nW003oU000ohd00?n5003oP0D00?me00<00?mi003oM@00ogd00`00ohD0
6P00oi400?nD003oU000oi`00?nS003oY`00ok<00?nk003od@00oo@00=[o001No`0e?ol0Lb300;`0
^@380;X0>QKo002Lo`06Iol0P4^<04To`000b_`00?oF003o_`00okL00?nc0P00oj/00`00ojH00?nW
003oX`02003oX`06003oX000oj<00?n_003obP0[eLd00?nW0`00oj<04@00ojL00?n_003o]`00olh0
0?c]003okP00eOl0@RS0015Xo`00onT00?o>003o_`00ok<00?nW003oX`00oiL00?n=00800?n500@0
0?mi003oM@00ogD00?mb1@00ofH00`00of<00?mO003oH`02003oIP03003oJP00ogH00?n200<00?me
01@00?n1003oS@00c[h00?o2003o``00omT00>7m001io`0i4Ol0Y`3J002Po`00m?P00?no003oY`00
oi`00?nD003oL000oeL00?m7003o?0800?lh00<00?l`003o;000obP00P00obP2003o9@04003o7@00
oaT00?lM003o7@@00?lI00<00?lF003o3P00o`X01000o`X200?o1@0300Go0004o`<01?l300800ol5
00L00_l8003o=@04o`<02Ol001Co000Go`008?l000@08ol000@0:ol003?o000co`00;ol0100co`00
0`0go`3oooooooooo`02ooooo`03o`000?oooooooooo00Kooooo00001Ooooooo0000oooooooooooo
000000Sooooo1?l00004ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool2
o`0000;ooooo01H00ol5003o2P00o`X00?lI003o9P00oe<00?mK003oC`00oeL00?mS003oQ@00n=d0
0>cU00FQo006eJ/00?mm003oMP00oel00?m;003o?000ocP00?l/0P00obP00`00obH00?lM003o6@0@
003o6@0?003o7@00ob<00?lX003o=000od@00?R_003l]`00l=T08<3J003oW000a/h00=_F003o]`00
ogT00?m^00800?mV00h00?m^003oM@00ogd00?n5003o/`00^o`00;_o02Tco`09W_l00<k`003o/`00
oi`00?nD003oR@800?n500D00?mm003oN@00ogT00?mi003oO@03003oQ@05003oR000oi@00?nD003o
U000oiP00P00oj<04`00ojl00?nc003o^`00om400?3l01E=o`15D_T00;Oo01U9o`00??l0S0k0009H
o`00`ol00=co003Yo`0A`?`00?oU003od@00ol800P00okL2003o/`04003o^000ol800<[B003o[`80
0?n[00H00?n_003oaP00U?l00?[I003o]`00ok<2003o[`800?nc00/00?no003og@0gH?l00>Co002E
o`1a:ML00>go003oj@00olh00?nk003o/`02003oX`05003oU000oi400?n5003oQ@00ogd00`00ogD0
0`00ofh00?mV003oIP05003oIP800?m^00<00?mi003I_P00oK000`00ohD05000ohd00?nH003odP05
WO`00?oU003dm002Q?l083[o040O``05G?l08a[o0033o000omd00?CU002jj@0g/?@00?G0003oG`00
odL00?m00P00ocP4003o:005003o9P00oad00?lI003o6@00oad01000oaT00`00oaH00?lB003o2P03
003o2P0300;o2004o`<01Ol000T01Ol000@03Ol001Co000Do`006Ol0100So`000`0Wo`00;ol003?o
000503?o0080@_l00oooool2o`0000Sooooo00001Ooooooo0000oooooooooooo000000Oooooo00Oo
0000ooooooooooooooooo`000?oooooo000000?ooooo00?o0000ooooool000000oooool00ol0003o
ooooooooo`02ooooo`05o`000?ooooooooooooooo`03o`D00P00o`X04@00oaH00?lQ003o;000ocP0
0?m0003oA`00oe/00?m^003oR@00om804FCo02_E]000ojP0@7oa003oO@00oe<00?m400800?lh0`00
obP00`00obD00?lQ003o6@02003o6@03003o7@00oaT00?lI00D00?lI00H00?lM003o6@00oaT00?lI
003o7@00ob42003o:00=003o>000od000?m?003oI`00gJ/00;_Y02RMo`0c]>T00:K`003oW000ohT0
0?mm003oN@02003oO@0=003oP@00ohD00?n=003oYP00a_P0@E;e07LRo`00^ol00;oo042dkP00oj/0
0?nD003oT@09003oQ@05003oR@00oi800?nD003oW000oj000P00oj<04`00ojL00?nc003o/`00okl0
0?oA003Io000_ol00>Go003Eo`00^ol006Ko01hAo`00SOl00<Ko003^o`00oo`00?o]003of@00om40
0P00olH2003o_`0=003o^`00oll00=;o03?0l000okl00?nk003o]`00ol<00>g/06Qam@00mNd00?o6
003o^`02003o/`0?003o]`00okl00?o:003ol@00aol0:gkE02dgo`00POl00>7o003dm000omH00?no
003o/`00ojL00?nS00800?nD0`00ohD4003oM@07003oLP00ofT00?mV003oJP00ofh00?mb003oM@02
003oN@04003oS@00eMd00;[I003oV0800?n=01<00?nH003h_P00fNT009Go003Qo`00Y?l0IDSC01V`
o`00Z?l00<ko003`m00TVOl05GCo042B``02]>T09<3U003`YP00ofH00?m700800?lh00H00?l/003o
:000obP00?lX003o9@00oah6003o6@03003o5P00o`h00?l:00@00?l:00<00ol500Co0`05o`001P05
o`001009o`003Ol0017o000Ao`0201Co000301So000Qo`008ol000<08ol0200co`0204;o00Cooooo
00?o0000ooooooooool01_ooool00005ooooool0003oooooooooool000001oooool01ol0003ooooo
oooooooooooo0000ooooool000000oooool00ol0003oooooo`000003ooooo`03o`000?oooooooooo
00;ooooo01_o0000oooooooooooooooo00;o2000o`X00?l>003o5P00oa`00?lX003o;000ocP00?m4
003oF`00ofh00?n=003o^`0T]?`00;Sj003Mk@00l<X00?n5003oI`00od/00?m0003o>000oc001000
obP00`00ob400?lM003o7@05003o6@03003o7@00oaT00?lI00800?lI00<00?lM003o6@00obP00P00
obP04@00oc000?lh003o@000odL00?mO003oO@00oj/00<kh04H0o`00hN/00?ng003oW000oj`00?nH
003`]`00ohd00?n500800?nD00/00?nY003oeP00eO`0K3C7003hm000o>D00?o3003oY`00oiP00?nD
003oRP07003oQ@08003oR@00oi400?nG003oY`00ojl00?n[003o[`00oj/2003o/`0@003o_`00ol80
0?o?003oi@00oo@00?co003Yo`02I?l00TWo0805P01`7Od06H[o003`o`00ooP00?oY003og@800?oA
00P00?o6003o`P00olX00?o:003mh`10Ol000=Wh003oe@800?o:00H00?oI002[o`1E4_l037Gm003M
i@00olH3003o`P0<003oaP00omT05HOo00Ugo`0/C_H0g010040^b`10OoD02I;o003oh@00okl00?nc
0P00oj<2003oU005003oR@00ohD00?n5003oP@00ogT01`00ogD02000ogd00?nH003oS@00ohd00?nP
003Ij00RR?L00?nc0P00oi`05@00oj<00?nk003Ql010U]h0O0[m0014o`00^ol00?oU003Mj000om80
0?o:003oj@1/N>h00?no003oU@00ohD00?mT003oC`00od000?lh003o=003003o:003003o9@00oad0
0?lI00D00?lI1P00o`X01002o`P00ol500Co0`04o`<500Go000400Wo000Ao`004Ol0017o00@05?l0
00<08?l002?o000So`000P0So`000`0[o`00;ol003?o000503?o000303_o000oo`00?ol000Cooooo
00?o0000ooooooooool01_ooool000;ooooo0_l00009ooooo`?o00000oooool3o`0000?ooooo0ol0
0005ooooo`05o`000?ooooooooooooooo`02o`P00P00o`X04P00oa800?lI003o9@00ob`00?ld003o
@000eHD0093Q003Ie@00olh008go05Dhb@00gO00DGWG002gm000iLH00?mj003oA0800?lh00<00?l`
003o:000obP00P00obP01000obD00?lX003o6@00ob42003o6@03003o7000ob400?lI00800?lI0P00
obD4003o:00@003o=000ocP00?m0003oA`00j8D00>6o003Mg@10ZMh07Uko01=fo`00hO`00?o201J0
k00IU_000?3J003oX0800?nL00X00?nP003oZ`00iMd00=gl019Uo`00oo000?o:003o]`00ojL00?nP
0P00oi@01@00oi400?n9003oR@00ohD00?n900800?nA00D00?nD003oV000oj<00=;M003le@02003o
]`800?nc01800?no003o`P00ol800?oA003oh@00onT00?oh003]o`10V/0005Oo03hBo`00I_l008Wo
003[o`00oo`00?o`003oh@00omT4003od@0>003oe@00`_P0KBg0009co`00eOl00?oM003of@00onT0
0>Wo001;o`00g?l00?oY003od@00olh2003obP0B003od@00omd00?oh003Yo`06UOl0U`[0040ko`00
K_l06IKo00W0m000olh00?nc003oY`00oj<00?nI003oU000oi400?n=0P00ohD00`00oh400?mi003o
N@03003oM@0:003oN@00oh400=f/002gk000ok<00?nX003o/`00m>40:igT003o^`800?n_00T00?ng
003ocP00j>T00;?o084F[P0h>ol00?Ge003oaP00ok<00P00oj/02P00olX0@9W^003oh@00oi400?m^
003oF@00odL00?ll003o>000ob`3003o:003003o9@00oaT00?lI00<00?lI00<00?lB003o3P00o`h0
0P00o`X01000o`h00?l:00;o2003o`D600Go000400Wo000?o`005?l0017o00805?l000@04Ol001Co
000Do`008?l01@0So`0703?o000403_o0012o`00@_l004;o00Cooooo00?o0000ooooooooool01_oo
ool0027ooooo00Co0000oooooooooooooooo0`00o`X04`00oaH00?lI003o8@00obP00?ld003o?000
oeL00?nH003hdP05F?P0?Eko02^6j@00ok/00?nP003E[`00ogH00?mK003oA`00oc`00P00ocP00`00
ob/00?lX003o:006003o:004003o9@00obH00?lU003o9@L00?lX01h00?l[003o>000ocP00?m0003o
B`00of<00?nH003o]`00]o000?oB04>Kl@12JL0079;o02eeo`00e_l00?oF003o^`00ok<00?ng003o
[`00ok/00?oU0025o`10I>h0@8Zh003obP00okL00?n[003oX`00oiP9003oU006003oX000ol00@9Ki
003lj@00olX00?o61000ol808@00olH00?oA003oh@00oo000?ol003do`00eOl00:So06L/o`10F?40
0;oo003Qo`00lOl00?od003ok@00on400?oM003od@00omD00?oI003oh@00joX007go0021o`00lOl0
0?od003ol000m?`0:6co01U=o`00hod00?oY003of@03003od@0?003of@00onD00?oh003]o`00Jol0
@C_Z002go`00gOl00<;o003Mo000k=d00?nk003o/`00oj<00?nQ00<00?nD1@00ohD2003oO@0F003o
P@00ohD00?n9003oX000`^D05WWo003lj@00olX00?S/002^o@00om800?o2003oaP00fNT00?3d003:
o0058ol00:3o00VBo`00W?l00>G>003oX0800?nL00T01L3200:dn00gW_l00?ng003oP@00oeT00?m7
003o>000oc@00`00obP00`00ob400?lI003o6@03003o6@800?l>1@00o`X00`02o`L00ol500Go0006
00Go000300go000Do`005?l000D05?l01P0So`0202Oo00H0<ol000@0=ol004;o0012o`00@_l01?oo
ool00ol0003oooooooooo`06ooooo`008Oooool01?l0003oooooooooooooool3003o2P0C003o6@00
oa`00?lQ003o:000ob`00?lh003oA`00ofL00=WY003d_P00olh087co003oaP00ohd00?mb003oH`00
oeL00?m7003oA002003o>003003o<`00ob`00?lX01400?lX01l00?lc003o>000ocP00?m4003oA`00
oeL00?m^002cbP10WId00?nL003o^`00j>400:3o0;`0T`0oI?l00<Kh003oh@00__P00:3d003obP00
oll00?oY009Lo`00`_l00<kd003obP00okL00?n_003oX`00oj000?nI00D00?nD00X00?nH003oW000
oj<00?nW003o`000hO0078[o003Mo000]o000?oI0`00olX04@00om400?oD003oh@00n?P00>go003M
o`00d_l007Ko02dHo`0e9?l009So002ho`1oF]h00>go003oo000oo000?oY00<00?oQ02400?oY003e
nP00Z?l0JB;0041HiP00lOl00?So003Qo`0EJ?l0I3CC002Yo`00oo000?oQ003og@00omT00?oQ003o
i@00n?`00?So003Qo`1@B?<0@3KC002Ao`00n?l00?od003og@00olh00?no003o/`00ojl00?nV003o
X`00oiP00P00oi@00`00oi400?n5003oQ@03003oQ@0F003oR@00ohD00?nA003oX000fO000;_o041T
e`00RO`00>7o02^WmP00on400?oI003oi@00VOl06U;o08@>`000Z?l00=ga003dn006b>400?nX003o
T@800?n=00T00?nE003o[000`^T0@7_V00V]eP00of400?m0003o>000oc@00`00obP00`00oad00?lI
003o6@03003o6@03003o3P00o`X00?l:00@00?l:00<00ol300Go0005o`001@05o`000`0Do`004Ol0
01Co000401Co000301So000Lo`008?l000@08ol000<09ol003?o000co`001P0co`00100go`00>ol0
04;o0012o`04ooooo`03o`000?oooooooooo00Kooooo000Qooooo`04o`000?ooooooooooooooo`80
0?l:01800?lB003o6@00oaT00?lU003o:000oc000?lh003o@000oe/00?mj003oP@00j;L00;3g003o
bP00ohd00?mb003oG`00oeL2003oA`08003o?000ocP00?lh003o>000oc@00?l/003o:000ob`<003o
:003003o;000oc000?lh00800?lh01X00?m4003oA`00oe<00?mO003oW000oh400?n9003oW000omH0
0=Wl04U;iP00[?l0@6c707=No@1kC^X00=;o01Fhn000eoX00?7l00E`o`00iO`00?oM003obP00ok/0
0?nc003oZ`800?nS0P00oi`2003oX0800?nS01d00?nW003oZ`00ok<00?o:016No`1`9?D0<5Go003F
o`00onD00?oE003od@00omD00?oA003ogP00onT00?Co041``00=G?l00:oo002Lo`05?Ol06Rco00ET
o`06JOl008Go003Mo`00d_l00>Go003om002003oj@0N003ok@00oo000?So0025o`10</0008Go003B
o`00hOl009Co048_kP00W?l00>7o003oo000ond00?oU003oh@00onT00?oh00:Bo`00X?l00<Ko02];
e@00TOl00=[o003oo`00onT00?oI003ocP00ol800?nk0P00ok<00`00oj/00?nW003oX004003oU080
0?n=01H00?n:003oT@00oi@00?nD003oX`00ok/00?oI003:o000]ol01fWo02^El@0A_?`0@;Si003d
o`0=S_l0^02Z002Ao`00m?000?o:003odP0[bm000?nA0P00ohD02P00ogd00?n1003oT@00m>400=;X
0032n000ohX00?m4003o>000ob`2003o:003003o9@00oad00?lI00800?lI00<00?lB003o2P00o`h0
1@00o`X00`05o`001?l200Go000400Go00802Ol01`0Do`000`0Ho`008ol002?o000502?o000302oo
000co`00<ol000@0<ol000<0=_l004;o0012o`000P12o`04ooooo`03o`000?oooooooooo00Kooooo
000Qooooo`06o`000?ooooooooooooooo`00o`X00?l=0P00oaT05000oa`00?lX003o:`00oc<00?lh
003o@000odl00?mL003oMP00h;d0>HC102^Gb000l<D00?mk003oH@00oeL00?m?003oA`00odD00?m0
1@00ocP3003o=PH00?lc00<00?l`003o;@00oc000P00ocH3003o>00M003o>`00odL00?m7003oDP00
oeL00?mT003oKP00ogP00?>K00Jdf`00g^/00=O^003Qf@00ln400;So03iBo`0NP_l0067o03UehP00
^ol02GKo003cnP00on400?o?003oa@00okd00?nc003oZ`00ojP00P00oj<01@00ojH00?n[003o^000
jmh00?o:00800?o003T00?oC003Io@0CM?l02gKo003`o`00oo000?oT003og000oml00?oQ003oh`00
oo<00?Go0035o`09Iol005Co00a4o`2M0]<0`P9J06d9e`0Y;^<03dOo03U8n@01D?l00=ko003mo`00
ooD00?o`003om@00ooX00?So003Io`00W?l0GQVZ03QFo`00ZOl09CWo0615jP04UOl00>go003oo@00
ooD00?o`003ol`00oOP009ko002Do`0<<_l066Go03DTo`0@O_l00;7o003?o`00oo000?oO003oe000
oll00P00olL01000oMd0?I?B003obP00ojh2003oZ004003m]@00ojd00?n^003oW0800?nD01H00?nG
003oX@00oj<00?nc003o`P00omL00?o^003Yo`0:Dol066co04=2e@0[KmD0BU7L006Jo`00Y_l00=WV
003o]P00oj<00?nB003oP`00ogP00?me0P00og002000ogD00?mm003oL`00ogd00?n7003o@000ocP0
0?l[0P00obP01`00oah00?lI003o6@00oaT00?lG003o3`00o`d01@00o`X00`02o`L01?l200Go0005
00Go000301;o000Do`005?l000D05?l000<08Ol002?o000Qo`00100So`001@0Vo`00;_l002ko000c
o`00<Ol000@0<ol000<0=Ol0043o0012o`000P12o`04ooooo`03o`000?oooooooooo00Kooooo000Q
ooooo`05o`000?ooooooooooooooo`00oaH00P00oaT04`00ob400?lV003o:000ob`00?lh003o?000
odL00?m?003oE`00ofh00?nc02^Zj@02^?000;?E003:Z000ofH00?mK003oE`00od/00P00odL01@00
odD00?m0003o?000ocP00?ll00@00?lh00<00?m0003o?@00od002@00ocP07@00od000?m4003oA`00
odL00?mC003oE`00of<00?mV003oKP00ogd00?n9003d]`00ok<00?n[003o^`10`:400=g`003of@00
onD00?oV003lo014?ol04D;o03^do`00on400?oI003ocP00okl00?nk00@00?nc00d00?nk003dh@10
S]h00>7d003oi@00omT00?oQ003Uo000OOl0Y2G[001bo`00hOl00?od00<00?oY01000?o`003lo000
]ol0@5G;00Dbo`0ICOl04BKo09`0`0340:h0a@2n001[o`00X?l00;3o0036o`00jOl00?Co1000ool0
2`00l?l00>7o003:o`00[?l04T?o048`n@0=G?l00;Oo003Eo`00jol00?co00<00?oo00`00?Co002g
o`00POl007ko05@=`03b0600MbS0008bo`00`ol00>So003ol@00on42003of@0;003oi@0oJ?l05Hko
003ofP00okl00?nk003oa`00fN`07;Sl003o_`00ojL01000oj<04@00ojl00?ng003o`P00om400?oY
00:Jo`00Lol0o`2Y0:/0o`00C?l00;_o003ho000on400?o3003oZ`00oi`00?n:00800?me0P00ofH0
2000of<00?mO003oE`00oeL00?mC003oC000ocP00?ld0`00obP5003o6@H00?l:00<00ol500Go0005
o`001@05o`0200go0003017o000Do`005?l000@05?l000<06?l002?o000So`00100So`000`0Wo`00
<ol003?o000703?o000403Oo000ko`00?ol004;o00Cooooo00?o0000ooooooooool01_ooool0027o
oooo00Co0000oooooooooooooooo0P00oaT01000obD00?lX003o:000oc02003o>00<003oA000odL0
0?mC003oG`00ofh00?n5003`c`00eN`00?nP003oO@00ofh00?mV0P00oeL00`00odl00?m;003oA`04
003oA`03003oB`00odL00?m700800?m700@00?m?003oE`00od/00?m40P00oc`2003o>005003o?000
ocP00?lk003oA000odL00P00od/05`00oe<00?mG003oE`00ofH00?mZ003oL`00oh400?n9003oU000
oiP00?nS003oZ`00okL00?nk003o`P00om@00?c]041gn@20=il00<ko003ho00I/Ol00?3d00800?oM
01800?o0003o]`00ok<00?nk003oaP00b^400;_o02Pno`00`ol00?oa003ol000hOl007ko074B`000
[?l00>Go003oo000oo@2003ol00?003om@00n?l00=[o002=o`00X?l009So001Oo`0T7ol0N03o000a
o`0;NOl00:_o0036o`00eOl00>7o00800?3o00d00?Co003ho`00l?l00>_o003Qo`00b_l00;_o0021
o`1Q6]<00:3o002oo`00eOl00>Co00<00?3o00d00>go003Uo`00fOl00;_o002Lo`00A?l0L`3o001S
o`0LH?l0H2c0041/`000l?`00?o]00800?oU00@00?oh02^On`00Y?l00?S`0P00omD01P0IS_P03FSo
003Qm000ol<00?nc003oYP800?nW01H00?n_003o]`00olH00?o>003of@00oo400;?o01/mo`1Y0?l0
f`2m03`Io`0;B_l00>Sl003of@00ol800?n_003oX000ohX00?me003oJP00ofH00?mS0P00oeL02@00
oe<00?m;003oA`00od000?lh003o<000ob`00?lX003o9@04003o6@03003o4P00o`X00?l:00D00?l:
00<01?l300Go0005o`000`05o`000`0=o`005?l001Co000501Co000401So000So`008ol0023o00H0
8ol000<0:ol003?o000_o`001@0co`000`0ho`00@_l004;o000204;o00Cooooo00?o0000oooooooo
ool01_ooool0027ooooo00So0000oooooooooooooooo003o7@00obD00?ld003o<0800?lh00d00?ll
003oA000odL00?m?003oE`00of<00?m^003oQ@00j=T0@8jh003oZ`00oh400?me00800?mV01000?mO
003oE`00oeL00?m?003oD`00odl00?mG003oH`00ogX00?mK003oC`00oe<00?mK003oW000okl00?mO
0P00odL01P00od@00?ll003o@000od000?m4003oA@<00?m700@00?m?003oE`00oeL00?mG0P00ofH0
5@00og<00?mi003oQ@00ohD00?nA003oU000oj000?nW003o[`00okL00?o7003of@00n?`06G_o020j
o`00aol0DF7i002oo`00C?l00>ch003oc003003o`P0N003ocP00onT008go05TYo`00Yol00:So003e
o`00hOl008Wo04Poo`0/VOl00>Wo003lo`00ool00?ol003on000ool00?Co003Yo`00eOl00<;o002[
o`00SOl005ko08@3`00=7ol007go002_o`00`_l00=7o0P00hOl04@00jOl00?3o003Yo`00iOl00=ko
003Eo`00b_l00W_o001Oo`1K9?l007Ko002go`00c_l00=Wo003Qo`00iOl00>7o00800=Wo01P00<ko
002go`0EF?l0;3Ko04P^o`00V?l00;Oo003:o`00iOl00?co003on000oo000?od003ho`1SElh00Xko
003lo000onT00?Cd002go`1<<?l0<E[o003oeP00okl3003o/`03003o]`00olH00?Sd00800?oY00h0
0?oh003Fo`00U?l08`ko0=<0V`210jh0097o002oo`00onD00?oF003odP00o<h00?nI003oM@800?mV
0P00oeL01000oe<00?m;003oA`00od@2003o>0@00?lX1000oaT00`00oa800?l:003o2P03003o2P03
00?o1@05o`001Ol000H01Ol000<03Ol001Co000Do`00100Do`000`0Ho`008ol002?o000602?o00T0
<ol000<0>ol004;o0012o`000P12o`04ooooo`03o`000?oooooooooo00Kooooo000Qooooo`0<o`00
0?ooooooooooooooo`00obP00?lh003oU000odl00?m0003oA000odL00?m;0P00of<07000ofX00?mb
003oO@00oiD00?o0002_l000oj`00?nA003oP@00ogd00?mb003oKP00ofX00?mV003oFP00oeL00?mO
003oH`00gJl0Eh36003oKP00oel00?mZ003oU@00mlL00?n1003oG`00oe<9003oA`05003oB`00oe<0
0?mG003oE`00oe/00P00ofH00`00og000?me003oO@02003oQ@0Q003oU000oiP00?nP003oY`00ok<0
0?o5003oh@00o?`00<[o00Tfo`1K6Ol0@47e0025o`00b_l00?c]003oeP00olX00?o>003od@00omD0
0?oY003lo000`_l0EQ[0001bo`00col00<ko01Hko`2:8_l00:So003Yo`00l?l00?So00800?oo00l0
0?[o003`o`00iOl00=Go003:o`00W?l005?o001<o`2O1oT0<Pko00<do`00W?l00;_o003>o`00dOl0
0P00fOl07000gOl00=Go03n3o`00aOl00<Ko002go`0PL?l04`?o0=<0XP0E<_l008Go002oo`00aOl0
0;ko003:o`00X?l009Go003:o`00_ol00:3o05`No`1I1l00BASE0029o`00_ol00=Wo003Yo`00m?l2
003oo`0<003lo`00kOl00hKo002Po`00lOl00?Co0423m@0PCOl06JWo003do000omd00?o20P00ok/0
5P00okl00?o6003oe@10YL000;Oo003ho`00lOl00<;o00U>o`0e5?l0f`3g060PkP0/=_l00;?o003/
o000OOl01G?o002Lo000n/D00?me003oIP00oel2003oE`06003oB`00odL00?m7003o?000ocP00?ld
0`00obP00`00ob400?lI003o6@02003o6@03003o4P00o`X00?l>00<00?l:00<00_l800Go0005o`00
1005o`001009o`005?l001Co000Ao`0601Co00808?l01P0So`0:03?o000403_o000oo`00?ol004;o
00Cooooo00?o0000ooooooooool01_ooool0027ooooo0_l00002ooooo`0I003o=000oe00@8JJ003o
U000oe800?m?003oD`00of<0=kbn003oX000ogd00?n9003ocP00o<800=c]00FMo000kND00?S>003o
`P00oi400?nL042dTP00k:P04L2c003oKP02003oIP0<003oMP00j<X01Gol003oW000ogT00?n5003X
g@10S/P00?nD003oH`00oeL00?mC0P00odL00`00od/00?m7003oA`02003oA`03003oB`00oe<00?mG
00800?mG00H00?mS003oIP00ofH00?m`003oM@00ogT2003oQ@0P003oT@00oi@00?nL003oX`00ojl0
0?o5002[o01AIL0009So0=L0P03109004F3o003Fo`00n?l00?o`003ogP00omD00?oA003oe@00omd0
0?o]003on000b_l09D[o00U9o`0^CmD00:Co040^m@00T?l00<Ko003Qo`00kOl4003`o`0=003Uo`00
hOl00=7o0036o`00Zol005Oo06D3hP2U0:80nP1O01P@o`0U9?l00:_o0032o`020036o`0M002jo`00
b_l00;_o04`/o`0]L?l00;?o002_o`00SOl005?o04D3o`00Gol0097o002Wo`00XOl0ZRGJ002To`0R
Aol03DGo002Wo`00Zol009co001Vo`1U2/L0<RKo001Go`00^ol00=7o003Qo`00kOl00P00m?l09P00
l?l00>Go002?o`0[9Ol00<ko041oe`05BOl0;4go016]o`00onT00?oI003ocP00olD00?o6003obP00
o>D00?Cd003Bo`10E=X00=Wo002ko`0E?Ol0M13E002=o`0ADOl0@7oZ002go`00OOl0@V;J00fho000
n>400=g:003oS`00og800?mV003oG`00oeL00?mC0P00odL01@00od@00?lh003o>000oc@00?l`0080
0?lX00<00?lU003o7@00oaT00P00oaT00`00oa800?l:003o2P03003o2P800ol500<01?l300Go0005
o`000P05o`000`09o`005?l001Co000501Co000301So000So`008ol000L08ol000<09ol002_o000[
o`001`0co`00100go`00?ol004;o0012o`03ooooo`;o00002?ooool0027ooooo02[o0000oooooooo
oooooooo003oG`00ofL0P82G003oW000of@00?mO003oI`00n<800?CB003o`P00oj000>7>002To00g
XOl00=cS003oa`0VP?@078ko003/l000olX00?o300:]m00IYO@00=fk003oNP00og800?mi003oP@00
ok<009co003o^`00oiP00<Zk003:k000d_000?Rg003oKP00oe/2003oE`06003oC`00od/00?m;003o
C`00od`00?mC0`00oeL2003oF`<00?mV00<00?m`003oM@00ogT00P00ohD04000oi400?nD003oW000
oj<00?n[003o_@00onD00>Wo021Xo`00NOl0@3Ka03mPo`0=T_l00?7o003oo000on/4003oh@0<003o
l000ooP00?Co003Eo`00TOl0@coT01X/o`0IG?l00:So003:o`00eOl00>7o0`00jOl03@00hOl00<Ko
003:o`00b_l00;oo002[o`10DO4004Co00XEo`1G1Ol005[o0029o`00Yol00P00/ol07@00W?l003So
002Do`00W?l09Bco001co`00X?l009co009To`00@?l0603o014bo`00O_l009Go002:o`1G4Ol006[o
07/:o`05AOl009Go002Lo`00Jol0053o04X0o`00Eol009So002go`00a_l00<[o00<00=Wo00/00=go
003Io`00^?l0<C_o03]=o`0EBOl007Wo003Bo`00iOl00?oY003og@03003od@0E003oe@00o?0008Go
001Ko`0XCOl008go001jo`305Z@03f?o003Fo`00C?l00=Wo003ln000lOl00W3o003`k@00ok/00?nL
003oQ@00ofh00?mV00800?mG00@00?mC003oA`00odL00?m40`00ocP3003o:003003o9@00oad00?lI
00800?lI00<00?lD003o2P00o`X00`00o`X800Go000300Wo000=o`005?l000@05?l000<06?l002?o
000So`001`0So`000`0_o`00<ol003?o000603?o000303Ko0012o`00@_l00080@_l01?ooool00ol0
003oooooooooo`06ooooo`008Oooool0:_l0003oooooooooooooool00=7o003Q[`00`o000>bc003o
M@00og800?n1003o[`00Z?P00;OY003Im00cS_`09FGo0223m000oj400?nH003UcP0I]?P00<;h041k
iP00Zo`009co003ofP00ojP00?n:003oQ@00ohT00?nA003o[00LXOP00>GU003o``0`[O00CD_0003o
^000ohT00?m^003oH`T00?mG0P00oe/00`00oel00?mV003oIP02003oIP800?me01<00?mi003oQ@00
ohD00?nA003oU000oi`00?nS003oZ`00ok/00?oI002Ho`00b_l00=;o00eMo`1a0?l006Ko003Bo`00
iOl03];m00800?ch0P00oo002`00oo@00?oo003ho`00iOl00<ko002`o`10@ol07S_o002Xo`00_ol0
0=7o00@00=Wo03/00<3o01ELo`00/ol00;_o002go`00Yol008go001^o`0Z3_l0_02^001Do`00ROl0
09Co002So`00X?l0087o05XBl@00Eol007;o080EP00[D=D008go0029o`0=COl0E`3V0<l0W`0Z0ol0
6AOo001fo`00N?l00S;o05T>o`1o3_l006?o001mo`00M_l0@3;N04T3o`2Q08@00cko002Eo`00Y?l0
09co0411`000/ol008Wo0025o`00b_l00<Ko002Lo`0N7?l0097o002co`00`_l00>go003oo`00oo00
0?oQ003og@02003of@0H003oi@00oo@00?7o0036o`00Iol0Q@3002TAo`00O_l00<;o003lo000o?@0
0?oU003oh@00oo400:Oo05aU`000n=d00?ng003oQ`00ogH00?mV003oF`00oeL00?mC0P00odL01@00
od@00?lh003o>000oc@00?l`00<00?lX1000oaT00`00oa800?l:003o2P03003o2P0500;o2004o`<0
1Ol000Go0004o`800P05o`000`0Ao`005?l001Co000701Co000301co000So`008ol000@08ol000<0
:?l003?o000co`001`0co`000`0fo`00@_l004;o000204;o00Cooooo00?o0000ooooooooool01_oo
ool0027ooooo02co0000oooooooooooooooo02C0[`00iND00;OX003oY000oiL00=gI003o/`00hN40
5G?o01/Yo`00[o`0>j7U003o^`00l<800?n2003oO@00ohd00?nT00G0aP00f_@02Rco01lao`00jO00
0?o>003o^P00j<800?nT003oX000ojl00?CQ02RUo`0EYO`098?h003`i@00oiL00?mm003oKP00ofH0
0?mS003oF`800?mG00H00?mK003oE`00oeL00?mK003oG`00of<5003oIP04003oLP00ogD00?me003o
P@800?n50P00oi@09000oj000?nS003o/`00okP00?o>003oj@00ooP00?7o002`o`00K_l04CKo042;
hP00SOl0;HOo001^o`00d_l00?oo003oo000ool00?co003`o`00hOl00=Go002`o`00K_l09BSo001K
o`00[?l00<?o0036o`00b_l00:So002ko`06Rol0D@gG001jo`800:Oo03D009co0025o`00Fol002go
0840jP06;ol006?o0025o`00TOl009Co001mo`098ol0O0km0014o`0_0?l004oo001io`00L_l005Oo
000Mo`2I08l09POo0014o`00Gol005co0010o`1=1ol01B[o001Go`00Gol006?o000ho`150ol0cP37
0482e@00K_l008go001no`0K5_l008Go048No`0IK?l00:_o002To`1>9=D04CKo002_o`00b_l00>Go
003do`00ool00?o`003ok@02003oj@0I003ol@00ooP00?ol003Uo`00`ol0@63009d0^@1Y1l0008Go
003Qo`00oo400?oM003od@00olX00?oE003Uo020@kd007Ko01Vao`00ojh00?mi003oIP00oe/00?mG
003oC`03003oA`<00?lh1000obP01@00obD00?lI003o6@00oaT00?lG00D00?l:1`05o`000`0Ao`00
5?l001Co000501Co000301So000So`008ol000L08ol000<0;ol003?o000co`001`0co`00100go`00
>ol003_o000oo`04ooooo`03o`000?oooooooooo00Kooooo000Qooooo`0Yo`000?oooooooooooooo
o`00oiD00?oB002ko`00b^T00?oD00VQo`0AV_P079Ko003Fn005Mo`00?3X003oY000ohD00?mi003o
KP00og800?me003oR@00ojl00?oU00F3o`0`R_l0P4O@042UiP00`_D00<[l003o``00okl00>GM003X
k@00[?l00?oU003obP00ojl00?nB003oO@00ogD00`00ofH3003oH`03003oG`00of@00?mV00800?mZ
00D00?mV003oKP00ofX00?mZ003oLP03003oM@800?n501@00?n=003oU000oj000?nS003oZ`00ok<0
0?nk003obP00omT00?oY003lo`00gOl008go03HJo`0TBOl03EGo00Lco`0eD_l00=go003`o`800?So
04L00?3o003Uo`00gOl00=7o002No`212^L0a03A034To`10I<000:oo002ko`00Z?l06DGo02A_o`00
QOl09P?o001Ro`00UOl009co002Ao`00L_l0A@ko01H=o`2D0?d0RP;m054L`010:^H007Wo0025o`00
NOl005_o01HLo`1^0<004AOo001Bo`00Gol005Oo0014o`026ol0/02K08T0n@009Ol06B?o00lDo`00
6_l0N03o00hAo`108l004B;o02PVo`057ol0]02j06D0o`00@?l006[o001eo`00Iol06QSo00d^o`0h
6Ol0087o002Ho`00O_l0=RWa0010o`00VOl00=7o003Qo`00l?l00?co003oo002003on00=003mnP00
POl00>Go003Yo`00/ol0;5co008Go`1C8?l0TakJ001Ko`15Gol00?3h003ocP02003o`P0;003o_`00
olX00?oF002_o000U?@02MG]003oP@00ofX00?mS003oE`00oe<00`00odL01000oc`00?lk003o>000
ocP4003o:0<00?lI00<00?lG003o3P00o`X00`00o`X01@03o`D01Ol000Go0005o`001?l200<01Ol0
00<04Ol001Co000Do`00100Do`000`0Lo`008ol002?o000802?o000302_o000co`00<ol000L0<ol0
00<0=ol004;o0012o`001?ooool00ol0003oooooooooo`06ooooo`008Oooool0:ol0003ooooooooo
ooooool00?3I04YSj@18=]L01U?o01bMm000/o00=83J003m^000oih08;kN02_E/@00ok<00?m[003o
H@00oe`00?mO003oIP00kI@00<[Q01_5c004Uo<00?o0003Le00Hbo00>Dc_02>>o@00b_<00<gm04]E
l`0hN?<08Ygo003og000ok/00?nS003oT@00oh<00?mk003oL`00og001@00of/01@00ofd00?n2003j
W000oJ400?mh00D00?me01L00?mj003oQ@00ohD00?n=003oU`00n;<00?nc003o[P00okH00?nh003o
`P00ol`00?oI003oj@00cOl07H7o00ino`0Q:_l0n01l06X9o`00Sol00;go003Go`03003Vo`16003G
o`00Y?l00;go002ko`09U_l006Ko054>e`0>=?l007So002Go`00W_l008oo00Tdo`0/7Ol0053o05L4
oP04A_l007go0023o`00OOl005Co01XDo`1G1?/0bP200404h`019ol004go001Vo`00Jol006Co001B
o`00>?l0B`Co04L4o`00;_l0:23o01PCo`0G2_l01@[o08P0n@2C0?h07`?o0302o`1f0?00C`3o0<H0
b`1[0?l0F@3o09d0jP0>0_l0E`Ci09/0h01>1>h002Wo00@lo`04=?l004Go01@Fo`1>2MD004go001Y
o`00Jol0<A[E06HAo`00Nol00:Wo002ko`00aOl00>7o003[o`800?Go01T00>Ko01A_o`1@EOh00:Ko
002ho`00P_l0IBK6020/o`00W_l00<Go02]Wn@00eO`00?gS003oa@00okP00?nc003o[P00oj/00?na
003Lc000ojH00?nK003oQ`00ofH00?mO00800?mG00D00?m7003oBP00odL00?m7003o>`02003o>006
003o=P00obh00?lX003o:000obH00?lL0P00oaT00`00o`l00?l:003o2P02003o2P0300;o1`05o`00
1Ol000@01Ol000<04_l001Co000Do`001P0Do`000`0Io`007_l0027o000602?o000302_o000co`00
<ol000P0<ol00`12o`04ooooo`03o`000?oooooooooo00Kooooo000Qooooo`0Co`000?oooooooooo
ooooo`0h@ol00=g/003Bo`0/COl04:O`003oZ000o:`00?mi003oMP00X<H00?mn003oG`00oeL00?mC
003oDP02003oE`0D003oH`00og800?n50230Z`00ohd00?n/003In000]Od0@6oi0193o`15<nX0Y03i
058:`005Kol00<[l003obP00oj/00?nL003oS@00ohD2003oO@0?003oM@00ogT00?mm003oQ@00ogd0
0?n2003oY000`_P00?nT003oS@00oh400?mm003oM@00ogT00?n100800?n503<00?n9003oU000oj<0
0?3M003oi@00olX00?o>003obP00oll00?oA003oh@00ond00?Co002co`0l=ol06BKo0740o`0U6?l0
07So002co`00a_l00<ko003:o`02T_l00;Oo04DTiP0XEOl009co002Do`0T;_l0CPk005d7m@2?4_d0
5DGo0021o`00OOl006?o040Sm@1T1>H00Qoo001Ko`00J_l006ko001Zo`00Fol0043o01l7o`290?d0
J`3o000Uo`00A?l00P00Col0A00h7?l00RKo000Uo`0P0?l0Z@2b02`3o`0o0?l0^`3m03h0o`0k0?l0
S@3^0<L0XP1a0?l0T`3o0<`0a`3V0:H0m`1f0>l0I`3[08T0f03o0800o`2H0>X0/`3?05H0o`0;0ol0
J@?;05H0o`032Ol0@P?o05D3o`054ol0E`go000Qo`0b1ol0AAKc001Ko`00SOl0<D?o0029o`00^ol0
0:Co003Mo`00hOl00=Go002=o`1I:?T0053o02Q9o`1=0ol009So002Xo`00jOl00?Co003Fo`1=HML0
0?o>003o^`00ok<00?nW003oX`00oi`00?nH003oT@00ohT00?n0003oM@00ofH00?mS0`00oeL01P00
od/00?m7003oA`00odD00?m0003o?0800?lh00L00?ld003o;000obP00?lU003o7@00oaT00?lB00@0
0?l:00<00_l800?o1@05o`001005o`001009o`004Ol0017o000Ao`0501Co0003023o000So`008ol0
00H08ol000D09ol003?o000co`00:ol002oo000603?o000303Oo0012o`00?ol000Cooooo00?o0000
ooooooooool01_ooool0027ooooo013o0000oooooooooooooooo002nh@00oj@00?o:003:k000n=40
0?n=003oLP00of<00?mO003oH`00oe<00?m;1000odL05P00odl00?mG003oG`00ofH00?m^003oN@00
ohT00?nT003jdP00on400>co002=o`1]2/00A@ko0025o`0eLOl00?oU003o_`00mlD00?nT003oU@00
ohT2003oQ@0:003oR@00okL00<K2003oU@00oi@00?3U003Fo000hL800?nH003oR@D00?n504D00?n9
003oU000oiP00?n[003:j@00L_l00;_o002go`00on400?oI003og@00on400?o`003Io`09L?l0097o
002Eo`00Iol0B@Oo058Qo`0IGOl00;?o002ko`00[?l01Bko0029o`00A?l00S;o0025o`00P?l05B[o
09<3`03805l0027o001Co`00K_l006[o001Ko`00??l09`Ko000]o`00Bol005_o001Oo`02?_l004Co
000ho`0Y2Ol0U@3009/0e@0>3Ol0033o03TEo`0]4Ol0A@Oo04h3`0032Ol0DP3o0=h0XP1I0?l0H@3o
0;@0e02T0<00fP300:X0o`3n0;<0]P3o0?80_@3o04X01@3o0000:03B0?T0nP2907`0o`0o0?l0<03o
09`0l@1F0?l0:03o07D0o`240?l0AP3o08P0o`0[0?l0cP3000LKo`00E?l006Ko080T[P00K_l09BSo
001fo`00a_l00<[o0033o`00W_l02CKo0>L0W0204L`006Ko002no`00jOl00?co003on000oo@00>Sc
003obP00ok<00?n_003oX`00oi`2003oU0800?n500@00?mh003oKP00ofH00?mS0`00oeL00`00oe<0
0?m;003oA`03003oA`07003oA000od000?ll003o>000oc@00?lX003o9@02003o6@D00?l:1`05o`00
0`0Ao`005?l001Co000501Co00/08ol000<09ol003?o000co`00200co`000`0go`3oooooooooo`02
ooooo`03o`000?oooooooooo00Kooooo000Qooooo`0=o`000?ooooooooooooooo`00ogd00?n1003o
W00T`>d00<;]003oZ000ofh00?mK003oC`02003oA`04003o@000od@00?m4003oA@800?m701D00?m;
003oD`00oeL00?mV003oKP00ogd00?n=003oYP00omT00;Oo0813a@2G1od0FQ;7002=o`00iOl00?oa
003of@0H`oD00?CF003IeP00oj@00P00oi@02P00oiP0@<2Q042Y_000okL00?ne0032m00IOol00?Sd
003/^`00oi@2003oR@800?n500X00?n:003oU000oi@00?nS003oZ`00olh00:oo040je`00hOl00?cd
0P00onT0>@00ond00?od003ho`00gOl00<[o002Po`10<?l0L0[o05/GZP00M_l009co002[o`00V?l0
2CKo05`Fo`1X8?d0;3Ko001^o`00JOl004So024=o`2[0<00H@[^0010o`00B?l05CKo000ho`008Ol0
OP3m00X=o`00>?l04Bko000ho`1F1mh03AOo000Qo`032Ol0CP3o09H0ZP080ol001;o00h5o`2o0>80
X@3H04H0o`0L0?l0?`3o0:`0hP2Y0?P0k`1f0><0k`3o0600o`0j0?l0SP3o08X0o`370?l0L0050?l0
000V0?l0303o07/0h@3V09<0o`370>l0T`3/0>L0X02[0?D0c`3W0;X0o`3W07h0iP2m0?<0KP3G0<`0
X03^03/0o`1A0ol002go048>o`0n1ol00T;o002Ho`00[ol00;Oo0029o`00K_l03B?o0?h0Q@2W1h00
;6Co002Do`00hOl00?ol003ok@00omd00?o?003o_`00ok<2003oX`800?nD00D00?nA003oQ@00oh40
0?me003oLP02003oIP03003oG`00oeL00?mG00800?mG00<00?mC003oC`00odl00P00odl02@00od/0
0?m?003oG`00oel00?ld003o:000oah00?lI003o5P04003o2P0300?o1@04o`<01Ol000@01Ol0200D
o`00100Ho`007?l0023o000Po`0702?o00/0<ol000<0?ol0ooooooooool00_ooool00ol0003ooooo
ooooo`06ooooo`008Oooool03_l0003oooooooooooooool00?mS003oKP00b[L03I;o003mZ@0T[Ol0
0?mf003oC`00odL00?m01@00ocP05`00od000?m4003oB`00odl00?mG003oG`00ofh00?me003oR@00
oih00?no0032o000SOl0V@2O06d:`009>_l0@57a002@o`00iOl00;3o00V7o`00k=d00?n_00800?nP
00X00?n[003og@0LPol04L3Q003bg00TL?l00>7d003o``00oj/00?nL0P00oi@0@@00oi400?nD003o
U000oi@00?nP003oY`00ok<00?o:003:n000X?l0@6oG0426gP00moX00?o`003om000ool00?So003U
o`00dOl00;_o001^o`00B?l0>@?o001Oo`00N_l008Go0029o`00J_l00R[o05L0kP00=Ol004oo00/g
o`00;Ol03Pgo07D0o`0D0ol001Wo05<0gP1c1ol0A@We00D<o`280?H0;P?o000Bo`1O0<00=P?o0;@0
e00K0ol000[o01l3o`2D0?40h@2=0:<0o`0E0?l04@3o03L0o`2X0<00K@3o07X0b`2^0?l0]P3o0?<0
^`3o0600o`0G0080o`0000<0o`040?l0;P3o03h01`3o00002P3o08h0m`2P0=H0c`3g0;<0^`3E0?40
_@3^0>L0o`2>0?l0D@3o01l20?l0000I0?l0RP3K0=00c03@07X0l@1Z0<00;P[o001Co`00NOl0097o
002Lo`00UOl073;o08X<kP0n2_l0@1_a008bo`09;_l0<g?o003Mo`00oo@00?oQ003od@00olX00?nk
003o/`02003oX`07003oV000oi@00?n5003oQ@00ogd00?me003oLP03003oIP03003oG`00oeL00?mG
00800?mG00d00?mJ003oG`00ofL00?n@003oG`00ofL00>6n003oMP00odP00?lh003o9P00oaT00?lF
00@00?l:00<00_l800Go0005o`001005o`0200go00L05?l000<06?l002?o000So`001`0So`0203?o
0080;ol01`0co`000`0ko`3oooooooooo`02ooooo`03o`000?oooooooooo00Kooooo000Qooooo`0<
o`000?ooooooooooooooo`00oe<00?mV003`dP0/^=T00?mV003oO@00oh400?m42000ocP08`00oc`0
0?m7003oA`00oe<00?mO003oKP00ogd00?nE003oZ`00olH00<Kd00e=o`00Y?l01F3o003Eo`00V?l0
:4Wo02A=o`0fAmD00?Sh003oeP00okl00?nk003o]`00ok/00?oF041gn@10[N80:kKR016:o`00c_00
0?nk003oZ`00oj000?nL00<00?nD00/00?nG003oX`00ok/00?nk003o_`00olh00?oY02Q`o`159Ol0
0;?o003^o`02003oo`0a003ho`00kOl00=go003:o`00^ol009co001fo`1E7]<0?0Go02/:o`00Fol0
06ko001Go`00@?l0T@3;04d9o@024ol0OP;>00P3o`1:0?l0b`3T09`0b`0D0?l0J@3o08d0`00T0?l0
;03o0<40b@1U0?l04@3o02`0o`2/0>@0S03o0200o`0=0?l0>`3o08@0o`3F0>D0DP3o02/0o`160?l0
EP3o09l0o`3G0:H0Y`3o0?80c03j0940o`1I0?l0100<0?l000090?l04`3o01/0o`2>0?l0d03o06P0
n`3J0?l0f`3o05@0o`0@00@0o`0001/0o`0@0?l0<P3o05@0k`1b0<<0f00O1ol02Bko001Wo`0AFOl0
<eGo001Vo`00:Ol0V02Z001;o`00ROl009co00/Xo`0`L?l00>Go003om000on400?oA003oa`00ok/0
0?nc003oY`00oj<00P00oi@00`00ohT00?n5003oP@02003oM@04003oJP00ofh00?mV003oIP@00?mS
00h00?mY01c0[`00oj00097/003oR@00olH00=GI003o`P0LZM400/2c003o:`00oad00?lI003o3P<0
0?l:00<00_l800?o1@04o`<01@05o`000`0Ao`005?l001Co000501Co000301co000So`008ol000T0
8ol000<0;ol003?o000co`001`0co`04ooooo`03o`000?oooooooooo00Kooooo000Qooooo`0;o`00
0?ooooooooooooooo`00od000?m?003oY000oi400?m7003oA000od000P00oc@4003o;00T003o=000
ocP00?lh003o>000od000?m7003oC`00oel00?nD003h/`02`<X00>?[003Ml000[ol00<;l003hn000
fOP00?cY003oj@00gO`007Ko06TUd000U?l00>7h02C0k@0L`>`00?3/003oe@00onD00?Sh04QNo`01
UOl00?ca003odP00ok/00?n_0P00oj<03P00oj000?nL003oX000oj<00?nc02B>j@00on400=GU003o
i@00ond00?3o00UAo`18=?l00=Oo0P00l?l05P00kOl00=Wo002Ho`00[ol00:_o002Lo`0/G?l0N`KM
0:l0`0025ol004So00Tno`1=7=X01A3o03/0o`3C0>/0;03o0900kP0c0?l0CP3o0>00T0240?l207`0
o`0G0>00P@1l0?l0Y03e0=h0^01Q0?l0MP3704h0o`3L05/0K@3o03L0o`0o0?l0AP3o09P0fP3Z0<40
O03o07P0o`2?0?l0^`3G0;L0`03n08D0m`2X0?l0E@3o01003`3o00001`3o00P0o`120?l0K03o04D0
o`1?0?l0:P3o0100203o00006`3o00P0l`2H09@0`01J0nh003co000ho`1F0?l0BAS00:@0fP046ol0
A3So002Xo`00^ol00;Oo041TjP0AR_l00?oh003oh@00om400?o:003o`P00ok<00?n_003oX`00oi`0
0?nD003oS@02003oQ@<00?me00<00?mZ003oIP00ofH00`00ofH03000ofX00?mh003I^`00n?P00;O`
00;0i@0E/O000?nT003oMP00ogh00?m8003o;@800?lI00<00?lF003o3P00o`X00P00o`X00`03o`D0
1Ol000Go000400Go00805?l00P0Ao`0401Co000401So000Lo`007?l0023o00L08ol000D09ol003?o
000co`00<ol002oo000603?o00Cooooo00?o0000ooooooooool01_ooool0027ooooo0_l00002oooo
o`07003o>000oc`00?bL003`LP00ocD00?l`003o;007003o:00?003o:`00oc@00?lh003o?000odL0
0?mC003oI`00oj@01Jgd03Nao`13M/P00?S/002ko`00om800?o200800?nk01@00?o>003dn000TOl0
0:7o02dko`0ENol00:_o01F3o`00n?`00?c`00:ho000hOl0@4Wa003enP00on400?o:003o`P00ok<0
0?n_003oY`800?nS00`00?nW003oZ`00ok/00?C`02UYo`00TOl00?3o0036o`00hOl008Go001Co`00
dOl2003Qo`0]003Io`00a_l075So03Doo`00TOl008go001Ko`0S6ol0U@3H06<0l@0E5ol0;A7o06h0
m@0k0?l0GP3o0=X0`03W0=d0d@2^0;/0n@2g0>80e`3L0>80ZP3[0;L0jP3L0?L0JP3g09`0f`3=0?<0
^02Z0?l0iP3109<0o`3[0<H0T03o0:/0b`300:80Y03^08@0o`3W0;/0Z`3o0900o`3Y0?d0jP3S0>l0
Z`3o09H0o`0<01<0o`0000<0o`0?0?l0403o00X02P3o00006`3o00P0o`0D0900o`0O0ol03Pgo06h0
jP3V0800C@?o001<o`00LOl0@6ci002ko`00c_l00=Wo003Qo`00m?l00?oh003oi@00omd00?oA003o
bP00ol800?nk003o[`00oj<00?nD003oT@02003oQ@04003oO@00ogD00?me003oM@800?mb01000?m^
003oLP00og800?me003oQ@00oj000?oF05Pao`00V?l00?bo003oLP00oeL00?m4003o>000obP00?lQ
0P00oaT4003o2P0300;o2003o`D01?l200D01Ol000<02Ol001Co000Do`001P0Do`00100Po`008ol0
02?o000Po`0602?o0080;ol000@0:ol003?o000co`00<?l0100co`03ooooo`;o00002?ooool0027o
oooo00So0000oooooooooooooooo003o:000ob`00?l`003o;0@00?lX00<00?lU003o:000obP01@00
obP08@00oc000?lh003oA000ofH00?Rg0032j000e^d00>76003oYP00okh009Go003obP00ojL00?nP
003oY`0L`=H009Sh00fQo000oO<00?Sd002To`3807X0;C_o002Po`05V_l007ko00Lko`05J?l00?3m
003oj@00om400?o2003o_`02003o/`0>003o[`00oj/00?nc003o]P00ol800?oU00f3o`02H?l0G2o;
002=o`10Q_d008go041Eo@00`?l2003>o`0G009oo`00V?l006[o0:@>WP00L_l007go001Zo`00@_l0
8`?o0;`0l`1V0=h0703o08P0o`3Q0?D0kP350?h0KP3o0100o`0[0?l0PP3b0=@0oP3U0?l0J03o02<0
0`3o00004@3o04T0o`1c0?l0J03j0940kP3L0?l0SP310?l0dP3i0?80ZP2W0?l0_`3m0?`0V`3H0?l0
`@3o0>d0`03o0440o`230240o`0001d0o`0O0?l0J`3g0:L0f`3[0>00LP2k0>X0^03[01l7o`1M0od0
>dgo002Bo`00[ol00<[o003Io`00iOl00?3o003oo`00oo000?oY003oh@00omh00?oQ003Mk@00__P0
0>7M003oZ`00oi`00?nD003oT@02003oQ@03003oN@00ogD00?me00<00?me00l00?mi003oP@00oj@0
0?nQ003ocP00eO`0?gOo00:>o`00iND00?mm003oC`00od@00?lh003o:000oad00P00oaT00`00oa80
0?l:003o2P02003o2P0300?o1@05o`001Ol000@01Ol00`0Do`000`0Ao`005?l001Co000301Co0004
023o000So`008?l0023o00808ol000<08?l002?o000So`000`0So`0303?o000302ko000co`00<ol0
0080<ol01?ooool00ol0003oooooooooo`06ooooo`008Oooool01Ol0003oooooooooooooool00?lU
00<00?lQ00<00?lL003o7@00oaT00`00oaT00`00oad00?lQ003o9@03003o:00=003o;000oc@00?ll
003oC`00og800?nL003oNP00og800?n2003o]`00]ol00?o6003oV002003oT@0C003o]`00ok<00?3B
003oa`00omX00Yko041D`000OOl075So04@Xo`2g0?d0/`30009Po`02R_l00?oa003og@00olh00?o:
003o`P02003o^`0M003o]`00ok<00?nm003obP00omT00?cd003Mo`00L_l05bgo064Uo@0PCOl083Ko
02]niP00X?l00;Oo01a_o`1=9<00<c[o07D:gP00Eol005oo0018o`019Ol01`Wo09@0m@3B0=L0I@3o
0<H0o@3o04401@3o00000`3o01l0o`0j0?l0:P080?l0000<0?l0>P3o0480o`2M0?h0`P3j0:@0iP2m
0?D0S`3n09P0nP3Y0?l0X@3o07<0o`1X8P3o00007P3o04l0nP3N0;80o`1h0?l0J@3o04h3m@0F4Ol0
03So00D^o`00Eol009ko002go`00b_l00=Wo003Yo`00l?l00?oo003on000oo000?o]003ol`00e_l0
2c_o002co`00omH00?nc003oX`00oiP00?nD003oT@800?n500<00?n1003oN@00ogD00P00ogT03`00
oh400?nE003oaP00fMh00?Cd001Go`00eNT00?SI003Fg@00ofh00?m?003o@000ocP00?lX003o9@03
003o6@03003o4P00o`X00?l:00800?l:00<00ol500Go0005o`000`05o`000`09o`003Ol001Co0008
01Co000401co000So`008ol0027o00H08ol00P0co`00100[o`00<ol003?o000_o`0203?o00Cooooo
00?o0000ooooooooool01_ooool0027ooooo00Co0000oooooooooooooooo3000oaT2003o700?003o
9@00obP00?lX003o:000ocH00?lk003oA@00od`00?m?003oE`00og000??G01REo`00hjh00?n50080
0?mm03800?n8003oS@00oiT00?nQ003o/`00om804m;^003`o@00]Ol005Oo06@0o`3U05h0IBKO01b0
n`00hol00?oc003ml00[X]000?oV003jj@00enh00?o?003oa`00olT00?o?003of@00onT00?oj003`
o`00gol00<oo002`o`0:<ol0J0c3001jo`00SOl008So001Oo`0V8ol0H@Of004Wo`079_l0?@kk06X1
mP0G0?l0C`3o0:d0d`3c0</0m02S0?l02180o`0000X0o`080?l0403o05D0o`1O0?l0/03o05L0o`27
0?l0H@3o01`0o`038@3o00008@3o0180o`230?40]03[0:h0SP2Z01`0o`042Ol00B;o001?o`00I_l0
07go002Bo`00Uol008oo006Yo`00gol00>ko003ho`00oOl00?oo003onP00gOl02i3o02]]o`00[_d0
0?oB003o^`00ojh00?nX003oX`00oiT00?nA003oR004003oQ@0A003oR000oi800?nj0037j`0LU><0
:hKE003ogP00ojH00?n:003]W000ogP00?m?003o@000ocP00?l]003o:000ob400`00oaT01P00oa80
0?l:003o2P00o`X00Ol800Co0PD01Ol000<02?l001Co000Do`000P0Do`000`0Bo`005?l001Co0002
01Co000301Wo000No`007?l000@08ol000<08Ol002?o000So`000P0So`000`0ao`00<ol003?o0003
03?o00Cooooo00?o0000ooooooooool01_ooool0027ooooo00Co0000oooooooooooooooo0P00o`X0
0`00o`h00?lB003o3@02003o4PL00?lI00<00?lN003o9@00obP00P00obP06`00oc@00?lh003o>000
od@00?m;003oJ`00a^D00?nL003oO@00og800?m^003oLP00ogD00?mm003oQ@00oiL00?n[003o_`00
olh00?c]0423`009>_l0dP300:@0fP029_l009co003Bo`02003Uo`0Q001^o`00c_l0@6SC00:Io000
omd00?oE003oe000omT00?oQ003ok@00ooP00?So003Yo`00fOl00;oo01Eco`0l<NT0P0Om040Zm@00
Gol0<3[o000No`2/0=00FP3o00`3o`1Q0?l0SP3U05H0o`2g0</0W`3o0=80`03o0</0o`0C01D0o`00
00D0o`080?l0303o02<0o`0@0?l0300S0?l0000B0?l04`3o07H0c@3o09<0o`1U0?l0=`3o0840``1:
1oD004Co001So`00K_l007_o01Tfo`10@Ll00;?o003>o`00fOl00>Wo0`00l?l01@00Zol04Qco002H
o`00ooP00?oM00800?o>00L00?oF003hl00=/Md00?nN003oU000ohd00?n900800?n=00/00?nD003o
W000ok<00>GM01Z@o`00U?l00=7d003oU000ogT00?mZ003oE`02003oA`03003o>000oc000?lX0080
0?lX00D00?lM003o6@00oaT00?lI003o3P02003o2P0300?o1@04o`<01Ol000D01Ol000<02Ol001Co
000Do`001`0Do`000`0Lo`008Ol002?o000702?o000302Oo000Vo`00<ol000<0<ol01?ooool00ol0
003oooooooooo`06ooooo`008Oooool01?l0003oooooooooooooool7003o2P03003o3P00oa800?lB
00D00?lI00<00?lQ003o9@00obP00P00obP01`00oc@00?lh003o>000odL00?mG003oNP00ofh01000
ofH05P00og800?me003oQ@00oiL00?n[003o`P00omD00?oY003Jo`00F_l0A@Oo0<D0JP2H6Yl0S2Gh
03Too`09Ool00:_o00MBo`0cJ?l00;?o003ho`00ond2003oh@0J003oj@00ond00?od003oo000m?l0
0>Wo003Bo`00_ol00:Co034fn01f0<00A@gR000No`1]0?l0803o06d0o`2H0?40R@3e0740o`3B0=D0
U`3o0?40f03Q0>X0o`2l0?l0B@3o038m0?l0000P0?l04`3o09X0g@3i0<80o@2C0?l0U`3o08d0fP1B
0l00;A7o0014o`00Gol004[o07`3l@00M_l00:3o002Lo`00OOl00<ko003Qo`00iOl00=go002No`0g
AOl00=[o003oo000oo400?o`003Bo`02Lol00;kh003ocP00ojP5003oU00>003oW000ojl00?cM003/
l00PPol00?cU042Fd`00oi400?m^003oIP00oeL00?m?003oA`00oc`2003o>007003o;000obP00?lX
003o9@00ob400?lI003o5P03003o2P0300?o1@05o`001Ol000@01Ol000<03Ol001Co000Do`002@0D
o`000`0So`008?l002?o000702?o000403?o000[o`00<ol003?o00Cooooo00?o0000ooooooooool0
1_ooool0027ooooo00Co0000oooooooooooooooo2P00o`X02000oa800?lF003o6@00oaT00?lL003o
6@00ob400?lU0`00obP01`00oc@00?lh003o?000odD00?m?003oD`00oeL00P00oe/2003oIP0E003o
M@00ohD00?Z`003oaP00l?000?Cd003do005S_l085Go002Lo`10:/L00:So002?o`0Z4_l0Ibco044E
`00k:_l0093o003Io`00m?l00?ol00800?oh01X00<Kl003do`00ool00?co003`o`00fOl01dko0025
o`00TOl006Co02PKo`290=h0?`3o0:00l@3J0;d0g@3m0>/0V03^0>/0dP3Z0?<0i`3K0<d0l@2i0?l0
H03o0<@0o`1A0?l013d0o`000200o`0C0?l0H@3o08X0o`1_0=/0f02c0<00Q@3Z0;80o`0G1ol003So
001;o`0>:ol0:Aco001Wo`00B?l0G1Ko001fo`00a_l00=Go003Io`00c_l009Co0091o`00d_l00>Wo
003Bo`0gM?l01F3o06aF`000n>P00?nk003oZ`800?nP01800?nD003oX000oj000?nS003o_`00`_l0
@7_m003QlP00ok<00?nX003oR@00og800?mV003oF`00oeL00?m;003oA`00od82003o?007003o>000
oc@00?l`003o=000obD00?lI003o5P03003o2P0300Go0004o`<01Ol000D01Ol00P0Do`000`0Ao`00
5?l001Co000601Co000301So000Po`008?l000P08ol000<0<ol002oo0?ooool00oooool00ol0003o
ooooooooo`06ooooo`008Oooool01Ol0003oooooooooooooool01?l300800_l82000o`X00`00o`h0
0?lI003o6@03003o6@05003o8@00obP00?lX003o:000ob`00P00ocP01000ocd00?m7003oA`00od/2
003oE`0K003oF`00ofH00?mb003oR@00h=L0?hko001Co`10PoD00:_o002Do`00b_l00=Ko002`o`10
/L000=Co0426kP00Gol0R@3i0:H3b`0kF?l00:co003Bo`00kOl00>Wo006To`0PF?l02J7o00800>go
01D00>Go003Bo`00ROl0K@3o001Zo`01B?l05Q7o04X0o`3?0:X0m`1^0?l0003o03H0o`0K0?l0003o
03h0o`1c0?l0E@3o0980o`0m0?l0A@3o00@0?P3o00008@3o00`0o`1=0?X0dP3M0=h0S`3o0580o`0[
0?l04@3o000Bo`008Ol00Q_o02X;o`1L1ol0R0[R08T3P000Col008Wo002go`00a_l00<?o002ko`00
Sol005Oo002Ho`0LAOl0=e7o03PHo`00^ol00>co003Uk@00okl00?n`003oY`04003oX`0;003o[`00
olh0<;7l041AkP00/oL00?n[003oU000oh400?me003oIP00of<00P00oeL03000oe<00?m?003oC`00
of<00?m;003o@000oe<00?2n003o>000obP00?lM003o4P<00?l:00<01Ol000Co0`05o`001005o`00
1@0=o`002Ol001Co000Do`004Ol000P05?l000<07?l0023o000So`00200So`04ooooo`03o`000?oo
oooooooo00Kooooo000Qooooo`04o`000?ooooooooooooooo`801Ol000<00ol500Go0001o`P02000
o`X00`00oaH00?lI003o6@02003o6@05003o8@00obP00?lX003o:000ob`00P00ocP01000od000?m7
003oA`00od/2003oE`0V003oH`00ofh00;O:02RUj000eNT00?oI003og@00iO`0:7oo003ol@00ond0
0?oY003ol000n_d00=Wo00Ego`1Z0=h0S@ji04PEo`0X:_l0@6Ce003>o`00`ol035Co008Zo`00`_l0
0=Wo003Mo`00d_l0@S?m02aIo`0A:_l0037o018Go`2O0?l0/02a0=d0`03o03X50?l000040?l01@3o
0100o`0@0?l05d00o`000240o`0C0?l0MP3n0=80a@3o09L0o`2H0<00<`3o01D0o`0=0?l09@Go0840
`01i0[X0:1_o00dZo`00Dol007;o002Lo`00Zol00:oo002Ho`05@Ol0>3;E021Ao`0e;?l0DBGo0029
o`10H=L00>Wo003ok@00omD00?o2003o]P00ok<00`00oj/06`00ok<00?no003odP00/o`0?Sco0039
j000oj/00?nA003oQ@00ogD00?mb003oKP00ofH00?mS003oG`00mJ400=VP003oaP00ofh00?mS003o
OP0TR/800?mG003oA000oc000?lI003o3P02003o2P0300;o2004o`<01Ol000H01Ol000P03Ol000Wo
000Do`003Ol001Co000Ao`005?l001;o00D05?l000<06?l002?o000Po`001P0So`04ooooo`03o`00
0?oooooooooo00Kooooo000Qooooo`04o`000?ooooooooooooooo`@01Ol000<01?l300?o1@00o`X0
1@00o`X00`00o`h00?lB003o6@04003o6@<00?lX00@00?l/003o=000ocP00?lh0`00odL03000od/0
0?mG003oF`00ofH00?mf003oS@00oi`00?nW003oaP00Zol006[o003oh@800?oA00h00?oM003enP0Y
IOl0:D?o001bo`00UOl0087o05`:o`0;:?l005_o002@o`06A_l0093o002ko`800<[o00X00;oo0021
o`0L@_l082Oo0640o`1?0?l0c`2i0>h0P03o04d0o`0GBP3o00007`3o03H0o`1[0?D0d03_0>40c`3[
0<L0f00k0?l0K@3o0;/0jP3:0?40>P;o0010o`00Dol006ko0021o`00TOl009co002Ao`02EOl0EP[0
00Teo`00Y?l00;_o02BFo`00hOl00?7o003lm000onD00?oE003oaP00ol801000ok/02P00ol800?o6
003of@00N_l005?o003obP00ojL00?nL003oT@00ohD3003oP@0>003oR@00ogd00?nD003Aj010`<@0
0?nP003/cP00^md0>l36003/eP00oiD00?n9003o7P00o`h3003o2P0300?o1@04o`<01Ol000T01Ol0
00@03Ol000Wo000=o`002_l00P0Ao`0501Co00808?l01@0So`04ooooo`03o`000?oooooooooo00Ko
oooo000Qooooo`04o`000?ooooooooooooooo`D01Ol000<01?l300?o1@02o`P01P00o`X01@00oa@0
0?lI003o6@00oaT00?lM00@00?lX00@00?l`003o>000ocP00?ll0P00odL09@00od/00?mC003oE`00
of<00?mV003oN000ohD00?nL01G0f@0gT_l00>Sh003obP00ol800?o6003ocP00b_P0>h?o041g`000
V?l00=Wo002[o`02EOl006ko05H:iP144Ol0ZPV[02QPo`00U?l00:3o002Do`00Zol009co001mo`00
Dol001Ko0:T0o`3o01<0CP3o00007@3o04d0o`190?D0`@2f0?l0O@3o0940o@380;X0m`2k07H0e`02
4ol0043o001Go`00J_l007Wo001mo`00K_l0@3K^00X/o`1a1oT0BB7T002ko`00c_l00>7o003`o`00
ool00?o`003oh@00omT00?oA00800?o:00`00?oB003Uj@00__@00?oI003oh@00oo4009So003Qo000
oll00?nc003oZ`00oj@2003oW00@003AdP00o<h00?cB003oV000ok<00>G`02ako`00W?P01h3Q003/
`P00ofX0@<23003oD`00ocP00?lN003o5P@00?l:0`04o`<>00Go00802Ol0100Do`001P0Ho`007?l0
023o000So`008?l002?o00Cooooo00?o0000ooooooooool01_ooool0027ooooo0_l00002ooooo`L0
1Ol000<00ol5003o2P00o`X01000o`X00`00oa@00?lI003o6@02003o6@05003o8@00obP00?lX003o
;000oc000`00ocP3003oA`0B003oD`00oeL00?mG003oIP00ofh00?mm003oX000iND0>h?o003oh@00
ok/00?ng003o/`00ol<00?[Q003oj@0EU_l0;:7o0P00n?l03`00hOl00<?o002=o`1A3OD0`@2]06PX
`000D?l071oo041P`000SOl007Ko001^o`00B?l0JP3m0=H0b@1@0?l0000m0?l09`3o0;40dP3R0<80
e`3M0=L0nP2W0740o`1f0>X00PWo00DGo`02;_l005Oo001Oo`00Fol03Q7o07/:o`2A0?401Cko001Y
o`00^ol00=Go003Yo`00m?l00?co003ol000ond00?oQ003og@00omT00?oQ002=o`00dOl00<Ko003l
n000V?l00;?o031oo`10XL000;gc003Ag@00omX00:O/003og@00ok/00?oQ002=o`00omh00?3F00jU
o@14F_l0K5K0003of@00ohd00?mW003oD`00od@00?lh003o:000oah00?lI003o3P05003o2P0300Go
0004o`<01Ol000P01Ol00`03o`D01@02o`P00ol500?o1@05o`004Ol000D05?l000<07?l0023o000L
o`000oooool2o`0000Sooooo000Qooooo`05o`000?ooooooooooooooo`09o`001P05o`0200Co0`D0
0?l:00H00?l=003o6@00oaT00?lI003o7@00ob44003o:0<00?lh00@00?m4003oA`00odL00?m?0P00
oeL03P00of<00?mY003oO@00j<X00/3M003hcP00oj/00?nW003oX`00oj/00?nc003o`000om800:o/
0P00ond04P00oo`00>Wo002[o`00POl05B?o03`GmP1B2/00]`3005PAhP0A<_l01CKo00hEo`00A?l0
037o01l3o`3<0:H0o`0S0?l044l0o`0003`0o`0^0?X0g@3o0980n@2f08`0o`1B0?l0:`3o00l0o`2h
0:X03Pgo060:o`00>?l0043o00<Eo`2/0;d0K`?o00U1o`00U?l00;_o003>o`00gOl00?3o003ho`00
oo`00?oh003om000ond00?o^003om000c_l0@C?a002Do`0EOol01ECo009oo`00m?`0>jgo03mKo`0c
R_l00;oo00ETo`00e_P009Sl003Jo`0E<_l0087o002Lo`1HMNh00=GX003En010XL@00>6c003oG`00
odL00?lh003o;000obP00?lL003o6@00oaH5003o2P800ol500L01?l200Go0005o`001Ol000Co0`05
o`001?l300800_l800X00?l:003o9P00ob400?lU00;0JP00odl00ol500Go000=o`004Ol01P0Do`04
ooooo`03o`000?oooooooooo00Kooooo000Qooooo`06o`000?ooooooooooooooo`0=o`002?l01P05
o`000`03o`<00_l7003o2P03003o2P06003o3@00oaT00?lI003o6@00oah00?lQ0`00obP01@00obh0
0?lh003o>000oc/00?m200800?m702L00?m:003oE`00oeL00?mL003oIP00og<00?mm003oS@00ohl0
0?nD003oU`00oi`00?nS003oZ@00ok400?nm003oa`00om@00?oQ003okP00hOd076ko0025o`00Col0
09Ko005Ko`1I5Ml0<2_o044Ke@1c1=l0ZP2Z07<6cP1U0/@0^02V0<`0lP3N0>T0o02U0?l0=P3o01l0
C@3o00005`3o02@0o`1G0?/0g`3B0?l0U`3o0;d0`01`0?l0E@3]0:P0k@1i0>L0@03o000Go`053ol0
VP3G07`0e@076ol0:cCW0028o`00U?l02fgo0032o`00e?l00>Ko00800>ko01h00:?o002mo`00^Ol0
9Kko00Mgo`0V>_l0Oa3E00^1o`00k_d00>?Y003oeP00omT00=7`003[l000^_d0:gkE002hl`0[Io40
08ch02]Tl@00g_D00?[5003^]@00oj408=3?01fRe`00ogd00?m?003o?@00ocH2003o:0800?lI00<0
0?lG003o2P00o`d01P00o`X00`02o`L00Ol900;o1`02007o2@800?l:00d00?l=003o6@00of800?n5
02^nW@00oHD00?lQ003o2P04o`801Ol000So000=o`004Ol000804_l00P0?o`04ooooo`03o`000?oo
oooooooo00Kooooo000Qooooo`07o`000?ooooooooooooooo`0Ao`005?l000go000400Go000300Co
0`05o`001Ol000@00?l:00H00?l=003o6@00oaT00?lI003o7@00ob43003o:004003o<000ocP00?lh
003o?0<00?m700X00?m;003oE`00oeL00?mK003oJ@00ofH00?me003oN@00ohD00?n90P00oi@07000
oiP00?nS003o[P00ok<00?o2003ocP00om400?oQ003ol000m?l0=gOo002/o`00`_l00:So001fo`00
QOl004co01L3o`0B2Ol0A`3o01`0o`1Y0?l0L@3E0=L0U`3n06L0o`2Q0?l0I03o00a=0?l0000R0?l0
PP3o08L0m`2_0=D0o`3d0>h0h`3108l0o`3J0<D0BP3o02@0o`0L0?l0R03o0;40a@0W1ol003Co001G
o`00L?l004So01dgo`00QOl0<P?o002oo`00eOl00=;o002Do`1B7_D008go041Hc`0O3_l007ko041/
`000W?l00=[l003ocP800?no01800?nk003o``00__`0@<34003oa`00ok/00?o:002[o`0P^>403J7:
003oP000ogd00?nT003XbP00k8T00?m7003o>000oc02003o:005003o7000oaT00?lI003o6@00o`h0
3000o`X02P00o`h00?lI003o9@00ocd05JVn003oJP00ocP00?lI003o3P02o`P700Go000300Co0ooo
oooooooo00;ooooo00?o0000ooooooooool01_ooool0027ooooo00Co0000oooooooooooooooo0P0D
o`000`09o`001Ol000Go000400Go000300?o1@00o`X00?l:00<00?l:1000oaT01000ob400?lX003o
:000obP3003o>005003oA000odL00?m7003oB`00oe<00`00oeL2003oIP800?me02000?mm003oQ@00
ohT00?nD003oV000oj<00?n[003o^`00ol800?o:003od@00on400?o]003ln000iOl00=go003Do`00
a_l00:oo002Po`00P_l0=COo0014o`00>?l0027o00L5o`0`0?l0^@3o0<d0o`3j0<h0o`1E0?l044`0
o`0002D0o`0C0?l0A@3o02h0o`2F0?d0i03o07L0fP3i0>40a`3G0=`0Y03009<0o`1F0?l0g02o0;L0
fP0G0ol01AOo02@So`01?_l003So064Bd`20780007Ko002co`00^ol00:3o002Eo`1<6Ol0P1S>01aP
o`00/ol00>7o003>o`00W?l00?oQ003o_`00ok<00?n_00800?n[01000?S:003oY`00oi`00?nL003o
]`00n?`00?nL003oQ@00og000?mV003oJP00og800?mV003o@000ocP00?l`0P00obP01P00ob400?lI
003o6@00oaT00?lB003o3PT00?l:00/00?l>003o5P00oaT00?lU003o>000oe@00>7/0170W000oc`0
0?lU003o5P02003o2P801?l30P05o`000`03o`D00_l8003o3P04ooooo`03o`000?oooooooooo00Ko
oooo000Qooooo`06o`000?ooooooooooooooo`0Do`004Ol00P0Do`0600Go000500?o1@00o`X00?l:
003o2P00o`d00`00oaT01@00oad00?lX003o:000obP00?ld00800?lh00D00?m0003oA`00odL00?m7
003oC`03003oE`04003oF`00ofH00?mZ003oLP800?me01l00?n5003oR@00oi@00?nD003oX`00ojh0
0?no003oaP00olh00?oA003oh@00onT00?od003oo`00l?l00=co0036o`00^ol00:?o002Do`00OOl0
06?o001<o`094ol04`?o02h0o`1Y0?l0V`3o0=d0o@3o0:D0o`0j04h0o`0000`0o`190?l0J03o08X0
o`150?l0V@3o06T0n@310?X0dP3B0?d0]`300><0n01F0?l202@0o`0Q0:@0e`0g2^@0EP?V018Po`00
Gol008Wo002Lo`00UOl0;Qko01Tmo`302VL0BBOE002/o`00kOl00?oh003hn000X?`00?o>003o/`00
oj/00?nS003oX@00oi`00?nH003oU000oi400?n=003oU@00n;h00?n1003oLP00ofH00?mO00800?mG
00@00?m;003o?000ocP00?l/0P00obP00`00ob400?lI003o6@02003o6@04003o5P00oa800?l:003o
3PD00?l:00d00?lF003o6@00oaT00?lM003o>00=`;/00?mc003Uj@00eIP00?mZ003o<000oad00?lF
00D00?l:00<00?l>003o5P00obD01?ooool00ol0003oooooooooo`06ooooo`008Oooool01?l0003o
ooooooooooooool301Co0003017o0005o`001Ol000<01Ol000<01?l300;o2000o`X00P00o`X01000
o`l00?lI003o6@00oaT3003o:004003o=000ocP00?lh003o@0800?m70P00od/01`00oe<00?mG003o
E`00oeL00?mS003oIP00ofX00`00ogD2003oQ@0M003oU000oj000?nW003o^000olX00?o>003oe@00
omd00?oQ003ok@00oo000?oo003`o`00g_l00<?o002Xo`00W?l008go001mo`00J_l004Co06@:o`2L
0<00OP3^0:`0o@3S0?<0kP390?l0RP3o04D0CP3o0000103o01/0o`000?l05`3o01L20?l0200K0?l0
303o0100o`1`0?l0N`2k0=L0V`3o08T0m@1I0?l0]`3a03d0o`2X0<`01a7o001<o`00K_l0ACO^001C
o`194_l0NaG^009Do`1M?MD05G3o003Yo000onD00?oI003odP00okl00?n_00800?nS0P00oi@01000
ohT00?n5003oQ@00oh42003oO@05003oLP00ofH00?mL003oE`00oe<00P00odL00`00oc`00?lh003o
;002003o:003003o8`00oad00?lI00@00?lI0P00oaH01000o`X00?l?003o4P00oa84003o6@0;003o
:000od000?mj003`dP0=YO`0;<32002ch@00oe<00?lh003o7@00oaH00P00o`h01@00o`l00?lM003o
<@00l:/00?m000Cooooo00?o0000ooooooooool01_ooool0027ooooo00Co0000oooooooooooooooo
0P0Do`000`0Ao`003Ol000[o000600Go00<00?l:00@00?lB003o6@00oad00?lU0P00obP01000ob`0
0?lh003o?000od@3003oA`03003oC`00oeL00?mG00800?mG00@00?mO003oIP00ofH00?m^0`00ogD0
2P00ohD00?n9003oU000ojl00?o:003odP00d_P00?o]003oi@00onT2003ol00D003oo000ool00?3o
002ho`10DO404Dgo001^o`00M_l007;o001Zo`00Col0@1_i04/0o`2e0</0i`1W0?l0D@3o0700o`15
0?l0@P3o01]E0?l0000P0?l05`3o0;P0iP2j0=d0n@3L0?l0W`3o0?X0NP3O06l0e`2m0:/0jP0^0ol0
0Rko07`7`01U0nh05D;o000eo`00TOl0:iSm02A`o`00ooP00?oM003od@00ol800?nc003oZ`00oj<0
0?nH003oU000ohT00?n5003oP@00ogT2003oM@08003oJP00ofH00?mS003oE`00oe<00?m;003oA`00
od02003o>004003o<000obP00?lX003o:0l00?lI00/00?lU003o;000m7T00>b_003oj009Ool008go
003Yg@00fKh00?mG003o9@03003o6@05003o7000odl00?mG003oY000oh801?ooool00ol0003ooooo
ooooo`06ooooo`008Oooool01?l0003oooooooooooooool401Co000301;o0005o`001Ol000<01Ol0
00l00ol5003o2P00o`X00?l:003o5000oaT00?lQ003o;000obP00?l`003o>000oc`00?m8003oF`00
oe`01P00oeL01@00of<00?mV003oIP00ofT00?mb00800?me00/00?mm003oQ@00ohD00?nD003oZ`0k
WOP00:Wj002=o`00lO`00?ch003hn002003oo00D003oo`00o?l00?3o003Do`00SOl0DC3^05/0n@00
@?l005oo001Ko`00A?l0DPOG04H0o`0m0?l0K@3o0:H0o`3M0?d0o`3K0?l0>P3o00aE0?l0000L0?l0
303o03d0o`2Q0?h0I`3g0=80m`210?l0K`3o01X0o`0?0>l0IP2G0?l0K@3o07P7l@1B3_D007ko002E
o`00`ol00=co003Uo`00oo@00?oI003obP00ol800?nc003oX`00oi`00?nD003oS`800?n500H00?mi
003oM@00ogD00?m^003oIP00of<2003oE`04003oB`00odL00?m7003o?0800?lh00<00?ld003o;000
obP00P00obP2003o7@X00?lI00h00?lM003o8@00obP00?l`003oF`00l9400?n8003`i@00n>T00?mj
003oF`00od000?l`003o:0800?lQ00D00?l[003oC000e[h00>SM041ohP04ooooo`03o`000?oooooo
oooo00Kooooo000Qooooo`04o`000?ooooooooooooooo`@05?l000<02_l000Go0005o`001005o`03
003o2P0<003o5`00obD00?l/003o<000oc@00?lh003o?000odl00?mG00flaP00ogH00?mO0P00oe/2
003oH`@00?mV00@00?m^003oM@00ogD00?me0P00ohD07000ohT00?nD003oZ`00o=d00:_j01UAo`10
>ol0@63C002Po`00m?l00?So003do`00l?l00>Wo003Do`00[ol008Wo000do`1?0<0003So0010o`00
=?l001go00D0o`0^0?l0_02b0:<0o`3Q0<020?l0E@030?l0203o0000o`0005@0o`0001d0o`0^0?l0
F03o02h0o`1o0?l0>P3o01<0o`000?l04`3^0:X0R03o01X9o`00>Ol005Oo002Ao`00[ol00<[o003[
o`00ool00?o]003og@00om400?o6003o]`00oj/00?nP003oU000ohX00?n5003oO@02003oM@04003o
KP00ofH00?mV003oG`800?mG0`00odL01000oc`00?lh003o>000ocP5003o:003003o8@00oaT00?lI
00L00?lI01H00?lM003o8@00obP00?lX003o=000od000?m?003oN000k=d02ES`003oR@00oel00?m7
003o>000oc000?lX003o;000ocP00?m;003oLP00o<H0847o1?ooool00ol0003oooooooooo`06oooo
o`000_ooool2o`0000Cooooo00?o0000ooooooooool00_ooool2o`0000?ooooo1Ol00003ooooo`?o
00001?ooool01?l0003oooooooooooooool501Co000300Wo0005o`001Ol000801Ol000l00ol5003o
2P00o`X00?l>003o7000oeL00?mK003oC000od@00?m7003oC`00ogH00?mj00:Ff@00oj400P00ofX2
003oIP800?m^00<00?mZ003oKP00ofh00`00ogD03@00ogd00?n5003oR@00ohd00?nD003oX`00okL0
0=kX003Yo`00I_l0AC3?032>o`00fOl00P00jOl04@00iOl00=go002eo`02Jol005_o0018o`103Ol0
5Pgo01HAo`0<1ol01`Wo0200o`0m0?l0ZP3o0?<0Y03f0=@0o`2B05T0o`0000<0o`0<0?l0003o01l0
0`3o0000303o04T0g03o0640o`1C0<000R[o001Wo`00POl0:6Co002/o`00jOl00?co003om0800?oY
00P00?SU003oeP00ok/00?nS003oU000ohd00?n5003oN@800?me00@00?mZ003oIP00ofH00?mK0P00
oeL3003oA`05003o@000ocP00?lh003o>000oc001P00obP02@00ob400?lM003o7@00oaT00?lQ003o
7000oad00?lQ003o9@02003o:00;003o;000ocP00?m4003oC`00og<00?S2002_n000okl00?n/003o
E`00od@00P00ocP01P00oc`00?mQ003oJP00o;/0=j7d00F6f@Cooooo00?o0000ooooooooool01_oo
ool00005ooooool0003oooooooooool000002_ooool01Ol0003ooooooooooooooooo000000;ooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooooooo`D0
5?l000<02Ol000Go0005o`000P05o`004`04o`<00?l:003o2P00o`h00?lI003oB`0IT[l088kI003o
H`00oel00?mW003lY`00d^D00:3`003oV@00ogd00?me003oN@00ogd00P00oh45003oM@04003oO@00
ohD00?n5003oQ@800?nD01/00?nS003o/`00oll00?oa002go`00TOl0@A[o0025o`00d_l00=go003I
o`00eOl00:?o034Eo`1P4Od0D@?o034=o`1A1ol0b03506D0o`1h0?l0J@3o0580o`2k0?T0fP3i0?l0
UP3o02H0G`3o00002`3o08X0jP3_0<L0V`1]0?l0=`3o0010o`00A?l093Ko002Xo`00e?l00?Co0080
0?co00P00>Go041TkP00a_l00?oM003oX`00oi@00?n:003oQ@<00?me0`00ofH3003oE`04003oB`00
odL00?m7003o@0@00?lh00<00?l`003o:`00obP01P00obP00`00ob400?lU003o8`05003o:00C003o
=000ocP00?m0003oC`00n/X00ZgY02ATo`00^o`00/3U003oT@00odl00?m7003oB`00oeL00>R^003o
[002XNT00;_d003lW004ooooo`03o`000?oooooooooo00Kooooo00001Ooooooo0000oooooooooooo
000000_ooooo00Go0000ooooooooooooooooo`000003ooooo`Go00001?ooool2o`0000;ooooo0P0D
o`00100Bo`005?l0017o0008o`0500Go000I007o2@00o`X00?l=003o6`00ob/00?mD003NW`00g]H0
4<37003NbP04]]@0=fGe002oj`00okP00?fY003oU`0Cd<X00?nc00K6l`00oi`00?n8003oP000oh<0
0?n2003oP`03003oQ@0<003oTP00oi@00?nN003o/000okd00?oE003oj`00n?l00=;o04eFkP0[IN@0
0;_o0P00aOl04000`?l00:oo002:o`00JOl005[o001:o`0[9N@0?PKo0980k03[09T0d@3U0;P0lP39
0?`0j03:0?l0KP3o00=O0?l0000F0?l0C`3c0=`0[03n06L0oP0h1?/0B1;E03T=o`1D:o409D_o01bF
o000gol00>7o002Oo`06D?l00;?m00K;iP00ok/00?nY003oV@00ohd00?n5003oP0800?me00@00?mY
003oIP00ofH00?mL0P00oeL2003oBP800?m700<00?m2003o>`00ocP00P00ocP00`00oc@00?l^003o
:`0:003o:00F003o:`00obP00?l`003o>000oc/00?m7003oC`00ohP00?[A003Ih`00^_P00?nQ003o
L`00oel00?mL003oH@00ofh02n?50027o`01`nH00?n:003oG`?ooooo0_l00008ooooo`0000Gooooo
o`000?ooooooooooo`000008ooooo`Co00001?ooool01?l0003oooooooooool00002ooooo`03o`00
0?oooooooooo00?ooooo00Co0000oooooooooooooooo1@0Do`000`0=o`001Ol000Go000300Go000G
00;o2000o`X00?l:003o5000ob400?m4003dcP00m9P00>bT003o[000kN407EKo080og00dI^400?S/
003ofP0T^?@00<Ko003`g@00oj/00?nD003oS@00ohT00`00ohD07@00ohT00?nD003oU000oi`00?n[
003Qf@00oo008:Om003Uo`00`ol00;Oo002Eo`09?Ol0087o00Uco`05I?l009co002Qo`00TOl007go
001Zo`00Col0033o000Bo`0H0?l0EP3o0:l0`03W0;<0o`1P0080o`0jH03o00002P3o01/0o`2J0?X0
P@2`0=h0V0330:d0[P008Ol005oo0029o`00ZOl2002co`0:04`oo`00c_l00?oh003of@00ol<00?n_
003oX000oi800?n5003oP@800?me00@00?m^003oIP00ofH00?mV0P00oeL00`00oe<00?m?003oA`02
003oA`03003o@000oc`00?lh00D00?lh1000oc000`00ob`00?l`003o:`03003o<00E003o=000ocP0
0?lh003o?000odL00?m?003oI000oh400?nX032Bn000SOP00?b_003oO@00ofh00?nE003Uf@00b_80
0>7U015om000X;l00?m?00Cooooo00?o0000ooooooooool01_ooool00005ooooool0003ooooooooo
ool000001oooool01ol0003ooooooooooooooooo0000ooooool000000oooool01_l0003ooooooooo
ool0003oooooo`0000Gooooo00Co0000oooooooooooooooo100Do`000`0?o`001Ol000Go000300Go
000K00Co0`02o`P00?l:003o2P00oaL00?lM003o?000ofL00?m?003oE`00ogX00?nk0036n000hND0
0:Sh041kc`00W?l0>2co03>ho000om800?nc003oX000oi`00?nH003oTP00oi@00?nA00800?nD0100
0?nH003oX`00ojl00>SM002co00e>_l05Soo01a6o`00??l01DGo001Zo`1=9<00>Ago040fgP00POl0
06ko0P00L_l03000Hol00R?o04T5gP071Ol04@3o03<0o`1Q0?l0X@3o0>D0n@3o0;P0o`1H0?l03640
o`000180o`1k0>h0h03C0;80G@3o06T0o`10</0004oo011Co`0];?l04E7o01UEo`00b_l00;oo003d
n000l>`00?oM003IcP00oih2003oQ@04003oN@00ogD00?me003oKP800?mV00L00?mS003oE`00oeL0
0?mC003oB`00odL00?m;00800?m700<00?m4003o@000oc/04000ocP04P00od@00?m7003oC`00oe`0
0?m^03_0[`10XOD05Goo003o_`00oiD00?nI003obP0A7ol0:kVa003oU00LS^D00<:H003oA0Cooooo
00?o0000ooooooooool01_ooool00005ooooool0003oooooooooool000001oooool01ol0003ooooo
oooooooooooo0000ooooool000000oooool01?l0003oooooooooooooool2o`0000Gooooo00Co0000
oooooooooooooooo1@0Do`000`09o`001Ol000Go000300Go000H00?o1@00o`X00?l:003o4P00oaT0
0?lX003o<000ocP00?m;01G0aP09Q/X00?CQ003oY000ojH00?no003Mm00j5_l02FSo002go000omX0
0?CJ003o^`00okL00?nN0`00oi@01`00oiP00?nS003oX`00ok<00?o:0430f`00col00P00W?l05P00
Y?l00;_o002_o`09DOl0P@300:00`000>?l070oo000ho`00Gol004Co000Uo`1b0?40AP3o02L0o`1F
0?l0h03o0:T0o`3g0:P0o`2l0?l0M`3o011R0?l0000B0?l0503j0<X0iP2j0=@0LP0[1ol0K0?o098J
WP0XAOl00:Co001mo`00B?l0C4ko015Lo`2G;L/0I77N002ck000oj/00?n=0P00ohD2003oN@05003o
M@00og800?mV003oIP00oe`00`00oeL00`00od/00?m7003oA`05003oA`03003o@000od@00?m000<0
0?m000<00?m7003oB000ocd00`00ocP2003o?0800?m701400?m;003oE`00oe`00?m^003oO@00oj@0
3KCU041/kP00ol803KS/002go000hO000?Ze003oLP00ofh00?mW003o@004ooooo`03o`000?oooooo
oooo00Kooooo0002ooooo`;o00002Oooool3o`0000?ooooo0ol00005ooooo`03o`000?oooooooooo
00?ooooo00Co0000oooooooooooooooo1@0Do`000`0=o`001Ol000Go000300Go000J00;o2000o`X0
0?l:003o3`00oaT00?lM003o:000oc000?ll003oB`00oel00?S3003oO@00oh800>S:003Io`00_oP0
0<[l055Rn@10ZL00=g?o002@o`00omT00?nX003oX`00oi`3003oX`0M003o[`00ok<00?o2003oe@00
onh00?co003Yo`00iOl00=Go0033o`00ROl0@57?040^jP1B0?l0L@;>000]o`00@?l00Qoo07@0o`2Q
0>00O03o0580o`3:0?T0j`1C0=h0o`3o0;00o`110?l0>P3o01L0H`3o00004P3o01<0o`000?<0V02Z
0?l00RKo00IWo`00[?l00<ko003Fo`00c_l01G?o003Bo`10U_d00>SY003o_`00oj400?nD003oR@<0
0?n500<00?n1003oN@00ogD00P00ofH2003oF`800?mG00D00?m?003oB`00odL00?m;003oA`03003o
C`<00?m700D00?m?003oLP00oiP00?mf003oBP04003o@0<00?m701400?m?003oE`00oel00?m^003o
N@00ohd00?n[003Xj@00a_P00>SU003IbP00oj@00?fG003oG`00oe<00?m7003o>004ooooo`03o`00
0?oooooooooo00Kooooo000Qooooo`04o`000?ooooooooooooooo`<05?l000<04Ol000[o0005o`00
1@05o`001003o`D00?l:003o2P00o`d2003o6@0C003o9@00obP00?ld003o?000od/00?mK003oG`00
og000?nT003o``00omX00?no003lj@02Lol0C4ko003hn000olX00?nc003oY`02003oX`0N003oZ`00
ojl00?nc003o_`00ol800?oE003oiP00oo@00?co003]o`00hOl00<[o002go`00UOl00TGo02H3o`2C
0:X0I@3o00<=o`004_l04@3o04X0o`3R0;80/P3o09/0o`3M0?d0o`2B0?l0c03o06L0o`0@G@3o0000
0`3o01l0o`000?l070060?l0000>0?40ZP2?0?l0K1Ko0020o`00]ol00=Wo003`o`00n?l00?Sh003o
l@00onD00?o>003o/`00oj<2003oU0<00?n=00P00?nI003oW000oj000?me003oKP00ofH00?mS003o
F`H00?mG00/00?m^003:_P00ofh00?mK003oE`00oe/00?mW003M/`10`<000?m^003oDP06003oA`0B
003oC`00oeL00?mG003oIP00og800?mm003oS@00ojl099gh01bMg@00oj@00?n=003oN@00ofH00?mG
003oC`00odL00?ll1?ooool00ol0003oooooooooo`06ooooo`008Oooool01?l0003ooooooooooooo
ool501Co00D01Ol000D01?l300;o2000o`X00?l>003o3@02003o6@0C003o8@00obP00?lX003o>000
oc`00?m7003oD`00oel00?mb003oQ@00oi400?nT003Xk000Z?l0E5K001V3o`00m>T00?o7003o]`02
003o/`0N003o]`00okl00?o2003o`P00olh00?oE003oiP00oo@00?oo003]o`00fOl00<?o002_o`00
W?l007;o02PZo`162ol0/03D06H0`01B0?l0903o06d0o`2[0?d0nP2I0>T0gP3o0980o`0m0?l0H03o
01L0o`0<G03o00006@3o01<0o`1W0?l0@@3o07H0o`1=0?l08`3o0540o`1T0?l0E@3o0000o`0G09`0
`01<4Ol0:2go002Po`00jOl00?So003oo000ond00?oM003ocP00ol800?nc003oYP00oj000`00oi@0
1@00oi`00?o301FIl000oiP00?n100800?mm00@00?m^003oJP00of<00?mK0P00oeL03P00oe/00?mS
003oQ@0L_>400?n5003oJP00ofH00?m^003oZ002_>400?C2003oLP00oeX00?mC0P00odL05@00od/0
0?m?003oD`00oeL00?mK003oH`00of/00?me003oP@00okL00?cI01iao`00omH00?nL003oP@00og80
0?mT003oE`00odL00?m0003o>004ooooo`03o`000?oooooooooo00Kooooo000Qooooo`04o`000?oo
ooooooooooooo`<05?l000<04Ol001;o0005o`001@05o`001002o`P00?l:003o2P00o`d3003o6@80
0?lX0P00ocP03@00od@00?m?003oFP00ofH00?mb003oP@00oi400?nX0032eP00on`0?fco01aXo`00
n]h00P00ol807@00olH00?o:003hm000omT00?oA003oe@00omd00?o^003oo000o?l00>Wo002Do`10
EOD008Wo002=o`00NOl005Oo004To`2I0=@0o`1T08@0o`290=h0gP3D0=H0m@3j0:l0o`150?l0203o
00d0o`0805d0o`0001T0o`040?l0I03o0<P0o`2e0?X0c@3o09H0iP3_0>X0l`3V0>/0j`2H0?l0Z@3o
03h0^02V05hBhP0:<?l0P5JS003No`00n?l00?oh003oj@00omT00?o>003o`P00ok<00?n[00@00?nS
00T00?nk03n7o`1ALM<00?Rk003oT@00oiL00?360170^P00ogT01@00ofH03000ofX00>JQ0036o`0E
U^D00?n9003oO@00ohD00?S:00Eoo`00hOl00?n=003oH@H00?mG00l00?mO003oJP00ogH00?mh003o
P@00ohd00?c200fUo`10@/000<;o003o/`00ogd00?m^003oH@00oeL00P00odL00`00ocSooooooooo
o`02ooooo`03o`000?oooooooooo00Kooooo000Qooooo`04o`000?ooooooooooooooo`@05?l000<0
2?l000Go0005o`000`05o`001@04o`<00?l:003o2P00o`X00?l=00<00?lI0P00obP03`00oc000?lh
003oA000odL00?mG003oIP00ofh00?mm003oQ@00oi`00?n[003odP00hO`0@6C700KEkP02003of@0I
003Ml000jOP008go003lm000onD00?oY003ol@00k_l00?So003`o`00iOl00<;o03]=o`0=5ol006ko
001Wo`0E=_l01Q?o04/0fP1`0?l0e`2G0;h0l@3_0=80o`1=0?l06`1Q0?l0000J0?l0G03o04T0oP1S
0=d0fP330?/0o`270;/0o@370:H0S`3o0;80o`2R0?l0/02^07`0o`00??l008Go002To`00fOl00?Co
003oo000ond00?oM003od@00olX00?o2003o]P00ojl2003oZ`0<003o/`00olH00>Wh002no000olH0
0?n_003DgP00f_@00?nP003oO@00og800?m^0P00ofH03P00ofh00?me003o[P00Zo@00>GU003oY000
ohd00?nX03>dj@0A/OP00?nk003oV@00of/00?mS0`00oeL01@00oe/00?mV003oJP00ohd00?3B0080
0?n=00d00?nH003o^`00m>`077Oo003:l00o`<H00?n=003oM@00ofH00?mG003oB`00odL00?ll00Co
oooo00?o0000ooooooooool01_ooool0027ooooo00Co0000oooooooooooooooo100Do`000`0?o`00
1Ol000Go000400Go00<00?l:00@00?l=003o6@00oaT00?lQ0P00obP2003o>00G003oA`00od/00?mG
003oIP00ofh00?mm003oS@00oiP00?n[003o^`00on4078Ko003No@00fOP00?Ch003Uo`0=J?l03I;o
003do`00ooP00>Gl003Uo`00Sol00P00hOl03@00d_l01EWo001bo`195OT004Co0010o`104Ol0K`39
02P0o`1h0?l0/03i0?L0cP3o04d0H`3o00006P3o07L0m`3I0?L0V03S0<d0PP3o0=<0/@2T0?40AP3o
02@0o`1]0?l0I@3o03P5o`2:0;X00R[o0022o`00^ol00=;o003Io`00b_l00?cl003ok@00omd00?oA
003obP00olL00?no0P00ok/02P00okl00?o:03Ndo00gE?l00?oU003`g@0?ROl00=7h003oX000ohD5
003oM@0<003oO@00oi@00=WU0353o`00on400?n[003ocP1?GOl00>7X003oW000oh400?m`1@00ofH0
4@00ofh00?me003oU000]o@00KkF003oW000ojL00?3:003Yn01=IOd00?oF003oZ`00oi400?n9003o
L000oe/00?mG00800?m71?ooool00ol0003oooooooooo`06ooooo`008Oooool01?l0003ooooooooo
ooooool201Co000301;o000=o`001ol000D01Ol002<00_l7003o2P00o`X00?l:003o3`00oaT00?lL
003o9P00obP00?l`003o>000od800?m:003oFP00of@00?m`003oP000oi800?nG003oZ`06eLl00?gL
002Qn000W?l05YWo00MFo`0eF?l0073o078Pj@00N?l009co002mo`00/ol02Eoo001no`020032o`0=
002ko`04K?l09TCo01hXo`1J0?T08P_o0680kP2H0?@0S@3o0>@0n`3?0?l0o`2Q0?l0?@1Q0?l0000M
0?l00`3o02T0oP2g0<00o`2f0=D0S@3o04h0o`2=0?T0gP2f0400o`024Ol0P1;000Tao`00C?l05QKo
08@7o`0g<ol054Wo002Go`00Y?l0;DOo02^6k000i_l00?o`003okP0NXoX00?;^00BRn000om`00P00
ol`02P00om`00?oc01ijo`0@Yol0:YSo00k1k000okd00?nL003oS@00ohD3003oP00G003oP`00ohP0
0?nI003o`000enP0?I_i003^j`0[Z]`00=W]003mc000oiT00?n5003oM`00og000?m^003oJ`00ofh0
0?mh003oTP00ohd00?nQ00K6j`04Y?800P00ol003000n=h00;Go00E8o`0FT?P00?o5003o]P00dN/0
0?bN003oNP00of@00?mJ003oDPCooooo00?o0000ooooooooool01_ooool0027ooooo00Co0000oooo
oooooooooooo0`0Do`000`0=o`001Ol000Go000200Go00801?l300P00_l8003o2P00o`X00?l:003o
5000oaT00?lQ003o:0800?lh02D00?m7003oB`00of<0@<1c003oO@00ohD00?nX0430e`00ok/00?cQ
002go`10V_D0AE[G003`m000omh00?o`003ao000]ol0<2ko001So`0o<_l01DGo028Xo`2k0<002E3o
001^o`09G?l009co0021o`00J_l0@2;30383o`3409/0g`350>d0b`3F0>h0n@2R0080o`2J00<0o`0f
0?l0003o0000G`3o00005`3o02L0oP2/0?<0/`3R0=@0L03o03L0o`0B0?l0=P?o04h0o`2L0?d00Qoo
001?o`00J_l007go001bo`0IFOl0@2S/080:`002=_l0K23V03ljo`00/ol00>7o00800>go01000;Oo
02]Uh@00Y?l00?od003oi@00onT00?Ch003ao`1TD^800:So003om000om400?nc003oX`00oiP00?nD
0P00ohd03`00oi`00?nH003oU000oj400?nc003obP00n?@0:9;o003lj@00ol<00?n[003oV000ohT0
0?n2003oN@02003oM@0E003oO@00oiP04JGU003Ml000ol800?oQ006=o@00omd00?oI003hl@00c_l0
6Dgo003ao000onT00?oU002Ho`00[^H00>cM003oP@00ofH00?mS00Cooooo00?o0000ooooooooool0
1_ooool0027ooooo0_l00002ooooo`0301Co000=o`001Ol000L01Ol01000o`X0;@00oa@00?lI003o
8@00od000?m4003oB`00oe<00?mO003oS@00f_@00?nD003oY000hO000;Ol0036k000a_`0@3[?041c
o@00ond00?o>003obP00om800<[h04EJo@00POl00=Wo042>kP00^ol007[o074:`00o1ol0V`[a00D^
o`00A?l06Qco0014o`150ol0e0360?h0JP3o00`0o`1:0?l0E@3o0:T0o`0V0?l0:P1M0?l000030?l0
103o0180o`000080o`0002L0o`230=80l@2C0?l0a`2Z0:l0o@1M0?l07`Ko000Qo`0b0ol0I@3o01HE
o`00A?l006[o002=o`00X?l00:Co034Yn000I_l0L0?m0?l0A@1I5LL00UGo002Lo`20Bnl00;oo002P
o`00N?l00=go003lo`00o?P00[7o02QXo`00`_l0LBWi0032o`00n?P00?oD003o_`00ojl00P00ojL0
4@00ok<00?n_0170l000ok<00?nW003o[P00ol<00?oI003>o`1?@ol00?cY003o``00ojl00?nP003o
U000ohd00?n900800?n501D00?nA003oW000b^`00;_o035>o`00eO`00;oo003on000m?P06H?o0025
o`1k6_l009Co02AXo`00_ol01G_o00k5k@00ok<00?n1003oM@00og800oooool2o`0000Sooooo000Q
ooooo`06o`000?ooooooooooooooo`0Do`003Ol01P05o`000`03o`D00_l8003o2P03003o2P0V003o
5`00oaT00?lX003oLP00o:P00?n1003oJP00ogh00=GM002Dm000oL`00?cM002on02[1kD007go041k
a`00m?P00:_d003ocP00ok/00?nh003o``00kNP00?o`02BFo`00ooP00?cl002oo`10F>h0>cko001a
o`0A5ol0<BSo09`:]P2U0:X0I@?m07`0o`3o01/30?l000030?l04`3o01/0o`0@05`0o`0000@0o`04
0?l0003o0540o`1F0P3o0540203o05d0iP3X0><0T01h0?l0@P3o0800o`1B0?l0H@SU0P00@?l0;@02
6ol0S@[@028=o`1A4_l076co002go`00^ol00;So002To`00Hol0Kako041T`003B_l0LbS008PJn@0>
@ol08QGo07Xff`00/ol00:3o003Io`02R_l03C[o041Mo@0I7ol00VCo009ko`00oNh00?cU003/h@00
ol800?o3042QmP00on`0@9;;003odP00ok/00?o001Flo000m?P00<?o02EJo`00o?`00>SU003o``03
003oZ`0H003h]`00l;<00?nD003oV000oj<00?nk003hi@00gOl01HOo00Mgo`00c_l00=go002Ho`1B
0?l0P@3000dOo`198?T0@SOa003Mo000olX00?nT003oT@00ohd00?n51?ooool00ol0003ooooooooo
o`06ooooo`008Oooool01?l0003oooooooooooooool900Go00@00?l:02000?l>003o6@00oaT00?lX
003o?000l8D0@:FI003QdP0aN>`0EGcb06Hdo`00S?l0097o021go000TOl00=Gl003oeP00ol800?S:
003oZ`00ojL00?nV003o/`00ok/00?o6003of@00omd00?o]002go`00a_l0MeK000>Ko`8008Go00L0
B1co00dOo`0N3Ol0GP3o0=/0e03o0:T0o`0K05l0o`0002l0o`080?l0B@3o02X0o`1P0?l0c@3n0840
m`3`0?X0`P2`0>X0W03002l0o`0L0?l0MP3e0:L3m@00@?l005_o001Go`0o8ol0BASJ001^o`00I_l0
@5Sa0033o`00eOl00=7o002_o`09BOl0@T?J002oo`00b_l03ESo0021o`0J<?l0h02/05TMn`199<00
?2oo015Xo`00OOl03B?o0:P0d`3^09/0G@?o002Lo`00g?l009co002go`02003oi@0B003Io000QOl0
0>Wo003og@00omD0:mGY002Ho`00Z?l00:Oo06a6o@00/ol0@63V003Qo000olH00?o>003Xj`00b_@0
0?o60P00ojL05000ojl00?no003ocP00onT00?So02a3i000I_l00:3o001jo`0O4_l0h`3M08h0X`1F
3/00Z@2e0022o`00oN/00?S:003o/`00okh00?321?ooool00ol0003oooooooooo`06ooooo`008Ooo
ool01?l0003oooooooooooooool400Go000300Co0P05o`001Ol000800_l81000o`X04P00o`h00?lI
003o6@00obP00?ld003oH`02]<h00?n_003l`P00c]D04Ecl003Ik@00o=H00?o300VQn00PW_@00?o:
003oX0<00?nL01@00?nQ003oX`00ojl00?ng003o`P00om800?oM003ok@09`?l00=Wo003Do`00^ol0
09co001no`00Eol02AOo0200o`240?l0iP3S0?l0=Ul0o`0000l0o`080?l0F03o0:40o`0C0?D0a`3:
0?d0^P3o0>h0^P370=X0FP3o02@0o`040ol00`go05`AgP00Col00P00K_l0;@00C?l0H0Oo001bo`00
/ol00<[o003Jo`00iOl00>7o002Po`0IH?l00:So003Bo`00n?l00>go003Io`00Y?l002go00^;o`00
L_l0093o00U9o`0o4ol0k`2L0;`0P01A2_l0@COe05HUm@0PDol0Q03o02Qdo`00Y?l0097o002Lo`1A
B/000;?o003Qo00I_?P00>km0021o`0IEOl0:Aco0940l@2O1n800:Co003do002003ol00I02^WmP0I
]O`00?oB003o^`00ol800?oB003obP00omd00?oa003do`00Y?l06Rco00lIo`1@6?l0:P[o00U1o`05
DOl0H3OZ002Lo`10CML00Foo003`m000m?000:Co003lh@04ooooo`03o`000?oooooooooo00Kooooo
000Qooooo`04o`000?ooooooooooooooo`D01Ol000<00ol500Go0003o`D01@00o`X03`00oa800?lI
003o7@00obP00?ld003`P@00of/00?mS003oMP00n=800[7d003ba@00oiP00?nL003Ui@02003oY00I
003oT@00oi@00?nD003oU000oiL00?nS003oY`00ok<00?no003obP00omD00?oQ003om000o?l00>7o
002Xo`00TOl007Wo001Oo`0>5?l0Y03^0?X0/`3j0=d0o`1P0?l0201N0?l0001I0?l0B@3o09h0o`3S
0?X0aP3i0780`@3o07T0o`2T0=L0o`1H0:h0o`2<0?l01`Wo000Qo`00@?l006Co001io`00POl007Ko
0018o`1?0>h00:oo003Io`00kOl00?3o003eo`00f_l0@:gG003on000oo@00?o`003oo000iOl0087o
041An@00aol00?3o003Qo`00[ol0K2SR06P3o`104nX0:2ko001bo`00gOl00;go0193o`00Zol0P4jK
035Jo`108o40LA;0001@o`1T;>8008go002No`0EBOl0Z`ji08d0`01E3Ll0;Q[o02a2o`0J?ol04DWo
003:o`01F?l00<[o003Fl000onT0@;Bl042N_000onT00?oa00FUo`00c_l02I3o098Bo`3n0:P0^02f
014Oo`0gMol009co002Ao`00c_l00>Wo001mo`0PJ?l03EWo03=5o`00X?l01?ooool00ol0003ooooo
ooooo`06ooooo`008Oooool01?l0003oooooooooooooool400Go000300Co0P05o`000?l:00H00?l:
0`00oaT02@00obP00?l`003o?000odL00?m?003oIP00n;h00?nA003I^004003oO@<00?n50P00ohT0
5@00oi@00?nL003oX`00ok<00?nk003ocP00omD00?oQ003ol000ool00=ko058]hP1/2_l0@4;00018
o`0=4ol0<03o0800o`3F0?d0o`2U0?l02P1M0?l0000M0?l0103o01L0o`1c0?h0^`390?l0h03K0;`0
[P1l0?l0BP3o09@0jP3[07X0Q@3301L3o`0=5ol0043o001Oo`00OOl009Co002Lo`00SOl009Go00F:
o`00iOl00?3o003lo`00ood00?oh003om000onD00P00on40>`00ond00;_o0163o`00V?l009Om003o
n000d_`00W_o01ELo`05G?l0;Dko002Lo`00`_l00?oh02^dm00A/Ol00?oY003hk000l?`0C4Oo002P
o`00gOl00V3o002_o`1@=]D0J@OJ0:l0``2F1ol05SOo042>m@00`ol00;_o02aPo`10BOT0FQCO001C
o`1^B_l00:oo034oo`00b_l00?3o002oo`02F?l007[o002=o`0B8?l0iP240=<0P00J:?l00;?o003I
o`00hO`00?oQ003hi@00ln400?oN042Jl@00c_`00=7o00Cooooo00?o0000ooooooooool01_ooool0
027ooooo00Co0000oooooooooooooooo1005o`0200?o1@D00?l:0P00o`h3003o6@800?lX00L00?ld
003o>000od@00?m;003oF`00ofL00?mc00800?m^00D00?mb003oM@00ogD00?mi003oO@02003oQ@0D
003oS`00oi@00?nS003o/`00olH00?oI003oi@00ond00?ol003ho`00hol00:co001Vo`151ol0=P[o
04h7e`0g0?l0h`2P0?<0/`3o05aN0?l0000M0?l0203o07<0o`2i0?<0[`2V0?l0]03E09@0n@0c0?l0
:03o06D0o`2M0?L0S@300:`0]P1^0>X001ko03TJo@00OOl009co002Wo`00]ol00<Ko003Eo`00jOl0
0?So003oo`00oo<00?oU003oh@00omT00P00om40>`00omd00;_l003/m000onD00??[003of@00onD0
0?od00:eo`10T/00@5G0003ao`00o?400?oI003Fe000olH00?no003obP00iO00093o016Yo`00onT0
0?oU003ho00MRol0Q1[^05LEo`00J_l004co002@o`00m?`00?C]003hm00=/Ol00i?o003Fo`00]ol0
2Goo05//o`05DOl0FE;0002To`0X?Ol01DWo01DPo`2L0?T07QWo00Dfo`2l0<`007;o003`o`00onT0
0?o>003o^`00oj/00?o3003>l000b^D00?o:00Cooooo00?o0000ooooooooool01_ooool0027ooooo
00Co0000oooooooooooooooo0P05o`0200?o1@03007o2000o`X00?l:00<00?l:00<00?l>003o2P00
oa800P00oaT02`00ob400?lX003o:000ob`00?lh003o?000od@00?m;003oD`00oeX00?mS00<00?mV
01T00?mb003oM@00ogD00?n1003oQ@00ohd00?nD003o[`00ol<00?C`003Yo000m?`00=Go003ho`00
l?l00=ko015/o`1k=lL003So03X:o`3G0>/0`02^0<D0o`3o0700o`0<05h0o`0001h0o`0@0?l0N`3n
0=80h03o0;H0o`1[0?l0@`3o01`0o`080ol00`Go00<9o`1M0?l0X03009@0l@1J0?l0:`Oo001Ro`00
W?l00:oo0032o`00dOl00>7o003`o`00n?l00?oo003oj`00on400?oE003od@00olh2003obP0>003o
fP00olh00?o6003oa`00olX00?oA003og@00ooP00=go015Xo`00m?l00?oU003obP00okP2003oZ`0B
003o]`0PT_`00?oQ003Io000olh00?o6003Ul000Y_d00;_o0018o`00[ol009So003Qn000gMT00?o:
003oeP00Z?l00<Oo0P00om805P00X?l0>i;o016Qo`00K_l0Nac;04d>o`2W0<00R`3E008^o`00ROl0
0;_o0029o`12C/000<ko003Uo000omT00?n[003oU`00oiD00?nH003oW000oj@4ooooo`03o`000?oo
oooooooo00Kooooo000Qooooo`04o`000?ooooooooooooooo`800Ol91`00o`X00`00o`d00?l:003o
5003003o6@04003o7000obP00?lX003o:0800?lh00L00?lm003oA`00odL00?mB003oE`00oeX00?mT
00800?mV01H00?m`003oM@00ogD00?mm003oQ`00oi@00?Zm003Qn00UUOd088Ko05e:e@0AJ?l02Gko
003?o`00_Ol00:Ko001ho`01A_l0C0SL07T0e@3S0<`0o`1k1@3o00000`3o00X0o`0=0?l0001G0?l0
000P0?l00`3o05L0o`1Q0?h0SP3n09d0n`2O0;<0cP1A0?l0DP3o02X4o`007_l003?o00/Wo`0?6ol0
G`3i0:T0P01<4Oh01TKo02]Tj@0[M^@00;So003?o`00g?l00>Ko003co`00oOl00?o^003oh@00om40
0?o5003o`P00ok/2003o^0800?nc03<00?nh003o_@00olD00?oI003`n00YF_l00;gm01Igo`0M__X0
0?oA003oY`00oiT00?nG003oW00[eJT00?nS003oZ`00ojH00?nX003o]P00mMH00?Gh00UZo`00hoX0
0?gT003[dP00ok<00?n[003o_@00hnh00??2003o/@00ojh00?nm003od@00n^/009co05<Eo`18<MD0
CQGO05PFg00n8?l01f?o003Vo@00n_X00<3o002oo@0F]?004l?e003`h`00oh<00P00ogX00`00ogd0
0?nBooooo`03ooooo`03o`000?oooooooooo00Kooooo000Qooooo`04o`000?ooooooooooooooo`X0
0?l:1@00oaT01@00oad00?lX003o:000obP00?l`00800?lh00<00?m0003oA`00odL00P00oeL01000
oe/00?mV003oIP00ofX2003oM@0C003oN@00ohD00?nA003oW000ok<00?o>003oj@00`_`00;_o01U`
o`09I?l01cco00E1o`0F6?l06Qco05X0o`3o06`0o`190?l04`030?l000050?l06`3o04d0o`0j0?l0
G03o04D0E`3o00002`3o01/0o`1E0?l0VP3M0=h0bP3i09<0o`2n0?P0`P3008T0m@111ol01b3o0080
04oo00/002go02L:o`157=<0>1Oo08H7o`0a3Ol02Bko002Do`00_ol00<[o003Bo`02003Fo`0F003c
o@00oo400?oE003o`P00ok/00?nc003oZ`00ojL00?nS003oY`00ojH00?nc003o^`00onP04G_o002g
o`00on400?oM042]kP0I/Ol00?nV003oR@@00?n500d00?n=003oT@00oiP00?nS003o`P00onT00;Oo
003ll000olX00?n_003oX`00oiP00?nD00800?n=01@00?nA003oV000ojL00?no003oi@00hOl02ESo
002/o`10BNX008co002Ho`00d_l00?oQ003of@00l?@0Lf;m003o^`00oiP00=VW003oL0800?mV00<0
0?mb003oTOooool00oooool00ol0003oooooooooo`06ooooo`008Oooool01?l0003ooooooooooooo
ool2003o2P03003o3P00o`X00?l:00<00?l:0P00oa85003o6@@00?lX00@00?ld003o>000ocP00?m0
0P00odL06@00oe<00?mG003oF`00of<00?mV003oJP00og800?me003oN@00ohD00?n=003oV000ojL0
0?nk003od@00ond00>go001mo`10AOd0E2o^02Hdo`122_l0K0We0<L0i03o04T0103o0000203o02@0
o`1P0?l0_03o06@0o`3C0?l0I03o02<0o`0CE@3o00008@3o00P0o`0S0?l0RP3Q0?40W`3o06d0o`12
0?l0Q03o05L0e`008Ol004oo001So`00J_l0@4;V0419`000Jol006Wo050Eo`200mL0@3K0001mo`00
Y?l009Co009Po`00M_l0<BCo0038o`00Y?l00?3Y003oaP00ok<00?n[003oY`04003oX`0;003oY`00
okL00?oF042>`000e_`00?o3003oZ`00olX02KcY003m[P00ogd00`00ogD09000ogT00?n1003oR@00
oi@00?nS003]c010S^h008go002_o`00j=d00?n_003oW000ohd00?n5003oO@00oh000?n5003oT@00
ojl00?3U002Ao`00Y?l00>Go003Xm000o?@00<Go01E/o`00n?`00?oF003o_`00olh00<Kd002Hi@00
ohT00?mb003oH@800?mO00<00?mS003oTOooool00oooool00ol0003oooooooooo`06ooooo`008Ooo
ool01_l0003oooooooooooooool00?lF003o2P800?l>00@00?l?003o2P00oa800?lB1000oaT00`00
ob400?lI003o8`04003o:0<00?lh00L00?m0003oA`00odL00?m?003oE`00oe/00?mS00800?mV01l0
0?mb003oM@00ogD00?n8003oS@00oi@00?nW003o^`00o>400>cl001Ko`0U;?l00;oo002eo`00W?l0
06ko000]o`2T0?40o`2>0?l0003o02h0o`1A0?l0?P3l0<h0o`1P0>T0c`3I0=X0l@3L0?l0G@3o09X0
o`1505H0o`0001l0o`0Z0?l0RP3g0:00hP3P0:l0n@0V0?l0:03o07T0o`1F1mh005_o001Zo`00NOl0
087o002Ao`00W?l00f[o01X/o`02BOl0@3gm03D/o`0A?_l09R3o040K`000Fol0O2WR03I0o`1T;Ol0
5Kch003hf@00ok<00?nS00800?nP01000?nH003oU000oiT00?nP003o[`00on400Y;o002kn000ok/0
0?nH003oS@00oj/00?n0003oM@00og800?m^0`00ogD02`00ohD00?n=003o_P00jnP0@:gZ003odP0o
[O008V;o003>h@00oi`00?n500@00?me01@00?n5003lbP09Q_l0@<3<003hk00=[OP00?o>003odP0[
V_T0IRCo002Lo`00olX00?n_003oY`00olH00?CU003oQ@00of<00?mG003oD`800?m?00<00?mSoooo
ooooool00_ooool00ol0003oooooooooo`06ooooo`008Oooool2o`0000;ooooo0P00oaT00`00oaH0
0?lI003o5006003o6@04003o7@00oaT00?lQ003o9P<00?lX00D00?l`003o>000ocP00?lh003o@002
003oA`04003oC`00oeL00?mG003oH`800?mV0P00ogD07P00ogT00?n5003oS@00oiP00?n[003Ii@0T
T_`0A4Oo0415l@00c_l00>Wo003Ao`00X?l005oo00Dbo`1N0?l0o`0f0?l07`3o08H0dP370?h0bP2f
0?l0o`3?0;X0o`2O0?l0lP3[0>T0m@3/0=X0o`1o0?l08eH0o`0001l0o`0D0?h0/03:0?T0W03m0240
o`023?l002Go0010o`00Gol007;o0025o`00U?l00:3o002Wo`0CRol00:Co002Xo`00Y?l00Tgo021M
o`00[ol00:So0036o`00e_l00;go003Io000W?`00?CQ003oZ`00oj000?nL00@00?nD00X00?nH003X
]`05/N4009co0025m000ojP00?n5003oO@00ogD00?m`0`00ofH03`00ofX00?m^003oM@00ogd00?n=
003XaP00P?l00?cM003oZ`00hL8009cd00;0k000olh00?mm003oLP02003oIP07003oKP00ogd00<;U
003o]`00oi`00<KB016Ql002003o/`06003biP0aKOl00>Wh003oaP00oi`00?nA0P00ohD00`00ofX0
0?mK003oC`03003oA`04003oBoooooooooooooooo`;o00002?ooool0027ooooo00Co0000oooooooo
oooooooo3000oaT00`00oad00?lU003o:002003o:006003o<000ocP00?lh003o>000oc`00?m40P00
odL01P00oe<00?mG003oE`00ofH00?mZ003oLP800?me0P00ohD2003oU00K003oY`00j<h00?cY003E
o000o?P00?ol003ho`00fOl01F3o02ddo`103l00I0Oo0?L0MP3b0=`0bP3008P0o`2D0<00T`3C0?d0
i`2G0?l0W`3o0:`0jP3:0?40[P3o0?80]@3o09h0o`0b00<0o`0000<0o`0S0?l04`3o01/00P3o00A>
0?l0000M0?l0K`2n0?l0N03o04d0o`112M<002Go0014o`00Fol006[o001mo`00TOl00:Oo002go`00
`?l00<[o0032o`00]ol01F3o03<jo`00^ol00>Go003lo`00oo@00?o[003oeP00olh00=G>003oY`00
oiP00P00oi@2003oS@0:003oR000ohd00?nD003oX000olH0@;b]003oW000ogT00?mb003oJP800?mV
0P00of<2003oIP0=003oJP00ogd00?nE003o^`00_OD00?nk003oS@00oi400=g>01Udo`00n<X00?mj
003oJP02003oG`0C003oIP00ofX00?mb003oN@00ogd00?n[003o[`00oi@00?nP003oa@10H?d00=;l
003Qg@00oi`00?n5003oN@00ofX00?mO003oE`02003oA`03003o?000od000?lh00Cooooo00?o0000
ooooooooool01_ooool0027ooooo00Go0000oooooooooooooooo003o7@0:003o6@07003o8@00obD0
0?lX003o:`00obP00?l/003o=003003o>004003o@000odL00?m7003oBP800?mG01h00?mO003oIP00
og800?me003oN@00oh400?n5003oR000oi@00?nH003oX`00okL00?o6003oe@00omd00?o]003oo000
l?l00:Co040m`000I_l05Qgo0680o`1>0?l0GP3o0640o`0H0?l0D@3o0>l0k01i0>h203/0o`0>05H0
o`2V0?l0nP2o0<X0fP3g0<h0o`0L0?l0003o02h0o`1T0?l0N`3o04D0o`0^0?l0A@3o00A<0?l0000?
0?l04`3g0<80m`210>H0V`3>0<T0KP3R06@3o`009Ol003So000do`0T?_l005oo002Po`00`_l00<oo
00800=7o00l00<[o002To`0e8?l0G4om003Uo`00ooP00?oY003oe000okl00?nc003oY`00oi`00?nD
003oT@00ohT01@00ohD01@00ohT00?nX002_e@00oi@00?mb00800?mV00<00?mO003oE`00oeL00P00
oeL03P00oel00?mV003oMP00`]d00=W/02^f``00oiP00?mi003oLP00ohT00?ng003UcP00ofh00?mK
1000oeL04`00of<00?mZ003oJP00og800?mm003oP@00oi400??X009_o`0XEOl00g7d003oZ`00oh40
0?m^003oIP00oe/00?mC003oA`00oc`00P00ocP00`00obcoooooooooo`02ooooo`03o`000?oooooo
oooo00Kooooo000Qooooo`06o`000?ooooooooooooooo`00obP00?lU0P00oaT01@00oa`00?lI003o
7@00oaT00?lM00800?lQ0`00obP00`00ob/00?l/003o=003003o>00:003o@000od/00?m7003oA`00
odl00?mG003oF`00ofH00?mb003oS@800?n502X00?n9003oT@00oi800?nD003oX000oj<00?nc003o
^`00olh00?oI003oj@00ooP00>ko003Bo`00[ol008Go000ho`2B0<`080oo03/0o`1=2_l00Q?o02/4
o`2g0<l0P03o00d0o`0L0?l0BP3o0<H0a`240?l0Y0330?<0bP3Z0>00o`2>0?l0X@3o09X0oP3J0?l0
>P3o07<0o`1o0?l09`3o00a;0?l0000?0?l0G03V0=@0R`3o05H0o`1S0?l0K@3o0840`01M0o40<P?o
060E`01o8?d0;aKo0021o`00b_l00=Wo00800>7o00/00=Go002=o`2D8]0004Oo002_o`00hOl00?oY
003oc000ok/00?n[003oX`02003oU005003oR@00ohD00?n5003oQ@00ogX00P00ogT01P00ogd00?n9
003oT@00og800?mV003oH`L00?mG00H00?mK003oJP00ohD00?3M02^Wl`00oh43003oH`800?nA00@0
0?mK003oD`00odl00?m<0P00oe<2003oE`0@003oG`00ofH00?mZ003oM@00ohD00?n[0036j@00^ol0
0?o>003oX000ogd00?mb003oIP00oe/00?m?003o@P800?lh00<00?l/003o:?ooool00oooool00ol0
003oooooooooo`06ooooo`008Oooool01?l0003oooooooooooooool3003o:003003o8@00oah00?lQ
00800?lQ1@00obP00`00ob`00?l`003o>003003o>003003o@000odL00?m700800?m700H00?mD003o
E`00oel00?mV003oQ@00o=T2003oW0<00?nD02L00?nP003oX`00oj/00?ng003o_`00olX00?oE003o
j@10^?T00>Co003>o`00/?l0087o02dEo`1N0?l0043o001Go`00Col004Co04P;o`1d0?l00Pco000>
o`130?l0Y0300;`0/P0g0?l0L@3o09<0o`2d0>40nP210=80m@350?l0lP3S0?l0M`3n0>D0o`380?l0
I03o00@0B`3o00007P3o03h0lP3W0<L0k`0X0?l02PSo040GkP057ol0;@go01TOo`00Hol008Go009k
o`00W?l00=Go003To`00kOl00?3o003Yo`00hOl00<?o00EEo`1X2L00<h[o003ho000mM`00?nk003o
Z`00oi`00?nD003oT@800?n500<00?n1003oN@00ogD01000ogD00`00ofh00?mV003oH`03003oE`@0
0?mC0P00oeL02`00oe/00?m^003lZ`00i[<00?mW003oE`00oe<00?m?003oE`00oe<00?m;00D00?m7
01@00?m;003oE`00oeL00?mK003oIP00ofh00?mi003oS`00ok/009Co003oeP00oi`00?n5003oM@00
ofH00?mK003oC`00odD00?lh003o<0800?lX1?ooool00ol0003oooooooooo`06ooooo`008Oooool0
1Ol0003oooooooooooooool00?l[00/00?lX00@00?l]003o<`00ocX00?m21P00odL0=@00odd00?mE
003oE`00oeX00?mV003oL000oi@00>7L01?0kP0[d=800?nh003oYP00ojD00?nS003o[P00okH00?o2
003obP00om@00?oO003on004Pol0087o002[o`0;?_l0E2G/03XSo`00COl06foo0023o`00Jol003ko
0649h@0<5_l003_o000`o`0`2_l01aCo0700o`0=0ol05`3o0400o`2g0=/0a03Z0800o`2n0=D0iP3A
0>80m`3G0?l0m`1e0?l0N03o06H0o`0804X0o`000100o`0Y0>L0[02U0?h0G@3f04/:m@00@_l005;o
00@fo`1R4?l0;AoE001ho`00[_l00<co003Qo`00k_l00??o0P00n_l03000mOl0:k7/002Bo`00Uol0
:fOW02i9l@00]?`00?o?003o[P00oi`00?nD003oRP800?n500T00?mh003oM@00ogD00?m`003oJ`00
ofT00?mV003oI000oe`00P00oeL01000oeD00?m9003oA`00odX3003oA`08003oBP00oe800?mT00KE
^000ohX00?m?003oA`00odD2003o@P800?m000@00?lm003o@000od000?m50P00odL05@00odX00?mE
003oE`00of400?mY003oM@00ohl00?nj02^nc@00k_<00>7I003o^00MeKD00?mm003oJ`00of400?m5
003o>000oc000?lX003o7P04ooooo`03o`000?oooooooooo00Kooooo000Qooooo`06o`000?oooooo
ooooooooo`00ocP00?l`2000obP01`00ob`00?ld003o>000ocP00?m7003oNP00ogH00P00oeL00`00
odl00?mC003oE`02003oE`0:003oFP00ofH00?mZ003oM@00ohd00>cA081BR000fOP00?oB003o]`80
0?nc02L00?ng003oaP0=VO000?c`003oj@00oo000?3o02Q_o`06C_l0<47o018Io`0]7?l004co002P
o`00Zol009So01U5o`1T3N80>a[E01`Zo`00Fol005oo001Ko`02>_l02B?o000Mo`0F1Ol0a@3o0=80
/`1h0?l0CP3o09l0o`2c0?T0]`3009l0o`390?l0m@3g0?l0K03o01`0BP3o00003`3o00`0cP3G0740
o`2D0?d02A_o001Go`00J_l006ko009=o`0g>_l0=Pko009=o`00a_l00>Wo003eo`02003oo`@00?oh
00P00?cl003Qo`10G?T00:_o003:o000ok/00?nL003oT@800?n500D00?mm003oN@00ogD00?mc003o
JP02003oIP05003oH`00oeL00?mG003oE`00odl02@00odL01@00odl00?mK003oBP00od000?ll00T0
0?lh01L00?m0003oA`00odL00?m;003oE`00oe/00?mZ003oP@00oj/009co003df@00okL00>7M009o
o`09Oo@00>6n003:dP00oi409ME^003o?000oc000?lX003o6@04ooooo`03o`000?oooooooooo00Ko
oooo000Qooooo`04o`000?ooooooooooooooo`800?lh00P00?l`003o:000ob/00?lX003o<000obP0
0?l/003o=0800?lh00L00?ll003oA000og<00>GF003oU000ofX00?mO00@00?mG01X00?mK003oI000
ofH00?me003oP@00oi400?n[003dj010H<000?3l003ocP00okd00?no003oaP00omT00>7h00Uco`00
n?l00?co003Yo`00__l0ECg>0>X0W`0l6?l0087o00UXo`800;_o01T0097o05<Po`10FOd03TWo01hT
o`00L_l007Go001Zo`00Gol004_o008Oo`080ol0M@3o0:l0i01F0?l0703o02/0o`1B0?l0H@3o09l0
o`3^0;T0o`1[0?l0J03o0800o`040440o`000100o`080?l0003o03P0o`0K0?l0=P3o04D0o`0n0?l0
E@3j09`0_`3R02`0o`1;0>h0;0_o001Oo`00MOl008Go0P00SOl01`09I?l00:Co002[o`00jOl00?Go
003oo`00oo@00P00oo003@00onT00?oQ003oj@00a_`00?Cd003og005`>P00?o:003oV000oi400?n9
003oQ@00ogT00P00ogD01@00of/00?mV003oIP00of<00?mK00<00?mG1000odL00`00od@00?ll003o
>003003o>003003o?000od000?lh00800?lh0`00oc@00`00oc000?ld003o=005003o>0800?m701<0
0?m?003oF`00ofh04JWE003be`0I[O@00?nc003oS@00oi`00<;F003/f@00Yo`00<Kl003Mf@00ofh0
0?m;003o?000obP00?lI00Cooooo00?o0000ooooooooool01_ooool0027ooooo00Go0000oooooooo
oooooooo003o?003003o>003003o=@00oc@00?lh00@00?lh00`00?m0003oA000odL00?mV003McP00
ok<00>bL003oKP00ofH00?mS003oG`00of<2003oIP0O003oLP00ohd00=fg003o[`00okL00?oQ001V
o`00k?P00?oI003obP00olh00?oQ002/o`00d_l0P3^V003Io`00d_l008go001no`13:mD0DbCo014m
o`00Z?l00<Ko003Eo`00c_l009Go01UTo`00Z?l0>5Kh001;o`020029o`0B001io`00Fol004Co00hD
o`2b0?l0^03D02h0o`071Ol030?o01`0o`0k0?l0J@3o0<<0fP3o07P0mP3[0?@0o@3o0:40o`1=@@3o
00006P3o02X0o`1=0?l0VP3o07l0oP320>h0a@3Y0>X0e03o0<<0`02[0=L0=`3o008?o`00>?l005oo
001mo`00SOl009co002Wo`00]ol00<Ko003Io`00jOl00?Go003on000oo000?o]0P00on402@00omT0
0?oE003of@00olX00?nm003o[`00ojL00?nH003oS@02003oQ@04003oO@00ogD00?me003oJ@800?mV
00D00?mO003oE`00oeL00?mG003oB`03003oA`03003o?000ocP00?lh00H00?lh00<00?lc003o;000
ob`01@00obP00`00ob`00?lX003o<`03003o>00E003o@000od/00?mG003oG`00ofh00=g30228o`00
onD00?n=003oLP00ofh00?mf003oW00AV_@008gd03_0e@00gY@00?RA003oNP00oc000?lI00Cooooo
00?o0000ooooooooool01_ooool0027ooooo00Go0000oooooooooooooooo003oA`08003o>00;003o
?000od@00?m7003oB`00oeL00?ma003>g@00ROP009SX003oZ000og801000ofH06@00ofh00?mm003o
X000hNd097ol003Qk000n?@0087o003`o`00onD00?oI003oh@00ond00=[o009To`05F?l007;o0021
o`127<<01D7o00Ulo`00POl0<C_o0099o`00eOl00P00iOl06@00e_l00=;o003>o`00OOl00WOo002L
o`00V?l007;o01TGo`095ol030Oo0;P0S`290?D0317o000Mo`031Ol0=`3o0:<0n@2T0<00fP300:`0
n@2g0?40dP3C0?l0I03o0100@03o00006P3o01/0o`1[0?l0`03k09X0l03e0?h0S@2k0<00]`3R09P0
e`1Y0?l0a`2m0;`0YP0C0ol00B[o000lo`09DOl008go002Po`00[ol00<;o003Ao`00hOl00>Wo003e
o`00ooP00?o`0P00on402P00omD00?oA003obP00ol800?nk003o/000oj<00?nL003oU000ohT2003o
Q@04003oN@00ogD00?me003oJ`800?mV00@00?mK003oE`00oeL00?mC0`00odL00`00odD00?lh003o
>003003o>0800?ld0P00ob`00`00ob/00?lX003o:008003o:00H003o<000ocP00?lh003o?000odL0
0?mG003oH`00og800?nT03JSdP0`/NP00?mn003oH`00oe/00?mO003AY000_/X00?nD02B>m000e=L0
0;?E003oR@00od000?lM1?ooool00ol0003oooooooooo`06ooooo`008Oooool01ol0003ooooooooo
ooooool00?m7003oA000oc`01000ocP00`00oc`00?m0003oA`02003oD`08003oE`00oe/00?mj003l
g@20G]000?o6003oT@00ogT2003oLP0<003oKP00og800?mh003oP@00ohd00?S6003/k010T_d05H?o
0025o`00fOl00?Sl0P00n?P03@00o?`00>7o002Wo`106oD0@1Co04@/o`00Hol03G?o003Go`10E=L0
0;Oo0018o`00iOl00P00n?l06@00l?l00>Wo003Mo`00aol00;_o002_o`00W?l008go03<^o`0k0?l0
a02j0:P0`0102Ol002ko000do`0O0ol0W03006T0o`2;0?l0DP3o0640o`2G0?l0b@3o0?h0]03o01L0
@03o00008`3o0380o`0m0?T0l`330?P0a@3o0?l0X@370>/0EP3o02/0o`0P0?l0Q@3e06h0m@2d0;d0
>`Ca05H:gP028ol02Eco002Ho`00Yol00;_o003:o`00eOl00=go003[o`00o?l00?o`003oi@00omd0
0?oA003obP00ol800?no003o/`00oj/00?nS00800?nD00<00?n9003oQ@00ohD00`00ogD01000of/0
0?mV003oIP00oe/2003oE`06003oC`00odL00?m7003oA`00oc/00?ll0`00ocP2003o;0l00?lX01L0
0?l/003o>000ocP00?m;003oI`00ohD00?n9003IcP00^^d00?nE003oI`00oe<00?m;003oA`00odl0
0?mC003oI`00oi4007[b03R0g@00oi400?m8003o8@04ooooo`03o`000?oooooooooo00Kooooo000Q
ooooo`04o`000?ooooooooooooooo`<00?m700@00?m4003o@P00od000?m40P00odL00`00oe<00=FE
003oS@02003oKP07003oP000ol800=Ko003lg@00oiP00?n5003oN@03003oM@0c003oO@00ohD00?nD
003oY`00ol<00?oM003on000Zol0@4WZ0036o`0XFOl00:So003Jo`00J_l03Eco07<:o`2B0:<0P1GL
0033o`0=[Ol00?So0036o`00m?`00?oh003oo000ooP00?oo003lo`00l?l00>Wo003Io`00b_l00;_o
002Lo`00ROl005Oo02T9o`2U0<40G@3o008Oo`00C?l004So040Gm@0L5ol0:03o08T0m@0X0?l0CP3o
0;L0n@3g0840oP1M0400o`0001H0o`0K0?l0Z@3o09h0o`2B0<40o@1e0?l0T`3o0>L0NP1B0?l0803o
008<o`004_l0:P?o08D0`02_0:X0Y`3J00DSo`00I_l0087o001fo`00Y?l00;oo0P00b_l03000Sol0
0>Go003on000onT00?oM003od@00olh00?o2003o]`00ok<00?nV003oX`800?nD00<00?n=003oQ@00
ohD00P00ogT01@00ogD00?m^003oJP00ofH00?mO00800?mG00@00?mC003oA`00odL00?m71000ocP7
003o:008003o8@00obD00?lU003o6@00ob400?lM003o8@00obD4003o:00F003o=000ocP00?m;003o
R@10`:T00/3F003Ig@00b^/00?nA003oH`00od/00?ll003o>000oc`00?m0003oC`00o;/00?o2003l
j@00oh400?lh003o8@Cooooo00?o0000ooooooooool01_ooool0027ooooo0_l00002ooooo`03003o
C`00odL00?m700D00?m702H00?mG003oG`00oj/0@<2h002jaP00oi400?nB003leP0ANol00=Gh003o
]`00oi400?n5003oP@00ogd00?n5003oRP00oi@00?nP003oY`00ok/00?oE03o0m000`ol0:Bco001G
o`0F?ol00:Co0021o`2/7[80I2Go00eko`00L_l0@5S0003:o`00n?l00?o^003ok@800?oY0P00oo00
6@00ooP00?oo003do`00l?l00=co003>o`00/ol02EWo001Oo`117>h0J@OR00TSo`0O2_l07a;o001Q
o`00Hol005Oo000lo`1:0l003`Go00T0o`0X0?l0Q@3009l0o`3o07H0@03o00002`3o0380o`1P0=D0
o`3V0800`P3C05X0o`160?l0W03709P0gP1l0?l05Pgo008003Co02@001ko0842g@1m0?T0CP[000/X
o`00Eol002go03Pgo`0TMol00;?o002_o`0I@_l00=go003lo000ond00?oQ003od@00olX00?o2003o
^`00ok<00?nX003oX`00oiP00?nD003oT@00ohT00?n5003oP@00ogT00?me003oL`00ofX00?mV003o
H`00oe/2003oE`04003oB`00odL00?m4003o>`800?lh00<00?l/003o:000obP01000obP00`00oa`0
0?lI003o7@07003o6@0I003o8`00obP00?lX003o;000ocP00?m0003oE`00oh400>7`079Un00o;?<0
0>SM003oNP00od@00?ld003o;000obP00?l`003oC`00bYP0:mEU003oLP1IP;`00?mZ003o>003oooo
o`;o00002?ooool0027ooooo00Ko0000oooooooooooooooo003oE`00odl2003oB`800?m700h00?m;
003oD`00oeL00?mV003oS@0I[O@008gh003o_P00okX00?SF009To`00om800?n[003oU0<00?n=01H0
0?nA003oZ@00ojL00?nW003o]`00o=d00?oQ03^ho00;>ol0[03[0:`0g01I0_l08a[o03h:o`00Y?l0
08Go003Mo`00/ol0B5Ko031_o`00iOl00?oQ0P00omT04000omd00?oQ003oi@00oo000?oo003ho`00
l?l00=Wo003:o`00]ol0@4Wm05D>o`1]0mL03aco001So`05BOl2001jo`0;001eo`00I_l005?o000h
o`008Ol01`Go05d0o`1l0?l0bP3N0?l0N`3o01/0>`3o00003`3o00`0o`040?l05`3o02h0o`2B0?80
j02W0?l0[03^0:D0g@0_0?l09`3o0840b`1Q0?l00Q?o008Zo`02001?o`0H000ao`1f1=<0@2O^034A
o`250>X0O0Oe04H3m@00C?l008Go002Ho`00SOl006Co002Po`00TOl00?3l003oi@00omT00?oA003o
`P00ok/00?ng003oZ000oj<00?nH0P00oi@01`00ohd00?n5003oQ@00ohD00?mi003oM@00og800P00
ofH01P00oel00?mG003oE`00od/00?m7003oA0800?lh00<00?ld003o:000obP00`00obP00`00ob40
0?lM003o6@07003o6@800?lM01000?lL003o9@00obP00?lX003o=000oc`00?m?003oS@00oj`00?oF
00J^h000m=d00>F9003o@000oc000?lX1000ob401@00obH00?lh003dZ`00ofL00?lh00Cooooo00?o
0000ooooooooool01_ooool0027ooooo00Go0000oooooooooooooooo003oF`07003oE`0<003oG`00
ofX00?n1003lcP00gNd01G_o003[j`00eO000:3l003ocP00ojl00?nP0P00oi`04000oj@00?n[022M
iP00ol<00?nk003oeP00[?l00?3o02RMo`1J:Mh0/`[L0:/3^@3G0=D0i`1n001jo`00e_l2003lo`06
002_o`00Zol00?od003Ul000om400?o:0P00om407000omd00?oQ003ol000ool00?Co003Uo`00dOl0
0;oo002[o`00M_l0CP[00<P0T@02?_l008Go002Lo`00V?l008go001io`00K_l005_o0010o`025ol0
4`?o0:00`03?0<D0e`2f0=<0h03o07hj0?l0000@0?l0303o02X0o`150?l0SP3o0:T0o`2:0?L0dP2k
0>h0M@3o04L0o`0L0?l03@3o0200o`280?l01Aoo001Go`8006?o01H02Cko01=6o`00J_l005oo000]
o`2A0<00Q@3001hLo`00Dol0CA[o0010o`239i`0@6SN00:Mo`00n?l00?o]003oi@00on400?oB003o
aP00okL00?n`0P00oj<01@00oiP00?nD003oU000oi400?n=00800?n500<00?mm003oM@00og800P00
ofH00`00of<00?mG003oD`02003oA`800?lh00<00?l`003o:000obP00P00obP<003o6@0C003o7@00
oaT00?lQ003o9@00obP00?l`003o>000odL00?mK003oNP0=`;h08:[:003oMP00oe<00?lh003o:000
ob400?lI003o5P02003o4P05003o5000oad00=6D003oB002o``01?ooool00ol0003oooooooooo`06
ooooo`008Oooool01?l0003oooooooooooooool2003oI003003oG`00oe`00?mL00800?mL02H00?mT
003oIP00og000?mm003oTP00n;D00?GI003<l`0MUol00?Sc003oc`00ok/00?nc003o[P00ok400?[I
00^dl`00aO`00?oY003SiP00^_P0@UKo02iDe@07?ol05Y?o011io`0KB?l0@2Oo02MJo`0@Iol0:lKY
003oj@00on40:mG1003NkP00ol`00?o5003o_@800?o201h00?o<003oe000on400?oe00C1o`00f_l0
0;?o00Udo`0/HmD00Fco03d`i`06D?l08DWo001mo`00Y_l00:ko002[o`00T_l006ko001Jo`0[=oH0
02ko06h4g02]0;X0M`3X05@0o`100?l0_P3a0?T0Y@3o00dh0?l0000Z0?l01`3o05L0o`2Q0?l0c`3n
08T0e`3^0>00o03/0:`0k@2N0;40l@1T0?l0B03k004;o`007_l01ROo004io`00I?l0073o001mo`00
P?l008oo002Do`00OOl0?B[E00XIo`00Aol0P2650783l`2`09h0f00j00APo`00/ol00=Co003^o`00
n_d00?[j006go@0CcOD00?oG003obP00okP00?na0P00oj<01P00oih00?nI003oU`00oiL00?nI003o
W0800?nG00/00?n5003oNP00ogD00?mj003mQ@00oe`00?m?003oA`00oc/00?lh003o;@03003o:080
0?lL00<00?lI003o7000oaT00`00oaT00`00oa@00?lI003o5005003o6@0?003o7P00obH00?lX003o
>000odD00?mE003oO@00n=T05j7[003oL`00oe800?le003o8@00oaT00?l=00800?l:0P02o`L01002
o`X00?l`00;o6`04o`84ooooo`03o`000?oooooooooo00Kooooo000Qooooo`05o`000?oooooooooo
ooooo`00ogT00P00ofh00`00og800?n0003oLP03003oKP0S003oM@00oh400?n=003oW000ojl00?oD
041Lo@1XD]<00?oa003dl000o>D00?SM003obP00on400?3l015_o`09W_l0@63G001bo`00POl0<6Co
003Qo`00o?P00=go0032o`00U?l00:3o003ao`00ond00?oE003ocP00ol800?no003o/`00okL00P00
ok<03`00okl00?o6003oe@00ond00?Cl0095o`00OOl0H2cN02i4e@00I_l00U7o001Oo`00Y?l00;_o
002oo`020032o`0>002go`00QOl0?2Co02L7o`2:1ol0?@?o03X7o`0]3Ol001go000>o`0H0?l0I03o
0>l0/`3o01L40?l000050?l0103o01<0o`190?l0:@3o00P0;P3o0000;@3o02H0o`170?l0103o06@0
n@3g0<d0o`2V0?l0S`3o0800o`350?l0g`2e0=d0_0200?l00`Go000Qo`00@?l005Oo001Vo`00MOl0
08Wo002Ho`00Y_l00:_o002Ho`00TOl0087o002Do`10H<0040[o08`3jP1U0nH0EQ_E040ViP00Z?l0
08go003>o`00fOl01ESo003Fo`0EXOl00>Wl003oa`00okL00?nc003o[`04003oZ`0?003o[`02`=X0
0=kL002Lo000oj@00?n=003oT@00o<H00?ng003oO@00oh800?m?003o@000ocP00?l/00800?lX00<0
0?lM003o6@00oaT01000oaT00`00o`X00?l>003o2P02003o2P04003o3P00o`X00?lF003o5`800?lI
00l00?lU003o:000ocP00?mC003oI`00ogd01L3200^^iP00ohd00?32003oG`00ob400?lB003o2P04
o`<01@05o`000`0=o`005?l0ooooo`03ooooo`03o`000?oooooooooo00Kooooo000Qooooo`0:o`00
0?ooooooooooooooo`0A^=D00?n9003oO@00oiT00l_:003oP@800?me01L00?mi003oO@00ohT00?nD
003oX000ok<00=k[003Bo`2Y8_l00=[o00F7o`00X?l00=gl003ok@10[K`00:_o06l8e@1c5L0009co
0036o000o?@0=GSl003:k@02003og@09003ol@00cOl008Go003hn000on400?o>003o_`00ok<00?n_
00800?n[01000?nV003o/`00ok<00?o2003dj000dOl00<[o01UTo`12;<000:3o00J/o`00a_l0@7?0
04Tob`00]ol00<[o0P00dOl04P00c_l00;_o04e7e@0T;_l0@57m001Ko`1G4Ol03A_o0014o`00??l0
5Pgo0;@0]@2C0?<0]`3e0?h0F`3o0000o`0b0?l0N`80o`1E00D0o`2a0?l0M`3o07<0o`0n0?l0100]
0?l000080?l0503o08D0o`1n0?l0K`3o0980i03o0<h0`02;0?l205T0o`0<07`0o`3S0<L0YP3o03h0
o`1=1ol003Go001;o`00Fol006Oo0021o`00V?l00:ko1000^ol04@00[ol009co001Ko`0/;_l0<6Co
01Q>o`10</00@2?Z02dco`00Y?l009co001Co`00O_l00;3o003ll000ol`00?no00<00?nk00P00?oB
003Ei@00olh00?o:003og@00^ol00>SU003o/`800?n[00X00/3F003Fk00=ZND00?nA003oE`00od80
0?lh003o;000obP00?lQ1@00oaT01000o`l00?lB003o2P00o`h6003o2P0A003o3@00oaT00?lI003o
7@00ob`00?m8042QX@00/lh00=7A003Qk01NA?400?cM0430L`00odP00?lQ003o2P02o`P00`05o`00
0`0=o`005?l001Co000201Co00Cooooo00?o0000ooooooooool01_ooool0027ooooo00[o0000oooo
oooooooooooo02RBn000ojl00?nP003Ej@0>]]T00?n=0`00ohD04`00ohT00?2c003oZ`00ojl00?o3
00>WnP00Z?l09Bco080/[P10FOT008Go003Mo`00b_l0Ec3o07/o`00>Kol0<6So003do000omd00P00
olX02`00ok/00?no003ocP00onT00;?o03]go`0PZOl00?ca003obP00ok/00?n_00D00?nS00h00?n_
003o^`00m>D007go041In@0TPol00<;o02Bho`00mOl00=Wo001Wo`1a6^X00:Co003Eo`800>7o01T0
0=go016Fo`0[J]D01GOo002Eo`00I_l0@@[o000lo`00Gol005Oo04TPm@0>3Ol0C`3o0800o`3:0>H0
o`120?<0Z03V0>/0h@3e0?l0J03g0>d0nP3:0?h0V@3o02h0o`1202`0o`000P3o02X05P3o0:T0oP3Y
0?D0l`3b0=40m`2W0<D0o`2P0<L0@`3o03L0o`2X08@0C`3o06d0o`3[0:`0EP3o008Go`026ol0@1So
02H3o`00B?l005?o002co`00a_l2003Ao`0A003:o`00^ol0097o03DXo`10<ol00:3o0030o`00X?l0
>2co04PPo`0>;?l0@@ko03DXo`00]ol00>go003om000omT00`00olX05P00omD00;oo002ko`00oo@0
0=gh003/o003E?l00>7l003Yk002V_l00?o/003Qm009VO`00?ng003oO@00of<00?m?003o?000oc00
0?lX003o8@00oad3003o6@03003o2P00o`l00?l:00D00?l:00<00?l>003o2P00o`X00P00o`X02@00
oaH00?lI003o=000ogH00=6o003oP@00ok<00?ng00^Rj002003oY003003oU@00ob400?l:00801Ol0
00<02Ol001Co000Do`000P0Do`000`0Ho`007?l0ooooo`03ooooo`03o`000?oooooooooo00Kooooo
000Qooooo`0Qo`000?ooooooooooooooo`00QOl00?oB003ocP00YoP00?gV003oW000oi400?n=003o
T@00oj000<KM003/f@00olX00?oJ00V=o`126OT0b01<06P:o`1D2L003Roo001No`0;:?l00;?o0356
o`00mOX08VWo002Do`00omT00?n_00800?n[00T00?nc003oaP00n?@09Gko003hn000TOl007go003o
f@00ok/00P00oj<2003oV00@003oV@00oj<00?n[003o^`00on4009Co00Ugo`09]?l00?o]003oj@00
oOP00;Oo001mo`10EL000;ko003Uo`<00>Wo01X00=go003=o`00`ol00:So020jo`1/6_l006[o001i
o`00J_l005_o040VhP0H2ol0>`3o0<l0ZP2P0?40]P3o0<L0k`2V0?l0o`300=H0kP2b0?l0h03C0?l0
O`3o0=00o`0f0?l022X0o`0001P0o`0f0?l0J`3o0:h0o`1g0>40o@310?l0jP3P0<H0e`1J0?l0:`3o
01`0o`0P0?l00`Go04D3o`1B0?l0CP?003L0o`1A1ol0<AWo07`>kP1I5_l073ko002Vo`00dOl2003I
o`0X003Eo`00b_l01F3o001fo`00TOl00Vco003To`00`_l06I[o002/o`0E@Ol0oP1V0680c`0=H?l0
@8[0003Mo`00n?000?oI003oh@00fOP00?Ch002ko`1N5]h007Ko02Dco`00N_l0K1[/01Ugo`0gV_l0
A5ko002Ho`0Y8?l03G?o003>j@00m<h00?n901SBX`00j7T00?l`003o:0@00?lI00<00?lB003o2P00
o`X02`00o`X04@00o`h00?lI003o7@00obT00?l`003oA000iK/00?m^02^fT`00`Z@00?m<003o:@00
oa800ol500Go0009o`004Ol000<05?l000<07?l0023o000So`001?ooool00ol0003oooooooooo`06
ooooo`008Oooool02_l0003oooooooooooooool0?5;o003hn000a_`0=fCo003`d@00ojL2003oW00D
003oY`0`_>d00?3d003Eo000onT00?3d002[o`10:m<0UQ;o06d3l@2P0</0^02b07T0o`00V?l00?Sl
003oh@00on<04Hko003obP00l<82003oW00;003oX000ojL00?no003:o`0Z^o800?o:003Xj@0=Pol0
0:So003o_`00oj001000oi@03`00oiP00?nS003hg@00gOl00>ch03_0j000omd00?oA003of@00oo00
0:So02DXo`0Y?ol00;oo003]o`02003ho`800?3o01/00>7o003Eo`02Ool004oo021To`00SOl008Wo
001io`00Gol004_o004Jo`1Y0?l0cP3;04H0o`1R0<00CP3o09P0l@3N0<`0X03^09L0o`3`0:40gP3m
0?T0_@3o0:40o`1P0?l06`3o04400P3o02L00`3o00`0o`030?l0000T0?l000110?l0403o0340o`2l
0<d0o`2V0?l0U`3o0:@0fP1M0?l0:`3o00d0o`022?l001ko000Qo`00<?l002Wo07H0l@058ol005oo
001jo`00POl00:Co006Wo`00gOl00>Go003Yo`00iOl00<Ko080NjP00Y?l00>Wo003>o`00oOl00?So
003Yo`00d_l009Co00e9o`00W?l04E7o04a;o`1?Bol00;_o003on000k?`05Eco002Ao`10M<00@6_G
003Yo000n>P00?o/00j=o`00omd00?o3003`f@00o=d00Z7o003/f@00k<X009cd003leP00l9h00?m8
003o<000obP00`00oaT00`00oaH00?l:003o2P0>003o2P0=003o4P00oaT00?lM003o;000od`00?m0
003oWP00b^D00=Ub003o8@00o`X00ol500Go000301Co000301Oo000So`008?l000808ol01?ooool0
0ol0003oooooooooo`06ooooo`000_ooool2o`0000Cooooo00?o0000ooooooooool00_ooool2o`00
00?ooooo1Ol00002ooooo`?o00001Oooool02_l0003oooooooooooooool00;oo03=/o`00SOl00?Cd
003oa`00ok<2003oZ`0D003o^`00n>T0:7oo00::o`00a_l0857o04HnkP00[ol009Go01hTo`0Y;?l0
CPk000Dno`00POl00=gd003oaP00ol000?3`003oY000oi@2003oS@0D003oT@00oi`00>GU00F:o`00
oM`00?n[003o_`00[o00?jWd0430PP00oi@00?nA003oS@00ohT00?n?003oU000oiP00?n_003o^`00
olL2003o^`07003o`P00olh00>gc002co`0Q?ol00:3o003ao`04003oo`0K003do`00k_l00=go003:
o`00/ol00:_o002Po`00TOl007;o001<o`00??l0C0ST0>T0`01a0?l07`?o01D0o`0c0?l0P03o09l0
o`1>0?l0Y03e0<80gP2Z0?l0[P3o0>T0fP3o07L0o`3?0080o`1g00@0o`260?l0H03o0180o`0@8`3o
0000603o00`0o`1=0?l0RP3o0980eP3a0:H0o`280?l0I@3o04H0o`0[0?l05@3o00P3o`00:?l004Co
001;o`00A?l0BACm04L0o`00C?l008Wo002[o`00_ol00=Co003Uo`<00?3o01/00>go00:Bo`00iOl0
0?oh003om000oo000?od003ho`02WOl06S_o00EPo`00hOl00?3o0036o`09K?l0Aeko002go`00Gol0
0:3o003Bo000oo0009Go003Ug@00ok/00?o6003Ij`00b[l00P00oiP00`00olH00=W`003Uf@02003o
NP05003oS@00l;D00?m0003o:000ob400P00oaT00`00oa800?l:003o3P05003o2P0700;o2003o`D0
0_l800Go0003o`D01Ol000;o1`04003o2P0<003o3P00oa800?lI003o7@00ob`00>eY0029k000oe@0
0?l]003o4P05o`002Ol00P0Do`000`0Ho`008Ol0023o000302?o00Cooooo00?o0000ooooooooool0
1_ooool00005ooooool0003oooooooooool000002_ooool01Ol0003ooooooooooooooooo000000;o
oooo00?o0000ooooool000000oooool00ol0003oooooooooo`02ooooo`0Oo`000?oooooooooooooo
o`05I?l00:Co003do`00onT00?oA003o`P00olX00?oQ003of@00m?@009co07`>l@10DNX0@7o0003I
o@00kOl0?foo0025o`00/ol0H3o?002ko`00/ol00<;Q003o[`00oj<00?nP003oS@03003oQ@05003o
R@00oi400?c6002ko`00e<l00P00oiP01P00ok<08;Sh0430W@00ohT00?n5003oR@800?n500@00?n=
003oT@00oiP00?nL0P00ojL0;P00ojl00?ng003oaP00aoD0@3k0002Xo`00lOl00?ol003om000ooP0
0?od003oo`00o?l00?3o003Qo`00eOl00<Ko002go`00Yol009co001Ro`1A3_l00a7o0702iP210<<0
A@Wm000Jo`0:1Ol0X03C06d0o`2=0<l0:`3o02l0o`1G0?l0L@3o0:h0o`3j0:00oP250>@0o`3j0;/0
o`1c0?l0d`3o06l0o`0^0?l0D@3o01<R0?l0000I0?l0103o01<0o`2:0?h0l03W0?l0kP3L0;/0d`2O
0?l0O@3V07X0b`2L0<00/`3V01lJo`00Dol005_o001Oo`00B?l091oo05d0o`00Dol007[o003:o`00
g?l00?3o003do`03003oo`03003hn000oo@00?oY00800?oQ02400?o]003`o000Eol00=;o042BjP00
gO`00?oY003Um000m?P00>km002Do`00kOl00?o]003oeP00olX00?o6003oZ`00oi`00?nT003o/@00
ohD00?mm003oP@00n<H00?n_003`U@00oel00?mG003oH`00fKX00?m8003o:000obD00P00oaT00`00
oa800?l:003o2P03003o2P800_l800<00ol500Go0004o`<00`05o`001@03o`<01Ol000Co0`04o`<0
0ol500<00?l:00P00?lF003o7@00ocP00?2T003o/`00hJL00?lU00Go00805?l000<06?l0023o000S
o`00100So`04ooooo`03o`000?oooooooooo00Kooooo00001Ooooooo0000oooooooooooo000000_o
oooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000001?ooool0
2?l0003oooooooooooooool0@2k000Edo`00lOl00?od0P00on405@00W?l00<?o003:o`1F9ML07U;o
01a5o`17<NX00?7l003oh@00gN`00=gd003Mo`00n?`086Co002co`00on400?o3003oY`00oiL00?n=
003oQ@04003oN@04003oP@00oj/00?Cl003oTP800?n100<00?nI003oY000ohT01000oh42003oQ@04
003oR@00oi400?nD003oU0800?nS00H00?nc003oaP06boD078Ko009oo`00o?P2003oj@0F003ok@00
oo000?ol003oo`00l?l00>7o003Io`00b_l00;_o002Wo`00TOl006[o01D?o`2D0<00bP2G02T9o`00
=?l003So04d:o`0n1ol07`?o0:`0d`804@3o00h0<`3o08D0`02^0?l0m`1n0?D0h`2Z0?l0_P3o0=`0
o`3n0>D0o`000?l0RP3o04T0o`0C0?l06b80o`0000h0o`080?l0IP3o03H0o`1T0?l0M`3e0>l0o@2a
0<80o`2Z0?l0H@3o02H7o`00<ol005_o001Vo`8006ko00`0@470020jo`1l4^H0@2_00427`000g?l0
0?3o003ho`00ool00?oh003ol000ond2003oh@08003of@00om400?oI003ok@00b_l00?o]003oj@00
o>42003oe@0=003og@0>d_<0963o003Mo000omT00?no003o[`00oj<00?nH003oT@00ohd00?n5003o
LP02003oKP09003oOP00o8d00?mC003oB`00odL00?m4003oDP00ocP00?lX00800?lI00<00?lB003o
2P00o`X01000o`X00`03o`D01Ol000Co0`0600Go000600Co0`05o`001?l300Go0004o`<00_l80P00
o`X02P00oaH00?m004B0d@00ocP00?lM00;o4`09o`005?l001So000Po`0502?o000302_o0?oooooo
oooo00;ooooo00?o0000ooooooooool01_ooool00005ooooool0003oooooooooool000002?ooool4
o`0000Cooooo00?o0000ooooooooool01?l00005ooooo`;o00000_ooool03`109?l00:oo003Mo`10
W/L06/Ko003ho000b_l0EcCo081B_@00c_l00>Gh003ao00gNol00:3l003o`P02003o^`09003obP00
on403Gol00Ego`00omT00?nk003oY`00ohl00?n500800?me0`00ofh01000ogD02L2T003oU000ogP3
003oM@800?mi00D00?me003oN@00ogD00?me003oNP03003oQ@09003oT@00oi@00?nD003oX000ojL0
0?o>00JanP00oo000>c]00800?oI0P00on409P00oo000?od003lo`00jOl00>7o003Eo`00a_l00:Co
001So`00OOl005oo014Wo`2M0>/0P@3d000Uo`00Bol005?o02P^o`00>?l0<ACo0447o`004_l030?o
0640o`2C0?l0o`300<<0n@240?l0S03o0:X0o`3I0?l0o`1c0?l0UP3o0=@0o`2h0?l0F03o04T0o`0?
8P3o00004P3o03/0o`2:0?H0j`3`0>h0/`3J09/0o`1U0?l0W`3o07T0n@0S1ol003So001Oo`00K_l0
07Wo0025o`00ROl008go001Zo`8009So00@00>?o003`o`00ool00?oo0P00oo002@00on400?oM003o
e@00om400?o<003obP00omT00?cU003obP02003o`P800?o600`00?o>003oj@0>JOl00;?o003>i@00
okl00?n_003oW000oi@00?n5003oO@00og<2003oIP05003oG`00oe/00?mC003oA`00od@00P00ocP0
1P00oc<00?lX003o7@00oaT00?lF003o3P@00?l:00<00_l700Go0003o`D03`05o`001`02o`P00?l:
003o@P00hLH00?lU00?o1@05o`000P0Do`000`0Po`008ol002?o000202?o000302_o000Wo`00<ol0
00?ooooo0_l00008ooooo`0000Goooooo`000?ooooooooooo`000007ooooo`07o`000?oooooooooo
ooooool0003oooooo`000003ooooo`03o`000?oooooo000000Sooooo023o0000oooooooooooooooo
05D:o`09EOl00:Ko00aFo`06KOl01Y3o001=o`00W_l0:iSf01?Eh@00ol800??N002jiP0[eK@00?nW
003oWP00ojP00?nf003oc009cOX00:km002co@00c>/00>g=003oTP00ogd00?m`003oJ@800?mV00D0
0?mT003oH@00of/00?mY003oJ003003oIP<00?m[00T00?m`003oM@00ogD00?me003oN000oh000?n5
003oR000ohX00P00oi@00`00oj400?n[007Sa003003oa`0Y003oc`00om400?oL003oiP00ooP00=;o
006eo`00aol00<Go002ko`00Qol0A1Gf000ho`0_6?l0E`;E02/aoP0T8ol0:c?o001[o`00L?l006Wo
001Oo`00COl003So000Qo`032?l0N@3o0?H0S@2j0?80KP3o05@0o`2H0>40e`3D0>P0b`3^0=80g03o
0?`0_@3o06H0o`1:0?l0503o00<08P3o0000803o02X0o`2c0>l0eP2^0?l0S@3o0640o`0f0?l0:`3o
0500n`1f0_h04RKo001Oo`00Lol0083o002=o`00VOl00:Ko002^o`00`_l00=7o003Vo`00l?l00?oo
003onP00oo000?oY003oh@00omL00?oA003obP00ol800?nm0P00ok/4003o]P0H003o^000ol007LGN
01R>o`0O@?l00>Km003oc`00ok000?nN003oS`00oh<00?me003oK@00of400?mJ003oE@00odX00?m5
003o>`00ocP00?lf003o:`00obH00?lL0P00oaT00`00oa800?l:003o2P02003o2P0300;o1`03o`@0
1Ol000X01Ol000<02_l000Go0008o`001005o`001@03o`D00?lI003oL`01oa<02?l000805?l000T0
8Ol002?o000So`008ol002Go000Xo`00<ol0037o000co`001?ooool00ol0003oooooooooo`06oooo
o`0000Goooooo`000?ooooooooooo`000007ooooo`07o`000?ooooooooooooooool0003oooooo`00
0003ooooo`04o`000?ooooooooooo`0000Oooooo017o0000oooooooooooooooo04X0o`0f5_l04@3o
040Wn@0e3ol0D1So0163o`00oo@00=gQ003o]`00ojL00?nP003oY002003oS@0;003oT@00oiP00?n[
003og@00POl00?oF003ocP10ZN800<;h003ba`00ogd00P00ofH2003oF`<00?mG00D00?mK003oE`00
oe/00?mO003oH`04003oIP03003oJP00og800?me00800?me00@00?n1003oQ@00ohT00?n90P00oi@0
1000oj000?nX003o/`00okL2003o`P0X003od@00omT00?oQ003on000c_l093ko001fo`00Zol00:Co
001no`00=Ol0]`300<`0Z`00:Ol007;o001co`00SOl008Wo0021o`00MOl006[o001Go`00@?l01AOo
05d0o`2A0:l0M@3o0;P0m`0g0?l0:`3o05H0o`1U0?l0f`2j0;H0o`2^0?l0j03d0?l0I03o0980o`1A
0?l04b80o`0001l0o`080?l0I03o0<00g03o0=l0[P1`0?l0:`3o00d0o`022?l0027o000mo`00Fol0
06Oo001fo`00TOl00:3o002[o`00^ol00<[o003Io`00i?l00?3o003lo`00ool00?od003ok@00on40
0?oA003obP00ol800?nk00800?nc01T00?n_003oY`00oj/00?nS003oZ`00ojl00?nc003oa@00oo@0
06Ko02BBo`00m?P00>7X003o[`00oi400?n5003oM@00ofh00?mO003oE`00od/00?m7003o@000ocP0
0?l`00800?lX00D00?lQ003o6@00oaT00?lB003o3P04003o2P0300?o1@05o`001Ol000P01Ol000l0
4_l000go000Do`004Ol001Co000Ao`005?l0017o000=o`001Ol000Co5@04o`L03Ol001Co000Ho`00
100So`000`0Wo`00:ol003?o000303?o00Cooooo00?o0000ooooooooool01_ooool000;ooooo0_l0
0009ooooo`?o00000oooool3o`0000Cooooo0_l00005ooooo`0Po`000?ooooooooooooooo`00G_l0
3B?o0>00Q@2@0=X0/02?04`To`00Z?l00?oY003o``00oj/00?nH003oS@00ohT00?n1003oO@00ohD0
0?nA003oaP10YNH01Hkh003o]`00oi`00?n/003Ql00<Jn/00?n1003oIP00oe/:003oE`03003oG`00
of<00?mV00800?mV00D00?mZ003oL`00ogD00?me003oN@02003oQ@0H003oR@00oi@00?nD003oW000
oj<00?n_003o/`00okl00?o6003ocP00omD00?oQ003ol000n?l049go020jo`00ROl0@6Ci001Oo`1l
0oT0KP3Z04d:o`0R9?l007;o0P00W?l05`00U?l008Wo001io`00Hol005?o000lo`095ol0Z03008H0
i00H0?l04@3o00d0o`0D0?l09`3o04X0o`1]0?l0P03o0:80o`3B0?d0oP3Y0?l0SP3o02<0o`080280
o`0001h0o`050?l05`3o04D0oP2L0=/0c03009<0F@3o0200o`071Ol001[o000co`00@?l05BKo00<c
o`00O_l009So002Wo`00]ol00<Ko003Ao`00g?l00>Go003`o`00m?l00?co003om000ond00?oM003o
bP00ol82003o/`03003oY`00oj<00?nS00@00?nS00h00?n_003o`000omT00>Wo0416n@20C[800<[o
01FJk@00oi`00?n=003oO@00of/00?mO003oE`800?m70P00ocP01000ob`00?lX003o:000oa`2003o
6@03003o4P00o`X00?l:00800?l:2P05o`000`0Do`004Ol001Co000:01Co0003017o000Do`006?l0
00D08ol01P0co`04ooooo`03o`000?oooooooooo00Kooooo000Qooooo`0@o`000?oooooooooooooo
o`00[?l05S?o0:D0S`0A8ol0:dKf01aXo`10V_D00?od003lg@00okL00?nA003oP@<00?me00h00?mi
003oR@00oj`0?hKd003Qm000oi`00?n5003oR@00gLH00>K:003EW000oel00?mG003oC`<00?m;00<0
0?m7003oB`00oe@01000oeL00`00oe/00?mS003oIP02003oIP04003oL`00ogD00?me003oN@<00?n5
02800?nA003oU000oi@00?nS003oZ`00ok<00?nk003oaP00om400?oE003oh@00oo@02KGo035Ae@00
=Ol0@2Co0583`0183Ol0EPkC00U9o`0a;?l006?o041ke`00[_l00:_o002Po`00SOl006?o001<o`0Y
4Ol08A7o0387o`1d0?l0A@3o0P005_l02`022?l03@3o0200o`0k0?l0F@3o07`0o`3^0>@0jP3b0?l0
Y@3o08h0o`0j02D0o`0000d0o`0K0?l0H0310?l0O@3o08T0n@2_0<00MP3Z00`3o`1F0_l001Wo03H7
o`104Ol093[o008008Go00@009So002co`00a_l00=Co0P00fOl02@00[ol00<?o003ao`00a_l00?cd
003oe@00ol800?nc003oY`02003oX`03003oX000oi`00?nL00800?nP01P00?nS003o]@00hO@04I;o
001fo`0h=ol07;cl003ocP00ojl00?nk003oZ000og<00?mS003oE`00od/00?m7003o?000ocP00?l/
003o:000obD00?lL003o6@00oaH5003o2P0300Co0`05o`001Ol000@01Ol000<02Ol000go0009o`00
0P0Do`000`0Bo`005?l001Co000801Co000301So000Lo`008ol000<08ol000D09ol003?o000[o`00
<ol002oo000303?o00Cooooo00?o0000ooooooooool01_ooool0027ooooo01[o0000oooooooooooo
oooo00ELo`1H?n800bco002Ao`06LOl00=Wo002Ao`09U_l089Ko002Dm000ojP00?me003oKP00ofH0
0?mY003oLP00ogd00?n`0036k000m>400?nE003oLP800?m^00<00?nI003oKP00oeL00P00od/6003o
A`03003oC`00oe<00?mG00<00?mG0`00ofH01000ofh00?me003oM@00ogD3003oQ@03003oT@00oi@0
0?nD00800?nS02L00?nc003o^`00olX00?oE003oh@00ond00?oh003ao`00]Ol0087o05`:o`3^0800
g02D02POo`00QOl008;o002Ao`00^ol00;go002go`00X?l008Go04dTe`1P1ol0R@30028Ao`0k0?l0
0QOo000Yo`00<?l0027o008<o`0X0?l0?`3o04h0o`2_0>80`P3a0?X0E`3o05T00P3o04D00`3o01L0
o`000?l0000T0?l0000N0?l0E@3m0=`0j`360>X0d03o06`0^03g0<00]P2N0;h0B`3o0;/0kP0J3Ol0
043o001Ko`00@?l0<cko001Vo`00]ol00;_o0021o`00Y?l005[o03=@o`0AR_l008Go002Do`00onT0
0?o>003o[P00oj<00?nP0P00oiP4003oU00G003oW000okX07:gU003/l000b_`03KCl002=o`00V?P0
0?oJ003>k000j=800?fY003oJP00oel00?mC003oB`00oc`00?lh003o;000obP00?lU003o7000oaT0
1@00o`X200Go000300Co0`05o`001Ol000<01Ol000<03Ol001Co000Do`002P0Do`0201So0003027o
000So`008ol000<08ol000<09ol002_o000co`001P0co`04ooooo`03o`000?oooooooooo00Kooooo
000Qooooo`0Bo`000?ooooooooooooooo`00o?@00=go03Q7o`10X_400>gc003oh@00dO`00?3X003o
]`00oj@00?n9003oJP00ofH00?mS0P00ofH02P00oiP02IKF00:Uo000j>d00?nA003oH`00oel00?mK
00KEN000oe<:003oA`06003oC`00oe<00?mG003oE`00oe/00?mO0P00ofH01000of/00?me003oM@00
ogT3003oQ@0_003oT@00oi@00?nD003oX`00oj/00?nc003o_`00o>D00?o]003ol000oo@00?ol003]
o`00^_l007;o04L7`01^0?d0AP3o00dno`00V?l00;?o002oo`00a_l00<[o002oo`02Nol05B_o01hE
o`1A9?D005oo0014o`0o0?l002Wo001:o`00A?l002Wo04L0o`330?40U`3o0;/0kP3H0?l0j`2T0=h0
e03/0<h0nP3d0?l0_03o02h09P3o00007`3o0:80`@3o0900o`2@0</0Z`3006d0o`1:0?l0ZP3E0:00
kP3;0800N@3;02P0o`2?1nX0D@[o040SiP00N_l009So0025o`1J7/00043o05XN`010ANh04Eco07DY
`000SOl009co003`k000ojh00?nS003oW000oiP01P00oi@05000oiT00?nW0032aP00olX00?C/02BJ
o`0IE?l00ZWo002Po`00_ol06]Fj003oN@00ofX00?mV003oE`00od@00?lh003o;000obP00?lU0P00
oaT00`00oa800?l:003o2P02003o2P0300?o1@05o`001Ol000<01Ol000<02Ol0017o000=o`002P0D
o`00100Lo`008?l0023o000Po`0502?o0080:ol0200co`04ooooo`03o`000?oooooooooo00Kooooo
000Qooooo`0Ao`000?ooooooooooooooo`00omH00?Cl0411hP00W?l00mGN003oaP00gN4009ch003o
[`00ogd00?mZ003oIP00oe/00P00oeL02000oe/00?mS003oNP00n<800?nc003oJP00oeL00?m;0`00
odL00`00od@00?m0003o?002003o?003003o@000odL00?m700<00?m700D00?m?003oE`00oeL00?mG
003oF`02003oIP04003oJ`00ogD00?me003oO@800?n503000?n9003oU000oi@00?nL003oX`00oj/0
0?nc003oaP0L`?005HKo003Qo`00n?l00?7o042MjP00U?l0DP3o021=o`0a@ol06D7o008Wo`00TOl0
0;_o003Ao`00fOl00=Ko003:o`00X?l0Va[V001Zo`00SOl007go00XTo`1>1oD0043o001Lo`00Dol0
02Wo060=o@0:2Ol0:03o0;h0`01Q0?l0K@3o0800o`2[0?l0nP3F0?l0M`3o054T0?l0000O0?l0303o
03X0oP2/0<40o`2g0>X0>`3o0680`0080ol0@0cm014Co`023ol0U`3o000Yo`0P>_l00ROo08@3`015
3_l0<1?o03/^o`1b8?/007ko002Ho`00/ol0@9W^003]o`00/ol0:<3d003dk@00k>400?nX003oW002
003oU003003oT@00ohd00?n900800?n501D00?n=003oTP00oi@00?nP003oZ`00okl00?oY002/o`1E
1ol0H5;R003oi@00oj/00?n=003oP@00gM800?mf003oD`00od000?ld003o:000obD00P00oaT4003o
2PL01Ol000<03Ol001Co000Do`00200Do`000`0Lo`008ol0023o000702?o000302Oo000co`00;ol0
00L0<ol000<0>ol0ooooooooool00_ooool00ol0003oooooooooo`06ooooo`008Oooool03ol0003o
ooooooooooooool00?C>01YFn01c?m<00:oo003Pc`00oj/00?nc01c0h@00^]d00?mf003oH`03003o
E`07003oDP00oe<00?mG003oH`00iJl00>Fo003oF`02003oA`03003o@000oc/00?lh00H00?lh00<0
0?ll003o@000odD00`00odL01000oe<00?mG003oE`00oe/2003oIP07003oKP00ogD00?me003oP@00
ohD00?n9003oT@02003oU0800?nS02/00?nc003o]`00olH00?oU015go`0kEOl00=Wo003Bo`00L_l0
<RcY041Al@00X?l00:_o00U=o`0IH?l0EC?m00::o`00fOl00>Go003To`00fOl02HOo002/o`00]ol0
0:_o001mo`0]:?l0Q`OZ001Oo`00K_l006Ko001Go`00A?l001Wo0800o`280?l0;`3o04H0o`2K0?l0
/`3o0?X0_P3o07<0o`0C02@0o`0001h0o`0<0?l0/@3f0;X0kP3D0800o`0[0?l03@3o000Bo`00;?l0
043o00DWo`0h9?l004oo001mo`00Fol0TAKX001Oo`00N_l006ko029Ro`00_ol00=go003ao`00oo`0
0?o]003oj@00olh00?o2003o]`00oj42003oU003003oT@00ohT00?n500D00?n501H00?n=003oU000
oj<00?nk003og@00a_l02H?o022Fo`0LS_l00?[S0430WP00oj/00?oa003oY000fKX00?mK003o>000
ob`00?lX003o7000oaT00?l>0`00o`X00`04o`<01Ol000Go000300Go000300Wo000=o`004Ol000<0
5?l000D04Ol001Co000Do`005?l001So000201co00P08ol000<0<ol002oo000_o`001`0co`000`0k
o`00@_l0ooooo`03ooooo`03o`000?oooooooooo00Kooooo000Qooooo`0:o`000?oooooooooooooo
o`00oj/00?o>015To`00`_@00?nh003oV0800?n=00@00=fT003oJP00oe/00?mG0P00od/3003oA`04
003oD`00oj000?mG003oB`800?ll2`00ocP01@00od800?m7003oA`00odL00?mC00800?mG00H00?mK
003oIP00ofH00?mc003oN@00ogd2003oQ@0H003oT@00oi@00?nD003oX000oj<00?nV003o/`00okl0
0?o>002Lm000`ol06E7o002Eo`00ROl0@4Ge03dbi009S_l00=Wo0032o`0=;_l00;oo00V>o`00SOl0
0>go0P00l?l05`00jOl00>7o003Io`00b_l00;_o001Zo`1V0?D006Oo001mo`00N_l007;o001So`00
Col03A?o03L0o`0<0ol05@3o03/0o`2/0?d0l0340?l0RP3o05P0o`0<02@0o`0000X0o`150?l0[@3H
0?l0YP3o07@0o`0g0?l0703o04d9l@02;_l005Oo0P00Fol04P00TOl009So001^o`10M<000:So002[
o`00V?l0;SG/002go`00iOl00?So003ol000omd00?o>003o`P00ok<00?nW003oW0800?nD00<00?n9
003oQ@00ohD00`00ohD06000oh400?n5003oQ@00ohT00?nL003QdP05=_l0@:Fh003El000j=d00;_/
04AGe`02`?000=gX003Io010ZJ400?n=003oE`00od@00?ld003o:000oa`00?lI003o4P800?l:00<0
0_l800Go0005o`001005o`0:01Co00808ol00P0Po`0502?o000302Oo000[o`00;ol000L0<ol000@0
=ol003_o000go`00@_l01?ooool00ol0003oooooooooo`06ooooo`008Oooool04?l0003ooooooooo
ooooool00?n_003hj@00Zol01JWl02_Eb`00ohd00?mi003oM@00ofh00?mK003oE`00od/2003oA`03
003oA@00od000?m000<00?m00`00ocP01@00oc@00?l`003o=000ob`00?l`00800?ld1@00ocP3003o
A`0=003oB`00oeL00?mG003oF`00ofH00?m^003oM@00ogd00?n5003oR@00oi400?nD003oW002003o
X`0C003oY`00ok000?nk003o`P00omT00=;l002go`09M?l072?o08@>l@0k=_l009;o003No`00kOl0
0>7o0025o`00kOl00?Co003Uo`02003lo`0F003eo`00l?l00?3o003Qo`00fOl00;_o001Oo`00O_l0
08go002Do`00R?l007Go001Vo`00Eol0043o000Uo`003_l03@3o02/0o`2D0>80cP3b0?l0/BH0o`00
01l0o`150?l0UP3U0<00/P3o08l0o`210?d0W03m0443o`00>?l0067o001io`00SOl00:3o002Wo`00
]ol00;oo003:o`00a_l00;Oo00a7o`0IAOl00;oo003]o`00oo@00?oQ003ocP00ok/00?nc003oX`00
oiT00?nD00@00?n500<00?n1003oM@00ogD00P00ogD04000oh400?n5003oV000k=d00=W:003o^`09
U^400?n[003Ie@00co8008Wo080`g010I?T00?SE003oR@00ofL2003oE`04003oD`00oah00?lI003o
4P800?l:00<00_l800Co0`05o`001005o`000`0Ao`005?l001Co000501Co000301Oo000Lo`007?l0
00P08ol000@0;ol003?o000_o`00;ol01P0co`0204;o000303oo0012o`3ooooo00?ooooo00?o0000
ooooooooool01_ooool0027ooooo00oo0000oooooooooooooooo003oW00[b;@0:g3j002hm@00jlT0
0?n3003oM@00ofT00?mQ003oE`00odl00P00odL00`00od800?lj003o>002003o>004003o=P00oc<0
0?l`003o;@H00?lX0`00ob/01@00oc<00?lh003o>000ocX00?m200800?m700h00?m?003oE`00oeL0
0?mQ003oIP00ogP00?nF003oS@00ohl00?nD003oW000ojh00?oD003o_@800?nh00l00?nm003oa@00
ol`00?oN003mn000e?l0:gCE07PAe@2M6kd0:egQ003Go`00n_l00?oe003ol`00g?<00`00oo006000
oo<00?oe003oo@00oOl00??o003^o`00hOl00=Co0037o`00^?l00:ko002Qo`00SOl02EGo001?o`00
Aol003Ko004Jo`061_l0M`3/05T0o`2?0?l0e@300?l0G2H0o`0001l0o`0:0?l0FP3o09L0o02A0<<0
n`2R0<H0N`3E04`2o`0[6Ol006?o001ko`00R?l00:7o002co`00`_l00=7o003Fo`00g?l00=Co0023
o`0CFol0?E_O01Q_o`00b_l00?Se003hh`00olD00?n^003oX`00oi@00?n?00<00?n500<00?mj003o
M@00ogD01000ogD05000ogP00?n2003oU`00oh<00?n5003oR000ohD00?n?003oZ000j><009Cj003Q
h@0C^n<019SV003[f@00ckl00??2003mIP00obD00?lI0`00o`X00`04o`@01?l200Go000300Go0003
01;o000Do`004_l000H05?l000@07?l002?o000So`008Ol01P0So`0202ko0003037o000co`00<ol0
00D0<ol000<0>?l003go0012o`000P12o`04ooooo`03o`000?oooooooooo00Kooooo000Qooooo`;o
00000_ooool02000ohd00?nW0032j000hO000?nS003oP@00ofh00?mV0P00oeL00`00od/00?m7003o
?003003o>004003o<000obP00?lX003o;0`00?lX00@00?ld003o>000ocP00?m00P00odL04@00oe<0
0?mG003oG`00ofH00?mb003oQ@0[V]l00?2n003oX`00ojL00?nk003oh@0=Ool00?cY003ocP00omH0
0?OQ00800?oM00`00?Sd002Po`1=D/<0@5gN002go`00[ol005Oo00I_o`00o?P00?oU003oh@00omT3
003oh@0I003ok@00oo000?oe003oo`00m?l00?3o003Uo`00hOl00=7o0032o`00/ol00:?o0027o`0k
=_l0@0oN000Uo`0P3ol0R@3N03l0o`3C0>00iP2V0>l0/`310=X0kP2Z0?l0O`0V0?l0000@0?l0@@3j
0;l0_@3o08@0o`1B0?l0803o008<o`00;Ol004oo001Ko`00C?l004_o00eco`00b_l00=Wo003Uo`80
0>Wo00`00>Co002oo`00Aol0>D[o0419`000P_l008go003oi@00ol<00?nW003oU000ohT2003oQ@D0
0?me00D00?m^003oJ@00ofH00?mZ003oIP02003oJP0@003oIP00ofX00?me003oO@00oj403I;/003d
k000ojl00?mm003oS@00oh405X3B003oO@00od000?lS003o6@<00?l:1P05o`000`0Ao`005?l001Co
000501Co000301So000Lo`008?l000P08ol02@0co`000`0oo`00@_l003oo000304;o00?ooooo0_l0
0008ooooo`008Oooool04?l0003oooooooooooooool00?nA003o[000o>D00?CX003oYP00ohT00?me
003oIP00oeL00?mC003oA`00od@2003o>003003o=@00ob`00?lX00D00?lX0P00obD00`00obH00?lU
003o:006003o:0800?lh00<00?ll003oA`00od/00P00oeL01P00ofH00?mZ003oN@00oiD0:jNf003l
g@800?nk01<00?oF002no`05T_l00?3l003Un010YNh0:kkB003hn000ooP00>7o00Dno`1H>l000=go
003`o`00`ol00;?o02^Wk000n?@00?oI00<00?oA01d00?oI003oh@00on400?o]003om@00ool00?So
003`o`00iOl00=go003Ao`00`_l00:_o002Ho`00P?l0EaWo05/0m@190ol0?`3o0>X0P02h0>00Q03o
0:00`01F0?l0Q@3o0=D0o`3o0:40o`1T0?l0:P0T0?l0000M0?l0<P3o09T0iP2m0>40`02X0>X0:03o
0483o`0E4ol02bco01XAo`1K6Ol004oo0029o`00d_l00>Go003`o`00m?l00?So003eo`02Rol00;Oo
003Jo`00/ol0=dGo02Qoo`02R_l00>7/003oZ`00oiL00P00ohD00`00ogd00?mi003oM@02003oM@03
003oKP00ofH00?mV00@00?mV01400?mS003oG`00ofH00?mV003oKP00mK<00>c>003oU000gJ@00?mO
003oE`00oe/00?RP001@o`00ofX00?lV003o5P03003o2P0300?o1@05o`001Ol000801Ol000<02?l0
00go000Ao`001P0Do`0302?o0003023o000So`008ol000<08ol000<09ol002_o000`o`00200co`00
0`0ko`00@_l004;o000304;o00Cooooo00?o0000ooooooooool01_ooool0027ooooo013o0000oooo
oooooooooooo003o[`00^^D00ZGh022Um00Jd=`00?nk003oQ@00ofX00?mO003oD`00odL00?m40P00
ocP00`00obd00?lX003o:002003o:003003o9@00oad00?lM00@00?lI00<00?lM003o8@00obP01000
obP01000oc000?lh003o@000od/2003oF`0N003oIP00ofX00?me003oQ@0c`=H00;g`003lm000omd0
CD3h003>n000U?l0P1G500eTo`00POl04ESo00<io`10DL000;Oo001Oo`00/ol0>F;o003ll@00onT0
0=Wl002go000omh00?oE003obP00olH00?o:0P00om407@00omD00?oQ003oj@00ooD00?oo003`o`00
kOl00>7o003Eo`00c_l00;_o001Vo`00Iol006_o00DZo`1f0<00o`1X0:40/P2<0?D0A`3o02d5o`0_
0?l0903o08/0^@3d0>h0j@3V0?l0d03o06@0o`0<02<0o`000100o`0S0?l0F@3o09X0jP2m09L0o`24
0?l0a02Z0800o`1i0=`07QSo001Zo`00V?l00;_o003Io`00jOl00?3o0P00ool4003on007003Uo`09
Lol00?Cd003oi@00__@00?n[003oU002003oQ@800?mi0P00ogD00`00ofh00?mV003oIP02003oIP03
003oH`00oe/00?mG00800?mG00P00?mK003oE`00of<00?nL003oU000oel00?m?003oB`800?m700D0
0?mC003oHP00oi`00?lX003o5P02003o2P0300;o2005o`001Ol000<01Ol000<03ol001Co000Do`00
1P0Do`000`0Po`008ol002?o000602?o00T0<ol000@0=ol003_o000ko`00@?l01012o`04ooooo`03
o`000?oooooooooo00Kooooo000Qooooo`0Co`000?ooooooooooooooo`00m=d02F3o003o^`00okL0
4jC]02c0o000gLh00?n1003oKP00oe/00?m7003o@000ocP00?ld003o;@02003o:003003o9@00oaT0
0?lM00T00?lI1@00obP07`00ocP00?m0003oC`00l9D00?mf003oN@00ogD00?n1003oT@00ok/00=Og
002@o`00[?l0@4g00029o`00[?l0@3_o003>o`00l?@05K7o0035nP00a_l098?o003:o`00o?`00?o]
003of@00omD00?oU003`i@00olD01@00ol807P00om400?oE003oh@00onT00?gj003do`00kOl00=go
003Eo`00b_l00<;o002/o`00A?l0?1co03/Ke@1P0ol0Q0?a0840`00Y2Ol01A_o000Yo`007Ol00`Go
01D0o`170?l0V`3o0<40o`3o09h0o`1/0?l04b@0o`0001<0o`0G0?l0;P3o05T0m`3F0<@0ZP2D0=L0
3PWo004/o`0S1ol0M@k;00EHo`00Y?l00=Wo003]o`00n?l00?oo003on000oo000?oY00800?oU00<0
0?o]0170i@00olX00P00ok/01@00oj@00?n?003oQ@00ohD00?mm00800?me00H00?mb003oIP00ofH0
0?mV003oI000oel8003oE`04003oKP00oeL00?m7003oA0@00?lh00@00?ll003oB000ob400?lB0P00
o`X00`03o`D01Ol000Go000300Go000300So000Ao`005?l000H05?l000<07?l001ko000So`001P0S
o`000`0Wo`00<ol003?o000603?o000303oo0012o`00@_l000D0@_l01?ooool00ol0003ooooooooo
o`06ooooo`008Oooool04_l0003oooooooooooooool0?j;o003o]`00ohd00?n9003[f@0AYOP00>SQ
003oY000[mT00?mW003oD`00odL00?lh003o<0800?lX00<00?lQ003o6@00oad02`00oaT07`00obD0
0?lX003o:000obP00?le003o@000odl00?nT003dg@00oj@00?n=003oT@00ok<00?o7006EnP1F1oT0
B2oo003Qo000l>T00?oN002kn005`?@00?o:003ocP00om400?oY002oo`00^ol00?oY003oe@00olH0
0`00ol802P00ok/00?nc003o^`00ok<00?no003o`P00olX00?oE003oh@00ond2003Io`0=003Fo`10
HOl00;Oo002ko`00[ol00:3o001No`1h0l00O@OQ01Dbo`00>?l0DPkZ02DAo`020014o`09000Yo`0G
0ol0<`3o04l0o`2<0?l0dP3^0?X0l03o09H0o`0402L0o`000140oP2P0:h0o`0P0?l00QOo001Do`00
Gol003co054/m@0=DOl00:Co003Yo`00n?l00?oo003ol000on/00?oQ003of@02003od@06003o`P00
okL00?n_003oX`00oi`00?nB0P00ohD01@00ogT00?me003oM@00og800?mZ00800?mV00<00?mL003o
E`00oeL00P00oeL00`00oe<00?m;003oB`03003oA`03003oA000oc`00?lh00800?ld0`00obP00`00
ob400?lI003o2P02003o2P0300;o2003o`D01Ol000<01Ol000<03Ol001Co000Do`001@0Do`000`0P
o`008ol002?o000602?o0080:ol000<0;ol0033o000co`001@0co`000`0ko`00@_l004;o000504;o
00Cooooo00?o0000ooooooooool01_ooool0027ooooo01Go0000oooooooooooooooo003Bl000gJP0
0?mb003oKP00ohD00=Vo042F^010Q[D0?go/003I/`00of<00?m7003o>000oc000?lX003o9@00oad0
3P00oaT05000obD00?lX003o:000ocD00?m0003oC`00og800;[M003:i@00oj/00?nk002km000a_P0
09Cm0036o00AT_l00?oF003o]`00ojl00>c20P00oj/02@00ojl00?nm003li@02Nol0GdOo003ll000
olh00?no003o]`02003o/`03003o[P00ojl00?nc00800?nc01l00?no003obP00omT00?o]003oo01E
O=000:co0021o`1H3_l005oo041E`000ROl004_o05LLo`1I7?T0?R7^001fo`00K_l005oo001Ko`00
J_l005Oo00DKo`1l0?l0V0330<l0e03L0?l0o`1c0?l0I03o04T0o`0402L0o`000100o`0^0=/0i`2<
0?D0C@W7001No`00POl009Go002Po`00`ol00=Wo003]o`00n?l00?ol003ol000onH00?oM0P00om40
1`00ol800?no003o/`00ojL00?nS003oU000ohl00P00ohD2003oN@03003oM@00ofX00?mV00800?mV
00D00?mJ003oE`00oeL00?mG003oB`05003oA`04003o@P00ocP00?lh003o=0@00?lX00<00?lM003o
6@00oaL00`00o`X600Go000300oo000Do`005?l000D05?l000<07?l002?o000So`001P0So`0903?o
000303Oo000ko`00>ol000H0@_l01?ooool00ol0003oooooooooo`06ooooo`008Oooool05?l0003o
ooooooooooooool00?n@003oLP00oel00?mK003oJ`00a[h05HKd074ihP00okh00?n5003oG`00od/0
0?lh003o<000obP00?lM1@00oaT01@00oa800?lI003o4P00oaL00?lF00H00?lI0P00obP07@00oc<0
0?m0003oC`00oh400?o6003>o000n=d00>W/015[o`1DKOD00?o:00;0i@00iO@00<k/003oX000oi@0
0?nA003oU000oi`00?nS003o]@00on4009Co00Eoo`00iNd00?o:003o]`00ok<00?nW00<00?nS0280
0?nW003oZ`00ok<00?ng003obP00`_P00=go003Yo`0>L?l0P22Z05`Uo`0A;_l006[o05U3n@10<_40
1C;o00ELo`00L_l0<cKo002Eo`00W?l0097o0029o`00NOl006[o001?o`026ol0H@3o0700o`2;0?l0
`P3R0?T0j`3o0:d0o`0C7@3o00001P3o00@0o`0<0?l0:P3o03h0o`0G0?l03080o`0001L0o`0b0?l0
8`3o0000o`0S06T0o`1<3Ol005Oo0025o`00W?l00;?o003:o`00eOl00>Go003`o`00o?l00?od003o
iP00omT00?oA003oaP00ol800?ng003o/`02003oX`05003oU000oi800?n5003oQ@00oh400P00ogD0
1@00ofX00?mV003oIP00oel00?mJ00800?mG00<00?m?003oA`00odL00P00odL01@00od000?ll003o
>000ocP00?l`00<00?lX00D00?lU003o6@00oaT00?lI003o3`03003o2P0300?o1@05o`001Ol000<0
1Ol000<02?l001Co000Do`001P0Do`000`0Lo`008ol002?o000502?o000302oo000co`00<ol000H0
<ol02@12o`04ooooo`03o`000?oooooooooo00Kooooo000Qooooo`06o`000?ooooooooooooooo`00
ohD00?mK0P00od/02`00oel00=6[003Xg@00fND00;?M003oT@00ofL00?mC003o@000oc000?lV00@0
0?lI0P00oa83003o2P04003o3@00oa800?lB003o5P<00?lI01400?lM003o9@00obP00?le003o@000
odl00?n502C0aP00c^T0@Rce0415kP00j?@00>GE003oW`00l<h00?bg003oX004003oQ@09003oU000
oi`00?g2003]m000Z?l00;?o003oi@00olX00?nc00H00?nS01400?nW003oZ`00ok<00?o:003/l00E
I?l0=DOo015No`10?Nh00<Oo002oo`00b_l00;?o0151o`00J_l00:Oo002Xo`02002co`0=002_o`00
X?l008go001mo`00K_l005oo01`Oo`0S0ol0:`3o0;P0YP2^0?l0lP3=0?l0I00N0?l0000M0?l0403o
06`0o`1H0?l0`03o04d0o`1g0?l0A@3o08h0m`1m0=/0_@3[0940a`350:@0n@1P1ol0<B?Q001Co`00
UOl00:Oo002oo`00c_l00=Go003Fo`00/ol00?cl003oj`00omT00?oA003oaP00ol800P00ok<2003o
X`03003oV000oi@00?n900800?n500<00?mi003oM@00og800P00ofH01000oel00?mG003oE`00oe<4
003oA`05003o@000ocP00?lh003o>000ob`00`00obP00`00obD00?lM003o6@02003o6@04003o3@00
o`X00?l:003o2PH01Ol000<03ol001Co000Do`001@0Do`000`0Po`008ol002?o000602?o000302Oo
000[o`00<ol000H0<ol02@12o`04ooooo`03o`000?oooooooooo00Kooooo000Qooooo`06o`000?oo
ooooooooooooo`00m9@00?m;0P00od002`00od800?mG003oMP00n;L076So00G0bP00ohT00>F[003o
O@00oc000?lS00800?lI00<00?lF003o2P00o`h01000o`X00`00o`d00?l:003o2P02003o5P<00?lI
01000?lU003o:000oc<00?m0003oD`00ofh00?nP03^em002I?l009Go003AdP00oi`00?n0003oT000
ogd00?mb0`00ogD03P00oh400?n5003oV000okX0087o0415o@0X@Ol00<Kl003obP00oj/00?nS003o
X000oiP00?nD0P00oiP2003oX`07003o/`00olX00?S`001Oo`10EL000=co003Bo`02003do`05003Q
o`10U/00A3_o0021o`00_ol00P00b_l03`00`_l00;Oo002Po`00ROl007;o001So`00Dol003Co000B
o`0V0?l0``3a0?D0ZP3n0<80o`190?l04`0M0?l0000R0?l0G03o0<00o`230?H0c03h0;h0fP3^0>X0
l`3F0=h0b`3@0840`02[0<L0;03o04@=o`1^0<00X`3100TOo`00M_l0:57o002=o`00/ol00;_o03=L
o`00ROl00?7o003ol000on400?oA003ocP00ol800?no003o/`00oj/00?nS003oX0800?nD00D00?n=
003oQ@00ohD00?mi003oLP02003oIP04003oH`00oeL00?mG003oD`<00?m700H00?m0003o>000ocP0
0?lh003o<`00ob`2003o:003003o9@00ob400?lI00800?lI00<00?lF003o2P00o`X00P00o`X00`03
o`D01Ol000Go000300Go000300go000Do`005?l000D05?l000<08?l002?o000So`001@0So`000`0[
o`00<ol003?o000703?o000303Oo000ko`00@_l000H0@_l01?ooool00ol0003oooooooooo`06oooo
o`008Oooool05Ol0003oooooooooooooool00?m=003o>000oc000?l]003o=@00odD00?mO003oQ`0@
`=`076Sm003?g00>d<000?mG003o<000oah00?lI003o3`0;003o2P0A003o3@00oa@00?lI003o6@00
ob400?lX003o>P00oe@00?mQ003oYP0hZ<H00=K:003oZ000fO<00=cQ003j]@00ofT00`00of403P00
of@00?m[003oL`00og/00?n8003oW000okP00?[h001`o`00i?d00<Cc003o_@00oj400?nL1P00oi@0
3`00oj400?o2003Vl00C/Od00=c`002mm@00jNH00?oQ003oj@00ooX0:kkn002Bo`1/:NT0@g3T003A
o`02003Lo`0>003?o`00^?l01Ugo03<bh@0I5_l0GQc400LSo`1c2=40J`;E0;<0g@2j0;`0mP300?l0
;P3o01D50?l000030?l0203o0000o`0001<0o`0002L0o`0=0?l0703o07H0o`0n0?h0PP3P0><0Z@3o
0<X0jP2G0?l0P03o0=T0c`1d0>L04@;o06d2o`0k7_T004[o02/_l`1>4^D0E1WW03`@oP1f2^<07SOo
002:o`00P_l0FCSZ02YZo`0;O_l00=_o003oj`00oml00?oF003oc000olD00?nh003o/`00oj/00?nS
003oX000oi`00P00oiT01P00oj/00?n?003oN000og000?mV003oI0800?mG1000odL2003o>`800?lh
00D00?l]003o:000obP00?lX003o8@04003o6@03003o3@00o``00?l:00800?l:00<01?l200Go0005
o`000`05o`000`07o`003ol001Co000601Co000301ko000So`008ol000@08ol000@09_l002ko000^
o`00;_l01@0co`000`0ko`00@_l004;o000704;o00Cooooo00?o0000ooooooooool01_ooool0027o
oooo00Ko0000oooooooooooooooo003o=000obP2003o8@07003o:000od000?nT003Ed@0k_>`0@9[0
003oW002003l]`03003o<000oaT00?l>00h00?l:01000?lB003o6@00oaT00?l`003oE000NN40EH2h
003Be@00ok<00?mf003oNP00ol<00?mb003oJP00oeL00?m?0`00oeL04P00of<00?m^003oM@00oi@0
0<;M003oe`0T[Ol004oo003ok000ol<00?nW003oV000oi@00?n=003oR@00ohX00?n9003oT@800?nD
01`00?nT003o[`00om800?no003o^`00ol800?o>003og@00ooP00<;o03`Po`00J_l00<[o003Uo`00
l?l00>_o003Mo`00Z?l06D7o001fo`00Hol003So0387o`0e4Ol07PWo06`0n`3M0?40o`0O1@3o0000
1@3o00`0o`0Z0?l0=P3o04T0o`0<01<0o`0000l0o`0D0?l0PP3o0=<0m@3g0?l0N`3o09X0T`3o07<0
o`0_0?l0@P3o09`0gP2o0<000a7o000ho`00E?l00P00L_l05000P_l007;o02dHo`1<6?l0?`3o02hB
o`1=3_l0;B3o002=o`00_ol00?3o003oo000oo000?Sh003Bo000omD00?o:003o_`00ok<00?n_0P00
oj/02000okl02KC/00:Yl000m=d00?n1003oM@00ofX00?mS0P00oeL01000odl00?m7003oA`00od@4
003o>005003o;@00obP00?lX003o:000oad01000oaT00`00oa800?l=003o2P02003o2P0300?o1@05
o`001Ol000<01Ol000<02_l001Co000Do`001P0Do`0802?o000302Oo000co`00<ol000D0<ol000<0
?ol004;o0012o`001`12o`04ooooo`03o`000?oooooooooo00Kooooo000Qooooo`;o00000_ooool0
3`00ob`00?lM003o6@00oaT00?lL003o;@00oel00?mj003dV000c/X00?nT003oC`00ocP00?lQ003o
5`05003o2P0500?o1@00o`X00ol500;o2002o`L01P00o`X02000oaT00?lM003QHP0[eHH00?nI003o
O@00okL00?mW0P00oe<00`00ogT00?m;003oA`02003oA`800?m;00h00?mG003oF`00ofH00?me003o
S@00olX00k_o01IBo`00X?l00?oQ003o^`00oj<00?nH003oR@D00?n500l00?n9003oT@00oi@00?nH
003oX`00ojL00?n[003o]P00olX00?o/002Xo`10R^X0@6C002ago`00e_l00P00n?l03@00l?l00>go
003Mo`00b_l00;?o001no`0G3_l03C[o0018o`008Ol0<03o0>80b@3o01/0103o0000203o02<0o`0^
0?l0[@3o06T0o`2Y0?l0L`3o02<0o`0G4@3o0000703o0380o`1=0?h0U@390?l0cP300>/0k03O0;H0
@P3o0140o`071Ol03`?o09T0iP0l1Ol0043o001So`00OOl009So002So`0BC_l005_o001Zo`09AOl0
j`1G0?l0L`1]1l0007go002ko`00g?l2003do`0A002To`00^ol00?od03^dl000b^T00?o2003o^`00
okP00?no003:k020@h000<;/003oX000ohD00?me003oJP00ofH00P00oeL2003oB`800?m700@00?ll
003o>000ocP00?lh0`00obP00`00obD00?lI003o6@02003o6@03003o5P00o`X00?l:00<00?l:2005
o`000`0Ao`005?l001Co000401Co000301co000No`008?l000D08ol02@0co`001@0ko`00@_l004;o
0012o`00@?l000<0@_l000@0A_l0oooooooooooooooo0_l00008ooooo`008Oooool04ol0003ooooo
ooooooooool00?lM003o6@00oa800?l:003o5000oaT00?lQ003o=000odP00?2X003>dP00odP00?l/
003o6@00o`l00P00o`X300?o1@<01Ol000@01?l300Go0002o`P00_l81000o`X03000o`h00?lI003o
7@00oc000?lh003oB000oj@00?mC003o@000oc`00?lh003o?0800?lh01000?m4003oA`00odL00?m?
003oE`00ofX00?me003oS@00l=H00h?j0:0F]P00W?l01I[l00g0j@00oj000?n=2000ohD0:P00ohd0
0?nD003oU000oj000?nS003o[P00olH00?oQ002=o`2K2/l079go003]o`00oo`00?oh003oo`00oOl0
0?Co003Yo`00fOl0097o04DBo`05=_l007;o001Wo`0e8?l0KP3o0>h0/@3o0000o`150?l0D@3o05D0
o`120?l0I03j0;L0m@2m0?<0a`3m0>/0o`2>0?l0@@3o06@0o`0^0?l040l0o`0002@0o`0<0?l0Y@3f
0?L0[P3o0800o`280?l0/03C08l0o`1>0?l001go000Yo`0F4Ol0N03o080A[P0Q8?l006?o002Ho`00
^?l00;_o002go`00Zol008go00LTo`0B5Ol01bSo04@Ho`1_=l006EWo022;o`00fOl008Wo00MQo`00
X?l007ko003ok@00olh2003o`P0<003oe@09[O`0F7CR003`j@00oi`00?n=003oP@00ogD00?mV003o
G`00oeL00?m?0`00odL01@00oc`00?lh003o>000ocP00?l[00<00?lX00<00?lQ003o7@00oaT00P00
oaT00`00o`h00?l:003o2P03003o2P0300?o1@05o`001Ol000<01Ol000<03Ol001Co000Do`001P0D
o`000`0Qo`008ol002?o000402?o000302Oo000[o`00<ol000D0<ol000<0>ol004;o0012o`001P12
o`000`1Ao`3oooooooooo`02ooooo`03o`000?oooooooooo00Kooooo000Qooooo`05o`000?oooooo
ooooooooo`00oaH01000o`X02@00o`h00?lF003o8@00oc000?mO0230/`00oeL00?l`003o6@02003o
2P0300?o1@05o`001?l300D01Ol000D01?l200Go0004o`<00ol500;o2003003o2P06003o3P00oaH0
0?lL003o9@00oc000?mW0P00oc02003o=00D003o<000oc@00?lh003o>000oc`00?m7003oC`00oe/0
0?mZ003oO@00ohd00?n[00Jfl000c_l00=Kl00flk000ol800?nE003oQ@00ogd2003oN@800?me00D0
0?mm003oQ@00ohD00?n5003oR@02003oU008003oX000ojP00?oF003Xn000ROl009So003Fo`00oo@3
003ol00L003oo@00n?l00?3o003Mo`00a_l00:3o002Ho`00ROl006ko0018o`0o2>40bP300>H0`@3V
0<D0h@3;0<40o`3i0;H0_P3o0=H0e`3V0?L0Z`3o0>00o`3o0600o`2]0?l0c03o06P0o`0<0?l010h0
o`000180o`0C0?l0H03o0=<0iP3j09l0o`0k0?l0NP3Z06l0k`0Y4Ol002go001?o`00A?l0@0go00d^
o`0AAOl09R3o07lgiP00b_l2003>o`0L002ko`00TOl0FBS^001bo`00Y?l02FCo041EgP1F6]D0097o
01a`o`0EL?l08D?o002=o`00kOl00?o]003of@00omD00?oD003oj@02E?l00;oo003obP00oj/00?nL
003oU@00ohT00?mf003oI0800?mG0`00odL01@00oc`00?lh003o>000ocP00?l[00800?lX00<00?lU
003o7@00oaT00`00oaT5003o2P0300;o2005o`001Ol000@01Ol000<02Ol000go000=o`001P0Do`00
0`0So`008?l002?o000502?o000302oo000co`00<ol000@0<ol000<0>ol004;o0012o`001P12o`00
0`1>o`3oooooooooo`02ooooo`03o`000?oooooooooo00Kooooo000Qooooo`05o`000?oooooooooo
ooooo`00o`X00P02o`P03005o`000_l7003o2P00o`X00?lF003o?000k;<00<ZA003Bh@00oeh00?lF
007o20d01Ol000<01?l300?o1@00o`X00`00o`X00`00oaL00?lI003o7@02003o8@06003o9@00obP0
0?lX003o:000ob`00?l`0P00ocP00`00od@00?m?003oMP02003oV009003oX000n=X00KKm003hh@00
omX0G83^003oW000ohD00?mm00H00?me00D00?mi003oQ@00ohD00?n5003oR@02003oU006003oYP00
olX05Jg`003ok@00o>`00?oY0`00on407@00oo000?oe003oo`00kOl00>7o003Ao`00_ol00:_o002=
o`05>_l003co0584n`1>0?l0EP3o0940m@1]0?l0I@3o0=D0o`1i0?l0Z`3a0:h0o`2=0?l0o`1T0?X0
O@3L0?l0o`300?l0G03o05P0o`0C00l0o`0000@0o`1=0=40o`3:0=L0MP300P0P0?l04@2<0;`002go
001Go`00Hol005Oo084B_@2?6_40097o002/o`00/ol00=Oo003Qo`00gOl00<;o00eIo`00W?l0:57o
00800=;o00T008Go02/mkP1A4_l0?1Co01XAo`00ROl00<ko003ho`00oo@00`00onT02P00ooP0NdK0
003Un000omH00=GM003hj@00^n`0;9[`003h[`00of/2003oE`05003oD`00odL00?m7003oA000oc`0
0P00ocP01000obd00?lX003o:000obP5003o6@03003o5P00o`X00?l:00<00?l:0P03o`D600Go00P0
5?l000<08?l002?o000So`00100So`000`0_o`00<ol003?o000503?o000303Oo0012o`00>ol000H0
@_l01?ooool00ol0003oooooooooo`06ooooo`008Oooool01Ol0003oooooooooooooool01?l300D0
1Ol000T00?l:003o3P00oc@00=W:003o;@00obD00?lY003o2P04o`803P05o`000`04o`<00ol5003o
2P02003o2P03003o3@00o`h00?lI00@00?lI01<00?lQ003o:000obP00?lX003o;000ocP00?m4003o
A`00ofL09<2k0170j@00olH00>Wd02ije@00ok/00?nP0430[@00ohT00?mi00L00?me0P00ogT3003o
Q@07003oT@00oi@00?nN003oY`00okL00?o2003oaP02003od@0N003oe@00on400?oY003om@00m?l0
0>Wo003Mo`00dOl00;oo002To`00SOl07a[o07`3`01D1=`0027o06D0o`1I0?l030?o09P0fP3N0:H0
CP3o02l0o`0c0?l0N`3E0?X0[`3;0<d0X`3o0<h0`03j0=X0o`1c3P3o0000<P3o00P0o`000?l0G@3O
0<d0L@3o03l0o`0D0?l00Pco00hFo`09=_l006Oo001eo`00L_l004Co080H/P00M_l00;oo003Eo`00
jOl00?3o003]o`00/ol0@6Ca003Qo`00Z?l00?7o003`o`00hOl00;Go0415`0240l/0[@2Z034Lo`00
W?l00;_o003ao`00iOl00=Wo003Do`00iOl01F_o03aao`05Qol04FSo002co`0PV_l00?nc003oT@00
of/00?mO0P00oeL01000od/00?m7003oA`00od@2003o>006003o;@00obP00?lX003o:000ob400?lM
0`00oaT00`00oa800?l:003o2P04003o2PL01Ol00P0=o`0601Co000302?o000Po`008ol000D08ol0
00<09ol003?o000co`00100co`0704;o000304Ko001Ao`3ooooo00?ooooo00?o0000ooooooooool0
1_ooool0027ooooo00Co0000oooooooooooooooo0P05o`000`09o`003Ol000So000200Go000600;o
2010`4400?ll003o3P00o`X00ol54P05o`0200;o20<00?l:00<00?l>003o4P00oaT01000oaT04000
ob400?lX003o;000ocP00?m0003oA`00oel00?2X04El^000J_`0LBGR00?=j000oj@00?n=003oP@00
ogD2003oLP800?mZ00<00?mV003oJ`00og800`00ogD0:P00ogd00?n5003oQ@00ohT00?nD003oU`00
oj<00?n[003o/`00okl00?o2003obP00om400?oI003oi@00mOX00>7o003Fo`00dOl00<Ko002Xo`0L
EOl006ko014Wo`1f0>80:A[o001Co`0`>_l002Go000Qo`1K0>80W03R02l0o`0<0ol0803o0800o`2l
0=@0I@3o0:P0m@3V09/0o`270?l0?P`0o`0000h0o`0O0?l0?@3o0480oP360=H0iP3R0=`0g@3C0740
o`1B0?l001;o000ho`00Dol006ko0021o`8008go00D00Tgo041=jP00]ol00>7o003^o`02003lo`03
003ao`09XOl00?oh00<00?oh01P00?Co003Do`00T?l0BC3Z014bo`10G<00EAS0001jo`00`_l0<g_o
01Y3o`00_Ol06Tko06AUfP00iOl02KSl003Yn000omX00?cB003oU@00ogd00?m[003oIP00oe/2003o
E`06003oD`00od/00?m7003oA000ocP00?le0`00obP00`00ob400?lI003o6@03003o6@03003o3`00
o`X00?l:00<00?l:00<00_l800?o1@05o`001@05o`000`0=o`005?l0017o000501Co000301co000S
o`008ol000@08ol000<0:ol003?o000co`00100co`000`0oo`00@_l003oo000404;o000304[o001A
o`3ooooo00?ooooo00?o0000ooooooooool01_ooool0027ooooo00Go0000oooooooooooooooo017o
000401Co00802Ol000<01Ol000Co0`03o`D01005o`001@08o`002Ol0017o000Ao`003Ol000804Ol0
00<02Ol000go0005o`001P05o`001004o`<01Ol000Co0`03o`D5003o2P0D003o5P00oaT00?lI003o
6@00oad00?lV003o:000oc@00?m4003oA`00oel00?n=003o_P10Knh02FCo003VgP00oj000?n5003o
M@00ofX6003oIP03003oJP00og800?me00800?me0`00ohD2003oU00T003oX`00ojL00?n_003o]`00
ol800?o6003od@00omT00?oQ02_;mP10I=X009So002ko`00/ol0@73^02DIo`186Ol0B@Oo0014o`01
A_l007go001^o`00Eol002go0<`0B01U0?l001[o000Bo`1e0<00[@340580o`0o0?l0N03o0>L0MP31
0?l0o`2J0P3o00000`3o0100o`0=0?l000060?l0000K0?l0203o02T0o`2d0?X0eP3c0940/`3G0740
o`2c0?T0oP1f0740o`0G0ol00bOo001;o`00Gol008Wo002Ho`00Yol00:oo002ko`10XML00>go003j
o`00ool00?oh003om000ond00?oY00800?oQ01L00?o]003lo00AP_l03d?o01Eko`00b_l00:3o00EX
o`07:?l0P3>0001Co`1Z<ol00e[o04@oo`00e_l00?od003og@00olH00?nc003oX000ohd00?mm003o
L`02003oIP09003oH`00oel00?mG003oF`00odl00?m;003o@000ocP00?l`00<00?lX00<00?lM003o
6@00oaT00P00oaT00`00oa@00?lB003o2P04003o2P0400?o1@04o`<01Ol000Co0PD01Ol01P0Do`00
0`0Ho`007?l002?o000502?o000302_o000co`00<ol000@0<ol000<0?ol004;o0012o`001012o`00
0`1:o`3oooooooooo`02ooooo`03o`000?oooooooooo00Kooooo000Qooooo`04o`000?oooooooooo
ooooo`H05?l000<04Ol001Co0009o`000`0=o`0201Co000300oo000Do`005?l000H05?l000<02Ol0
00go0005o`001`05o`000`04o`<00_l7003o2P04003o2P0B003o5P00oaT00?lI003o6@00oah00?lX
003o<000od000?m?003oG`0I`9`00=;M00V:m000omh03XK]002gm000oh400?mZ0P00ofH00`00of<0
0?mV003oIP03003oIP05003oJP00ogD00?mi003oM@00ogd00P00ohD0:`00oi400?nD003oW000oj<0
0?n_003o/`00ok/00?o2003od@00omT00?oQ003jnP00_ol0;CCo002Ao`00UOl007;o02dHo`3Z0:<0
043o0025o`00T_l0097o001jo`00B?l00Qoo06X0`00I7ol0043o00TOo`0f1ol0@PCo03/0o`0E0?l0
:`3o07D0o`2/0?d0nP2L0?l0QP3o0980o`1k0?l0F@3o01001P3o0000=P3o00P0o`2D0?h0`P320?l0
fP3008@0o`0g0?l0OP3N06T0o`290</0]03H03L6o`0A4ol0@2kN0022o`00W?l00;?o0032o`00dOl0
0>7o003`o`00ool00?od003ol000onD00?oQ003of@00om400?oE003oh@00iOP007So003Jo`10L>H0
0?7o003ho`00hOl00:co018go`3o04D0K@?R08X4n009COl00:3o003lm000omD00?nk003oZ`00oi`0
0?n=003oP@00ogP00?mb003oJP800?mV00P00?m^003QW000o9400?mG003oA000oc/00?lh003o;0<0
0?lX00<00?lM003o6@00oaT00P00oaT00`00o`X00?l>003o2P05003o2PP01Ol000<03Ol0017o000D
o`000`0Do`000`0Ho`008?l002?o000402?o000302So000[o`00<ol000@0<ol00P12o`000`0oo`00
@_l004;o000204;o000304ko0?oooooooooo00;ooooo00?o0000ooooooooool01_ooool0027ooooo
00Ko0000oooooooooooooooo01Oo000Io`0401Oo01405?l000D04_l001Co000:o`003ol000So0006
00Go000300Co0@02o`L00?l:00800?l:00<00?l=003o2P00o`l00P00oaT04000oa/00?lX003o=@00
odl00?n<003mX`00mM@00>7K003oS`00ojH00<>f003XS000ofH00?mL003oE`00oeX2003oE`06003o
FP00of400?mT003oIP00ofT00?m`0P00ogD0;`00oh000?n5003oQ@00oi@00?nF003oWP00oj<00?n^
003o/`00ol000?o:003od@00on400?oY003Vo000P_l00Tco04dee`0^8_l0JQGk01h[o`00COl0ED;M
002Yo`00/Ol009Wo001?o`0G5ol0;SGc02l;o`00@?l005oo001?o`00D?l03bSo00@Ho`032?l0E03o
09D0e@3X0?X0Y03c0;00o`3d0<@0i`3X0?/0R@3o0980o`0G00D0o`000280o`0T0?l0J`3Z0=<0^@3f
07P0o`1L0?l05`3o00X8o`025?l0=`Sk05<3o`2W0<l0WP2[05<Ig`00K?l008[o02^@l`00aOl00=7o
003Qo`00k_l00?go003ol`00onT00?oQ003oe000om400?o<003obP00oll00??V00O6j`00on@00;_e
0P00on/04@00jod009Co02e4o`0R9ol0[@O20;84W`1b0nh04e[o003Ao`00n>/00?oD003o]P00oj<0
0?nI003oS@00oh000?mj00800?mh00X00?n2003e`00[`m800?nD003oG`00odX00?m2003o>000ocH0
0?l[0P00obP00`00ob<00?lI003o6@03003o6@03003o4P00o`d00?l:00D00?l:00<00_l500Co1004
o`801@05o`000`08o`002_l001;o000401Co000301ko000Qo`008ol000<08ol000<0:Ol002ko000c
o`00100co`000`10o`00@_l004;o000204;o000304Go001?o`3ooooo00?ooooo00?o0000oooooooo
ool01_ooool0027ooooo00Co0000oooooooooooooooo1P0So`00100Po`007?l001So000Ho`0>01Co
000401;o000Do`005?l000Wo00P01Ol01P00o`X03@00oa800?lI003o6@00ob400?l`003oW000[k<0
0?n1003o_`00ogH00?mO003oH`00og<00P00oeL00`00oe<00?mG003oE`04003oE`04003oG`00ofH0
0?mZ003oLP800?me0P00ohD00`00oi400?nD003oU`02003oX`0Y003o[`00okL00?oB003oi@00onT0
0?o]003om000lol00<[o002Lo`0f1ol0o`0K0:H:l@0LAOl00:Co002`o`00b_l00<Oo002Lo`0@1ol0
08;o0021o`1X4_l0I3O;001eo`00NOl006[o001Bo`00;Ol00`Wo0800o`3j0780Q03o04X0o`2?0?l0
_`3i09<0o`3J0?d0o`1g0?l08`3o00@00`3o00007P3o00`0o`1c0?T0i03j07H0iP2j0:l0fP1J0?l0
CP3o01@7o`00>?l0043o000ho`110ol09@Wo0605fP0N5Ol0@23o02Q5o`00[?l00<ko003Eo`00hOl0
0?3o003oo000onT00?oM003od@00olH00?o2003o_`800?nk01D00?o0003o`P00olH00?o>003oe@00
onD00>cl003>o`00N_l03T?o021/o`00T?l04Eco03``o`0cI?l00Z7o003Eh@00ok/00>c:003oY000
oiL00`00ohT02P00oi`08;SU0032m000ohd00?mV003oF`00odl00?m4003o?000ocP3003o:003003o
9@00oaT00?lI00@00?lI2@00o`X01002o`P00ol500Co0`04o`<300Go000300So000=o`005?l000<0
5?l000<06?l001co000So`00100So`000`0[o`00<ol003?o000303?o000303oo0012o`00@_l00080
@_l000<0A_l0ooooooooool00_ooool00ol0003oooooooooo`06ooooo`008Oooool01?l0003ooooo
ooooooooool702?o0007023o000So`008ol0023o000So`006?l001co000<01Co00804Ol000<05?l0
00go0005o`001005o`000`04o`<01Ol000?o1@05003o2P09003o4P00oaT00?lI003o:000oc@00?m0
003oE`00[lH00?mG00800?m?00<00?m<003oA`00od/00P00odL00`00od/00?m?003oE`02003oE`08
003oFP00ofH00?mV003oKP00ogD00?n1003oQ@00ohT2003oU00/003oX@00oj<00?n_003o/`00okl0
0?cU002go`10^<000?oo003lo`00i_l00;oo000do`0Y8?l0B@GZ04@Io`00N_l00:_o003:o`00fOl0
0=Ko002_o`00V?l00;Oo002=o`0G2_l007Ko002=o`00ROl006ko001:o`076?l0FP3o0<H0iP1F0?l0
>`3o01P0o`0W0?l0CP3o07`0o`3l08/0nP2X0?l0d`3o05430?l0000M0?l04`3o06P0h@2G0:X0o`2<
0?l0Z`3e0;P0j`0g0?l0K17^0018o`00Fol004So018Lo`00Bol02Cko064>n@1f0=X004oo002Po`00
]ol00:co00VBo`00VOl00>7o003ho000onD00?o:003oaP00okL01000ok<08P00okL00?nk003o`P00
olh00?oI003ol@00k?l0NbWo016Bo`00`_l00<ko003Uo`00SOl06B;o002/o`00o?400?oQ03=Po`00
omd00M;L003oV000oi@00?nL003o_P11E/000?CB003oS@00ogH00?m^003oL`00oh800?m;003o>000
oc03003o:003003o9@00oaT00?lL00@00?lI00<00?lB003o3P00o`h02@00o`X200;o200400Co0`05
o`001Ol000Go00804Ol00`0Do`00100Ho`007?l0027o000Po`0302?o00@0<ol000<0>ol004;o0012
o`000P12o`000`1Ao`3oooooooooo`02ooooo`03o`000?oooooooooo00Kooooo000Qooooo`04o`00
0?ooooooooooooooo``08ol000H08?l002?o000No`008?l001So000Lo`0;01Co000300Wo0005o`00
1Ol000D01Ol000<01?l300?o1@00o`X00`00o`X01000oa800?lG003o6@00oad2003o;003003o?000
od`00?m400<00?m01P00odL0>P00od/00?mG003oE`00oeL00?mS003oIP00og800?mi003oQ@00ohd0
0?nH003oW000oj000?nS003oZ`00ok<00?nk003oaP00omT0;9go041Xd`00g_l00>Wo00Ulo`00MOl0
=Bco001Vo`00X?l06DGo01a=o`0?<?l00<[o003Yo`00jol00>Go003Io`00eOl00:So001fo`00Z?l0
0:3o002Ao`00??l0317o00`7o`2a0:h0[03V00`7o`004_l010?o0200o`160?l0bP3C0><0i@310?l0
m`2g0?l0E03o01/20?l0000;0?l0303o0;40f`3l0:h0o`1N0?l0>`3o07D0o`1J0oT0033o001Go`00
J_l00P00K_l0=`00SOl007;o03DLo`00<Ol0Fb3o01E1o`0eAol0CCC000E2o`0c=MD007go002Do`0`
]?`00?oF003o^`00ok<00?n[003oY`00oj<00?nV003oZ`00ok<00?nk003obP00omT00?cd003No`00
VOl03KSo003ol000on400?Sd00F:o`00c_l008Go081;[P00fOl0AFg^042QhP00n=h00?n[003oX`00
oj/00?no009[o`00om800?nP003oW000olL00<;S016hg@00ogh00?m0003o>000ob`00`00obP00`00
obD00?lI003o6@06003o6@04003o5P00oa800?l=003o3P800?lB00@00?l>003o4P00oa800?lB0P00
o`X01@02o`L00ol500Co0`05o`002Ol000D05?l000<05ol001co000So`000P0So`001P0Wo`00<ol0
03?o000co`00>ol0043o00<0@_l000<0A_l0ooooooooool00_ooool00ol0003oooooooooo`06oooo
o`008Oooool2o`0000;ooooo3`0So`00100Po`008ol002?o000Ho`0:01Co0003017o000Do`003Ol0
00L01Ol01@00o`X02000oa@00?lI003o6@00oad00?lX003o;000oc000?ld1000ocP00`00oc`00?m4
003oA`04003oA`800?mG00T00?mO003oIP00ogT00?nD003oW000oj@0@<27003o/`00oj/00`00ok<0
4000okl00?oB003ol@00kOl06T[o002ko`00a_l007_o06h0gP02Lol00<;o0033o`0I?_l00<Oo002A
o`00f_l2003ho`0H003`o`00kOl00>Go003Eo`00a_l00;_o002[o`00W?l006Ko02X7o`300;X0N@3a
0189o`00;Ol002Wo0103o`2P0<00O@3o0:P0`0280=D0V`3o0=40o`3o0<l0o`0^0P3o00007@3o0100
o`1P0?l0c@360?T0AP3o0200o`0K0ol0:@Go040Ve`00Gol007Go0025o`00W?l00:Oo001no`00L_l0
08Wo002=o`14<ol0=eWo002Eo`0AT_l04G3o002To`15?oD01G_o003oj@00ok/00?n[00D00?nS01<0
0?n[003o/`00olX00?o]00FJo`0cNol00:So0033o`00omL00?o6003:eP00omH00?oM003`m000ROl0
Q1;m0415jP00`ol00?oI00800?o600h00?o:003odP00W?l00?S`01Vhh@00ROl00=;o003Nc`00ofX0
0?mC003oA`00ocP00?ld003o;0<00?lX00<00?lV003o8@00oaT03000oaT03000oc@00?mV003oKP00
oaT00?lB003o5000ob400?lF00;o3004o`<02Ol000go00L05?l000@07?l002?o000Wo`00:ol00P0c
o`001@0mo`00@_l004;o0012o`00A_l000?ooooo0_l00008ooooo`008Oooool02Ol0003ooooooooo
ooooool09ol003?o000Wo`00:ol002Ko000:02?o0006023o000So`008ol001So000So`008?l02P0D
o`000`09o`001Ol000Go000300Go00801?l300<00ol5003o2P00o`X00P00o`X01P00o`d00?lI003o
6@00oaT00?lM003o9@800?lX00<00?l/003o<000ocP00P00ocP2003o?0<00?m700/00?m;003oD`00
oeL00?mO003oIP00ogd00=KM003hf@10_=<0@:Vl003odP02003o^`0<003o_`00ol800?o6003oh@00
V?l008;o04Dod`10J=X03B?o04<bo@00K_l007;o0P00jOl07P0IJol00>go003ho`00oo`00?oh003o
o@00ool00?Co003]o`00hOl00=Go0032o`00Z?l0097o001bo`1>6_40^02j02/3o`00=?l004oo0014
o`1e0=L04PWo08D0`01B0?l0K03O0<T0o`3m0>L0o`1`0?l0=P80o`0000l0o`080?l0I03B0=`0W`3o
04h0o`0E0?l00Poo000Yo`00A?l005oo001bo`00ROl00:7o002go`00^ol00P00_ol02`00[ol0IB;^
00Eco`00c_l00>Wo003ho@00jO`00=Wd003dm00/^>`00?nc00800?nS0P00oiP08P00oiL00?nP003o
X`00ok<00?o:002Do`10Ood00<ka003lm00XH?l00>SK003o[`00oj/00?n_003o_`00omd00>Wo00UM
o`07E_l00VSo003NnP00a_P0@9gf003ln000^_P009co003Un000b_@05Kc/003o[000lZP00?mO003o
C`00odL2003o>003003o=000ob`00?lX00@00?lX0P00obD2003o8@03003o9@00ob400?lM00<00?lI
00P00?lM003o9@00od000?nL003oC000ob`00?lQ003o<0800?mn00<00?mC00;o2005o`000P05o`00
2009o`003Ol000go0009o`000ol=00;o5`03oa@05Ol00P0So`0203?o000303Ko0012o`00@_l00080
@_l01?ooool00ol0003oooooooooo`06ooooo`008Oooool02?l0003oooooooooooooool0;ol003?o
000_o`00<ol00P0[o`000`0Wo`008ol002?o000;02?o0003023o000Do`005?l000L05?l000<03Ol0
017o000Ao`001`05o`05003o2P05003o4P00oaT00?lI003o6@00oad00`00obP00`00ob`00?l]003o
>003003o>00@003o@000odL00?m7003oA`00od/00?mG003oF`00ofH00?me003d/`09`=H0;8Kl001V
o`00kOP00<k/003oeP800?o:01000?oE003oi@00o?`00=go002Po`0U:?l0W03V04P`fP00`ol00=[o
003lo`00ooP00?ch003om000onT00?o]0P00oo006000ool00?co003`o`00hOl00=Wo0036o`00POl0
1Bko0018o`1[2ML002Wo01XIo`10<_D006?o001Oo`00C?l002Wo05X0o`0A0?l09P3o08l0o`2f0?l0
kP3[0?l0B@<0o`0000d0o`0K0>P0a@2O0?l0T03N0740o`0j0ol00Q?o000ho`00Col0>dGo041Io@00
Qol00<Ko00<00=7o00P00<?o0025o`0T>Ol00;oo003ho`00onT00?oM003ocP800?o:00<00?nW003o
W000oi@01000oi@08@00oj<00?nc003odP00U?l00=Gl003obP00ol<00=Wh003Fh`00oj@00?nL003o
X000ojl00<Kl016an010U//00?Cl002To`1RD^`00:co02QXo`00c_l005_o003Qo000olX00?nc003o
Y000ohT00?mc003oF`00odl00?m7003o?003003o>003003o;000obP00?lX00<00?lX00H00?l/003o
:000obP00?l/003o<000ob`4003o:00<003o=000ofh00;_U003Q]`00odP00?ll003oP00``<H00?m8
003o8@00o`X00_l81@05o`002002o``00?lQ00n0_P00odl03Ol001co000So`009ol00P0co`00100o
o`00@_l004;o0012o`04ooooo`03o`000?oooooooooo00Kooooo000Qooooo`04o`000?oooooooooo
ooooo`@0<ol000D0<?l003?o000[o`009ol002_o000;02?o000401co000So`008ol001So00@05?l0
00<04Ol001Co000Do`000P0Do`0600Go000300Co0`03o`D00?l:00800?l:00<00?l=003o3P00oa80
1000oaT4003o:003003o<000ocP00?lh00800?ll01d00?m4003oA`00odL00?m7003oE`00oe/00?mV
003oKP00oh400?nI015ck000l?00CDO0002[o`00onT00?oI003oe@00omd00?o]003lo000e_l00:Co
06<0o@2L3^L04dWo0036o`00jOl00?oh003ok@04003oh@0<003oi@00onh00?oh003lo`00l?l00>7o
003Ao`00_ol009So014[o`2D0?d0<c3E0P00L_l2001mo`0:001bo`00Hol004Co000Uo`003_l0:@3o
05X0o`2/0?D0iP3_0?l0G0<0o`0000h0o`0<0?T0QP3[0:/0i`2=0?@0iP2E0>H0[030010:o`2=2X00
BPO^02XBo`0KE?l00<[o003Io`800>7o00/00=;o031_o`00@?l0@8[0002go`00onT00?o:003o_`00
ok<00?nW003oV002003oU00>003oT@00ohd00?n=003oT@00oiP00?o2003:o010H=h00>gd003oY`00
oj@00<;E02>ZeP00oi42003oS@0F003o[`00n<H00?o7042hf`00olX00?oU00>Ho`2O2^80Gaco00Dj
o`10D<000<?o003odP00oj/00?nA003oO@00ofh00?mK003oD`00odL00?m4003o?0@00?lh01/00?lc
003o=000oc@00?lh003o?000od000?ll003o@000ogd00?mV003o<`00ob`00?lX003o=000oc`00?mO
003oZ`02Q^400?m[003oF`00i[<00=gB003oF`00ob400?lB003o2P02o`P00P03o`D02`02o`P00Ol8
003o:@02`8d00?BL003o5P09o`005?l001co000Po`008ol00080<ol000<0?ol004;o0012o`001?oo
ool00ol0003oooooooooo`06ooooo`008Oooool01?l0003oooooooooooooool403?o0003033o000c
o`00;ol00080<ol000<0:ol002?o000So`002`0So`000`0Ho`005?l001Co000601Co000300Wo0005
o`001Ol000H01Ol000@00_l8003o2P00o`X00?l:0P00o`h3003o6@03003o7@00oaT00?lX00<00?lX
1000ocP01000od@00?m7003oA`00odL2003oE`09003oIP00ofh00?mi003oR@00oi`00?no003`m010
G<000>7j00800?oY00d00?Sl003No`00jOl00W3o04DTe`11?oT005oo001ho`09@Ol02HKo003on000
omd00?oE00800?oA01/00?oE003oh@00onT00?oh003do`00iOl00<ko0033o`00/ol0087o040b`00R
7?l003go002Eo`00W?l009So0029o`00MOl006Ko001?o`00;Ol00Pco0:D0g`2o0<00jP390?80ZP3o
08H00`3o00003`3o03X0gP2j07T0o`1B0?l0Z@2<01@0o`1]0?l0>0Wo02DDo`00Fol008Wo002`o`00
fOl00>7o003`o`02003]o`0<003Mo`00Yol0L0?V00eLo`00n_D00?o:003o/`00oj<00?nP003oU000
oi400?n91000ohD08000ohd00?nH003hcP00hOl0@<2d003oT@00ohd00?nE003`^`00ohD00?mm003o
P@00ohD00?n=003oV000oj/00?ng003>h@01M_l0@4;e07`7o@290mP0X@ko001jo`00gN`00?nc003o
V000oh400?m^003oH`00oeL00?m?0P00odL2003o?0<00?lh0P00oc`02000od@00?mb003oNP00odl0
0?mf003Xf@00oel00?m00P00ocP03@00oc`00?m4003oE`00oiP07;7Y003oW000oj003[CD003oH`00
od@00?lU003o6@00o`h01000o`X01`00oa800?m700FhaP00k=800?m<00?o1@09o`000P0Ao`00100L
o`00:?l003?o000ko`0204;o00Cooooo00?o0000ooooooooool01_ooool0027ooooo00Co0000oooo
oooooooooooo1P0co`00100_o`00<ol003?o000Wo`0203?o00X08ol000<08?l001So000Go`002@0D
o`000`08o`001Ol000Go000200Go00801?l300<00_l8003o2P00o`X00`00o`X01P00oa800?lI003o
6@00oaT00?lM003o8@800?lX00H00?l/003o:000ocP00?lh003o?000od@2003oA`0J003oB`00oeL0
0?mK003oIP00ofh00?me003oR@00oj000?nk003og@00gOl00<;o003ho`00hOl00;?o04QJo`00^ol0
4F3o04d/o@00Y?l00=Wo0028o`00hOl09:Wl003>k000olh2003obP0M003ocP00om400?oI003oj@00
iOl00=go00VMo`00N_l007Wo001Oo`10BNX0@4W0001no`09Mol00:oo002[o`00X?l008go001Zo`00
E?l0043o044DkP1B0?l0c@330:L0o@200?l0Y`3o0?D0h03o06000P3o00006`3o0480kP2R0;/0`00X
0?l020?o000Qo`00>?l003co03l0o`256^@008Go002oo`00hOl00?3o003do`00ool00?co003ao`00
ROl006Ko071>kP0^C=l06L3U003o]`00oj<00?nL003oU004003oQ@0;003oP000oh400?n5003oR@00
ojP00=Wd003oW000ogd00?mi003oM@00ogX01000ogD05000ohD00?n9003oU000ojL00?nk02_@g015
G/000Voo041P`002H?l0P2cL003In000o>D00=gI003oW000ogX00?mZ003oF`00oeL00?m;0`00odL0
3@00od@00?m0003o@P00od000?m7003oC`00ohd00>7Q003oOP00o:P00<KM003hT000odl00P00odL0
3000odl00?mC003oG`00ogH00>Fc00:di@00^^`00>>Q003oC`00ocP00?lX003o7@800?lI0P00oa80
3P00oaT00?lQ003o?000okL00?RL003o<000oaH00?l>003o7@03oa@00?lY01Ko0P0_o`00=ol00P12
o`04ooooo`03o`000?oooooooooo00Kooooo000Qooooo`04o`000?ooooooooooooooo`/0<ol000@0
<Ol002Ko000Xo`009Ol01`0So`000`0Qo`008ol002?o000801Co000301;o0008o`001Ol000H01Ol0
1000o`X00`00o`d00?l?003o6@03003o6@05003o8@00obH00?lX003o:000obd00`00ocP07@00ocd0
0?m7003oA`00od`00?mG003oFP00ofH00?m^003oO@00j;/00=7V032Xl001Wol0:h?c01Ejo`0HO_l0
0:Ko0012o`0k<ol0LC?o03d`o`00`_l00>7o003jnP00]_d00<;j003oe`00olL00?o200800?nm00d0
0?o2003obP00omT00?o^0030o`0aG]D044_o040ho`0[M=D008So02/nkP00T_l00;So00800<Oo02l0
0<3o002Io`0>EOl0A@[T03hCo`0n3Ol0=PKo07P6]00J1_l0@03k04l0o`3>0?T0j`3X0?l0IP3o00d0
o`000?l0G`3T0>T0Z03Z0480o`1B0^h05Q_o001Do`00I?l006Ko00]6o`0A=Ol00I7o003Yo`00mOl0
0?oo003onP00ooP00?oc003ol000n_P00=Co02Ajh`0[`m000>SD003oX`00oi@00?n8003oQ@00oh<0
0?mm003oN003003oM@04003oO@00n:@00?fL003oNP800?m[1000ofH05`00ofT00?mc003oM@00oh<0
0?nB003oX`00okP00?SV04MHo`00lo<00<ce003Aj@00l>h08Y?o01]Ao`00]OP00?nh003oY`00lk<0
0?mj003oL000oeX00?mE00@00?m<02d00?mE003oFP00oeL00?mO003oN000_kl00>_[003Qj@00oJh0
0?me003oI000ogH00?me003D/000ogD00?mh003oW000ojh00<cj003oZ@00ogL00?mE003oA@00ocP0
0?lc003o=@00ob/00?l`003o:000obH00?l_003o@000n:H00<G:003o@P00odD00?mS01SB^000gY`0
0?m=017O>P0Yo`00<ol0043o0012o`001?ooool00ol0003oooooooooo`06ooooo`008Oooool01?l0
003oooooooooooooool>03?o000302So000So`008ol000L08ol000<07?l001Co000Do`001@0Do`00
0`0Ao`003Ol000[o000300Go000400Co0`05o`001Ol000?o1@D00?l:00<00?lB003o6@00oaT00P00
oaT00`00oad00?lU003o:002003o;0<00?lh01/00?m4003oA`00odL00?mC003oE`00of<00?mV003o
KP00ogd00?nc003/g@00n?@07;cX003oj@00j?d04EWo01hIo`0W0ol0``2m08T0fP1E=oD00:Co003o
n000onD00?oL0430Y@00okl01000ok<0<@00okL00?o6003`i@03a_d0<8_o00E1o`00TOl00>7o003U
o`00`_l0Y2;1001bo`00b_l00=ko003Io`00b_l0:D_o0419`000POl007;o04TPo@00:Ol0043o000V
o`0G0ol0=`3o07D0o`390?l0o`1g0?l0403o0000o`0S0?T0X03Z0=P0d`2K07h0e`1S4Ol005_o001i
o`00ROl009co002_o`00c?l00>Wo003ho`00ooP00?o`003oj@00onD00P00omT02@0=`>d00?oL003o
g@00a]H00?nL003oU000ohT00?n5003oN@03003oM@03003oKP00ofX00?mZ00800?mZ00L00?mV003o
H`00oe/00?mK003oFP00oe/00?mS00800?mV01H00?me003oP@00oiP00<[B003Uj@00Z?d00=Gh003o
aP00ok<00?n[003odP00`_l00>gh03nUo00YLOl00?oV003:l000`_@00?nE003oJP00oel00?mG0P00
oe/0;P00ofh00>JL003oU000og800?mf003oR@00oj@00?cQ003>l000o<X00?nc003oX@00ojP00=g/
003XbP00oi`00?2o002kl000onT00W_o002cm000hj<00?n9003oMP00oe/00?m?0036X000ofH00?n/
003oB000ocP00?m2003oB`00ogH00?c:003oW002]>`00;_U003oNP00o9400ol501Wo000So`00<ol0
03Oo0012o`04ooooo`03o`000?oooooooooo00Kooooo000Qooooo`05o`000?ooooooooooooooo`0o
o`003@0co`000`0Xo`008ol002?o000702?o000301ko000Lo`005?l000P05?l01`05o`000`03o`D0
0?l:003o2P03003o2P03003o4P00oaT00?lI00<00?lI0P00obP01000ob`00?lh003o>000od02003o
A`0H003oB`00oeL00?mG003oH`00ofH00?m^003oO@00ohd00?nP003o/`00olH00?oI002mnP00H_l0
V0>00<l0XP2d0?L0@@ko01U_o`00Z?l00?oY003of@00ol`00?no0P00ok<2003oY`0N003oZ`00ok<0
0?nk003oeP0@Iol0@57a003Qo`00l?`00?oh003ho`00d_l0P4?9001jo`00fOl00>Ko003Yo`00gOl0
0:_o002oo`00[ol005_o03L0o`00Eol005oo01LQo`290?D0W03e0>D0n@3j0<X0o`1I0`3o0000703o
05@0_P3o0740o`0G0ol00Qoo001Co`00K_l008go002So`00^ol00<oo003Qo`00m?l00?ol003ol000
on400?oM003od@00olX00?o6003o^`00ojl00?n[003oU000ohd00?n5003oP@00ogT2003oM@04003o
J`00ofH00?mV003oIP800?mS1`00oeL05`00oel00?mV003oLP00ohT00?nT003>m00EQoP00?GI002k
o`00olX00?nP003oU000iK<00?nX003o]`00l=T03J7l039Io`0=_>`00?nc003oS@00og800?mZ0080
0?mV02`00?mb002TbP00e^<00?n/003oT@00`/h00?oF003Xf@00V?l0@3k^021Po000]o006Y3`02b>
m00]7Ol05Goh00Val000fNT02Goo02R>o`0P=_l005oo003]gP00omT00?CM003oPP00ogH00>Rc003Y
f@00oj@00?mO003oC`00fG<00?mZ003oV@00iMH00?nD003oNP00oeL00?lY003o4P09o`006Ol002Oo
0080<ol000<0?ol0ooooooooool00_ooool00ol0003oooooooooo`06ooooo`008Oooool01Ol0003o
ooooooooooooool0@_l000`0<ol000@0;ol002ko000_o`009ol02@0So`000`0Lo`005?l001Co0005
01Co000300go0005o`001Ol000@01Ol000<00ol500;o2000o`X00P00o`X00`00o`h00?lB003o5P04
003o6@04003o9@00obP00?lX003o;0800?lh0P00odL06P00od/00?mG003oE`00oe`00?mV003oJP00
ogD00?mm003oR@00oi@00?nW003o^`00omD00<cj001Go`2=1m@0@AKo041=jP1c:?D00<Ko003ao`00
onT00?oA003o`000ok<00?n[1000oj<07@00ojL00?ng003ocP00ZOl007Wo003dm000on400?oU003o
n015F/00<BCo041_hP00iOl00?Go003ho`00l?l00>Go003Eo`00W?l0@2O000U=o`00OOl007Ko001B
o`1]0mh0HP3V07`0o`3M0>H0o`1@00<0o`0001P0o`030?l0H02P0=h0CP3o040Ao`0/:_l001go041E
fP00UOl00:So0037o`00fOl00=Ko003/o`00oo000?oQ003oe@00olX00?o6003o]`00ok000?nS003o
V000oi@2003oQ@04003oO@00ogD00?me003oLP<00?mV00<00?mO003oE`00oeL00P00oeL01000oe<0
0?m?003oC`00oe<2003oE`0E003oG`00ofh00>G2003oeP0AZOP04JgM003oX@0=]?000=7M003oT@00
oh400?mm003oP@00oi400?n_003hk00CGol0093l003hdP00ojP00?n500800?mi02h00?n9003oS@00
ojP00=c`003Ii@10[N80?iKl002Do`00c_l002go03]go`00k?@00?c]003ge000jMd00=Wo003/h@00
j=d07:7h03Pko`0M:?l00;_o0032n000^>d0;63o002[o00PQ_@00;OQ003Qh@0JJO000?nI003oNP00
ogH0HX2k003oY000olH05L3I003oIP00od000?l/003o6@02o`P03Ol001Wo000So`00;ol00P0co`04
ooooo`03o`000?oooooooooo00Kooooo0002ooooo`;o00001?ooool00ol0003oooooooooo`02oooo
o`;o00000oooool5o`0000;ooooo0ol00005ooooo`06o`000?ooooooooooooooo`0ko`00?ol00P12
o`0<03?o000302_o000So`008ol000H08ol000<08?l001Co000Do`00100Do`02017o000300[o0005
o`001Ol000D01Ol000<00_l8003o2P00o`X00`00o`X00`00o`h00?lI003o6@02003o6@07003o7@00
obP00?lX003o<000ocP00?m0003oB`03003oE`0Q003oG`00ofH00?mV003oLP00ogD00?mm003oT@00
oiP00?nW003obP10^;D00<[o02hBo`00SOl0H3om002Xo`12B_T00W?o003ho000onT00?oA003o_@00
oj/00?nS003oX000oi`00?nD003oX000oj<00?ng03_0i@00l?D00?oF00800?o:01D00?oI003ho000
Zol0:6co002_o`00o?l00?om003oo`00o?l00?3o003Qo`00c_l00:oo002Wo`00V?l007go001Go`00
9Ol0503o07`0o`3o08L0103o00006P3o00P0o`2>0:h0o`3@09`0]02f09D0b@250=h003co001Vo`0c
>_l02hko002go`0A>_l00>7o003on000on400?oA003obP00okl00?nc003oZ000oj<00?nH003oT@00
ohT00?n50`00ogD00`00ofX00?mV003oIP02003oF`800?mG00<00?m?003oA`00odL00P00odL2003o
B`14003oD`00oeL00?mZ003oX00UJOP0:Gc`003oS@00oh800<kU02Qkm000ohd00?mb003oKP00og80
0?n5003Qi@0E_>D00LgL003Ui@0=Rol00:ol003o/`00ohd00?nI003Mk000o=T00=G`02E?o`10F;P0
1h3Y00Vhk000m>400=7:003>m00LT_000?Bk003oV000oh000>Fo00F6j000ok000?nE003/k000o>`0
0WOo003dh@00olH00?nD003Ii@00ojl00/2n0036k000M_l0H43o00VUl000b]d00?ng003GnP00omH0
0<Kh003Uf@00`Y`00?m8003o<000oaH00?l:00Go000Do`0202?o000302oo000co`3ooooo00?ooooo
00?o0000ooooooooool01_ooool00005ooooool0003oooooooooool000002_ooool01Ol0003ooooo
oooooooooooo000000;ooooo00?o0000ooooool000000oooool00ol0003oooooooooo`02ooooo`04
o`000?ooooooooooooooo`@0@_l0300co`0802?o0003027o000Lo`006?l000P05?l01`05o`001`03
o`D00?l:003o2P00o`X00?l>003o4P00oaH01000oaT02@00oad00?lX003o;000oc@00?lh003oC`00
gIP00?mZ003oIP02003oKP0G003oL000og800?me003oN@00ohT00?nH003oY`00ok<00>GM0021o`00
Lol009Go003Bo`00hO`00?Cl002no`00ROl0<9ko0032o000n>T00?o0003oZ`00oj001000oi@07P00
oiP00?nT003o]`00flL00?ng003o/`00ok/00?o:002[n010COT00;?o003lo000oo@00?o`003on000
ool00?3o003Yo`00fOl00<Ko002[o`00W?l02E7o01D/o`0G0ol0P@300;<0gP3[0;<0o`0j0?l06`80
o`0001P0o`1[0:h0o`0g0?l01@oo00LLo`0a3Ol0C@ko04T>o`1P2L<0B0go001ho`00N_l0?3?o04EQ
`000eOl00?oY003oe@00olh00?no003o/`00ojP00?nP003oU000oi42003oQ@06003oM@00ogT00?me
003oJP00ofH00?mS0`00oeL00`00odl00?m7003oB`06003oA`0m003oD`00of<00?n5003Mf@00oi`0
0?mZ003oJ@00oi400?C:003oMP00of<00?mO003oIP00ogX00>6W003oU@0[eI000?n_002Pm000c_@0
@<2Y003oaP00__@00:Co01VJm000l>402k7X003:h@00oiD00?RP003oQ@00oi400?o>002gm000okl0
0?mj003oG`00bXT00?mV003oH`00ofX00?n5003o[`00gO`00?nL003oMP00of@00?mb003oG`00ofL0
0?n[003El000gKL00<KQ003>g@0LYOl00H_o042JiP0cL?l0@57?003/h@02003oJP05003o<@00oaH0
0_l800[o0P0Do`000P0So`000`0[o`3oooooooooo`02ooooo`03o`000?oooooooooo00Kooooo0000
1Ooooooo0000oooooooooooo000000_ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`00
0?ooooooooooooooool000001?ooool2o`0000;ooooo0`12o`0303_o00T0<ol00P0[o`000`0Wo`00
8ol002?o000602?o0003023o000Do`005?l000805?l000@04Ol001Co000Do`003Ol01@05o`000`03
o`D00_l8003o2P05003o2P03003o5P00oaT00?lI00800?lI02<00?lU003o:000obP00?ld003o?000
odl00>F_003oV000m:@0:<2k003oT000ogX00?me003oO@00ohD00?nA01FIe@00k=X00?o:003oj@00
`ol0AC?c0036o`00on400?oI003oi@00l?l009co003:o`00O_l0@8?R003Xh@00oj/00?nH003oU002
003oS@05003oR@00ohd00?nD003oV000oih00P00oj<0<P00ojl00?o:003`m01LJL/00:cl003ol@00
on400?oT003ol000oo`00?3o003Qo`00eOl00<?o002Ho`00SOl004So06H2e@300800@@?o0300o`1Y
0?l0g@300?h0S@3o01<0o`0<0>h0b`2k0=h0K@3o00hHo`00Eol0?c;o001Vo`00K_l07QGo07lBo`1[
3O80:@go001Vo`00Z?l00>Wo003om000onT00?oI003oaP00ok<00?n[003oX000oi@00?nA0P00ohD0
1P00ogd00?me003oM@00ofX00?mV003oG`800?mG00<00?m?003oA`00odL00P00odL03`00od@00?m2
003o@000od@00?m7003oB`00of<0=god003`[`00of<00?mG003oDP00ogH00?nA003oG`03003oE`0R
003oF`00oel00?mZ003oM@00oh400?nE003o[000dN`00=;`003dg@00omT00?nn003oS@00mm400=6_
003oNP00of<00?mZ003oP@00Yo000?nL003`h@00oh400?m:003o@000odL00?m;003oF`00ofh00?o3
003/k000n;<00?m^003oC`800?m001H00?mO003:bP0/`<H00?n5003oJP00oj000;Od001^o`00gO@0
0=Kh003Bj@0T`>40:9WM003ocP00oh400?ld003dO@01obL02?l701Co000Ho`007?l00oooool2o`00
00Sooooo00001Ooooooo0000oooooooooooo000000Sooooo1?l00004ooooo`04o`000?oooooooooo
ooooo`?o00001Oooool01?l0003oooooooooooooool204;o0080?ol00P12o`000`0ko`00<ol003?o
000903?o00P08ol000<07?l001Co000Do`001@0Do`000`08o`001Ol000Go000500Go00@00?l:00<0
0?l>003o2P00oaH01000oaT00`00ob400?l[003o:002003o>007003oC`00o:@05L3>03Nho00A`>D0
0?nT003oRP02003oQ@0E003oT@00oj@00?CI00fMo`00oo000:Oo06QRe`00^?l00?3`003obP00ol80
0?oB003An00PV_l00?oQ003dj000c_P087og003oZ`00oi@00?n900D00?n503@00?nA003oU000oi@0
0?nP003oY`00olh00:od003oh@00omT00?oA003oe@00omh00?oY003do`00g_l00=;o003:o`00/ol0
@3Oo001No`0l8?l0G@3E02PKo`00=?l0L@?008@0o`2W0?40cP3i0?l0D@3o00@0h@2m0480o`1B0?l0
5R3o001^o`00QOl009co002Ao`00J_l008Go03TRo`2F09l0@33o002Io`00f_l00?7o003]o`00Zol0
0?oB003o^`00oj/00?nS0P00oi@00`00ohd00?n5003oP@02003oM@03003oJP00ofH00?mK00800?mG
1000odL2003o?0<00?lh00H00?ll003oA000oe<00?mV003oE`00od/2003oA`03003oB`00odl00?m7
00<00?m701P00?m?003oE`00oeL00?mT003oLP00ogd00?nP0460_000om800?nE003oR@00ogH00?m^
003oQ@00ofL00?mC003oC`00oe<00?n1003Mj000ofh00?mG003oNP00oc/2003o>008003oA000odl0
0?n[002gi@00oh`00>G`003oV000odD2003o;00F003oB000od`00?m@003oB000od/00=VD00g0aP00
hn<00?no003Uf@05`:L00?n200;0aP0`Q]d00?SF003oS@00oi`08;VY00;o3`05o`003Ol000Oo2@Co
oooo00?o0000ooooooooool01_ooool00005ooooool0003oooooooooool000001oooool01ol0003o
oooooooooooooooo0000ooooool000000oooool00ol0003oooooo`000003ooooo`03o`000?oooooo
oooo00;ooooo00Co0000oooooooooooooooo1P12o`000`0go`00<ol003?o000803?o000302oo000S
o`008ol000@08ol000<08Ol001co000Do`001`0Do`000`0?o`001Ol000Go000300Go000300Co0`03
o`D00?l:00@00?l:00<00?l>003o6@00oaT00`00oaT2003o:00:003o<000ocP00?lh003oA`00oel0
0?nL003Im000QOl00?cM003o/`800?nD00T00?nP003UcP09V_l05H[o022Fo`10K>h00:3o003ogP00
okl00P00ok<02P00ol<0<9[o070cjP00ol<00?n_003ocP00_N/00?nc003oR@00ohD3003oP@<00?n5
03@00?n8003oU000oi@00?nL003oY`00okL00?nk003o_`00ol800?o>003oe000onT00<Ko001Do`00
N_l00:_o002=o`1a6/00P@?D034Lo`00AOl0@4gi001Oo`00;Ol0JP3e04<0o`3G0>P0o`1`0?l0003>
0>L0CP3o00X=o`00@?l006Oo0025o`00[ol00<;o003:o`00]ol0>e7V001mo`09J?l02CKo041AhP00
`ol00:3o0036o`00`_@07<3I003o]P00oj<00?nP0P00oi@02@00oi400?n5003oP@00ogD00?mb003o
IP00oe/00?mG003oD`03003oA`03003o?000ocP00?lh00D00?lh00<00?ll003o@000oc`01@00ocP2
003o@00I003oA000odL00?m7003oA`00oe<00?mJ003oIP00ogd00?nL02Uhm00E`=H00?n5003oLP00
of<00?mK003oE000od/00?m4003o@000od@00?mG003oZ000odP00?ld003o;003003o:00D003o>000
odl00?n_002cl000oeL00?m^002Xo000odD00?lQ003o6@00oad00?lQ003o9@00ob`00?ld003oA000
of<00=_?003oW000ohT2003oC00:003oU@00bY@00?R9002Pf@0AOol00?FN003o>000oa800?lN003o
B`Cooooo00?o0000ooooooooool01_ooool00005ooooool0003oooooooooool000001oooool01ol0
003ooooooooooooooooo0000ooooool000000oooool00ol0003oooooo`000003ooooo`03o`000?oo
oooooooo00;ooooo00Co0000oooooooooooooooo1@12o`000`0go`00>ol003_o000703?o0080;ol0
00<09ol002?o000So`001P0So`000`0Lo`005?l001Co000401Co000300go0008o`001Ol000D01Ol0
1@00o`X2003o3P<00?lI0P00oad2003o:00P003o;000ocP00?lh003oA`00oeL00?m^003oV000m?00
@7oR003oa@00ojL00?nS003o[`00olH00?o]002Xo`2?0?l0Edko003hn000olD00?nW003oX000oj<0
0?nk003/k000]oP00?nn003oV000oi@00?nj003oT@00oh42003oM@07003oN@00ogD00?mi003oO@00
ohD00?n8003oR@02003oU0800?nS03T00?n_003o/`00okl00?o2003od@00on400?oh003>o`0M?ol0
07Ko0017o`243_40Oa;o0010o`00Uol008go001io`00Eol002Go03L0o`3H05L0nP2_0?l0003O0:80
a02004X0o`282^h03Q7o00DZo`00V?l00=Go003Io`00`_l0:fWE009To`00fOl02Eco02I7o`0R<?l0
5Soo002Ho`00jO`00?oI003o_@00ok<00?nW003oX`00oi`00?nD003oT@00ohd00?n1003oM@00ofT0
0?mV003oE`00oe<00P00odL00`00od000?ll003o>002003o>003003o<000oc@00?ld00@00?ld00<0
0?l`003o=000ocP01@00ocP04000oc`00?m7003oA`00odL00?mD003oIP00m:000>G>03NBm000om80
0?nP003oKP00oeL00?mC003oA`00od03003o>00A003o?000oeL00?l/003o9@00ob400?lI003o7@00
ob400?l/003oR@0TW^D00?ng003o>000oc000?mK003o<`00oa800P00o`X2003o6@0C003o7@00ob`0
0?m0003oH`00jlL00?mn003oC`00oc@00?lY003o9@00ob400?ll003h^`00k;/00?FL00G0dP00m6h0
0?n502V0aP04ooooo`03o`000?oooooooooo00Kooooo0002ooooo`;o00002Oooool3o`0000?ooooo
0ol00003ooooo`?o00001Oooool01?l0003oooooooooooooool404;o0005043o0012o`00@_l004;o
000ko`002@0co`000`0[o`008ol002?o000402?o000301ko000Go`005?l000D05?l000<04_l000Go
0005o`000`05o`000`04o`800_l7003o2P04003o2P03003o3@00oaT00?lI00800?lI02000?lL003o
8`00obP00?lX003o<000ocP00?m0003oC@00oeX00?m[003oPP00ojh00<c[003FiP00ol800?o502_@
_P00oNH00=Wj01eZo`06Yol00:go00^Gn000h<T00?nD003oS`00oi800>JY003Ic`0>]^d00?nQ003o
P0800?mj00<00?mh003oL`00og<00P00og<2003oM@800?mh0P00ohD0?@00ohX00?nD003oU000oih0
0?nS003o[P00okP00?o2003oeP00onH00?[m00BRo`06NOl0F@[E08h0_00DA?l008So002[o`00^ol0
09;o00U1o`0f8=D0>0OE07D8ZP170?l0d`2Z0?l0;P3N0=P0B`3n04PSe@04?_l03ROo0025o`00e?l0
0>_o003co`00k_l05[cl003hm@00oOP00??o002Vo`12??l0C3WE029no`00cod00?oV003oc000olD0
0?o7003ce000j<d00?nc003oa@00n=800>Rh003oS`00ogD00?m[003oH@00oeD00P00odL01@00oc/0
0?lh003o>000oc<00?l]00@00?l[1@00obP3003o:`03003o<000ocH00?lh00800?lh01L00?m2003o
A`00oe<00?mQ003oO@00dLl02hKj003Am@00ljh00?mV003oE`00odL00?lm003o=P00oc000?l[003o
:000ob<00?lQ003o7P00oaT00?lG003o5P02003o5005003o7P00ocD00=VT003oF@00oa`00P00oa80
6@02o`T00Ol900?o1@03o`<00Ol9003o2P00oaL00?lS003[KP01b<000=RI01j>gP00iXX00?l`003o
4P02o`L00_l:007o9@00odD00?lk003o9`00hE`00;>j003oA@02oa401?ooool00ol0003ooooooooo
o`06ooooo`008Oooool01?l0003oooooooooooooool804;o000303Oo000co`00<ol000H0<ol000<0
;ol002Oo000So`001@0So`000`0Po`005?l001Co000401Co000300go0009o`001Ol000<01Ol000<0
1?l300Go0000o`X01000o`X00`00oa800?lI003o6@04003o6@<00?lX01000?ld003o>000odL00?mO
003oMP00ok<00?ng0430[@02ZO@0<I7B003El000^_`0;5Wo0036o`0=BOl00:oo0P00onD02P00Zol0
0?nO003oQ@00ohD00?mm003oP@00oiD00?3B003oP@00ogD6003oIP03003oJP00ofh00?me00800?me
00@00?mj003oQ@00ohT00?n=0P00oi@06`00oj<00?n[003o]`00omD00?o`003on000lOl00<;o03]P
o`0`>_l00TGo0099o`00[ol00=Go003Do`0aC_l0087o01Xgo`00@?l02C;o03<0o`2n0?D0o`0^0=P0
b`0k0?l003So001io`02002Ao`0N003Jo`00n?l00?oh003ok@00on400?oI003og@00hO`00:3o002X
o`00iOl0DFgi040Lo`00e_l00?g`003Ao000k?`007Ko003an000_^P00?cd00fJo`00_^d00?nT003o
S`00oi`00?n9003oF`00odL00?m40P00ocP2003o<0l00?lX01@00?l/003o=000ocP00?lh003oA`00
oe@00?mS003oLP00oi`00;?d003lfP00ohT00?mZ003oE`00odL00?lh003o<000obP00?lU003o7@<0
0?lI00<00?l>003o2P00o`X00P00o`X01P00oa800?lM0170Q@00ob400?l:00Co0`H01Ol000d00_l8
003o5P00obT00>b@003Mk000ocd00?ll003UdP00ogX00ol500Wo000Do`004Ol000803Ol000D01?l2
003o4P00ofH00<j=00?o2@04ooooo`03o`000?oooooooooo00Kooooo000Qooooo`04o`000?oooooo
ooooooooo`H0@_l00P0oo`000`0ko`00=ol003?o000403?o000402oo000co`00:ol002Oo00D08ol0
00<08Ol0023o000Do`001P0Do`0500Go000300Co0`00o`X00?l:00<00?l:00<00?l?003o5P00oaT0
1000oaT3003o:00B003o:`00ocP00?lh003oA`00oel00?o30032k000e_@0:73h02S0j00[`>`0@6cm
0032o`0X@Ol0BAko01IFo`00hO`00?o:0P00ok<00`00ohl00?mi003oM@02003oM@800?mf00@00?mZ
003oIP00ofH00?mQ1P00ofH01000ofh00?me003oM@00ogD2003oQ@0n003oS@00oi@00?nH003oX`00
oj/00?nc003odP0@Pol00=Ko003Bo`10G>h07T?o002co`00SOl00:So01EXo`00kOl00>ko003Io`00
^ol04RCo0021o`00Iol091_o0680hP3[0400j`2]0383o`10;^X0<e7o002Xo`00b_l00>Wo003ho`00
oo@00?oQ003oeP00olX00?o>003dj@00o>D00>7Y003oh@00m?@03K7l0423`00JPol02e[o01ako`1K
F_l0;7_o01IFo`10J<00H4[m00Vdl000om800>^h07^0c`00oi@00?m[003oC`00od02003o>003003o
;000obP00?lX00800?lX00P00?lU003o8@00oad00?lM003o8@00oad00?lQ003o8`D00?lX00l00?l/
003o>000ocP00?m0003oE000ofX00?n5003oX007E_@00:_d003oX000oj@00?25003oA`00ocD00P00
obP01000oad00?lI003o6@00oaH3003o2P0K007o2002o`P00ol500?o1@02o`P00_l<00Co0`05o`00
2Ol000go000Bo`004Ol001Co000=o`002Ol000Go0000obD00?mO003d/`00ogH00?lI003o5P00obd0
0?n=00So0`0Ho`007?l000808ol000H07?l001Co0003o`d00>F50032[`02oal4ooooo`03o`000?oo
oooooooo00Kooooo000Qooooo`04o`000?ooooooooooooooo`X0@_l0200co`000`0[o`008ol002?o
000302?o0003027o000Do`005?l000@05?l000<03Ol000Wo0005o`000`05o`000`04o`<00ol5003o
2P02003o2P800?l>00<00?lD003o6@00oaT00`00oaT4003o:00G003o<000ocP00?lh003oA`00oe<0
0?m^003oV000oj@00?nX003o/`00oNP0087o01XPo`350;<0V0>^00]7o`02T_l00?o2003oY`00oi@0
0?n2003oM@00og801000ofH01000oel00?mG003oE`00oeX2003oE`03003oG`00ofH00?mV00800?mV
00<00?mb003oM@00ogD00P00ohD09P00oi400?nD003oV000oj<00?n[003o^`00olh00=cj001[o`00
J_l0@BcZ01U/o`00jOl00;Oo003>o`00n?P00?oh003mo`00l?l00=go002ko`00X?l00TWo03LCo`27
0?l0i`2c0<l0YP0f2_l0Q0[0040Io`0I<_l00;?o003Bo`00iOl00?cl003oj@00olX00?no0`00ok/0
5`00okl00?o6003ocP00onT01DWo003hm@00l>D00?oN01VUm000omH00?oN002To`00eOP03I[l021A
o`00co000=Wl003ogP00c/H00?mC003o@000ocP00?l`00800?lX00@00?lV003o9@00oaT00?lM1`00
oaT00`00oad00?lQ003o:003003o:00@003o<000ocP00?ll003oIP1bP=80@:G8003obP05ZOl00;?o
003hh@0`YMT00?mZ003oA`00oc<00?lX003o8@800?lI00H00?lF003o2P00o`X00?l:00;o2004o`85
00Go000300Wo000Ao`005?l000H05?l000X02Ol000?o1@00oeL00?C6003o]`03o`d03Ol000So0`07
oaT07?l00P0So`0202Oo000602?o000Qo`003Ol0003o5P00j:l00?B11?ooool00ol0003ooooooooo
o`06ooooo`008Oooool01?l0003oooooooooooooool:04;o00L0<ol000<0;ol002Oo000So`000P0S
o`02023o0003027o000Do`005?l000@05?l000<03Ol000Go0005o`000P05o`0200Co0`@00?l:00<0
0?lB003o5P00oaT01000oaT00`00ob400?lX003o:002003o:00F003o=@00ocP00?m4003oB`00odl0
0?mO003oKP00oh400?nA003oZ`00_n/05S?o07@0o`0X:ol083;o002co`00o?@00?no003oX`00oi@0
0?n0003oM@800?mV00<00?mK003oE`00oeL02000oeL3003oIP03003oKP00ogD00?me00800?n500d0
0?nA003oU000oi`00?nS003o[`00ok/00?o>02^Pj@00Gol0a@10001fo`00gOl00?ol00800?oY01L0
0?oU003oj@00ooP00?Co003Qo`00b_l00VCo06`Fo`2;3/<09ASo0:00o@3D0:P0C2So009Ho`00L_l0
;C3o001Ko`0PBOl0@47e06QFkP00/o`00?o7003o/`03003oZ`0F003o/`00ok/00?o6003oj@05Mol0
0>gV003o_`00ok<00?n[003oY`00ol8098;Y003`eP00okl00?cQ031eo`0LV_l00?ng003oO@00oel0
0?m4003o>0<00?lX00<00?lN003o6@00oaT02@00oaT00`00oad00?lI003o:003003o:00A003o=000
ocP00?m?003oO@00ojL00>Wl022>o01g6_l00>G`003Xj@00c]T00?mG003o=@00obP00?lQ003o6@00
oaH00`00o`X01`03o`D01?l300Go0004o`<01Ol000Wo000=o`001@0Do`00100Io`006?l001So000H
o`0201Co000600Wo0002o``00?Am003o:@0>o`807?l00P0So`000`0[o`00<ol003?o000203?o0006
02oo000Vo`003Ol00032E`00ogd00=g>1?ooool00ol0003oooooooooo`06ooooo`008Oooool01?l0
003oooooooooooooool804;o000303_o000co`00<ol000H0<ol000<0;ol002?o000So`00100So`00
0`0Go`005?l001Co000301Co00H01Ol000H00ol5003o2P00o`X00?l:003o3P00oaH4003o6@800?lM
1@00obP06@00oc000?lh003o>000od@00?m7003oC`00oel00?mV003oO@00oi400?nc003jiP10EL/0
1Eco002Po`0AZOl0K6;R003Ql000olH00?nc003oW000oh800?m^003oIP00oe/00P00oeL4003oD`03
003oC`00oeL00?mG00800?mG02h00?mK003oIP00ofH00?mZ003oM@00ogP00?n5003oR@00oi@00?nL
003oX`00oj/00?nc003o_`00omD00?;h001Co`00L_l0@6ci015`o`00oo000?oI003od@00omD00?oQ
003ol`00lOl00<ko002co`0e8?l004Co0021o`00H_l0N`?o0;<0l0077Ol02G3o0036o`00`ol007;o
0033o`00eOl00:Co041kl@0[eKH00?nW1000oj<01`00ojl00?nk003Qk011E/000=7X003oZ`00oj00
0P00oi403000oiT00?nE003oS@00oi400?nX003[lP00k>T0@:Fl003o]`00ofh00?mG003o>0800?lX
00<00?lQ003o6@00oaT03@00oaT3003o:00A003o;000ocP00?m2003oG`00m;h00>S6003oaP00d_l0
0?o6003oU@00ogd00?mC003o>000obP00?lU003o7@00oaH00P00o`X00`02o`P00ol500Go000200Go
00D05?l000@06?l001co000Po`008Ol00P0So`002P0Po`008ol0023o000Do`000ol5003>V000ocP0
7?l002Oo000[o`0803?o0004023o000>l4<00?lY003oF`Cooooo00?o0000ooooooooool01_ooool0
027ooooo00Go0000oooooooooooooooo04Ko000904;o000303Oo000co`00<ol000D0<ol000@09ol0
02?o000So`008ol00P0Po`0501Co00H01Ol000D00ol5003o2P00o`X00?l:003o3P04003o6@03003o
7P00ob400?lU00<00?lX0P00ob`01000oc@00?lh003o>000oc`2003oA`0C003oE`00ofH00?m^003o
O@00oj/00=gd0233nP00X?l0=i[l0036o000on400;kh002Ao`05S_`04I[h003lf@00ojT00?m^003o
G`02003oE`03003oB`00odL00?m700800?m;0P00odL4003oE`0]003oH`00ofH00?mV003oM@00ogd0
0?n5003oT@00oj000?n_003o/`00ok/00?o6003ocP00on404i?o01Uko`00iOl00:oo003lm000o=T0
0?o:003o`P00olh00?oI003]l`00Y?l03E7o001Wo`00O_l009Co002co`0L?Ol093;o024/o`00Hol0
0;_o003Yo`00hOl0@73a0032o`00ond00?oF003ocP00kKX00?nP00<00?nD00/00?nL003oY`00ok/0
0?oB002[o`00hN/00?nc003oU000ohD00?n1003oO@02003oLP0<003oN@00ok/00>?<003oS@00l:/0
0?oB03o0bP00gHd00?lh003o:000ob400?lM3P00oaT00`00oad00?lI003o:002003o:00@003o>000
od000?m?003oMP00oh400?2c035Qn000m<H00?mm003oG`00odl00?lk003o<000ob400?lI003o4P80
0?l:00H01?l300Go0005o`001Ol001Co000Ao`0301Co000301So000Po`008ol000L08ol000D08?l0
00co0`07ob`07?l002So000303?o000303Oo000oo`00@_l00080@_l000H0?ol003So000co`00:ol0
023o000Co`<4ooooo`03o`000?oooooooooo00Kooooo000Qooooo`05o`000?ooooooooooooooo`1:
o`002@12o`000`0oo`00<ol003?o000203?o000302oo000co`009ol000@08ol000H08?l001So000D
o`005?l0017o000=o`0500Go000300Co0`03o`<00?l:00800?l:00D00?l>003o6@00oad00?lY003o
;006003o:003003o;000oc000?lh00800?lh00d00?lk003oA`00odL00?m?003oF`00og800?mm003o
R@00ok<03Jgl03QAl@00j>T00?o>00800?nk00T00?oU01j0n000omd00=;o0036m00[Y=000?mb003o
H`00oe<02@00odL05`00oe<00?mG003oE`00of<00?mV003oKP00ogD00?n5003oT@00oi`00?ng00:U
m000olX00?oF003:l000ond00?cl002:o`00]o`00?oY00Van000om800?no00800?ng00L00?o2003o
g@00dOd0@4;J003Bo`00`_l01F3o00800>7o00D00=Ko002Wo`0[A?l00;oo003Qo`02003lo006002[
o`0iBol00?cd003o_`00ojl00?nL0P00oi@04P00oi400?nD003oU000oj000?o300V3l000]ol054co
003/cP00ohd00?n1003oM@00ofX00?mV003oG`00of<00>6A003oH@800?mO00H00?R_003oR@00od@0
0?l/003o9@00oad3003o6@800?lF00L00?l:003o4P00o`X00?lB003o2P00oaH00?lD00D00?lI01<0
0?lQ003o:000obP00?l`003o@000od/00?mK003oKP00oj002K3X00:Qj@00oj`00?mZ003oD`00odL0
0?lh003o:000oad00?lB00800?l:0`05o`000`0=o`005?l001Co000201Co000301co000So`008ol0
00<08ol000`09ol002?o000[o`00:ol002Oo000[o`009ol002_o000_o`00<ol003Oo000ko`0804;o
000403oo000go`00<ol002Co00Cooooo00?o0000ooooooooool01_ooool0027ooooo0_l00002oooo
o`T0@_l000<0>ol003?o000co`001@0co`000`0_o`008ol002?o000302?o00805?l000<03Ol000Go
0005o`001005o`000`04o`<00ol5003o2P02003o2P09003o4P00oaT00?lI003o;000oh400?m@003o
>000oc<00?lX00800?l/00<00?l`003o>000ocP00P00ocP06@00oc`00?m7003oA`00od/00?mG003o
IP00gK<00>76003oZ000o<X02KCh002`o`00eO000?nT003oW000ojL00?SM002Lm000ojP00?nH003A
]`00mM@00>RT003oF`00od/00P00odL00`00od@00?m0003oA005003oA`800?mG01@00?mK003oIP00
og800?nA003oTP00oi`00?nW003]i@00__l00?3d003>o01J=N801Foo002jo`00[Od00?oQ003ocP00
okl00?ng003o[`800?n[01L00?ng003oeP0KHol00?3h003ok@00^ol0:57o003ho000ooP00?Co003:
o`0[Dml00:oo003Uo`00ond00?oY003ol@10U^H00:_o003o_`00oj000?nD003oR@02003oQ@0<003o
R@00oi400?nD003o/`00on400;ko01^>o@00gM800?nH003oO@00ofh00?mV0P00oeL2003oC`08003o
C000odL00?m;00;0Q@00b/<00?lh003o:000obD2003o6@03003o5`00oaH00?l:00@00?l:00D00?lB
003o2P00o`h00?l=003o2P05003o6@0B003o9@00obP00?l/003o?@00odL00?mG003oKP00o<H009Go
00mBo`0/R^400?n=003oJP00ohL00>bX003o>000oaT00?lB0P00o`X01005o`001?l300Go000Bo`03
01Co0003023o000So`008ol000<08ol000<0:?l002oo000_o`001`0co`000`0ko`00@_l004;o0005
04;o0080A_l000D0AOl004;o0012o`00@_l003Oo0003ooooo`;o00002?ooool0027ooooo00Ko0000
oooooooooooooooo04[o0016o`0704;o000303oo000go`00<ol000@0<ol000<0:ol002Oo000So`00
0`0So`00100Ho`005?l000go0004o`<200Go00801?l300<00ol500;o2000o`X00P00o`X2003o3P80
0?lI00D00?lU003oB000k<H00?mO003oA005003o>003003o?000od@00?m700<00?m70P00oe<02@00
oe/00?m^003oV000W?000?oF0032o`00Y?l00?G?003o[002003oS@0<003oU@0=_>D05G?l003oY000
ogT00?m^003oN`00ofL00?m;003oA`00od000?ll1000ocP06@00od000?m7003oB`00od/00?m?003o
E`00of<00?mV003oO@00ok/00>K?003o/`00ol<00?c`041`o@0UB_l00:3o002co`00n?000?Sl002c
o@00omT00?o2003o/`00oj/00`00oj<05P00ojL00?oB002[m@00olh00?oB0036o005M?l00?o]003o
j@00n?P007[o03<Yo`0;>ol00>7o003og@00omD00?oB003Eh@00hO@0@<2d003oV000ohP5003oQ@0>
003oS@00oiP00?n_003odP00U?l00?3B003`aP00oj@00?m^003oG`00oeL00?m;003oA`00od03003o
>004003o@00I`6X00?l/003o7@800?lI00D00?lF003o3`00o`X00?l:003o3P03003o2P03003o3P00
o`X00?l:00800?l:00<00?l>003o4P00oaT00P00oaT05000ob400?lX003o<000ocd00?m7003oE`00
ofh00?nH003o``00Y?l00?no003oU@00oh40:kVd00G0T000oc000?lQ003o6@00o`X00_l80P05o`00
1P09o`004_l001Co000Do`006?l0023o00@08ol000<0;ol0033o000co`001@0co`000`0go`00?ol0
03oo000504;o000304[o001>o`00C_l00080DOl000<0C?l004ko001>o`000P16o`04ooooo`03o`00
0?oooooooooo00Kooooo000Qooooo`04o`000?ooooooooooooooo`80DOl02012o`000`0ko`00<ol0
03?o000403?o00@08ol000L07?l001Co000Bo`000ol5003o>000oa@00?l?00@00?l:00h00?l=003o
2P00o`l00?lD003o6@00ob400?lX003o<`00odX00>_L003]f`00ogd00?m;003oA`800?m501d00?m:
003oDP00ogP00?m^003oFP00oe800?mE003oE`00oe`00?mY003oO@00llX00=c`02`^o`0[J_400??S
003oV`00ogd00?mh003oM@00oh<00?nj00JZo@00om800?m[003oFP00odh00?m7003o@002003o>`H0
0?lh03800?lm003oA`00odL00?m?003oE`00oel00?mY003oN`00ojh07=OS02[Ei017MoX03hOo006Y
n00[UNh00?oG003o`000okd00?oL0127o`00onH00?nk003oZ@00oj400?nI003oU`00oi@00?nL003j
/`00oj`00?nX003o]P00g>@00?[L003oc000oll00?oT003SnP0HNOl02J[o003jnP00omT00?o5003o
^000oj/00?nX003oWP00ohd00?n3003oNP800?me0P00ogP04@00oh<00?n=003oW000okd00;7h03=k
nP00g?X04kK0003oN000oel00?mG003oA`00ocd00?lh003o<`00ob/00?lX00800?lV00D00?lN003o
6@00oaL00?lB003o3@0;003o2P04003o3@00o`X00?l?003o50800?lI01@00?lN003o:000ocP00?m6
003oIP00ofT00?mh003oTP00j=@0<GoE00BHo`00n^H09LG?003Ya`00of/00?m?003o<`00oa`00?l=
003o2P801Ol000D02?l001Co000Do`005?l0027o000402?o000302ko000ao`00<Ol000<0<ol00P0h
o`000`0mo`00@_l004;o000304;o000304Oo001<o`00DOl00080Col01`1Ao`000`1?o`3ooooooooo
o`02ooooo`03o`000?oooooooooo00Kooooo000Qooooo`06o`000?ooooooooooooooo`1Ao`00A_l0
1P12o`000`0ko`00=ol003?o000403?o000302oo000So`008ol000<08ol000L06?l001Co000=o`00
0_l<003EbP00od000?lQ00800?lI00<00?lF003o4P00oaH00`00oaT02@00obD00?ld003oC000odl0
0?mG003oY000ZnP00?mb003oFP02003oC`06003oF`00oh400?mj0036cP00j;L00?mZ0`00ofH02P00
ofh00?mb003oQ@00ok000Y[o002Eo000d_P00<[]003X_@00ofX2003oIP07003oJP00ohT00;OQ003o
/`00oel00?m;003o@P05003o>0800?ld1000ocP03P00od000?m7003oC`00oeL00?mV003oLP00ogd0
4JgE01>Tm@2G:L00>h;o003Qg@00okL00>bn0P00oi`02@00ojL00<;I01ZEo@00W?l00?SB003oX`00
oiP00?nA003oR@02003oQ@0E003oR@00ohl00?nD003oW000oj000?n[003o/`00okl00?oI003lo00/
OmD00:3o003Mo`00k>T00?no003oZ`00oj<00?nD003oS@00ohD00?mh00<00?me01<00?mb003oM@00
ogT00?n5003o]`0XOoP00jCo00hPo`00o>400?nX003oO@00of<00?m?003oA000ocP00?ld003o:`00
obP00?lQ00<00?lI00<00?lF003o4P00o`X04000o`X06P00oa800?lI003o6@00ob`00?m0003oJ`0/
^=T00?360036e@00ok/00?C]04EN`00N3Ol0@6C^003`g@06_]@00?3/003IdP00ogX00?lU003o4P00
o`X01?l300Go0009o`004_l00P0Do`0402?o000302_o000_o`00<ol000<0<ol000<0=ol004;o0012
o`001@12o`000`1Ao`00C_l0057o0007057o000405Go001Io`00FOl005go00Cooooo00?o0000oooo
ooooool01_ooool0027ooooo00Co0000oooooooooooooooo0P1:o`000`16o`00@_l004;o000504;o
00H0<ol000D0:ol002?o000So`008?l002?o000201Co000:00Go0000obH00?n9003hS@00oeL00?ll
003o:@00oad00?lI003o7@800?lI01l00?lU003o;000od`00>Fn003oX000ogX00?nk042Uf`00ohD0
0?mV003oG`00of<00?mZ003>/`10`:400:3h003oY000oh400?mm003VV@00ohD00?mm003oP@00n;/0
0;ol003In000olH00>c:03nFe@00ogD00?mS00<00?mG00D00?mO003oQ@00^]H00?mK003oA002003o
>003003o=000ob`00?l/00<00?lX00<00?l/003o<000ocP00P00ocP03000odL00?mC003oH`00ofX0
0?mi003oR@00ojP08[W`07]F`000Yo`00?cB003oV0800?n=00P00?nA003oW000ok/0:hkE0032o000
j=800?nL003oU0H00?n501D00?n9003oT@00oi@00?nP003oY`00ok/00=W`002To`0m?Ol0;C3o0021
o`00m?P00?o3003oZ`00oi`00?nD003oQ@00ogd00?mh003oLP00ofX00P00ofH04@00ofX00?m^003o
N@00iKl00?n_02^nhP00b^`00<Kh003I`P00ohd00?n9003oKP00od@00?lh003o;000obP00?lM00<0
0?lI00<00?l>003o2P00o`X01P00o`X01P03o`D00_l800;o2003o`D00?l:00?o1@H00?l:0P00oaT0
6@00ob`00?mm003F[P0XT^T00>bk003:aP00V?001K7U003hm009J?l0A6go00:2d@00oh000?mZ003o
LP00ocP00?lQ003o4P00o`X00ol500Co0`05o`004_l001Co000Ho`00100So`000`0_o`00<ol003?o
000203?o000303_o0012o`00>ol000D0@_l02@1Ao`000`1Io`00G_l0067o0003067o00Cooooo00?o
0000ooooooooool01_ooool0027ooooo00Co0000oooooooooooooooo0`1Ao`0504;o0080>ol01@0c
o`000`0Wo`008ol002?o000202?o000<01co000Do`005?l000Go0000oa800?m0003o]`0P[N400?nc
003oC`00ob`00?lU0P00ob42003o:00O003o=000od@07;Rk042hY@00Z>P00=gY003A`P00ohd00?mm
003oQ@00hJ@00?n5003oY000l>P00=g/003o]`00b/<00?n/003:l000ojP00?n`003oW000olh009cl
003Ai@00oiD00?nA003o/000ofH00?mG003oC`02003oA`07003oB`00oe/00>am003oA000ocP00?lc
003o;008003o:00L003o;@00ocP00?ll003oA`00ofh00?mn0330Z000ohd00?nP01bdm00VO?d00?oB
003Ij@0cZLh00?n9003oN@00ogd00?n1003oT@00oj/0EJRK0032n000ok/00?nL003oT@00ohD00?mm
003oN@800?me01D00?mm003oQ@00ohD00?nA003oU000oj<00?nc003obP00^o`0:h3E05]7o`00b_l0
0>7l003he@00ojl00?nP003oU000ohD00?mm003oM@00ofX01@00ofH03P00ofX00?mb003oO@00oi`0
0?3:01VNo`00fO@00?nk003Fg@00og800?m;003o>000obP00?lV0P00oaT01@00oaH00?l>003o2P00
o`X00?l>00<00?l:00D00_l800Go0003o`D01Ol000Co0`0200Go000400?o1@05o`000_l700;o20@0
0?l:01@00?l>003o6@00oad00?ld003oFP00oeL00?mO003oQ@00iN`00?nT003l^`00m>4009Cl003o
[`00ogD00?mC003o@000oc000?lQ003o6@800?l:00D01?l300Go000?o`005?l001co000302?o0003
02_o000co`00<ol00080<ol000<0>ol003oo0012o`001012o`000`1:o`00C_l0057o0006057o0004
05Wo001Qo`00GOl005ko00@0HOl01?ooool00ol0003oooooooooo`06ooooo`008Oooool01?l0003o
ooooooooooooool2057o000304Ko0012o`00@_l000@0@_l000<0=ol003?o000co`000P0co`000`0`
o`00:ol002?o000302?o00805?l002`04Ol000Go0000o`l00?m7003d`P00d_@00?mj003oC`00oc@0
0?l`003o;000obP00?l]003o=000oc`00?m;003oG`00ohD00?nc02bho000iM800?n/003oX@00fNT0
0?3Q003oaP00[o@0@9;m02U3o`10S/L009So003:o003Kol009Sh01iUo000d^40>jgd003AcP00ojL0
0?n1003oLP00ofX00?mJ003oC`800?m700H00?m4003o@000od000?ll003o>000oc@;003o:00=003o
=000ocP00?m4003oG`00]md07;cU003o_`00olH00:oo003KiP00oi`00?nc003oN@03003oKP09003o
N@00ojP00?3M01F/m`02/O`0>kSU003l^`00ohT00?mi00D00?me01<00?n1003oQ@00ohd00?nD003o
X`00ojl00?o6003oh@00_Od0NcOe003/o`00onT00?o:003o^`00ojl00?nP003oS@00ogd00?m^0080
0?mV00<00?mS003oF`00oeL00P00oel03@00ofH00?mZ003oN`00oiD00?oF06iJo`0=G?l00=WQ003o
_`00of800?lh003o:000oah00P00oaT00`00oa800?l:003o2P04003o2P0400Go0004o`<01Ol000?o
1@H01Ol000@01?l200Co0`03o`D00_l80`00o`X02000oa800?lI003o8@00ob/00?ll003oC`00ojL0
=l3Q0P00oh402P00ok<05JGl03M_o000hhl00?m?003o@000oc000?lU003o6@00oaH2003o2P0400Go
000=o`005?l001So00<08ol000<09ol003?o000co`000P0co`000`0go`00@_l004;o000304;o0003
04Ko001:o`00DOl000D0DOl000D0EOl0067o001Io`00HOl005go0005067o00Cooooo00?o0000oooo
ooooool01_ooool0027ooooo00Oo0000oooooooooooooooo057o001:o`00A_l000H0@_l000<0=ol0
03?o000co`000P0co`000`0^o`008ol002?o000202?o000301So000Do`005?l000801Ol000L00?l?
003o<@00ofX0:8[M003o^`00of<00?m400<00?lh02800?lk003oA000od/00?mC003oI`00ogd00>Fk
0032l000iOP02I[l0037j`02T_`04IKo032Qn000YoP00:od002To`00gN`00=GI003o^`03[_<00?nj
003dcP00omH00;[/003oY000ohD00?mb003oIP00oe/00?mB003oA`00od@00?ll0`00ocP00`00oc@0
0?l/003o:003003o:0800?lU00<00?lQ003o:000obD01000obP03000ocP00?ll003oB`00ofh00?nc
00ULn010R^X04Hko003o/`00oh400?mb003oH`800?mO00/00?mV003oKP00ohD0>l3>03=8o`0XH?l0
0;O`003oX000ogd00?me003oKP02003oIP0G003oJP00og<00?me003oP@00ohd00?nH003oY`00ok<0
0?o6003of@00aOl005Oo00VBo`00n?P00?oI003odP00on400=GQ003o^`00ogd00?m[003oIP00oel0
1P00oeL03P00of<00?m^003oT@00olX02K3o02Q=o`00ol800?mj003oC`00ocP00?lX003o7P00oaT0
0?lB1@00o`X01003o`D01?l300Co0P04o`<;00Go000300Co0`03o`D00?l:00800?l:01800?lB003o
6@00oah00?l/003oC`00_[h00?nE003oG`00ofh00?n_002Pj@09[N`00?n7003oI`00od/00?ld003o
:000ob42003o7@03003o4P02o``01Ol000805?l000@08?l002?o000So`009ol00`0co`000`0ho`00
@_l004;o000404;o00L0DOl00P1Io`09067o00Cooooo00?o0000ooooooooool01_ooool0027ooooo
00Co0000oooooooooooooooo0`1Ao`0504;o000703Oo000co`00<ol002oo000co`00;ol002So0003
02?o000>023o000Do`005?l0017o0004o`<00_l8003o5`00ob`00?m4003`cP10Mll00?Bn003oD`00
odL2003o@00P003oC000ohD00?mS003oI`00m;h00?nX003lh@14B_l0@4W002aAo`0VL?X00?3U00:U
n000ojP00?nL003o^`0X_?`00>c:003oQ@00oh400?ZX003oO@00ohT00?n_00:Jo`00ol800?n5003o
KP00oel00?mG003oBP00odL3003o>003003o=000ob`00?lX00<00?lX00@00?lU003o6@00oad00?lM
0`00oaT03`00oad00?lX003o:000obP00?l/003o>000od@00?m^003`bP00olh0>4[o00Uoo`00b]@0
0?mf003oG`03003oE`0:003oG`00ofH00?mi003oX000e^40=kcY01c0dP00oj`00?mi003oKP@00?mV
01D00?mY003oM@00ogd00?n=003o/`00ok/00?o>003of@00onT009;o08@3``0?;ol00<Oo003ln000
Z?`03G?o003Bl000j<800?n1003oIP00oe/00`00oeL4003oD`0>003oE`00ofT07;SM01Vlf@00d^D0
0?nk06R0b00=`:l00?mG003o@000ob`00?lI003o5P00o`h3003o2P0300;o2005o`001?l300l01Ol0
00<01?l300?o1@00o`X00P00o`X06@00o`h00?lI003o8@00oc@00?m8003oB`00odL00?mG003oKP00
oiP008co003ja@00a/X00?mS003oB000oc@00?l`003o;000od/00?m8003oE`03o`H03Ol001Co000P
o`000P0So`000`0[o`00<ol003?o000203?o000303oo0012o`00@_l00080@_l000<0B_l004ko001A
o`001@1Ao`09067o000306Go001`o`3ooooo00?ooooo00?o0000ooooooooool01_ooool0027ooooo
00Oo0000oooooooooooooooo057o001>o`00A_l000@0@_l000<0>ol003Oo000co`000`0co`000`0[
o`008ol002?o000202?o00<05?l002d02Ol000;o3000oad00?lV003o?000od/00?n=003`l000ohD0
0?mK003oD`00odl00?mC003oQ@00a^T00?nE003oS@02_>d00=Gd002Do`00Y?`00;Oo0021o`00_nH0
0?nP0330]`00og800?mf003Ei@00m;L00>7I003oMP00oel00?mQ003oJP00ogT00?nc016Qm00IXOl0
0>R_003oKP00oel00?mG003oA`00oc`00P00ocP00`00oc@00?lX003o:003003o:003003o7000oaT0
0?lM00H00?lI00h00?lM003o8`00obP00?lX003o>000od000?m?003oMP00olh04IgY003lf@00ml00
;<2A003oC`800?m700X00?m;003oE`00of<00?mm003oU@0eQ_D00>cM003oW000oh400?m^0P00ofH0
5`00oel00?mS003oIP00ofH00?m^003oO@00oj000<K`003Qm00;MOl00<;h003do000U?l0V@2?070P
n@0EEOl0@6C0002_o`00omd00?n_003oS@00ogD00?mY00800?mG00<00?mC003oB`00odL00`00odL0
3@00odl00?m^003h^P00ogH00?nc003oLP00gK<0A83E003/`P0X`:`00?l`003o6@00oa800`00o`X0
0`02o`P00ol500Go000B00Go000L00?o1@00o`X00?l:003o2P00oa@00?lI003o8@00ob`00?lh003o
@000odl00?mf003oW000k>D0:Ygm003oi@00o<X00?mO003oA000od000?m8003oY000hL<00?le00;o
2@09o`005?l001co00808ol000D09ol002_o000[o`00<ol003go000504;o00H0DOl000<0EOl005Wo
001Mo`001`1Qo`000`1Yo`00IOl0073o0004ooooo`03o`000?oooooooooo00Kooooo000Qooooo`04
o`000?ooooooooooooooo`80DOl000H0C_l004;o0012o`00@_l003oo000ko`0203?o000302oo000c
o`00<ol000@08ol001h07?l001Co000Do`004Ol000Go0000ob400?29003NS000ofX00?mf003oR@00
fO@00?nA003oKP00oel00?mS003oJP00e;l00=Wh003oaP00dNT00<?o0025o000olH00?nn003MeP00
iOl00?n^003oMP00ofL2003oF`03003AV000of/00?mK00800?m?00h00?mD003oF`00ofh00?nA003]
j@10ZMl00?nX003oO@00of<00?mC003oA`00oc`00?lh003o=0@00?lX00<00?lU003o6@00oaT02@00
oaT03000oa`00?lU003o:000oc000?m0003oD`00eJl088kd0036[`00ohD00>^:003oB`800?m000/0
0?m4003oA`00od/00>R=0170bP00k<X00<;`003oeP00oi`00?mm003oIP02003oG`<00?mG01@00?mO
003oJP00eJL00?oF002=l010^;400=W/019io00APol06W7o06HDo`0Q>ol099[o003`o`0I<_l02K7`
003o]`00ohd00?mb003oH@800?mG00<00?m;003oA`00odL01000odL00`00od`00?m?003oC`02003o
C`06003oF`00o;L00?n9003oB000obT00?lG0`00o`X00`02o`P00ol500Go000200Go000300Co0`05
o`001Ol000l01Ol000@00ol5003o2P00o`X00?l:0P00oaT05@00obD00?lX003o=000odP00?BW0032
eP02U_P0@hOa003o/`00ogd00?mS003oD`00odl00?mf003XaP00oh400?lY003o3@05o`004Ol001So
000202?o000502Oo000co`00<ol003?o000fo`001012o`000`16o`00B_l0057o0004057o00T0HOl0
00@0JOl0073o001`o`00KOl01?ooool00ol0003oooooooooo`06ooooo`008Oooool01?l0003ooooo
ooooooooool2057o000504ko0012o`00@_l004;o000ko`000P0co`000`0_o`00<ol002_o000402?o
000F01co000Do`005?l001Co0005o`000ol5003o:@00ogd05K7L003oeP00o=d00?3U003Yj@00oiT0
0?n5003oP@00oi@00?n9003o/`0XKol0?fco003>l0800?n_00L00>RL003oQ@00oj002L3/003Dg000
ogH00?mG00800?m71000od02003oA`0<003oE`00ofH00?mm003o/`00c_l00?nk003l/`00ohT00?mG
003oA@00oc`00?lh0P00ob`00`00obP00?lU003o8@0=003o6@0:003o7@00obP00?l`003o@000oel0
0?n9003ocP00og800?m?003oD@@00?lh00X00?m0003oA`00oeL00?n5003Uj@1:J?/00;_d0032j000
oj000?mS1P00oeL05@00of<00?mZ003oQ@00oi400?nL003o^`0LWO`00>Wl00>do@02AOl00V3o002n
o000on400?c`02RMo00eHOl00:_B003oO@00oel00?mG003oC`03003oA`03003o@000ocP00?lh00D0
0?lh00L00?ll003oB`00m:@00>bP003o<000oad00?lB00<00?l:2P05o`0200Wo000300Go000=o`00
2Ol000T01Ol000@00ol5003o2P00o`X00?l>0P00oaT02P00obP00?l/003o?000oeL00?n/003`]`00
[^H00<KM003oU@00ogh2003oKP0<003oW000c^400?mG003o<000oaL00_l800Wo000Do`007?l002?o
000Wo`00;ol00P0co`000`0ko`00@_l004;o000204;o000304ko001Ao`00DOl000<0DOl000<0EOl0
05Wo001Qo`001P1Qo`000`1Vo`00IOl0073o0002073o00Cooooo00?o0000ooooooooool01_ooool0
027ooooo0_l00002ooooo`80DOl000D0Aol004;o0012o`00?Ol003?o0002037o000302So000So`00
8ol000808ol001T07_l001Wo000Do`005?l001;o000=o`001Ol000?o1@00o`l00?lQ003oD000ofT0
0?mh003oS@07Xmh00<;e003j`P00kO000LSe003]c`0QE?d00<;Q0030k@00c=@00?n200800?mL00L0
0?mV003j]P00mK/00>NL007E[P00odd00?lm00@00?lc01000?lf003o>`00od000?m?003oN000ol80
0?3F04Y>k000^oP0:l3Y003mW`00oel00?m5003o>000oc<00?l^0P00obP00`00oa`00?lI003o6@03
003o6@07003o5`00oa800?lD003o3@00oa800?lD003o4P03003o6@0I003o7P00oc<00?mD002miP0F
eIh03]F`003oF@00oc/00?la003o:`00obh00?lX003o<000ocH00?lk003oBP00of`00?nQ003Fh@00
lm800>^[003oI000oeL00?m<003oBP02003oA`0F003oC`00oeD00?mJ003oH@00ofT00?me003oS@00
jn400;g`003obP00omX00=Oo01iSo`00g?D00?o5003o/`00ok000?fc003oZ000ogH00?mL003oE@80
0?m700<00?m5003o@000oc/00P00ocP01000ocH00?lc003o;@00oc02003o;@09003o<000od000>fX
003o9P00oaL00?l<003o2P01o`T01?l200L01Ol000<02_l000oo0008o`000P0Do`001`0?o`005?l0
01;o000?o`004_l000go000?o`001@05o`006`04o`800ol3003o2P00o`X00?lD003o6@00ob<00?lX
003o>000odD00?mO003oMP00ok@0;GGm00k3l`00hNH00?ne003cYP00lmT00=^m01KEQ`0HeGP00?ND
003NIP01od<03?l201Wo000202?o000402ko000co`00<ol003So00@0@_l000<0C?l004oo001Ao`00
0`1Ao`02067o000305oo001Qo`00HOl000@0HOl00P1`o`000`1[o`00L?l0073o0003ooooo`;o0000
2?ooool0027ooooo00Co0000oooooooooooooooo0P1Ao`001`16o`00@_l004;o000co`00;ol002Oo
000So`000`0Po`0201So00@05?l001d03Ol000Go0005o`000?l:003o4P00oaT00?l]003oB000oel0
0<ZL003o`P00POl00=[l002[o`02BOl04R3o003Xa`00ohT00<k:003oP@00oe<00?m0003oA000oeL0
2L3>003lW000odD00?af003o>004003o:00@003o;000obP00?ld003o>`00odL00?mG003oQ@00fNT0
7;Sd003Bj000oj`00?BT003oKP00od800?lh003o<0800?lX00<00?lM003o6@00oaT00`00oaT8003o
2P0<003o3P00o`l00?lI003o6@00obT04L1j003oC000oc000?m<003o@000obP00?lS0P00obD2003o
:009003o;000oc@00?m0003oF`00bZ<00KK4003oJP00ogX00?m;00H00?m701D00?m:003oD`00oeL0
0?mS003oIP00ogT00?nP003oW000oj000?O50025o`0TI?l00=Wl003o^`00oi`00?nA003oP@00ogD0
0?mV003oG000odl00P00odL01@00od000?lh003o>000ocP00?l`00D00?lX00H00?lU003o8@00ob40
0?lQ003o6@00o`h2003o2P0300Co0`05o`001Ol000@01Ol000D02Ol000oo000Ao`005?l0017o0006
01Co000501;o000Do`005?l000Wo000Ao`001@05o`007001o`P00?l:003o4P00oaT00?lQ003o:000
ocP00?m4003oD`00ofh00=WF0025o`0kCOl00<kl003Xk000W?@00?o6003o^`00m<H00=WB003m[P00
ocT00?lQ00So0`0Do`008?l002?o000Wo`0303?o00@0@_l000<0B_l0057o001Ao`000P1Ao`000`1D
o`00GOl0067o0007067o000306_o001`o`00L?l00080L?l01?ooool00ol0003oooooooooo`06oooo
o`008Oooool01?l0003oooooooooooooool2057o000704[o0012o`00@_l003?o000Boa403?l3017o
000301Co00803Ol000<04_l0017o000Ao`000`05o`004`02o`P00?l:003o5P00ob400?l`003oB`00
oel00?bW003Jo`1A3Od0=D?o040nkP0PDOl0@9ka003Qa000ofX00?mS003oE`00oc`00P00oc001`00
oc`00?2[003XO@00obd00?lU003o8@00oad00P00oaT05000oad00?lU003o:000obP00?le003o@000
odl00?n5003oS@00j=804HKd003oU000og800?mO003oA`00ocP00?ld003o:000obD00?lM1000oaT0
0`00o`X00?l>003o2P07003o2P04003o3`00o`h00?lF003o6@D00?lQ1000oaT2003o7@0:003o:000
ob`00?m0003dU@00k<H00?nY003oD`00odL00?m0003oA0800?lh00D00?ll003oA000odL00?m7003o
C`02003oE`0D003oIP00ofX00?mi003oR@00oi@00?nc003Mk000POl00?cY003o^`00oi`00?n=003o
O@00ofh00?mZ003oE`00odl00?m7003oA000oc`2003o>006003o;000obP00?lX003o:000obD00?lM
0P00oaT01000oad00?lI003o5P00o`h2003o2P801?l31@05o`001009o`003Ol001Co000Ao`0=01Co
000300go0009o`001Ol000801Ol001X00_l7003o2P00oaH00?lI003o:000oc000?ll003oB`00oe/0
0?m^003j]@1KJO`0@7?V01`fo`0XLol00<;M003oT000ofh00?mK003oD000odD00?lJ00?o1@05o`00
5?l001So00808ol000@0:ol003?o000co`00>ol00`12o`05057o000305co001Qo`00HOl000D0HOl0
00<0KOl0073o001^o`00101`o`04ooooo`03o`000?oooooooooo00Kooooo000Qooooo`0=o`000?oo
ooooooooooooo`1>o`00DOl004[o0012o`00>ol003?o000@obd06L2500;o5`0300?o1@0300;o:P03
o`T01Ol000@01Ol001D00_l8003o2P00oaH00?lM003o:000ocX0:<2@003oQ@00oj@0@;3?002no`00
[?l00?3`02a=o`00hMd00?nQ003oG`00odL00?ll003o;000obP00P00obD00`00od000?lU003o7007
003o6@0A003o9@00obP00?l`003o@000odl00?mS003oO@0I_>4088?o003hg@00oh400?mS003oC`00
od000?l`003o:000obD00`00oaT00`00oa800?l:003o2P02003o2P03003o3P00o`X00?l:00L00?l:
00@00?l>003o4P00oaH00?lF2000oaT01`00oad00?lX003oA`00oh400?mG003eP000od001`00ocP0
6`00od000?m7003oA`00oe<00?mG003oG`00ofH00?me003oO@00ohd00?o5003ol00kLol00>Gl003I
m000ok<00?n=003oO@00ofh00?mV003oFP00oe<00?m7003oA000oc`00?lh003o=003003o:003003o
9P00oad00?lI00<00?lI00H00?lB003o2P00o`h00?l:00;o1`04o`<500Go0003017o000Do`003Ol0
01005?l001`04Ol000Wo0005o`001Ol000?o1@00o`X00?lB003o8@00oc000?ll003oC`00ogX00?m^
003oO@00n[d008Go003dm000Zol0>Pko002go`00oj/00?mO003oA`00oc@00?lQ003o4P03o`D01Ol0
0P0Do`0302?o000302_o000co`00<ol000<0@_l000<0A_l004ko001Ao`000P1Ao`000`1Do`00GOl0
067o0005067o000306go001`o`00L?l000@0L?l01?ooool00ol0003oooooooooo`06ooooo`008Ooo
ool0;?l0003oooooooooooooool0DOl004ko001:o`00@_l0043o000co`007?l000;o8`00U:<00?aN
003o@000eGX00?n@003o5P00o`X00ol500Go0003o`D00_l8003o2P00oaH00?m@003o@000ocP00?m=
003IaP00omT00;?`002cj@00n=H00=KU003o^`00[n400=GY003oN000oeL00?m0003o<000obD00?lM
0P00oaT2003o4P07003o3`00o`X00?l:003o2P00o`h00?lB003o5P02003o6@0@003o9@00obd00?m0
003oD`00of<00?mm003/dP10F>800?CI003oR@00ogd00?n2003oE`00oc000?lX003o9@800?lI00<0
0?lF003o4P00o`h05@00o`X00`00o`h00?lF003o5P02003o6@05003o7@00obD00?l`003o=000oc<0
1000oc000`00oc@00?lh003o>002003o>00G003oA@00odL00?m?003oE`00of<00?mV003oKP00ogd0
0?n=01BIh`00[ol0Z1ZC0022o`00W?`00?3M003oU@00oh400?me003oIP00oel00?mC003oB`00od@0
0P00ocP01`00oc000?lX003o:000obP00?lN003o6@00oad00P00oaT00`00o`X00?l>003o2P02003o
2P0300Co0P05o`001Ol000801Ol000<02Ol000go000=o`004`0Do`00700=o`001Ol000Go0003o`<0
0?l:003o4P00oc000?nL003oG`00ohT00=;M003MdP10YLl06/_S003oaP00ol800<;o0032m010/<L0
0?nH003oI`00odP00?l`003o7P00o`X00ol500Go000Ao`0201Co0006023o000So`008ol002_o000c
o`00>ol00P12o`000`16o`00C_l0057o0002057o000305ko001Qo`00HOl000@0HOl000<0IOl006Wo
001]o`001@1`o`04ooooo`03o`000?oooooooooo00Kooooo000Qooooo`04o`000?oooooooooooooo
o`80DOl000d0C_l004;o0012o`00<ol001co0000ohD00?ll003EcP00d]T00?bk003oB000ob400?l?
00@00?l:01H00?lF003o9@00ofH00>RX003oE`00of400?nX002[o`1jP?000?nP003oO@00ogX00?mm
003oX000eNP00>6h003dU@00odP00?l`003o8@00oaH00?l>2@00o`X04`00o`h00?lI003o6@00obD0
0?le003oE`00ohD00?n1003oS@00l<8009Sl003:k@00oj`00>Fk003Lh`0T`7d00?lh003o:000oad0
0P00oaT00`00o`h00?l:003o2P04003o2P0500?o1@02o`P01Ol000;o2005o`000`03o`D;003o2P07
003o3P00oa800?lI003o6@00oad00?lQ003o9@06003o:00K003o;000oc@00?lh003o>000od000?m7
003oD`00oeL00?mO003oIP00ogD00?mm003oS@00i]H01KSo01aoo`0=W_l00?od003`e@00oj000?n9
003oO@00ogT00?m[003oF`00odl00?m000800?lh00D00?l/003o:000obP00?lU003o7003003o6@03
003o3P00o`X00?l:00800?l:00<00ol500Co0P05o`000`05o`000`0=o`005?l001Co000401Co0003
017o000Do`005?l000d05?l001`03Ol000Go0004o`800?l:003o6@00od000?cF003hbP00iMd0>kc`
003XZ`00oi`00?o2003oQ@00oi`00?nW003oZ00=^?l00?o:003MbP00oel00?ld003o8@00oa800?l:
00Co0`05o`004Ol00`0Do`00100Ho`007_l002oo000go`0204;o000304[o001Ao`00DOl00080DOl0
00<0E_l0067o001Qo`00101Qo`08073o00Cooooo00?o0000ooooooooool01_ooool0027ooooo00Go
0000oooooooooooooooo057o000204ko0080@_l00280<ol002Oo000Eo`001ol5003o@000olh0?H3U
003/R@00bVh00?lV003o5P00oa800?lF003o6@00obD00?a^003oH`00olh00?mj00?=]@00fND00?o:
003Eh@00oi`00?mK003oE`00of<00>6[042lc`0P_/808;SF003oW000od000?lI0`00o`X200?o1@80
1?l300<00ol500;o2000o`X00P00o`X04@00o`h00?lI003o8@00od@00?3:0036k000b_000?S2003U
h@0BAol0R3cG002[k000k>`00?n2003oC`00oc000?lX00<00?lI00<00?l>003o2P00o`X00P00o`X2
00?o1@H01Ol000<00ol300Go0005o`000P04o`<200;o20P00?l:00<00?l>003o5P00oaT00P00oaT0
0`00oa`00?lM003o9@04003o:00J003o;000oc@00?lh003o?@00odL00?m?003oE`00ofH00?m^003o
M@00ohD00?nA003o[P00omH00;oo01Y3o`00omd00?nk003oX000oi@00?n=003oY000ojT00?nX003o
E`00odL2003o>004003o;000obP00?lX003o9@<00?lI00<00?lB003o2P00o`X00P00o`X00`02o`P0
1?l300Go000300Go00803Ol00P0Do`000`0Ao`005?l001Co000B01Co000J00Go0003o`<00?l>003o
8@00od/00?ng02C0h@00ogT00?mZ003oD`00ogH02l_?003oJP00oel00?mS003oP@00olX05DWo0036
k000cZ@00?m8003o<000oad00?lB00;o2004o`<200Go000700Wo0003o`D00ol900CoA`0Lo`00<ol0
03_o000204;o00@0DOl000<0G_l0067o001Qo`00101Qo`000`1]o`00L?l0073o0005073o00Cooooo
00?o0000ooooooooool01_ooool0027ooooo00Co0000oooooooooooooooo0`1Ao`0204;o000;03_o
000co`008ol0017o0002oal00?m^003oLP00hMH00>Ro003XN`00obD00P00ob405P00obD00?l`003E
X000okl00?SM003M`P00b^H00=7>003oNP10`7L00?m8003o@000od@00?mO003o^`00oj000?mJ003U
W000]m400?m?003o5P00o`X200Co0`H01Ol001L00ol500;o2000o`X00?l>003o4P00oaT00?lX003o
B000ofL00?nL003/n000Y?`0BAko002oo`00o=H00=gh0037]@00ofX00?ll003o:000oad00?lI003o
4P05003o2P0300Go0004o`<01Ol000L01Ol000T01?l300Go0005o`001Ol000Co0`05o`000ol500Co
0`01o`P01P00o`X00`00oa800?lF003o6@03003o6@03003o7@00obD00?lX00800?lX01/00?l`003o
>000ocd00?m7003oE`00of<00?mj003oO@00oh400?n=003oV000ojh00?oY003>o`10Ll000[Sd003o
dP00ok<00?n[003o/`00fMd02ISe0170Z`00m8D00?m7003o?000oc@00`00obP3003o6@03003o5P00
o`h00?l:00<00?l:0P05o`001004o`801Ol000Go0005o`0;01Co00807?l000L05?l002?o000So`00
6Ol002?o000Do`006?l000D05?l000d04Ol000?o0`00obD0>l1m003oV000ogX00?mZ003oF`00oc00
0?ll003oKP06bll00?mK00800?m?00/00?nT03N>h@00j=X00=WU003oQ@00oe/00?f7003o>000ob40
0?lB003o2P0200?o1@07003o3P00ogX00?mi007IJP0Go`<0;ol003_o000204;o000504[o001Ao`00
DOl0057o001Fo`001@1Qo`000`1Uo`00JOl0073o0006073o00Cooooo00?o0000ooooooooool01_oo
ool0027ooooo00Co0000oooooooooooooooo0`1Ao`003@16o`00@_l003_o000co`00:ol001co000=
o`000_l<003o=000ojP00;oF003oE000oc@00P00obP02P00oc000?m0003oE`00oh400?SQ081J^@00
UoD00?mn003oE`00od02003o<00:003o=000oe009H3:003oV000ocD00?l`003o@000m:@00?l>00Co
0`T01Ol000d01?l3003o2P00o`X00?l>003o6@00ob<00?l`003oH`00jN400?ng02S0aP0XDO`00?CY
00800?nT00@00;GN003oZ`00od`00?lX0P00oaT4003o2P0300?o1@04o`<01?l300l01Ol00P04o`<0
0`05o`000_l800;o2005003o2P800?l>1000oaT00`00oad00?lQ003o:002003o:006003o>000ocd0
0?mC003oH`00ogX00?C20P00oj004000oj/00?nW003o^000`_`009So040Vo@10Ml/0:8?o003odP00
ol800=G`01Ego`00mKd00?m^003oE`00odL2003o>0800?lX00D00?lU003o6@00oaT00?lI003o5P04
003o2P0300;o2004o`<01Ol000<01Ol000<03Ol0017o000Do`001P0Do`0301So00808ol000P08?l0
02?o000So`008Ol002?o000Po`008ol001co00806?l00`0Do`006@0:o`000_lK003o;@00[i`00?lU
003o7@00oaH00?lM003o;@00oi@02mG0003oA000ocP00?ll003oB00A`8400?mj0426jP0TZO@00?n=
003`/`00ogH00?b1003o:@00oaH00P00oa802`00ob400?n=002Lh@02oaT07?l002_o000co`00?ol0
04;o001:o`00C_l00080DOl000<0G_l0067o001Qo`000`1Qo`09073o00Cooooo00?o0000oooooooo
ool01_ooool0027ooooo00Co0000oooooooooooooooo0`1Ao`006@1:o`00@_l003_o000co`00:ol0
023o000Ao`000ol5003o6P00od@00>cA003jV@00od@00?lh003o?000od`00?mC003oI`00oj@00=W`
003Im000e^<00<;2003lN@00ob`00P00ob401@00obP00?m80032f@00fJl00?lV00800?lB00<00_lG
00Co0`05o`000P09o`00100Ao`005?l000go000=o`0400Go000D00?o1@00o`X00?l:003o5P00oah0
0?l`003oJ`00ogX00?mf003h[`00V?000=G/003oR@00ofh00?m/003oE`00k6H00?lU003o6@00oaH3
003o2P0300;o2003o`D01Ol001@01Ol00P03o`D5003o2P03003o3P00o`l00?lI00<00?lI01h00?lM
003o9@00obP00?lX003o=000ocd00?mf003o]`00l=801HKo003Mi@00Z?l00?oN003o_`00olX00:oo
009/o`2H0?D0@6SG003Uo`00m?@00?c`042Fm@00k=H00?n:003oJP00oeL00?m7003o?000ocP3003o
:004003o7@00oaT00?lI003o3P@00?l:00<00_l800Go0005o`000P05o`000`09o`005?l001Co0007
01Co00808ol000@06?l002?o000So`007?l01P0So`00100Po`008ol001co000Lo`0201Co000301;o
0009o`000ol500800ol500L00_l8003o2P00o`h00?lQ003oF`0CcJ<00?l/00800?lX01<00?lh003o
A000oel00?nH02B3o`09S_l00>kS003>[`05`7T00?l`003o8@00oad00?lQ003oB`00n;/00?mZ00oE
<P0Ho`008ol00080<ol00P12o`03057o000305Wo001Qo`00HOl000<0HOl000<0KOl0073o001`o`00
1P1`o`04ooooo`03o`000?oooooooooo00Kooooo000Qooooo`04o`000?ooooooooooooooo`<0DOl0
0240Aol004;o0010o`00<ol002_o000Io`002Ol2007o4000ob400?m0003oL@0CgZ`00?mO003oE`00
l8000?nI003oZ@00oiX00;3e02bUi`00ohD00?6a003mQ@00ocd00?lL003o4P00o`l00?lB003o9P00
oeT00?FB007o4`04o`800P08o`000`0=o`004_l001Co000401Co00804_l000@02_l000Go0005o`00
1Ol00P00o`X04@00oa@00?lN003o:000oc/00?m:003oH@00ohL009O]003Dh@00ohL00?mO003oB@00
ocP00?l[003o7P00oaT00?l?00800?l:00<00Ol900?o0`05o`000P05o`000`04o`801Ol000Go0003
00Go000400[o0007o`002_l000So00/01Ol000<00ol300?o1@00o`X00`00o`X00`00o``00?lB003o
5`03003o6@0N003o7000obP00?lX003o:000ocX00?m:003XV@00l9T00?3:003j_@00g=`00<;`02F_
nP0QXOD0AG3Q001To`1i1:X0;ScE001mo`0fCOl00<Gh0038nP00j=h00>2d003oS@00j8800?mJ003o
@P00ocP00?l[0P00obP3003o6@03003o3`00o`X00?l:00800?l:1@05o`000`0?o`004_l001Co0005
01Co00807?l000<08Ol002?o000So`00300So`001P0Qo`007_l001Wo000Fo`005?l001;o00803Ol0
00H02?l000Go0004o`800Ol@003oG000oc<2003o500I003o6@00obH00?m0003mTP00g;P00<3`002k
nP09a=l00?n:003oE000od800?lh003o=P00ocP00?mh00BTe000odX00Ol>00So0`0@o`<07?l002Ko
000ho`00@_l004co0002057o000305So001Oo`00HOl00080HOl000D0I?l006_o001[o`00L?l006ko
0005073o00Cooooo00?o0000ooooooooool01_ooool0027ooooo00Co0000oooooooooooooooo0P1A
o`006@1>o`00B_l004;o000ko`00;ol001_o2P07o`D00^a=003`W000hH`00>Fn003FeP00hld00>G`
003oR@00ojl02KSd003Mj@00c_000<[E003oOP00oeL00?m[003oLP00oad00P00o`X200?o1@0500;o
2000od`00?lh00Oo100=o`00300Do`005P09o`001Ol000Go0002o`P00?l:003o4P00oah00?lX003o
>000od/00?n5003d`P00hND0@<370036cP00of<00?m5003o<000obP00?lM003o6@00o`h2003o2P03
00?o1@04o`<01Ol000D01Ol000/03Ol001Co0009o`005?l000oo000Do`003Ol0017o000Do`001Ol0
00go000800Go000300Co0`03o`D00_l800@00?l:00<00?lB003o6@00oaT00P00oaT07@00ob400?lX
003o:000ocD00?m0003oB`00oeL00?mW003oN@00oiP00?no002ko000hoD00>7l002co`207>/0E3_m
003Bo`00onT00?o:003lfP00gO@01YGo02B7n01CP=805L2_003oD`00oc`00?l`00800?lX00@00?lM
003o6@00oaT00?lF1000o`X00`03o`D01Ol000Go000200Go0003017o000Do`005?l000D05?l0200S
o`000`0Po`008ol002?o000902?o0003027o000Lo`005?l000@05?l000<03Ol000Go0004o`<00P03
o`D2003o2P0H003o6P00of<00?n5003oOP05R/X00?nA00VMk@00hM800?mj003AW000bY400?mK003o
E`00oh400>Fg003oD000c7D00?m0003oP@00od`01NQP02So000oo`00B_l00P1Ao`000`1Lo`00HOl0
067o0002067o000306Go001`o`00L?l000H0L?l000<0O?l0ooooooooool00_ooool00ol0003ooooo
ooooo`06ooooo`008Oooool2o`0000;ooooo0`1Ao`006@1:o`00@_l004;o000co`005ol7003/S@00
oi`01I;6003oS@00ogd00?mK003oR000m>P00>G/003obP00o?0077Co01ETo`0gYN`00?nH003oA000
oc<00?lU003o3P02o`P00P05o`001P09o`003Ol000Co0`08o`<04_l001Co00806?l000@07?l0023o
000So`008ol00P0Lo`0401Co000F017o0005o`001Ol000?o1@00o`X00?lI003o8@00ob`00?ll003o
B`00ogX00;k/0223o`0IJ?P00>cU003oP@00odD00?ld003o:000ob400?lI003o3P800?l:00<01?l3
00Go0005o`000`05o`000`0Do`004Ol0017o000801Co000300go000Do`003Ol000802Ol01`05o`00
0`02o`P00?l:003o2P02003o2P03003o3P00oaH00?lI00800?lI01d00?lM003o:000obP00?l]003o
?000od@00?m?003oG`00ogd00?nT022ao`10^>800?o:003Il000W?l0@2oo0099o`00Zol00?oF003o
[`00oj/00>6n003o]@00n>T00?nL003`X000oh400?m0003o<002003o:004003o7@00oaT00?lI003o
5P@00?l:00D00ol500Co0`05o`001Ol000go000601Co000301co000Po`007_l001H08ol000<08?l0
01So000Do`000`0Do`007@0=o`001Ol000Go0004o`<00_l8003o3P00oad00?lY003oS000ohD00?mS
003XYP05I?l00?o6003Xj@0X`>400?n5003MZ00=`=H00?cM003`cP00olD00?bP016haP00obT01olX
01Oo5P0ko`00A_l00080DOl000<0E_l0067o001Qo`000P1Qo`000`1Uo`00JOl006go0006073o0004
083o0?ooooooooooooooo`;o00002?ooool0027ooooo00Co0000oooooooooooooooo0`1Ao`006`1>
o`00@_l003oo000co`009ol000[o3@02o`l00?AO003o8@00obD00?ld003oKP00ok/098Oo001Zo`11
F/00:6So003Fm010`<000=VL003o@000ob400?lF00;o2004o`<02Ol0017o000401Co000301ko000P
o`008ol000H08ol000<08?l001ko000Ho`000`0Do`005`09o`001Ol0003o2P00oaH00?lM003o=@00
oc`00?m7003oD`00og800?nP042:l@00k=d00?nP003oMP00odX00?lh003o;000obD00?lI003o3P00
o`X00_l800@01Ol00P0Ao`0801Co0003017o000Do`005?l000805?l000<04Ol001Co000Do`001P05
o`000`04o`<01Ol000?o1@04003o2P05003o5P00oaT00?lI003o6@00oad00P00obP07@00oc000?lh
003o@000od/00?mO003oS@19NK`00;?`003laP00oj/00?o3003Ik@00c_l03H?o003ll000ol<00?nP
003oU000ohd00?n:003oT@00ofX00?mK003oB`00oc`00?ld003o;000obP00?lU00<00?lI0P00o`h2
003o2P0600?o1@05o`001Ol000Go0009o`004Ol01@0Do`0K02?o0003023o000Ho`005?l000<05?l0
01T02Ol000Go0005o`000_l8003o3P00oaT00?lY003o>000odP00?n2003dh@0AMol00;oo003obP00
n<800:_`003`e@00oel00?m@003oE000obT00?lh00So0`0Po`00;ol00080@_l000@0C_l0057o001D
o`00GOl00`1Qo`000`1Yo`00L?l0073o0006073o000307co0?oooooooooo00;ooooo00?o0000oooo
ooooool01_ooool0027ooooo00Co0000oooooooooooooooo101Ao`0204;o000L03?o000[o`008?l0
01Co0004o`<00_l8003o5P00obP00?n0003/o00cJ?l0@:g0003of@00o>D0@5Cf003oR@00oeL00?lh
003o7P00o`h00ol500Go000Ao`005?l001So000Lo`008ol0023o00X08ol000<08Ol0023o000Ho`00
0P0Do`001P09o`001Ol0003o7@00oc@00?m0003oP0800?mG00l00?mS003oMP00oj@00=;/003lh@00
oi400?m^003oDP00od@00?m0003o;000oad00?lB003o2P03o`D00`05o`000`0=o`004Ol001Co000=
01Co0005017o000Do`003Ol001;o0009o`001P05o`000`03o`D00?l:003o2P03003o2P@00?lI00<0
0?lU003o:000obP00P00ocP05@00od/00?mf003X`P00]nP00?nc003oU000oiT00?n_003obP00c_P0
6TKo003lj@00ol<00?nL003oR@00oh400?mc003oIP00oe/00?m?003oA`02003o>0<00?lX00@00?lN
003o6@00oaT00?lI1000o`X01004o`<01Ol000Go000=o`0501Co00807?l0300So`001`0Wo`00:ol0
02?o000Wo`00:ol002?o000Wo`002P0So`001@0Ho`005?l001Co000Ao`002Ol000801Ol001D00?l:
003o3P00oad00?l/003o?006_[<085Cd0021o`00A?l0EFg?003/n000X?@00?nA003oD`00oc@00?lI
00;o2009o`007?l002?o000co`000P12o`000`1>o`00DOl005Co0005067o000306go001`o`00L?l0
00D0L?l000<0M?l0ooooooooool00_ooool00ol0003oooooooooo`06ooooo`008Oooool01?l0003o
ooooooooooooool2057o000J04ko001:o`00@_l004;o000go`00<ol002?o000Lo`004Ol000?o1@00
oa800?l/003oG000c]400?CU003dl000m<X00?nA0032g@00okl00?mK003oB000obH00?lB00?o1@0=
o`0201Co00D08ol000H09ol002_o000Wo`00:ol002?o000Wo`0502?o000J01co000Do`005?l0017o
0005o`000?l>003/[`00ohT00?GL003`cP00ohD00?mi003oX000hO@00;_l0029o`00dND00?mn003o
J`00ofh00?bk003oG`0A`6H00?lB003o2P04o`<200Go000300So000Do`005?l001805?l000<02Ol0
00Go0005o`001@05o`001@03o`D00?l:003o2P00o`X00?l>00@00?lI00<00?lQ003o:000obP00P00
ocP01000odL00?mG003dU@00ogH2003oO@0=003oRP00ojl00>gY003]o00JCol00>7l002cm000oj@0
0?n9003oN@00of/00?mS003oE`02003oA`800?lh00@00?l/003o:000obP00?lS0`00oaT01@00oa80
0?l:003o2P00o`X01?l300801Ol000<02Ol001Co000Do`000`0Do`0;02?o000602Oo000co`00:ol0
02oo000co`00:ol00P0co`001@0[o`00<ol002oo000Wo`00:ol000P08ol000@07?l001Co000Do`00
4Ol00P05o`006002o`P00?l:003o6@00obD00?l`003oL000oi`00=g`003>n00LYO000Uco00i;o`00
`^P00?Qm003o<000o`l01Ol001Co000Po`00:ol003?o000oo`00@_l004ko0080DOl000D0GOl0067o
001Qo`00HOl006Wo0006073o000307Co0020o`00P?l000Cooooo00?o0000ooooooooool01_ooool0
027ooooo00Co0000oooooooooooooooo0`1Ao`000`1:o`00@_l003oo000203?o000F02?o000Lo`00
3Ol000Co0`00oaH00>6W003oQ@00_oP00?mn003oV000ogH00?mO003oS@00n=D00?Rg003oQ@00kHD0
0?l]00;o300=o`005?l0023o00808ol000@09ol002oo000co`00;ol01@0co`000`0[o`009ol002?o
000302?o000H01So000Do`005?l000Wo0003o`D00?lN003o?000of/00=W603>Io`00oj@00?nk003h
m02U9Ol009co003odP00oiD00?Fm0430e`0hJN`00?BW003A]`00oaH00?l:0`05o`0G01Co00H01Ol0
00<00_l8003o2P00o`X00P00o`X01@00oaH00?lI003o6@00oaT00?lU00800?lX0P00ocP04`00od@0
0?m?003oE`00of<00?mZ003oLP00ohD00?ng003Fk@0LFOl0P1[^00UTo`00V?P00?2n003oR@00ogD0
0?mV003oG`00oeL00P00odL2003o>009003o=000ob`00?lX003o:000obD00?lI003o7@00oaT00?lF
00800?l:00@00_l800Co0`05o`002Ol01@0Do`000`0Po`008ol002?o000602?o000502_o000Wo`00
:ol003?o000`o`002@0co`00100`o`00<ol002_o000[o`0602?o000G01Wo000Do`005?l000go0005
o`000ol5003o2P00oaT00?lQ003o<000odX00?BL042la000iMd00?nc003Mm00=/O000>SB003oIP00
od@00?lG00Go000Do`000P0So`00100co`00?ol004;o0016o`02057o000305Go001Qo`00HOl00080
HOl000<0KOl0073o001`o`000`1`o`000`1ho`00P?l0083o0004ooooo`03o`000?oooooooooo00Ko
oooo000Qooooo`04o`000?ooooooooooooooo`80DOl000@0C_l004[o0012o`00@_l00P0co`00600S
o`006?l000Wo0002o`P00?lM003oQ@1?VmL00?nn003oE`00od000?lh003oA000ofH00?o3003oPP00
oj@00=Jh042Jb`00o6X03Ol001So000So`009ol002oo00X0<ol000<0;ol002_o000So`000`0So`02
01Co000E017o0005o`000_l8003o6P00ocP00?mV003d`P00ond00=[o01E/o`00C?l00:3o003Io`00
]o002mGD003>W000fHD00?ll003o:@00o`h00ol500801Ol000<04Ol001;o000Do`00500Do`000`0A
o`001Ol000Go000500Go00<00?l:00H00?l>003o6@00oaT00?lI003o7@00obD2003o:0800?lh01<0
0?m0003oB`00odl00?mG003oH`00ofh00?mj003oU@00dM800?c`041``000eO@03L3M003oZ000ohd0
0?me003oJ@00oe/00?mG00800?m700H00?m0003o>000ocP00?ld003o:000ob/2003o:004003o8@00
oad00?lI003o5P800?l:00<00_l800Go000=o`00100Do`0902?o000402_o000co`00<ol002oo0080
<ol000<0;ol003?o000co`002P0co`000`0_o`00:ol002?o000302?o000Q027o000Ho`005?l0017o
0005o`000ol5003o4P00oad00?l/003o?000oeT00=V_00G0j000oh800?2_003o``00oi@00?3X003d
`P00okL00?mN00;o2009o`006?l002?o000_o`00<ol003oo0012o`00B_l004oo001Ao`00GOl00080
HOl000<0IOl0073o001`o`001@1`o`000`1lo`00P?l0ooooo`03ooooo`03o`000?oooooooooo00Ko
oooo000Qooooo`04o`000?ooooooooooooooo`<0DOl000<0A_l004;o000oo`000P0co`003P0So`00
3?l3003o8@00oad00?lY003oJP0Jd<X00>GI003oE`00obP00?lQ003o<000ohT00X[M0P00ocP01`00
of@00>G>003oC`04o`<07?l002?o000_o`00300co`000`0_o`00:?l002?o000202?o000J01co000D
o`004Ol000Go0003o`D00?lB003oE00FP<800?CU003oU000olX00XOo001?o`00kOP00?nk003o/`00
fl@00?mO003o@000obD00?lF003o2P04o`<01Ol000Wo000Ao`0601Co000701co000Do`006?l002?o
000Go`008?l001So000901Co0003017o000Do`003Ol000@01Ol000D00ol5003o2P00o`X00?l:003o
3P02003o6@05003o7@00oaT00?lX003o:000ob/00P00ocP05000oc`00?m7003oB`00oeL00?mO003o
KP00ogX00?nA003oZ`00om803EWo003>n000olX00?nT003oU000oh400?m`003oG`00oeL00?mC0P00
odL01@00oc`00?lh003o?000ocP00?le00@00?l`00L00?l/003o8@00oaT00?l>003o2P03o`<01Ol0
00@05?l000<07?l002?o000So`00100So`000`0Wo`00:ol002_o000B03?o000402oo000co`00;ol0
02Oo00<08ol001T07?l001Co000Ao`001Ol000;o2000oa800?la003>O@00ohD00MG0003Ue@00ohD0
0?mG003oLP00odP00?m?003oNP0IXN`00Y;E003oC000ob400?le00So0`0Po`009ol00080<ol00P12
o`000`1<o`00DOl005Wo0003067o00H0L?l00P1ho`000`1lo`3oooooooooo`02ooooo`03o`000?oo
oooooooo00Kooooo000Qooooo`04o`000?ooooooooooooooo`80DOl000P0C_l004;o0012o`00=ol0
03?o000[o`008?l000co0`800?mZ00D00?mG002cj@00ogP00?mS003o6P02003o4P0;003o;@00o:l0
0=g>003o;@00oa800?lL003>C`00ofh0=L15023o000[o`00100co`000`0fo`00<ol003Oo000703?o
000302ko000So`008ol000808ol00P0Do`004`0=o`001?l3003o5P00ogX00<:T003oI`00ofh00?n[
00:Fl00gXO@04L3>003oP@00ohD00<cF003/V000odP00?lQ003o4P02o`P00P05o`000`0Ao`005?l0
01Co000301Co000401So000Lo`008ol0023o00808ol000H07_l002?o000So`006?l002?o000Lo`07
01Co0003017o0005o`001Ol000<01Ol000D01?l3003o2P00o`X00?l>003o4P02003o6@05003o7@00
ob400?lX003o:000obd00P00ocP05@00od@00?m7003oA`00oeL00?mO003oLP00ohD00?nH003oZ`10
`<@01ESo07Xko`00k>d00?nc003oZ`00olh00?nG003oIP00oel00?mG003oC`02003oA`0;003oA000
od000?ll003o>`00oc`00?m8003oMP00oe<00?n1003o>000obD00P00ob400`02o`T01Ol001Co0002
01Co000301co000So`008ol000D08ol00P0co`0202oo0180<ol000@0;ol003?o000_o`00;ol00`0S
o`006@0Do`003Ol000?o1@00o`h00?lM003ALP00om800:oI00?EX`00m:@00?2X003oB000oc000?l/
003o>000n:000?nP003EY000lZh00?mG003oS@00odl01olE023o000Wo`000P0co`001@0ko`00@_l0
04ko001Ao`00GOl00080HOl01@1`o`00101ho`00P?l0083o0020o`04ooooo`03o`000?oooooooooo
00Kooooo000Qooooo`04o`000?ooooooooooooooo`80DOl000h0AOl004;o000mo`00<ol002ko000S
o`005ol000Co6`00jg<00?3502ZYf@00i[l00?a9007o3P800ol300d00ol5003o5000oeT00?>^003o
<`09o`805_l001Co000?ob407_l0037o000co`00=_l00080>ol000P0@_l003oo0010o`00@_l003_o
0010o`00>?l003Ko00<0<ol000D0<Ol002Wo000So`008ol0027o000201Co000E00[o0005o`000?l=
003o8@00ocD00?m0003oH@0>eK000>?S003]e000ohL00?mO003oE`00jh/01=GG03FZ]P00ocP00?lB
00?o1@05o`002_l000<05?l000D05ol001Wo000Lo`008ol001ko000402?o0005023o000So`008ol0
027o000So`000P0Lo`000`0No`005?l001Co000501Co000500So0005o`001Ol000Co0P03o`D00P00
o`X01@00o`d00?lI003o6@00oaT00?lN00<00?lX01X00?le003o>000ocP00?m5003oA`00oe800?mG
003oIP00oj/02McA003o^`00ol000?oN003Bo`0[NO400=Kc003oe00;bn<00<3e003oV`00oh000?m`
003oG`00oeL00?mB003oBP800?m700h00?m<003oD@00oeL00?mT003Na@00e/D00<o2003oG`00of40
0?Qm003`U`01o`h01Ol001;o00805?l000<07?l0027o000So`000`0So`0202So000302ko000co`00
<ol001L0<ol00100;_l002?o000So`006Ol000go0001obD00<B<003oC000n9@00=bc003oP000oc@0
0?mj003BdP0;eGH00?lN0P00oa@04@00ob400?lX003o>P00oj000=cV0235`000oe`00_l900oo000I
o`007_l001;o9`0?ocH08?l002Ko501<o`00FOl00080HOl000<0K_l0073o001`o`000P1`o`00101c
o`00Nol0083o0020o`04ooooo`03o`000?oooooooooo00Kooooo0008ooooo`;o00001?ooool00ol0
003oooooooooo`02ooooo`;o00001?ooool3o`0000Gooooo01Co0000oooooooooooooooo057o001:
o`00@_l003oo000co`00;ol002?o000Po`004Ol000?o1@00obT00=G3003o[000m;L00=V:00Co0`80
5?l000P04Ol000?o3@00oiP00?nc0430;P0Eo`009_l002_o0080<ol000@0=ol003_o0012o`00?ol0
1P12o`00100oo`00@_l003_o000go`0303?o000J02oo000So`008ol0023o000Do`004Ol000Wo0004
o`<00?l:003o4P00obD00?lh003oC`0E`<H0@8?G001mm000oiD00?m;003o@000odD00?R=003oO@00
m;h00?lF00Co0`09o`0401Co000301co000So`008?l000h08ol01P0Do`000`0=o`002Ol000Go0002
00Go000300?o1@00o`X00?l>00800?lI00H00?lM003o8@00obP00?lX003o;000oc@2003o>00F003o
A000odL00?m7003oD`00oeL00?mV003oP@0H]^<00;Oo003/k@00n?@005_o05HFm@0IK?l00>Wo0028
o`00o?P00<o[00G0k@00ok<00?m^003oH`<00?mG00l00?mK003oKP00ojT00?mm0430I009`;l0@:W;
022]k@00n>D00:_I003/[000o8d00?lG00Go000Ao`000P0Do`000`0Po`008ol002?o000302?o01d0
<ol00100:?l002?o000Lo`005?l000?o3@00j9`00?S>003U_`00od000?lJ003o4P00obT00>6T003o
G`00oaH01?l30P05o`004002o`P00?l`003oQ`00oi000=76003:Y`00oeh00_l<00?o3@00obd00?m?
00flcP00oeH02O1=03oo001Eo`02067o00@0L?l000D0Lol0083o0020o`00O?l0083o0004ooooo`03
o`000?oooooooooo00Kooooo0007ooooo`04o`000?ooooooooooo`0000[ooooo00Co0000oooooooo
oooo00000oooool00ol0003oooooooooo`02ooooo`07o`000?ooooooooooooooo`1>o`00@_l003_o
000202So000;02?o000Lo`004Ol000So0`00oaH00?m^003o[000od000?n@00Go500Do`000`0Po`00
200Ho`002?l7003UP@03o`d08?l0033o000go`00>ol03@12o`000`0oo`00@_l003?o000303?o0080
8ol001L08?l001Co000Do`002Ol000Go0003o`D00?l?003o9@00oc`00?mK003oS@00j?000?nD003o
LP00od000?ld003o:000ob400?lU003oB002o``01?l3017o000301Co000301ko000Po`008ol00140
8ol01@0Do`002@09o`001Ol000Go0005o`000_l8003o2P00oaH00?lM003o8@03003o:005003o<000
oc@00?ll003o>000od@00P00odL05000od/00?mG003oF`00ofX00?n1003o[P00jO@04V7o002Lo`10
EMh0JP3^00Tbo`00H_l00;?o042>`001`OL00>S6003oS@00og800?mZ0`00ofH03P00ofX00?Bg003S
h`00b/H00:3`03>dm00EF?`00?c2003oJ`00odl00?m4003/U000odd01Ol00P0Do`000`0Ho`008ol0
02?o000402?o000302oo000co`00<ol000X0<ol000P0=ol003_o000co`00=ol004;o000oo`00>?l0
04;o00<0=ol01@0co`009@0`o`008ol002?o000Do`000ol5003o=00L`;/00<[2003oA`03o`D01?l2
003o8@00ojL00?nP00;o6`0Ao`005?l0017o0009o`000?1Z003o@000oe000?la0430`000X;L00?m0
01W0W000o<800=F5003hU00@o`H04_lA02Ko4P1Io`00HOl006Go001]o`000`1`o`000`1eo`00P?l0
083o0002083o00Cooooo00?o0000ooooooooool01_ooool000Oooooo00Co0000oooooooooooo0000
2oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo01Ko0000oooooooooooo
oooo04[o000oo`00;ol000c0FP0:o`L03Ol000?o4@02oa<00?lB003o:@00gJP00?nH003o4P03o`d0
3ol<02?o000[o`009ol00P0So`001@0Eo`000?m400khHP0[o`00>?l00180@_l00P0co`00100[o`00
8ol002?o000Po`0201Co00801Ol001400?l:003o5000ocP00?bL003oNP00l;<02HOd003oS000oeL0
0?lh003o:000oa`00?lI003o4P02o`P01?l300Wo000301Co0003023o000So`008ol001408ol000<0
8?l001Co000Do`000`0Do`003`0=o`001Ol000Go0005o`000?l:003o4P00ob400<iR003o<000obP0
0?l`003o=000ocP00?ll003oA003003oA`0E003oB`00oeL00?mG003oH`00og800?2c00J6l`00Z?l0
0=[o0029o`0a=ol0R`O^0014o`05U_l00?Sl003oh@00ol800?nL003oR@00oh400?mb00800?m^00/0
0?mf003oR@09`;L0;YKT002@l000okL00?nA003E^`00ok<00?mW003o;002003o8@05007o9`05o`00
5?l001Co000Lo`001@0So`000`0co`00;ol003?o000;03?o000403oo0012o`00?ol003_o0080@_l0
00<0?Ol004;o000ko`000P12o`000`0go`00>ol003?o000203?o0009033o000Wo`008ol001Co0003
o`D00?m^003oMP00od002?l300805?l000D02Ol0003o8@00m9@02?l301So000301co000B00go000<
o`800ol900?o2@00oaX00?ll02c0]`00od@00_l^00?o1@0<ocT0<ol003oo001>o`00FOl0067o001U
o`00KOl0101`o`00101ho`00P?l0083o0020o`04ooooo`03o`000?oooooooooo00Kooooo0007oooo
o`04o`000?ooooooooooo`0000Sooooo1?l00003ooooo`;o00001Oooool2o`0000;ooooo00l0@_l0
03Oo000Po`000_lf003o=P00oad04L2c003oO@00m:@00<:W003oKP00oah02?l301Co000Qo`000P0_
o`0303?o000402_o000Kk400;ol003_o00@0@_l000L0A_l004[o001:o`00C_l004[o001>o`00Aol0
00L0@_l000H0?ol003Oo000co`00;ol002?o000Po`0201Co000A00Wo0005o`000_l8003o2P00oa`0
0?l`003oLP0P`=H00=gY04aYo`00ojP00>6g003oA000ob400?lB003o2P02o`P00P05o`0301Co0080
7?l04P0So`02023o000302?o000Do`005?l000805?l000T02Ol000Go0005o`000ol5003o2P00oa@0
0?mG003A[`00odP00P00oc`2003oA003003oD`00og800?mJ00@00?mG01<00?mS003oIP00ogD00?nE
003PeP00omd00?oa002ko`00OOl0P0?J01/Bo`00Iol00>Gl003og@00okd00?nT003oT@00ohT00?n1
00800?mm00l00?B/003Ik@00Z?003/K]003li@00oi400?mO003oLP00n:@00?l/003o7@00oa800?l:
00?o1@0=o`000P0Do`000`0Po`008ol002?o000302?o0003033o000co`00<ol000P0<ol00P12o`00
1@0go`00@_l004;o0012o`00?ol000T0@_l000`0>ol003Oo000co`00<ol002_o000So`003Ol0003o
A000ohD00?l]017o000Lo`0202?o000F01co0003aVd01olD01Go000So`009ol002_o000Wo`008ol0
01ko000Do`004Ol000?o1@00obd00?c6003o6@0=o`008?l002oo0010o`00C_l0057o0080HOl000<0
IOl0073o001`o`000P1`o`000`1mo`00P?l007co0002083o00?ooooo0_l00008ooooo`001oooool0
1?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool000001Oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo0??ooooo00?o0000ooooooooool01_ooool000Oooooo00Co
0000oooooooooooo00001oooool01ol0003ooooooooooooooooo0000ooooool000000oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo0??ooooo00?o0000ooooooooool01_ooool000So
oooo0_l00009ooooo`?o00000oooool3o`0000Gooooo00Go0000ooooooooooooooooo`00000;oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo00Wooooo00Go0000ooooooooooooooooo`000008ooooo`008Oooooogo`00
00Sooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo003ooooo
ob7ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo003ooooo
ob7ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-0.111595, 0.918695, \
4.21637*^-5, 4.21637*^-5}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(mandelbrotSet[{{\(-0.11\), \(-0.1\)}, {0.92, 0.93}}, 1000, {0, 100}, 
        ColorFunction \[Rule] Hue];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
10.5962 96.1538 -88.4423 96.1538 [
[.01923 -0.0125 -15 -9 ]
[.01923 -0.0125 15 0 ]
[.21154 -0.0125 -18 -9 ]
[.21154 -0.0125 18 0 ]
[.40385 -0.0125 -18 -9 ]
[.40385 -0.0125 18 0 ]
[.59615 -0.0125 -18 -9 ]
[.59615 -0.0125 18 0 ]
[.78846 -0.0125 -18 -9 ]
[.78846 -0.0125 18 0 ]
[.98077 -0.0125 -12 -9 ]
[.98077 -0.0125 12 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01923 -24 -4.5 ]
[-0.0125 .01923 0 4.5 ]
[-0.0125 .21154 -30 -4.5 ]
[-0.0125 .21154 0 4.5 ]
[-0.0125 .40385 -30 -4.5 ]
[-0.0125 .40385 0 4.5 ]
[-0.0125 .59615 -30 -4.5 ]
[-0.0125 .59615 0 4.5 ]
[-0.0125 .78846 -30 -4.5 ]
[-0.0125 .78846 0 4.5 ]
[-0.0125 .98077 -24 -4.5 ]
[-0.0125 .98077 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.01923 0 m
.01923 .00625 L
s
[(-0.11)] .01923 -0.0125 0 1 Mshowa
.21154 0 m
.21154 .00625 L
s
[(-0.108)] .21154 -0.0125 0 1 Mshowa
.40385 0 m
.40385 .00625 L
s
[(-0.106)] .40385 -0.0125 0 1 Mshowa
.59615 0 m
.59615 .00625 L
s
[(-0.104)] .59615 -0.0125 0 1 Mshowa
.78846 0 m
.78846 .00625 L
s
[(-0.102)] .78846 -0.0125 0 1 Mshowa
.98077 0 m
.98077 .00625 L
s
[(-0.1)] .98077 -0.0125 0 1 Mshowa
.125 Mabswid
.06731 0 m
.06731 .00375 L
s
.11538 0 m
.11538 .00375 L
s
.16346 0 m
.16346 .00375 L
s
.25962 0 m
.25962 .00375 L
s
.30769 0 m
.30769 .00375 L
s
.35577 0 m
.35577 .00375 L
s
.45192 0 m
.45192 .00375 L
s
.5 0 m
.5 .00375 L
s
.54808 0 m
.54808 .00375 L
s
.64423 0 m
.64423 .00375 L
s
.69231 0 m
.69231 .00375 L
s
.74038 0 m
.74038 .00375 L
s
.83654 0 m
.83654 .00375 L
s
.88462 0 m
.88462 .00375 L
s
.93269 0 m
.93269 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01923 m
.00625 .01923 L
s
[(0.92)] -0.0125 .01923 1 0 Mshowa
0 .21154 m
.00625 .21154 L
s
[(0.922)] -0.0125 .21154 1 0 Mshowa
0 .40385 m
.00625 .40385 L
s
[(0.924)] -0.0125 .40385 1 0 Mshowa
0 .59615 m
.00625 .59615 L
s
[(0.926)] -0.0125 .59615 1 0 Mshowa
0 .78846 m
.00625 .78846 L
s
[(0.928)] -0.0125 .78846 1 0 Mshowa
0 .98077 m
.00625 .98077 L
s
[(0.93)] -0.0125 .98077 1 0 Mshowa
.125 Mabswid
0 .06731 m
.00375 .06731 L
s
0 .11538 m
.00375 .11538 L
s
0 .16346 m
.00375 .16346 L
s
0 .25962 m
.00375 .25962 L
s
0 .30769 m
.00375 .30769 L
s
0 .35577 m
.00375 .35577 L
s
0 .45192 m
.00375 .45192 L
s
0 .5 m
.00375 .5 L
s
0 .54808 m
.00375 .54808 L
s
0 .64423 m
.00375 .64423 L
s
0 .69231 m
.00375 .69231 L
s
0 .74038 m
.00375 .74038 L
s
0 .83654 m
.00375 .83654 L
s
0 .88462 m
.00375 .88462 L
s
0 .93269 m
.00375 .93269 L
s
.25 Mabswid
0 0 m
0 1 L
s
.01923 .99375 m
.01923 1 L
s
.21154 .99375 m
.21154 1 L
s
.40385 .99375 m
.40385 1 L
s
.59615 .99375 m
.59615 1 L
s
.78846 .99375 m
.78846 1 L
s
.98077 .99375 m
.98077 1 L
s
.125 Mabswid
.06731 .99625 m
.06731 1 L
s
.11538 .99625 m
.11538 1 L
s
.16346 .99625 m
.16346 1 L
s
.25962 .99625 m
.25962 1 L
s
.30769 .99625 m
.30769 1 L
s
.35577 .99625 m
.35577 1 L
s
.45192 .99625 m
.45192 1 L
s
.5 .99625 m
.5 1 L
s
.54808 .99625 m
.54808 1 L
s
.64423 .99625 m
.64423 1 L
s
.69231 .99625 m
.69231 1 L
s
.74038 .99625 m
.74038 1 L
s
.83654 .99625 m
.83654 1 L
s
.88462 .99625 m
.88462 1 L
s
.93269 .99625 m
.93269 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .01923 m
1 .01923 L
s
.99375 .21154 m
1 .21154 L
s
.99375 .40385 m
1 .40385 L
s
.99375 .59615 m
1 .59615 L
s
.99375 .78846 m
1 .78846 L
s
.99375 .98077 m
1 .98077 L
s
.125 Mabswid
.99625 .06731 m
1 .06731 L
s
.99625 .11538 m
1 .11538 L
s
.99625 .16346 m
1 .16346 L
s
.99625 .25962 m
1 .25962 L
s
.99625 .30769 m
1 .30769 L
s
.99625 .35577 m
1 .35577 L
s
.99625 .45192 m
1 .45192 L
s
.99625 .5 m
1 .5 L
s
.99625 .54808 m
1 .54808 L
s
.99625 .64423 m
1 .64423 L
s
.99625 .69231 m
1 .69231 L
s
.99625 .74038 m
1 .74038 L
s
.99625 .83654 m
1 .83654 L
s
.99625 .88462 m
1 .88462 L
s
.99625 .93269 m
1 .93269 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.01923 .01923 translate
.96154 .96154 scale
3000 string
1000 1000 8 [1000 0 0 1000 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage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33FF0033FF0033FF0033FF0033FF0042FF0042FF0033FF0033FF0033FF0042FF0042FF00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33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0042FF0042FF00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33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0042FF0042FF00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33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0042FF00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33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00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33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00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33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0042FF0042FF0042FF0042FF0042FF0033FF00
33FF0033FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0033FF00
33FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
33FF0033FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
42FF0042FF0042FF0033FF0033FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
42FF0042FF0042FF0042FF0042FF0042FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0042FF0042FF0042FF0042FF0042FF0042FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0023FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0000FF0A00FF0A00FF0A00FF0A00FF1900FF1900FF2800FF2800FF3800FF47
00FFC200FF8500F0FF00C2FF00FFF000FF7500FF6600FF5700FF5700FF5700FF6600FF75
00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7500FF7500FF8500FF94
00FFB30066FF00C2FF00E1FF00F0FF4200FF00FFFF00FFE100FFB300FF9400FF8500FF75
00FF7500FF6600FF6600FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF57
00FF5700FF5700FF5700FF5700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF47
00FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF47
00FF4700FF4700FF4700FF4700FF4700FF4700FF5700FF4700FF4700FF4700FF5700FF57
00FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF6600FF5700FF57
00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7500FF7500FF75
00FF7500FF8500FF8500FFA300A3FF00FFC200FFC24200FF00FFD100FFB300FFA300FFA3
00FFA300FF9400FF9400FF9400FFA300FF9400FF9400FFA300FFA300FFA300FFA300FFA3
00FFA300FFA300FFA300FFB300FFB300FFB300FFB300FFB300FFC200FFC200FFC200FFD1
00FFD100FFE100FFE100FFF000FFF000FFF000FFFF00F0FF00E1FF00D1FF00B3FF0094FF
2300FF000AFF0085FF00B3FF00C2FF00E1FF00F0FF00FFFF00FFFF00FFF000FFE100FFE1
00FFD100FFD100FFD100FFC200FFC200FFC200FFB300FFB300FFB300FFB300FFA300FFA3
00FFA300FF9400FF9400FF9400FF9400FF9400FF9400FF8500FF8500FF8500FF8500FF85
00FF8500FF8500FF8500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF66
00FF6600FF6600FF6600FF6600FF6600FF6600FF5700FF5700FF5700FF5700FF5700FF57
00FF5700FF5700FF5700FF5700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF47
00FF4700FF4700FF4700FF4700FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0005FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0014FF0014FF0014FF0014FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0014FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
00FF0A00FF0A00FF0A00FF1900FF1900FF2800FF570047FF00FFF000FF6600FF3800FF38
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF3800FF3800FF3800FF3800FF38
00FF4700FF4700FF4700FF5700FF5700FF6600FF6600FF6600FF7500FF8500FF9400FFB3
00FFF000C2FF00A3FF0094FF0057FF00D1FF00E1FF00FFC200FFB300FFA300FFA300FFA3
00FFA300FFB300FFD1BD00FF00F0FF00FFA300FF7500FF6600FF5700FF4700FF3800FF38
00FF2800FF2800FF2800FF2800FF1900FF1900FF1900FF1900FF1900FF1900FF0A00FF19
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A05FF0005FF0005FF0005FF0005FF0005FF0005FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0023FF0023FF0023FF0023FF00
23FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
42FF0042FF0042FF0042FF0042FF0042FF0042FF0051FF0051FF0042FF0042FF0042FF00
51FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF00
51FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF00
51FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF00
51FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0061FF0061FF0061FF00
61FF0061FF0061FF0061FF0061FF0061FF0051FF0061FF0061FF0061FF0061FF0061FF00
61FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF00
51FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF00
61FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF00
61FF0061FF0061FF0061FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00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33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00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33FF0033FF0023FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00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33FF0023FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00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23FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00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23FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0042FF0042FF0042FF0042FF0042FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0000FF0A00FF0A00FF0A00FF0A00FF1900FF2800FF3800FF3800FF57
00FFA300FF4700FF3800FF3800FF3800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF3800FF3800FF3800FF3800FF3800FF3800FF4700FF5700FF6600FF9400FFE100C2FF
00D1FF0085FF00FF6600FF6600FF6600FF6600FF6600FF7500FF8500FFFF00FFC200FF85
00FF6600FF5700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF3800FF4700FF38
00FF4700FF3800FF3800FF3800FF3800FF4700FF3800FF3800FF3800FF3800FF3800FF47
00FF3800FF3800FF3800FF3800FF3800FF3800FF4700FF4700FF3800FF3800FF4700FF47
00FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF47
00FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF5700FF5700FF5700FF5700FF57
00FF5700FF5700FF5700FF5700FF5700FF6600FF6600FF6600FF6600FF6600FF6600FF66
00FF6600FF6600FF6600FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF8500FF85
00FF8500FF8500FF8500FF8500FF8500FF9400FF8500FF9400FF9400FF9400FF9400FF94
00FF9400FFA300FFA300FFA300FFB300FFB300FFB300FFB300FFB300FFC200FFC200FFC2
00FFD100FFD100FFD100FFE100FFE100FFF000FFFF00E1FF00C2FF0094FFCC00FF0500FF
8000FF9E00FF8F00FF5100FF0066FF0085FF0057FF1400FF0075FF0085FF00FFFF00FFF0
00FFE100FFE100FFD100FFD100FFD100FFD100FFD100FFC200FFC200FFC200FFB300FFB3
00FFA300FFA300FF9400FF9400FF9400FF9400FF8500FF8500FF8500FF8500FF8500FF85
00FF8500FF8500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF6600FF6600FF66
00FF6600FF6600FF6600FF6600FF6600FF5700FF5700FF5700FF5700FF5700FF5700FF57
00FF5700FF5700FF5700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF47
00FF4700FF4700FF4700FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0014FF0014FF0014FF00
14FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0014FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0014FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0014FF0014FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0000FF0A00FF0A
00FF0A00FF0A00FF1900FF2800FF3800FF3800FF4700FF5700FF8500FFF000FFFF00FFE1
00FFD100FFA300FFB300D1FF00F0FF00FFFF00FFB300FF6600FF5700FF4700FF4700FF47
00FF4700FF4700FF3800FF3800FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF57
00FF5700FF6600FF6600FF8500F0FF2300FF00FFF000FFB300FFB300FFB300FFD10094FF
0500FFFF00C700E1FF00FFE100FFB300FFA300FFA300FF9400FF7500FF7500FF7500FF66
00FF6600FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF7500FF5700FF3800FF28
00FF2800FF1900FF1900FF1900FF1900FF1900FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0014FF0014FF0005FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0051FF0051FF00
51FF0051FF0051FF0051FF0051FF0051FF0042FF0051FF0051FF0051FF0051FF0051FF00
51FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF00
51FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF00
51FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF00
51FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0061FF0061FF0051FF00
51FF0051FF0051FF0051FF0061FF0061FF0061FF0061FF0061FF0061FF0051FF0051FF00
61FF0061FF0061FF0061FF0061FF0061FF0061FF0051FF0061FF0061FF0061FF0061FF00
61FF0061FF0051FF0061FF0061FF0061FF0061FF0061FF0061FF0051FF0061FF0061FF00
61FF0061FF0061FF0061FF00
23FF0033FF0033FF0023FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00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23FF0023FF0023FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0000FF0A00FF0A00FF0A00FF0A00FF1900FF1900FF1900FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF3800FF3800FF3800FF4700FF5700FF7500FFA3BD00FF00FF75
00FF6600FF5700FF5700FF4700FF5700FF4700FF5700FF5700FF6600F0FF00FF8500FF66
00FF5700FF4700FF4700FF4700FF4700FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF4700FF3800FF3800FF3800FF3800FF47
00FF3800FF3800FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF47
00FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF5700FF5700FF5700FF5700FF57
00FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF6600FF6600FF6600FF6600FF66
00FF6600FF6600FF6600FF6600FF6600FF7500FF7500FF7500FF7500FF7500FF7500FF75
00FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF9400FF9400FF9400FF94
00FF9400FFA300FFA300FFA300FFA300FFB300FFB300FFB300FFC200FFC200FFC200FFD1
00FFD100FFD100FFD100FFE100FFE100FFF000FFFF00D1FF0094FF00A3FF00B3FF00A3FF
0085FF000AFFFF00D70066FF0094FF00B3FF00C2FF00D1FF00E1FF00F0FF00FFFF00FFF0
00FFF000FFE100FFE100FFE100FFE100FFF000FFFF00FFFF00FFF000A3FF00FFE100FFC2
00FFB300FFA300FFA300FF9400FF9400FF9400FF8500FF8500FF8500FF8500FF8500FF85
00FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF6600FF6600FF66
00FF6600FF6600FF6600FF6600FF6600FF6600FF5700FF5700FF5700FF5700FF5700FF57
00FF5700FF5700FF5700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF47
00FF4700FF4700FF4700FF4700FF4700FF4700FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0014FF0014FF0014FF0014FF0014FF00
14FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0014FF0014FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0014FF0014FF0014FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0014FF0014FF0014FF0014FF0023FF0023FF0023FF00
23FF0023FF0023FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0005FF0014FF0014FF0014FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0000FF0A00FF0A00FF0A
00FF0A00FF0A00FF1900FF1900FF2800FF2800FF3800FF4700FF5700FF6600FF8500FFC2
00A3FF00A3FF8000FF00A3FF00FFB300FF9400FF7500FF6600FF6600FF5700FF5700FF57
00FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF5700FF5700FF57
00FF6600FF7500FF7500FF9400FFA300FFC20038FF00FFFF00FFE100FFE100F0FF00E1FF
FF00E600C2FF00D1FF00C2FF00FFB300FF9400FF8500FF7500FF7500FF6600FF6600FF57
00FF5700FF5700FF4700FF4700FF4700FF4700FF3800FF3800FF3800FF3800FF2800FF28
00FF1900FF1900FF1900FF1900FF1900FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
05FF0005FF0000FF0A05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0042FF00
42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
42FF0042FF0042FF0042FF0042FF0042FF0051FF0051FF0051FF0051FF0051FF0051FF00
51FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF00
51FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF00
51FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF00
51FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF00
51FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF00
51FF0061FF0061FF0061FF0061FF0051FF0051FF0051FF0061FF0061FF0061FF0061FF00
61FF0051FF0051FF0061FF0061FF0061FF0061FF0061FF0061FF0051FF0061FF0061FF00
61FF0061FF0061FF0051FF00
23FF0023FF0023FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0000FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF3800FF4700FF5700FFD100FF9400FFF000FF66
00FF5700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF5700FFB300FF5700FF57
00FF4700FF4700FF4700FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF47
00FF4700FF4700FF4700FF4700FF4700FF4700FF5700FF4700FF4700FF5700FF5700FF57
00FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF6600FF6600FF66
00FF6600FF6600FF6600FF6600FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF75
00FF7500FF7500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF9400FF9400FF94
00FF9400FFA300FFA300FFA300FFA300FFB300FFB300FFB300FFC200FFC200FFC200FFD1
00FFD100FFE100FFE100FFE100FFF000FFF000FFFF00F0FF00E1FF00D1FF00C2FF00A3FF
0066FF0047FF9E00FF0038FFFF00A800B3FF00D1FF00E1FF00E1FF00F0FF00FFFF00FFFF
00FFF000FFF000FFF000FFF000FFF000D1FF00A3FF00D1FF0038FF00B3FF0066FF00FFF0
00FFB300FFA300FFA300FF9400FF9400FF9400FF9400FF9400FF8500FF8500FF8500FF85
00FF8500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF6600FF6600FF66
00FF6600FF6600FF6600FF6600FF6600FF5700FF5700FF5700FF5700FF5700FF5700FF57
00FF5700FF5700FF5700FF5700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF47
00FF4700FF4700FF4700FF4700FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0005FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0023FF0023FF0023FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0014FF0014FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0014FF0014FF0014FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0023FF00
23FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0000FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF1900FF1900FF1900FF2800FF2800FF3800FF5700FF7500FF9400FFC2
00B3FF1400FF8000FF00F0FF00FFC200FFA300FF8500FF7500FF6600FF6600FF5700FF57
00FF5700FF5700FF4700FF4700FF4700FF4700FF4700FF5700FF5700FF5700FF5700FF57
00FF6600FFD100FFA300FFD100FFD100FFE100E1FF00D1FF00E1FF00B3FF00A3FF0038FF
0075FF00E1FF00FFE100FFD100FFB300FFA300FF8500FF8500FF7500FF6600FF5700FF57
00FF5700FF4700FF4700FF4700FF4700FF3800FF3800FF3800FF3800FF2800FF2800FF28
00FF1900FF1900FF1900FF1900FF1900FF1900FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0042FF00
42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
42FF0042FF0042FF0042FF0042FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF00
51FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF00
51FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF00
51FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF00
51FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF00
51FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF00
51FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0061FF0061FF0061FF00
61FF0051FF0051FF0051FF0061FF0061FF0061FF0061FF0051FF0051FF0051FF0061FF00
61FF0061FF0061FF0051FF00
23FF0023FF0023FF0033FF0033FF0033FF0033FF0023FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0023FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0000FF0A00FF0A00FF0A00FF0A00FF1900FF0A00FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF2800FF1900FF1900FF1900FF19
00FF2800FF2800FF2800FF2800FF2800FF3800FF3800FF5700FF5700FF5700FF6600FF57
00FF4700FF4700FF4700FF3800FF3800FF3800FF4700FF4700FF4700FF4700FF4700FF47
00FF4700FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF47
00FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF5700FF57
00FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF6600FF6600FF66
00FF6600FF6600FF6600FF6600FF6600FF6600FF7500FF7500FF7500FF7500FF7500FF75
00FF7500FF7500FF7500FF8500FF8500FF8500FF8500FF8500FF8500FF9400FF9400FF94
00FF9400FFA300FFA300FFA300FFB300FFB300FFB300FFC200FFC200FFD100FFD100FFD1
00FFD100FFE100FFE100FFE100FFF000FFF000FFFF00FFFF00F0FF00E1FF00D1FF00B3FF
0075FF5100FFFA00FF0019FF5100FF0094FF00C2FF00D1FF00E1FF00F0FF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00F0FF00E1FF0075FF4200FF00C2FF00FFF000FFE100FFC2
00FFB300FFA300FFA300FF9400FF9400FF9400FF8500FF8500FF8500FF8500FF8500FF85
00FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF6600FF6600FF6600FF66
00FF6600FF6600FF6600FF6600FF6600FF5700FF5700FF5700FF5700FF5700FF5700FF57
00FF5700FF5700FF5700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF47
00FF4700FF4700FF4700FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF0A00FF1900FF1900FF1900FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A05FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
14FF0014FF0014FF0014FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0014FF0014FF0014FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0000FF0A00FF0A00FF0A
00FF0A00FF0A00FF1900FF1900FF2800FF2800FF2800FF4700FFA35100FF0066FF1400FF
00E1FF00E1FF00FFFF4200FF00F0FF00FFF000FFA300FF8500FF7500FF7500FF6600FF57
00FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF66
00FF7500FFD18F00FF5100FF0047FF5100FF00F0FF00A3FF0038FF0057FF7000FFCC00FF
0094FF00F0FF00FFE100FFD100FFB300FFA300FF9400FF8500FF7500FF6600FF5700FF57
00FF5700FF4700FF4700FF4700FF3800FF3800FF3800FF3800FF2800FF2800FF2800FF19
00FF1900FF1900FF1900FF1900FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0042FF00
42FF0042FF0042FF0042FF0042FF0042FF0042FF0033FF0042FF0042FF0042FF0042FF00
42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
42FF0042FF0042FF0042FF0042FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF00
51FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF00
51FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF00
51FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF00
51FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF00
51FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF00
51FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF00
51FF0051FF0051FF0051FF0051FF0061FF0061FF0051FF0051FF0051FF0051FF0051FF00
61FF0061FF0051FF0051FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0023FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0000FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF2800FF1900FF2800FF2800FF2800FF2800FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF4700FF3800FF3800FF4700FF4700FF4700FF4700FF4700FF47
00FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF5700FF5700FF57
00FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF6600FF6600FF66
00FF6600FF6600FF6600FF6600FF6600FF6600FF7500FF7500FF7500FF7500FF7500FF75
00FF7500FF7500FF7500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF9400FF94
00FFA300FFA300FFA300FFB300FFB300FFB300FFC200FFD100FFD100FFE100FFE100FFE1
00FFE100FFE100FFE100FFF000FFF000FFF000FFFF00FFFF00F0FF00E1FF00D1FF00B3FF
0085FF0066FFFF00E60028FF0085FF00A3FF00C2FF00C2FF00D1FF00E1FF00F0FF00F0FF
00FFFF00FFFF00F0FF00E1FF0066FF00A3FF1400FF0075FF0075FF00FFE100FFD100FFC2
00FFB300FFA300FFA300FF9400FF9400FF9400FF9400FF8500FF8500FF8500FF8500FF85
00FF8500FF8500FF8500FF7500FF7500FF7500FF7500FF7500FF7500FF6600FF6600FF75
00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF5700FF5700FF5700FF5700FF57
00FF5700FF5700FF5700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF47
00FF4700FF4700FF4700FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF1900FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0005FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0014FF00
14FF0014FF0014FF0014FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0014FF0014FF0014FF0014FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0005FF0014FF0014FF0014FF0014FF0014FF0014FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0000FF0A00FF0A00FF0A
00FF0A00FF0A00FF1900FF1900FF1900FF2800FF2800FF3800FF5700FF6600FF8500F0FF
00FFB300FFA300FFD100B3FF8F00FF00FFE100FFB300FF9400FFC200FF9400FF7500FF75
00FF6600FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF6600FF66
00FF7500FF8500FFA300FFFF00FFD100FFD100FFE100FFF000D1FF0019FF2300FFFF001E
0085FFFF00F500E1FF00FFD100FFC200FFC200A3FF00FFC200FFA300FF6600FF5700FF57
00FF5700FF4700FF4700FF3800FF3800FF3800FF3800FF2800FF2800FF2800FF2800FF19
00FF1900FF1900FF1900FF1900FF1900FF0A00FF0A00FF0A00FF0A00FF0A00FF0A05FF00
05FF0005FF0000FF0A05FF0005FF0005FF0005FF0005FF0005FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0042FF0042FF0042FF0033FF0033FF0042FF0042FF0042FF0042FF0042FF0042FF00
42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
42FF0042FF0042FF0042FF0042FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF00
51FF0051FF0042FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF00
51FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF00
51FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF00
51FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF00
51FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF00
51FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF00
51FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF00
51FF0051FF0051FF0051FF00
23FF0023FF0023FF0023FF0023FF0023FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0023FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0014FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0000FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF2800FF2800FF2800FF2800FF2800FF2800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF4700FF3800FF3800FF3800FF3800FF4700FF4700FF4700FF4700FF47
00FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF5700FF5700FF57
00FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF6600FF66
00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7500FF7500FF7500FF75
00FF7500FF7500FF7500FF7500FF8500FF8500FF8500FF8500FF8500FF9400FF9400FF94
00FF9400FFA300FFB300FFB300FFC200FFC200FFD100FFD100F0FF00FFFF00FFF000FFE1
00FFF000FFF000FFF000FFF000FFFF00FFFF00FFFF00F0FF00E1FF00D1FF00C2FF00B3FF
0094FF0066FFDC00FF0028FF0066FF0094FF00A3FF0057FF00B3FF00D1FF00E1FF00E1FF
00F0FF00F0FF00E1FF00B3FF1400FF7000FF00B3FF00E1FF0028FF00FFD100FFC200FFB3
00FFB300FFA300FFA300FFA300FF9400FF9400FF9400FF8500FF8500FF8500FF8500FF85
00FF8500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF6600FF6600FF66
00FF6600FF6600FF6600FF6600FF6600FF6600FF5700FF5700FF5700FF5700FF5700FF57
00FF5700FF5700FF5700FF5700FF5700FF5700FF4700FF4700FF4700FF4700FF4700FF47
00FF4700FF4700FF4700FF4700FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A05FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0005FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0014FF00
14FF0014FF0014FF0014FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0014FF0014FF0014FF0014FF0014FF0014FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0005FF0014FF0014FF0014FF0014FF0014FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0000FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF1900FF1900FF1900FF1900FF2800FF2800FF3800FF3800FF5700FF7500E1FF
00FF9400FF9400A3FFFF00D700FFFF8000FF0085FF00FFC20075FF00FFB300FFC200E1FF
00FF8500FF6600FF6600FF5700FF5700FF5700FF5700FF5700FF5700FF6600FF6600FF66
00FF7500FF7500FF9400FFA300FFB300FFB300FFD100FFF000C2FF0085FF0066FF3300FF
2300FF0075FF00E1FF00FFF000FFF00057FF00A3FF00FFD100FFA300FF6600FF5700FF57
00FF4700FF4700FF4700FF3800FF3800FF3800FF3800FF2800FF2800FF2800FF2800FF19
00FF1900FF1900FF1900FF1900FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A05FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
42FF0042FF0042FF0042FF0042FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF00
51FF0042FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF00
51FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF00
51FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF00
51FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF00
51FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF00
51FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF00
51FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF00
51FF0051FF0051FF0051FF00
23FF0023FF0023FF0023FF0023FF0023FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0023FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
14FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0000FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF1900FF0A00FF0A00FF0A00FF0A00FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF3800FF2800FF2800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF2800FF2800FF3800FF2800FF3800FF3800FF2800FF28
00FF3800FF3800FF2800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF4700FF4700FF4700FF4700FF47
00FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF5700FF4700FF4700FF4700FF47
00FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF66
00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7500FF7500FF7500FF7500FF75
00FF7500FF7500FF7500FF7500FF8500FF8500FF8500FF8500FF8500FF8500FF9400FF94
00FF9400FFA300FFD100FFC200FFD100FFD100FFE100D1FF0094FF00E1FF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F0FF00F0FF00D1FF0047FF0085FF00A3FF
0094FF0038FF7000FFFF00008F00FF0075FF0085FF3300FF0085FFFF000000B3FF00D1FF
00E1FF00E1FF00D1FF00A3FFAE00FF0047FF00D1FF00FFFF00FFF000FFD100FFC200FFC2
00FFB300FFA300FFA300FFA300FF9400FF9400FF9400FF8500FF8500FF8500FF8500FF85
00FF8500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF6600FF6600FF66
00FF6600FF6600FF6600FF6600FF6600FF6600FF5700FF5700FF5700FF5700FF5700FF57
00FF5700FF5700FF5700FF5700FF5700FF4700FF4700FF4700FF4700FF4700FF4700FF47
00FF4700FF4700FF4700FF4700FF4700FF4700FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A05FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0005FF0005FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0023FF0023FF00
23FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0000FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF1900FF1900FF1900FF2800FF2800FF2800FF3800FF4700FF8500FF75
00FF7500FF7500FF8500FF9400FFD100C2FFFF000000C2FF00C2FF0038FF00E1FF00FFA3
00FF8500FF7500FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF66
00FF7500FF8500FF8500FF9400FFA300FFB300FFC200FFD10057FF00D1FF0094FF0047FF
AE00FF0019FF0038FF00C2FF3300FF00FFF000FFB300FF9400FF7500FF6600FF6600FF57
00FF4700FF4700FF4700FF3800FF3800FF3800FF2800FF2800FF2800FF2800FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF0A00FF0A00FF0A00FF0A00FF0A00FF0A05FF00
00FF0A05FF0005FF0005FF0005FF0005FF0005FF0005FF0014FF0014FF0005FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0023FF0023FF0023FF0023FF00
23FF0023FF0014FF0023FF0023FF0023FF0023FF0023FF0023FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
42FF0042FF0042FF0042FF0042FF0042FF0051FF0051FF0051FF0051FF0051FF0051FF00
42FF0042FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF00
51FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF00
51FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF00
51FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF00
51FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF00
51FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF00
51FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF00
51FF0051FF0051FF0051FF00
23FF0023FF0023FF0023FF0023FF0023FF0033FF0033FF0033FF0033FF0023FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
23FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0014FF0014FF0014FF0023FF0023FF0023FF0023FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0000FF0A05FF0005FF0005FF0000FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF1900FF0A00FF0A00FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF2800FF1900FF2800FF1900FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF3800FF2800FF2800FF2800FF3800FF3800FF2800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF4700FF4700FF4700FF4700FF47
00FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF47
00FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF6600FF66
00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7500FF7500FF75
00FF7500FF7500FF7500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF9400FF94
00FF9400FFA300FFD10019FF00FFFF00FFF000FFFF00D1FF0066FF00D1FF00E1FF00E1FF
00D1FF00A3FF00F0FF00F0FF00F0FF00F0FF00F0FF00E1FF00D1FF0085FF4200FF0075FF
0075FF0047FF0500FF6100FF0038FF0057FF0057FF0028FFFF00C70057FF00B3FF00C2FF
00D1FF00D1FF00B3FF6100FF0085FF00C2FF00F0FF00FFF000FFE100FFD100FFC200FFC2
00FFB300FFB300FFA300FFA300FF9400FF9400FF9400FF9400FF8500FF8500FF8500FF85
00FF8500FF8500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF6600FF66
00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF5700FF5700FF5700FF57
00FF5700FF5700FF5700FF5700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF47
00FF4700FF4700FF4700FF4700FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
14FF0014FF0014FF0014FF0005FF0005FF0005FF0005FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0023FF0023FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0000FF0A05FF0000FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF1900FF1900FF1900FF1900FF2800FF2800FF2800FF3800FF4700FF4700FF57
00FF5700FF6600FF7500FF9400FFB300D1FF2300FF6100FF00C2FF00FFD100FFB300FF94
00FF8500FF7500FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7500FF75
00FF7500FF8500FF8500FF9400FFA300FFB300FFC200FFE100FFF000D1FF0038FF0038FF
0066FF00B3FF00F0FF00F0FF6100FF00FFD100FFB300FF9400FF7500FF6600FF5700FF57
00FF4700FF4700FF3800FF3800FF3800FF3800FF2800FF2800FF2800FF2800FF2800FF28
00FF1900FF1900FF1900FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A05FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
42FF0042FF0042FF0042FF0042FF0042FF0042FF0051FF0051FF0051FF0051FF0042FF00
42FF0042FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF00
51FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF00
51FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF00
51FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF00
51FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF00
51FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF00
51FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF00
51FF0051FF0051FF0051FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0023FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
23FF0023FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0000FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF2800FF1900FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF3800FF2800FF2800FF2800FF3800FF2800FF2800FF2800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF4700FF3800FF3800FF3800FF4700FF47
00FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF57
00FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF6600FF5700FF66
00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7500FF7500FF75
00FF7500FF7500FF7500FF7500FF7500FF8500FF8500FF8500FF8500FF8500FF9400FF94
00FF9400FFA300FFB300FFD100D1FF0057FFFF008ADC00FF8F00FF0500FF0085FF00A3FF
FF008A00B3FF00E1FF00E1FF00F0FF00F0FF00E1FF00D1FF0085FF0075FF1400FF0057FF
0047FF0038FF1400FF8000FF000AFF1400FF3300FFFF001E0057FF0085FF00A3FF00A3FF
0085FF00B3FF0094FF0047FF00A3FF00E1FF00FFFF00FFF000FFE100FFD100FFD100FFC2
00FFC200FFB300FFB300FFA300FFA300FF9400FF9400FF9400FF8500FF8500FF8500FF85
00FF8500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF6600FF66
00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF5700FF5700FF5700FF57
00FF5700FF5700FF5700FF5700FF5700FF4700FF5700FF4700FF4700FF4700FF4700FF47
00FF4700FF4700FF4700FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0023FF0023FF0023FF0023FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0000FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF1900FF1900FF1900FF1900FF2800FF2800FF2800FF3800FF3800FF4700FF47
00FF5700FF6600FF85EB00FF00A3FF00C2FF0085FF0028FF00E1FF00FFD100FFA300FF94
00FF8500FF7500FF7500FF6600FF6600FF6600FF6600FF6600FF7500FF7500FF7500FF75
00FF8500FF8500FF9400FF9400FFA300FFC20047FF00FFFF00F0FF3300FF4200FF00C2FF
00C2FF00FFFF00FFE100FFE10038FF00B3FF00FFF000FFE100FF8500FF7500FF5700FF57
00FF4700FF4700FF3800FF3800FF3800FF3800FF2800FF2800FF2800FF2800FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF0A00FF0A00FF0A00FF0A00FF0A05FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
42FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0042FF0051FF00
51FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF00
51FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF00
51FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF00
51FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF00
51FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF00
51FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF00
51FF0051FF0051FF0051FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0023FF0023FF0023FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0000FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF0A00FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF3800FF3800FF2800FF28
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF4700FF47
00FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF5700FF57
00FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF57
00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7500FF7500FF7500FF75
00FF7500FF7500FF7500FF7500FF7500FF8500FF8500FF8500FF8500FF8500FF9400FF94
00FF9400FFA300FFA300FFD1FF00E600FFF000FFFF00C2FF0057FF0085FF0094FF0028FF
1400FF0066FF00A3FF00A3FF00D1FF00E1FF00D1FF00C2FF00A3FF0057FF0028FF0500FF
FF00000500FF7000FFFF00F5FF00B83300FFFF0000FF0000FF007A0057FF8000FF0066FF
0038FF0500FF0047FF0094FF00C2FF00E1FF00F0FF00FFFF00FFF000FFE100FFE100FFD1
00FFC200FFC200FFB300FFB300FFA300FFA300FF9400FF9400FF8500FF8500FF8500FF85
00FF8500FF8500FF8500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF6600FF66
00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF5700FF6600FF5700FF57
00FF5700FF5700FF5700FF5700FF5700FF5700FF4700FF4700FF4700FF4700FF4700FF47
00FF4700FF4700FF4700FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF2800FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0000FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF1900FF1900FF1900FF1900FF1900FF2800FF2800FF3800FF3800FF3800FF47
00FF4700FF5700FF6600FF9400FFB300E1FF00FFD100F0FF0500FF0085FF00FFB300FFA3
00FF8500FF8500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF85
00FF9400FF9400FF9400FFA300FFA300FFC200F0FF00B3FF00C2FF5100FF0066FF00F0FF
00FFF000FFD100FFC200FFC200FFE10094FFFF00E6000AFF00FFB300F0FF00FF6600FF57
00FF4700FF4700FF3800FF3800FF3800FF3800FF2800FF2800FF2800FF2800FF2800FF19
00FF1900FF1900FF1900FF1900FF0A00FF0A00FF0A00FF0A00FF0A00FF0A05FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0023FF0023FF0023FF0023FF0023FF0023FF00
14FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0033FF0042FF00
42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
42FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0042FF0051FF0051FF00
51FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF00
51FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF00
51FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF00
51FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF00
51FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF00
51FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF00
51FF0051FF0051FF0051FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0023FF0023FF0023FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0000FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF2800FF1900FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF3800FF2800FF2800FF28
00FF2800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF4700FF47
00FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF47
00FF4700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF57
00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7500FF75
00FF7500FF7500FF7500FF7500FF7500FF7500FF8500FF8500FF8500FF8500FF8500FF94
00FF9400FFA300FFA300FFB300FFC200FFD100FFF000B3FF0075FF00F0FF00E1FFFF0099
0094FF0066FFFF003D0094FF00C2FF00C2FF00C2FF00B3FF00A3FF0075FF7000FFAE00FF
FF00006100FF7000FFFF003D9E00FF8F00FFEB00FFEB00FF8F00FFFA00FF8F00FFFF00F5
1400FF0075FF0085FFFF00000094FF00A3FF00D1FF5100FF00E1FF00FFFF00FFFF00FFFF
0075FF00FFD100FFC200FFC200FFB300FFA300FF9400FF9400FF9400FF8500FF8500FF85
00FF8500FF8500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF75
00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF5700FF5700FF57
00FF5700FF5700FF5700FF5700FF5700FF5700FF4700FF4700FF4700FF4700FF4700FF47
00FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
05FF0014FF0014FF0014FF0014FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0000FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF1900FF1900FF1900FF1900FF1900FF2800FF2800FF2800FF3800FF3800FF3800FF47
00FF4700FF5700FF6600FF7500FFC200FFB300FFB300FFD100E1FF00A3FF00FFE100FFF0
00FFA300FF8500FF8500FF7500FF7500FF7500FF7500FF7500FF7500FF8500FF8500FFA3
00FFB300FFA300FFA300FFA300FFB300E1FF0085FF0094FF2300FF0028FF00C2FF00FFFF
00FFE100FFC200FFC200FFB300FFB300FFB300FFE100E1FF00FFB300C2FF00FF6600FF57
00FF5700FF4700FF4700FF3800FF3800FF3800FF3800FF2800FF2800FF2800FF2800FF19
00FF1900FF1900FF1900FF1900FF1900FF0A00FF0A00FF0A00FF0A00FF0A05FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
42FF0042FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0042FF0051FF0051FF00
51FF0051FF0051FF0051FF0051FF0051FF0042FF0051FF0051FF0051FF0051FF0051FF00
51FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF00
51FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF00
51FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF00
51FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF00
51FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF00
51FF0051FF0051FF0051FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0033FF0033FF00
33FF0033FF0033FF0023FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0023FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0023FF0023FF0023FF0023FF0023FF0033FF0033FF0033FF0033FF0033FF00
33FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0000FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF19
00FF0A00FF0A00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF2800FF1900FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF4700FF47
00FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF47
00FF4700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF6600FF66
00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7500FF75
00FF7500FF7500FF7500FF7500FF7500FF7500FF8500FF8500FF8500FF8500FF8500FF94
00FF9400FF9400FFA300FFB300FFB300FFC200FFD100FFD100FFF000FFF000FFFF00E1FF
00D1FF0038FF0075FFFF001E0085FF00A3FF0038FF0066FF0028FF0038FF000AFF8F00FF
FF0099CC00FFFF0000FF0000FF0000FA00FFFF00E6FF00002300FF0047FFCC00FF0094FF
0057FF00B3FF00B3FF0094FF0028FF0028FF0085FF0075FF0094FF00E1FF00D1FF0038FF
00E1FF00FFF000FFF00094FF00FFC200FFB300FFA300FF9400FF9400FF9400FF8500FF85
00FF8500FF8500FF8500FF8500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF75
00FF6600FF6600FF7500FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF5700FF57
00FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF4700FF4700FF4700FF47
00FF4700FF4700FF4700FF4700FF4700FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0005FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0000FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF1900FF1900FF1900FF1900FF1900FF2800FF2800FF2800FF3800FF3800FF3800FF47
00FF4700FF5700FF5700FF6600FF7500FF8500FF9400FFC200FFF0FF002E00B3FF00D1FF
9E00FF00FFA300FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF9400FFD1
00FFE100FFC200FFB300FFB300FFC200FFD100FFFF00D1FF0057FFFF00000094FF2300FF
00C2FF00FFC200FFB300FFA300FFA300FFA300FFC200FF9400FF8500FF8500FF6600FF57
00FF4700FF4700FF4700FF3800FF3800FF3800FF3800FF3800FF2800FF2800FF2800FF19
00FF1900FF1900FF1900FF1900FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
05FF0005FF0005FF0005FF0005FF0005FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0042FF0042FF0042FF0033FF0033FF0042FF0042FF0042FF0042FF00
42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
42FF0042FF0051FF0051FF0051FF0051FF0051FF0051FF0042FF0042FF0051FF0051FF00
51FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF00
51FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0042FF0051FF0051FF0051FF00
51FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF00
51FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF00
51FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF00
51FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF00
51FF0051FF0051FF0051FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0033FF00
33FF0033FF0023FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF3800FF2800FF2800FF2800FF28
00FF2800FF3800FF2800FF2800FF2800FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF4700FF3800FF38
00FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF47
00FF4700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF57
00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7500FF7500FF75
00FF7500FF7500FF8500FF7500FF7500FF8500FF8500FF8500FF8500FF8500FF8500FF94
00FF9400FF9400FFA300FFA300FFA300FFB300FFC200FFC200FFD100FFE100FFE100FFF0
00FFFF00E1FF00C2FF0094FFFF00D70028FF1400FF8000FFFF003D5100FF2300FF8000FF
FF00009E00FFBD00FFDC00FFAE00FF5100FFFF00D7FF00A81400FF0066FF0094FF00B3FF
00C2FF00D1FF00D1FF00C2FF0075FF0094FF0038FFFF004C0019FF0057FF6100FFFF005C
0066FF0500FF8000FF00E1FF00FFE100FFB300FFA300FF9400FF9400FF9400FF8500FF85
00FF8500FF8500FF8500FF8500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF75
00FF7500FF7500FF6600FF6600FF7500FF6600FF6600FF6600FF6600FF6600FF6600FF57
00FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF4700FF4700FF4700FF4700FF47
00FF4700FF4700FF4700FF4700FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0000FF0A05FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0000FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF19
00FF1900FF1900FF1900FF1900FF2800FF2800FF2800FF2800FF3800FF3800FF4700FF47
00FF4700FF5700FF5700FF6600FF6600FF7500FF949E00FF0057FF0047FF0085FF00FFF0
00FFC200FFA300FF9400FF8500FF8500FF8500FF8500FF8500FF9400FFA300FFA300E1FF
0094FF00FFE100FFC200FFC200FFD100FFE100FFFF3300FFBD00FF0038FF00C2FF00D1FF
00FFD100FFB300FFA300FF9400FF9400FF9400FF8500FF7500FF7500FF6600FF5700FF57
00FF4700FF4700FF4700FF4700FF3800FF3800FF3800FF2800FF2800FF2800FF2800FF28
00FF1900FF1900FF1900FF1900FF1900FF0A00FF0A00FF0A00FF0A00FF0A05FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0042FF0042FF0042FF0042FF0042FF00
42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
42FF0042FF0042FF0051FF0051FF0051FF0051FF0042FF0042FF0042FF0051FF0051FF00
51FF0051FF0051FF0051FF0051FF0042FF0051FF0051FF0051FF0051FF0051FF0051FF00
51FF0042FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF00
51FF0051FF0042FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF00
51FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF00
51FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF00
51FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF00
51FF0051FF0051FF0051FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00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23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00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23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00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23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00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23FF0023FF0023FF0014FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00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14FF0014FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00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14FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00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14FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0033FF0033FF0033FF00
33FF0033FF0033FF0023FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0023FF00
23FF0023FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0000FF0A05FF0005FF0005FF0005FF0000FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF0A00FF0A00FF0A00FF0A00FF0A
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF3800FF3800FF2800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF47
00FF4700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF66
00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7500FF7500FF7500FF75
00FF7500FF7500FF7500FF7500FF7500FF8500FF8500FF8500FF8500FF8500FF8500FF85
00FF9400FF9400FF9400FF9400FFA300FFA300FFB300FFC200B3FF00FFF000FFF00094FF
00FFFF00FFF000FFF000FFF000FFF000FFF000FFF000FFFF00FFFF00F0FF00F0FF00E1FF
00D1FF00B3FF0085FF9E00FFFF00A85100FF0038FF7000FF00B3FF00C2FF00D1FF00E1FF
00F0FF00FFFF00FFF000FFF000FFE100FFE100FFE100FFD100FFD100FFD100FFC200FFC2
00FFB300FFB300FFB300FFB300FFA300FFA300FFA300FFA300FF9400FF9400FF9400FF94
00FF9400FF9400FF9400FF9400FF8500FF9400FF8500FF8500FF8500FF8500FF8500FF85
00FF8500FF8500FF8500FF8500FF8500FF8500FF9400FF9400FFA300FF9400FF8500FF85
00FF8500FF8500FF9400FFC200D1FF00FF9400FF7500FF6600FF6600FF5700FF5700FF57
00FF4700FF4700FF4700FF4700FF4700FF4700FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A05FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0005FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0000FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF1900FF2800FF3800FFB300FF66
00FF5700FF5700FF4700FF4700FF4700FF5700FFB300FFC200FFC200FFE100FF9400FF94
00FF9400FFA300FFFF00B3FF00FFF000B3FF00C2FF8000FF00A3FF00FFE100FFC200FFB3
00FFC200FFC200E1FF00B3FF00F0FF00F0FF00D1FF5100FF000AFF4200FF0500FF0047FF
2300FFFF00B80500FF0066FF0094FF00B3FF00C2FF00D1FF00F0FF00FFFF00FFFF00FFF0
00FFFF0066FF00A3FF00FFD100FFB300FFB300FFA300FF8500FF8500FF7500FF7500FF75
00FF6600FF6600FF6600FF7500FF7500FF8500FF8500FF9400FFB300B3FF00E1FF00B3FF
00A3FF00FFF03300FF00FFB300FF6600FF3800FF1900FF1900FF0A00FF0A00FF0A05FF00
05FF0005FF0005FF0005FF0005FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0042FF00
42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0033FF0042FF0042FF0042FF00
42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
42FF0042FF0042FF0042FF00
14FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00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14FF0014FF0014FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00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14FF0014FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00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14FF0014FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00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14FF0014FF0014FF0023FF0023FF0014FF0023FF0023FF0023FF0023FF0023FF0023FF00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14FF0014FF0014FF0014FF0014FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00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14FF0014FF0014FF0014FF0014FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00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14FF0014FF0014FF0014FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00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14FF0014FF0014FF0014FF0014FF0023FF0023FF0023FF0014FF0023FF0023FF0023FF00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14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0023FF0023FF0023FF0023FF00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14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0023FF0023FF0023FF0023FF00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14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0023FF0023FF0023FF0023FF00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14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0023FF0023FF0023FF0023FF00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14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00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14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00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14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
23FF0023FF0023FF0023FF0023FF0014FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0033FF0033FF0033FF0033FF0033FF00
23FF0023FF0023FF0023FF0023FF0023FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0023FF0023FF0023FF0023FF0023FF0023FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0033FF00
33FF0033FF0033FF0033FF0033FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0000FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF4700FF4700FF4700FF4700FF5700FF5700FF6600FF6600FF6600FF6600FF6600FF66
00FF7500FF7500FF7500FF7500FF7500FF8500FF8500FFB300FFB300FFA300FFB300FFE1
7000FF00FFF000FFC200FFB300FFA300FFA300FFA300FFA300FFA300FFA300FFA300FFA3
00FFA300FFA300FFA300FFA300FFA300FFA300FFA300FFA300FFA300FFA300FFA300FFA3
00FFA300FFA300FFA300FFB300FFB300FFB300FFB300FFB300FFB300FFC200FFC200FFD1
00FFE100FFFF00A3FFFF00B800A3FF00D1FF00E1FF00F0FF00F0FF00F0FF00E1FF00E1FF
00D1FF0066FF8000FF0066FF0066FF0019FF1400FFFA00FF0019FF0057FF0085FF0094FF
00A3FF00B3FF00C2FF00D1FF00D1FF00D1FF00C2FF00B3FF0085FF0019FF00B3FF00C2FF
00B3FF0057FF0500FF0057FF00A3FF00FFFF00FFE100FFD100FFD100FFD100FFC200FFC2
00FFC200FFC200FFC200FFC200FFD100FFD100FFE10066FF00E1FF00F0FF00B3FF8000FF
0085FF00D1FF00D1FFFF00B800FFFF00FFE100FFC200FFB300FFA300FFA300FF9400FF94
00FF8500FF8500FF7500FF7500FF7500FF6600FF6600FF6600FF6600FF6600FF5700FF57
00FF5700FF5700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A05FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0000FF0A05FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0005FF0005FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0005FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0005FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0005FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0000FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF2800FF2800FF2800FF2800FF2800FF2800FF3800FF3800FF38
00FF3800FF3800FF3800FF4700FF4700FF4700FF4700FF4700FF5700FF5700FF5700FF57
00FF6600FF6600FF7500FF7500FF7500FF8500FF8500FF9400FF9400FFA300FFB300FFFF
0066FF00FFFF00FFFF0085FF3300FF00B3FF00F0FF00FFFF00FFE100FFD100FFC200FFD1
00FFFF2300FF00FFB300FF9400FF9400FF8500FF8500FF7500FF7500FF7500FF7500FF75
00FF8500FF9400FF9400FFB300FFD10075FF0019FF0038FF5100FF00FFB300FFB300FFA3
00FFA30057FF00D1FF00FFB300FF6600FF4700FF3800FF3800FF2800FF2800FF1900FF0A
00FF0A00FF0A05FF0005FF0005FF0005FF0005FF0005FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0023FF0033FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0014FF0023FF0014FF0014FF0005FF0000FF0A00FF1900FF28
00FF2800FF4700FF9400FFE100FF4700FF2800FF1900FF0A05FF0005FF0014FF0014FF00
14FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00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14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00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14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00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14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00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14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00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14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00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14FF0005FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00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05FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00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05FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00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05FF0014FF0014FF0014FF0005FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00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05FF0005FF0005FF0005FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00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05FF0005FF0005FF0005FF0014FF0014FF0014FF0014FF0005FF0014FF0014FF0014FF00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05FF0005FF0005FF0005FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0023FF0023FF00
14FF0014FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0014FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF4700FF4700FF4700FF4700FF4700FF5700FF5700FF6600FF66
00FF6600FF6600FF6600FF7500FF7500FF8500FFB300A3FF00FFE100FFB300FFC26100FF
00FFF000FFB300FFA300FFA300FFB300FFC200FFF00047FF00FFFF0094FF00C2FF00FFF0
00FFF000FFF000FFFF00D1FF0085FFFF0000000AFF0047FF0085FF00E1FF00E1FF00FFFF
00FFF000FFF000FFF000FFF000FFF000FFF000FFFF00B3FF00D1FF00F0FF00F0FF00E1FF
00D1FF9E00FF00A3FF00B3FF00A3FF0075FF0057FF000AFFDC00FFFF00F5FF003DFF00F5
9E00FF8000FFEB00FFFF007A5100FF7000FFBD00FFFF0000FF0000FF0000FF001EFF00E6
FF0000FF00B8FF0000FF0000FF0000FF008AFF0000FF008A9E00FFBD00FF0500FF0019FF
0047FF0066FF0075FF0085FF0057FF0047FF0047FF00C2FF00D1FF00C2FF2300FF00A3FF
8F00FF00E1FF00FFFF00FFFF00FFFF00FFFF00F0FF0094FF0047FF0028FF000AFF7000FF
00C2FF00B3FF00A3FF0066FF00FFF000FFE100FFD100FFE10085FF00E1FF00FFD100FFFF
00D1FF00FFB300FFB300FFA300FFA300FFA300FFC20094FF00FFD100FFA300FFB300FFD1
00FFD100FF9400FF7500FF7500FF7500FF6600FF7500FF7500FF7500FF7500FF6600FF57
00FF5700FF4700FF4700FF4700FF4700FF4700FF4700FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF19
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A05FF0005FF0005FF0000FF0A00FF0A00FF0A00FF0A05FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0000FF0A05FF0005FF0005FF0005FF00
05FF0005FF0000FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF38
00FF3800FF3800FF3800FF3800FF3800FF4700FF4700FF4700FF4700FF4700FF5700FF57
00FF6600FF7500FFA300FFB300A3FF00FFF000FFB300FFB300FFC200FFD100FFE100FFFF
00E1FF0075FF6100FF0047FF0047FF00E1FF00FFFF00F0FF0057FF00FFE100FFB300FFA3
00FF8500FF7500FF6600FF6600FF5700FF5700FF4700FF4700FF4700FF4700FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF2800FF3800FF2800FF2800FF2800FF28
00FF2800FF2800FF1900FF1900FF1900FF1900FF1900FF1900FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A05FF0005FF0005FF0005FF0005FF0005FF0005FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0033FF00
33FF0033FF0033FF0033FF0023FF0023FF0033FF0033FF0033FF0033FF0033FF0023FF00
33FF0033FF0033FF0033FF0033FF0023FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0014FF0014FF0014FF0014FF0014FF0005FF0005FF0000FF0A00FF1900FF28
00FF3800FF5700FFFF4200FF00FFA300FFD1AE00FF00FFC200FF9400FF5700FF3800FF28
00FF2800FF1900FF1900FF1900FF1900FF1900FF1900FF2800FF3800FF4700FF6600FF75
00FFA300FFF00085FF00FFD10094FF00FFA300FF5700FF3800FF2800FF1900FF1900FF0A
00FF0A00FF0A05FF0000FF0A05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0000FF0A
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0014FF0014FF0014FF0014FF00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05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0014FF0014FF0014FF0005FF00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05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0014FF0014FF0005FF0005FF00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05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00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05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00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05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00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05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0014FF0014FF0005FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0023FF0023FF0023FF0014FF0014FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0000FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF4700FF4700FF4700FF4700FF47
00FF4700FF5700FF5700FF5700FF5700FF5700FF5700FF6600FF6600FF6600FF7500FF66
00FF7500FF7500FF7500FF7500FF8500FF8500FF8500FF8500FF9400FF9400FF9400FFA3
00FFA300FFB300FFB300FFC200FFC200FFD100FFE100FFE100FFFF00C2FF00C2FF0019FF
0085FF00D1FF00E1FF00E1FF00E1FF00D1FF00B3FF7000FFFF005C00B3FF00D1FF00D1FF
00A3FF00C2FF0094FF00B3FF00B3FF00A3FF6100FF0038FF1400FF2300FFFF00A8FF00C7
FF0000FF00C75100FF3300FF0028FF0028FF0019FF2300FF5100FFFF004CFF00B88000FF
5100FF1400FF0047FF0047FF0047FF000AFF7000FF0038FF0057FF0057FF0019FFFF0000
0066FF0094FF00A3FF0094FF0047FF00C2FF00E1FF00FFFF00FFF000FFE100FFE100FFD1
00FFD100FFC200FFC200FFC200FFC200FFC200FFC200FFC200FFD100FFD100FFD100FFD1
00FFD100FFE100FFE100FFF000FFF000FFFF00E1FF00A3FF0500FF0075FF00D1FFFF00B8
00B3FF0094FF0094FFEB00FF0085FF0057FF1400FF3300FF7000FF0038FF0066FF0075FF
0500FF00D1FF0085FF0085FF00FFFF00FFE100FFC200FFE10057FF00D1FF00FFD100F0FF
00FFB300FF8500FF7500FF6600FF5700FF5700FF4700FF4700FF4700FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A05FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0000FF0A05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0000FF0A00FF0A05FF0005FF0005FF0005FF0000FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF2800FF2800FF2800FF2800FF2800FF2800FF3800FF3800FF3800FF3800FF3800FF47
00FF4700FF4700FF4700FF4700FF4700FF5700FF5700FF5700FF5700FF5700FF6600FF66
00FF6600FF7500FF7500FF7500FF8500FFC200FFB300FFB300FFC200FFC200FFF000A3FF
0500FF00E1FF00FFE100FFC200FFB300FFA300FF9400FF9400FF8500FF8500FF7500FF75
00FF6600FF6600FF5700FF5700FF4700FF4700FF4700FF3800FF3800FF3800FF3800FF38
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF0A00FF0A00FF0A00FF1900FF0A00FF0A00FF0A00FF0A00FF0A
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0005FF0005FF0005FF0005FF0000FF0A00FF0A00FF19
00FF2800FF8500FF4700FF3800FF3800FF4700FF5700FF6600FF8500FFB30066FF0094FF
0057FF00FFFF00A3FF00FF940028FF00F0FF00FF7500FF6600FF7500FF8500FFF00028FF
00FFC200FF8500FF7500FF6600FF4700FF4700FF3800FF3800FF2800FF2800FF2800FF19
00FF1900FF2800FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF2800FF2800FF47
4200FF00FF5700FF3800FF38
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00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05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00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00FF0A00FF0A05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00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00FF0A00FF0A05FF0005FF0000FF0A05FF0005FF0005FF0005FF0005FF0005FF0005FF00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00FF0A00FF0A00FF0A00FF0A00FF0A05FF0005FF0000FF0A05FF0005FF0000FF0A05FF00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00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A05FF0005FF0000FF0A05FF00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00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A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00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A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00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A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00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A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00FF0A00FF1900FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF1900FF1900FF1900FF2800FF6600FF2800FF2800FF28
00FF3800B3FF00FFB300F0FF00FF1900FF0A00FF0A00FF0A00FF0A05FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0014FF0014FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0014FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0014FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0014FF0014FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0000FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF4700FF4700FF4700FF4700FF47
00FF4700FF4700FF4700FF4700FF5700FF5700FF5700FF5700FF6600FF6600FF6600FF75
00FF7500FF7500FF8500FF8500FF9400FFB300F0FFAE00FF00FFE100FFD100FFE100F0FF
00F0FF00D1FF7000FF0019FF0057FF0085FF0085FF00A3FF00D1FF00FFF000FFD100FFC2
00FFC200FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC200FFC200FFC2
00FFD100FFE100FFE100FFE100FFE100FFF000FFF000F0FF0066FF7000FF0500FF00F0FF
00F0FF00F0FF00F0FF00F0FF00E1FF00D1FF00C2FF0085FF0500FF0075FF0057FFFF00A8
0028FF0075FF0085FF0085FF0094FF00D1FF00F0FF00F0FF00FFFF00FFFF00FFF000FFF0
00FFF000FFF000FFF000FFE100FFE100FFF000FFD100FFC200FFB300FFB300FFB300FFB3
00FFA300FFA300FFB300FFA300FFA300FFA300FF9400FFA300FF9400FF9400FF9400FF94
00FF9400FF9400FF9400FF9400FF9400FF9400FF9400FF8500FF9400FF8500FF8500FF85
00FF9400FF8500FF8500FF9400FF9400FF9400FFA30075FF00FFB300FF9400FF8500FF75
00FF7500FF6600FF6600FF6600FF6600FF6600FF6600FF5700FF5700FF5700FF5700FF57
00FF5700FF5700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF1900FF1900FF1900FF1900FF1900FF2800FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A05FF0005FF00
05FF0000FF0A00FF0A00FF0A00FF0A05FF0005FF0005FF0005FF0005FF0000FF0A00FF0A
05FF0005FF0005FF0005FF0005FF0005FF0000FF0A05FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0000FF0A05FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0000FF0A05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0000FF0A00FF0A
00FF0A05FF0005FF0005FF0005FF0005FF0005FF0000FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF28
00FF2800FF2800FF2800FF2800FF3800FF3800FF3800FF4700FF5700FF5700FF6600FF94
00FFA300FFFF00FFB300FFB300FFD15100FF5100FF00D1FF00FFE100FFC200FFB300FFA3
00FFA300FFA300FFB300FFB300FFD12300FF00D1FF00FFFF00F0FF9E00FF0028FF00B3FF
00F0FF00FFF000FFE100FFC200FFB300FFB300FFA300FF9400FF9400FF8500FF8500FF85
00FF8500FF8500FF9400FFD10057FF00FF9400FFA300E1FF00FF7500FF5700FF4700FF38
00FF3800FF2800FF2800FF2800FF2800FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0000FF0A00FF0A00FF0A
00FF0A00FF0A00FF1900FF1900FF1900FF1900FF1900FF2800FF2800FF2800FF2800FF38
00FF3800FF3800FF4700FF4700FF4700FF5700FF6600FF6600FF7500FF9400FFA300FFC2
00FFFF000AFF00F0FF00F0FF00FFE100FFB300FFB300FFC200FFFF00E1FF0075FF00FFD1
00FFA300FF8500FF8500FF7500FF8500FFC200FFB39E00FF00FFC200FFB300FFC200FFF0
00E1FF0085FF0094FF00D1FF
00FF1900FF1900FF0A00FF1900FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A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00FF1900FF1900FF1900FF1900FF0A00FF1900FF0A00FF0A00FF1900FF0A00FF1900FF0A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00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19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00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19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00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19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00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF2800FF2800FF2800FF3800FF4700FF4700FF5700FF7500FFF08F00FF0057FF
00FF5700FF4700FF3800FF2800FF2800FF1900FF1900FF1900FF1900FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF1900FF1900FF3800FF5700FF4700FF1900FF1900FF1900FF0A00FF19
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A05FF0005FF0005FF0005FF0005FF0005FF00
05FF0014FF0014FF0014FF0005FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0023FF0023FF0023FF0023FF0023FF00
23FF0014FF0014FF0014FF0014FF0014FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0014FF0014FF0014FF0014FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0023FF0023FF0023FF0023FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0000FF0A05FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0000FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF4700FF4700FF47
00FF4700FF4700FF4700FF5700FF5700FF6600FF75AE00FF00FFB300FFA300FFE100FFC2
00FFA300FFA300FFB300FFFF00F0FF00D1FFCC00FF0500FF00A3FF0075FF8F00FF00E1FF
00FFF000FFD100FFC200FFC200FFB300FFB300FFB300FFB300FFA300FFA300FFA300FFA3
00FFA300FFA300FFA300FFA300FFA300FFA300FFA300FFA300FFA300FFA300FFA300FFA3
00FFB300FFB300FFB300FFB300FFB300FFC200FFC200FFC200FFD100FFD100FFD100FFD1
00FFE100FFE100FFF000FFFF00F0FF00E1FF00B3FF00C2FF00B3FF00A3FF0085FF0057FF
5100FF0038FF1400FF0085FF0094FF000AFF0066FF00D1FF00FFFF00FFF000FFF000FFE1
00FFE100FFD100FFD100FFC200FFC200FFC200FFC200FFB300FFB300FFB300FFB300FFA3
00FFA300FFA300FFA300FF9400FF9400FF9400FF9400FF9400FF9400FF8500FF8500FF85
00FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF7500FF7500FF7500FF7500FF75
00FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF6600FF6600FF6600FF6600FF66
00FF6600FF6600FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF47
00FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF1900FF1900FF2800FF2800FF1900FF1900FF1900FF1900FF2800FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF0A00FF0A00FF0A00FF0A00FF1900FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A05FF0005FF0005FF0000FF0A00FF0A00FF0A00FF0A05FF00
05FF0005FF0005FF0005FF0005FF0000FF0A00FF0A05FF0005FF0005FF0005FF0005FF00
05FF0005FF0000FF0A00FF0A00FF0A05FF0005FF0005FF0005FF0005FF0005FF0005FF00
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A05FF0005FF0000FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF1900FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF2800FF28
00FF2800FF2800FF2800FF2800FF3800FF3800FF3800FF3800FF4700FF4700FF4700FF57
00FF5700FF6600FF7500FF7500FF8500FF9400FFA300FFC200C2FF00E1FF0057FF00F0FF
00F0FF0094FF00C2FF00B3FF0075FF0094FFAE00FFFF0000FF00D71400FF4200FF4200FF
000AFF0047FF0500FF0075FF00C2FF00F0FF00FFFF00FFFF00F0FF00FFE100FFF000B3FF
0038FF00FFD100FFB300FF9400FF8500FF7500FF6600FF5700FF5700FF4700FF4700FF47
00FF3800FF3800FF2800FF2800FF2800FF2800FF2800FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A05FF0005FF0005FF0005FF0005FF0005FF0000FF0A05FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0014FF00
14FF0014FF0014FF0005FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0005FF0014FF0005FF0014FF0014FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0000FF0A00FF0A00FF2800FF1900FF2800FF38
00FF8500FF9400FF3800FF1900FF0A00FF0A00FF0A05FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0000FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF19
00FF1900FF1900FF1900FF1900FF2800FF2800FF2800FF2800FF2800FF2800FF3800FF38
00FF3800FF4700FF4700FF6600FF8500FFD100A3FF00D1FF8000FF00FFD100FFC200FFC2
00FFD14200FF0094FF6100FF0500FFFF0000000AFF2300FF00A3FF00A3FFBD00FF7000FF
0038FF0066FFEB00FF00E1FF00FFF000A3FF00FFD100FFE10047FF00F0FF00FFE100FF94
00FF8500FF8500FF8500FFA3
00FF2800FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF2800FF28
00FF2800FF2800FF2800FF3800FF4700FF9400FF6600FF6600FF8500FFC200FFE100FF85
00FF6600FF4700FF3800FF3800FF2800FF2800FF1900FF1900FF1900FF1900FF1900FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF0A00FF0A00FF0A
00FF1900FF1900FF1900FF2800FF4700FFFF00FF4700FF2800FF2800FF1900FF1900FF19
00FF1900FF1900FF2800FF1900FF1900FF0A00FF0A00FF0A05FF0005FF0005FF0005FF00
05FF0014FF0014FF0005FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0023FF0023FF0023FF0023FF00
14FF0014FF0014FF0014FF0014FF0014FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0014FF0014FF0014FF0014FF0014FF0014FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0005FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
00FF0A05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0000FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF2800FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF4700FF47
00FF4700FF4700FF4700FF5700FF5700FF5700FF6600FF9400F0FF0085FF8F00FF00E1FF
0019FF00FFD100FFE100D1FF7000FF0075FF00C2FF00C2FF00FFFF00F0FF000AFF00D1FF
00FFFF00FFE100FFC200FFB300FFB300FFA300FFA300FFA300FFA300FFA300FF9400FFA3
00FF9400FF9400FFA300FF9400FFA300FFA300FFA300FFA300FFA300FFA300FFA300FFA3
00FFA300FFB300FFB300FFB300FFB300FFB300FFC200FFC200FFC200FFD100FFD100FFD1
00FFE100FFE100FFF000FFFF000AFF0085FF0066FF0038FF0094FF0094FF0057FF000AFF
FA00FF7000FF2300FF0057FF0066FF0057FF00B3FF00E1FF00F0FF00FFFF00FFF000FFE1
00FFE100FFE100FFD100FFD100FFC200FFC200FFC200FFB300FFB300FFB300FFA300FFA3
00FFA300FFA300FFA300FF9400FFA300FF9400FF9400FF9400FF9400FF8500FF8500FF85
00FF8500FF8500FF8500FF8500FF8500FF8500FF7500FF8500FF7500FF7500FF7500FF75
00FF7500FF7500FF7500FF7500FF7500FF6600FF6600FF6600FF6600FF6600FF6600FF66
00FF6600FF6600FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF4700FF47
00FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF1900FF1900FF2800FF2800FF1900FF19
00FF1900FF2800FF1900FF1900FF1900FF2800FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF0A00FF0A00FF1900FF1900FF0A00FF0A00FF0A
00FF0A00FF0A00FF1900FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
05FF0005FF0005FF0005FF0000FF0A00FF0A00FF0A00FF0A05FF0005FF0005FF0005FF00
05FF0005FF0000FF0A00FF0A00FF0A00FF0A05FF0005FF0005FF0005FF0005FF0005FF00
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF1900FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF2800FF2800FF28
00FF2800FF2800FF2800FF3800FF3800FF3800FF3800FF3800FF4700FF4700FF5700FF57
00FF6600FF7500FF8500FF8500FF9400FFA300FFF000FFD100B3FF8000FF00F0FF00FFE1
00FFE100FFFF00FFFF00FFFF00E1FF00C2FF0057FFBD00FF0038FF4200FF4200FFFF0000
000AFFFA00FFFF00C7BD00FF0085FF0094FF00B3FF00C2FF00A3FF00B3FF00E1FF00C2FF
00FFE100FFB300FFB300FF9400FF8500FF7500FF6600FF6600FF5700FF4700FF4700FF47
00FF3800FF3800FF3800FF2800FF2800FF2800FF2800FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF0A00FF0A00FF1900FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0014FF0014FF0014FF0014FF0014FF0005FF0014FF0014FF00
14FF0014FF0005FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0005FF00
14FF0005FF0014FF0014FF0005FF0014FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0000FF0A00FF0A00FF1900FF8500FF4700FF4700FF47
00FFE100FFC200FF3800FF1900FF1900FF0A00FF0A00FF0A05FF0005FF0005FF0005FF00
05FF0005FF0005FF0000FF0A05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0000FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF1900FF19
00FF1900FF1900FF1900FF2800FF2800FF2800FF2800FF2800FF2800FF3800FF3800FF38
00FF3800FF4700FF4700FF5700FF7500FF9400FFB300E1FF00A3FF00D1FF00FFFF00FFE1
00FFF000F0FF00B3FF0019FF9E00FF0019FF0075FF00A3FF00C2FF00D1FF00E1FF00D1FF
00D1FF00F0FF00B3FF0085FF00FFE100FFB300FFB300FFC20075FF00FFA300FF9400FF85
00FF7500FF7500FF7500FF94
00FF2800FF2800FF2800FF1900FF1900FF1900FF1900FF1900FF2800FF2800FF2800FF28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00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28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00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28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00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF3800FF28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00FF2800FF3800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF3800FF3800FF38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00FF3800FF3800FF3800FF2800FF3800FF2800FF3800FF2800FF3800FF3800FF3800FF38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00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38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00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38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00FF4700FF4700FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF47
00FF4700FF4700FF5700FF5700FF6600FFE100FFC200FFB300FFD100A3FF00FFFF00FFC2
00FFFF00FF8500FF6600FF5700FF4700FF4700FF4700FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF4700FF5700FF853300FF00FFB300FFA30057FF00FFA300FF85
00FF8500FFD100FFB3BD00FF00FFF00094FF00FF8500FF5700FF4700FF3800FF3800FF38
00FF2800FF2800FF1900FF1900FF1900FF0A00FF0A00FF0A00FF0A00FF0A05FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0005FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0000FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF2800FF2800FF2800FF1900FF1900FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF4700FF47
00FF4700FF4700FF4700FF4700FF4700FF4700FF5700FF5700FF5700FF5700FF5700FF66
00FF6600FF6600FF6600FF6600FF6600FF6600FF7500FF7500FF7500FF7500FF7500FF75
00FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF8500FF8500FF85
00FF8500FF8500FF8500FF8500FF8500FF8500FF9400FF9400FF9400FF9400FF9400FFA3
00FFA300FFA300FFB300FFB300FFB300FFC200FFD100FFE100FFE100FFE100FFE100FFF0
00FFF000FFF000FFF000FFF000FFFF00FFFF00F0FF00E1FF00B3FF00B3FF00A3FF0094FF
000AFFFF00008000FF1400FF0075FF0094FF0047FF0094FF00B3FF00B3FF00E1FF00F0FF
00F0FF00F0FF00D1FF0066FF0085FF3300FF0094FF0500FF0094FF00FFD100FFC200FFC2
00FFB300FFA300FFA300FF9400FF9400FF9400FF9400FF9400FF8500FF8500FF8500FF85
00FF8500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF6600FF66
00FF6600FF6600FF7500FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF66
00FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF4700FF4700FF47
00FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF47
00FF3800FF4700FF4700FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF2800FF2800FF2800FF2800FF2800FF3800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF2800FF3800FF28
00FF2800FF2800FF2800FF3800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF0A00FF0A00FF1900FF0A00FF0A00FF1900FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF3800FF3800FF3800FF3800FF3800FF4700FF4700FF5700FF57
00FF5700FF6600FF6600FF6600FF6600FF6600FF7500FF7500FF7500FF7500FF7500FF85
00FF8500FF8500FF9400FFA300FFA300FFB300FFC200FFD100FFF00057FF0075FFAE00FF
FA00FF00D1FF00FFE100FFC200FFB300FFA300FFA300FF9400FF9400FF8500FF8500FF85
00FF8500FF8500FF8500FF8500FF8500FF9400F0FF00FF9400FF8500FF7500FF6600FF66
00FF5700FF5700FF6600FF4700FF3800FF2800FF2800FF2800FF2800FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A05FF0005FF0005FF0005FF0005FF0000FF0A05FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0000FF0A05FF0000FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF19
00FF2800FF5700FFB300FF4700FF2800FF2800FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF2800FF2800FF3800FFA300A3FF00FFA300FFB30028FF0094FF
00C2FF00FFC200D1FF00E1FF0094FF00FFD100FF5700FF2800FF2800FF1900FF1900FF19
00FF1900FF1900FF1900FF0A00FF1900FF0A00FF1900FF0A00FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF2800FF2800FF2800FF3800FF3800FF6600FFF000C2FF
FF006B00FFE100FFB300FF7500FF6600FF5700FF5700FF5700FF5700FF5700FF5700FF57
00FF5700FF6600FF6600FF6600FF7500FF8500FF8500FF9400FFA300FFA300FFB300FFC2
00FFC200FFD100FFE100FFFF000AFF0066FF0028FF0047FFCC00FF00F0FF00FFF000FFE1
00FFD100FFD100FFE100FFFF1400FFFF00D700C2FF00FF9400FF9400FF5700FF4700FF47
00FF3800FF3800FF3800FF28
00FF4700FF4700FF4700FF4700FF3800FF3800FF4700FF3800FF3800FF4700FF4700FF47
00FF4700FF4700FF5700FF5700FF6600FF8500FFFF00FFFF00FFFF00A3FF1400FF00F0FF
00FFD100FF8500FF6600FF5700FF5700FF4700FF4700FF4700FF4700FF4700FF3800FF38
00FF3800FF4700FF4700FF4700FF5700FF7500FFA300E1FF0047FF00FFF000FFB300FFA3
00FFB300D1FF00C2FF00FFE100FFA300FFB300E1FF00FF4700FF3800FF3800FF3800FF28
00FF2800FF2800FF1900FF1900FF1900FF0A00FF0A00FF0A00FF0A00FF0A05FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0005FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0000FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF19
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF4700FF4700FF47
00FF4700FF4700FF4700FF4700FF4700FF4700FF5700FF5700FF5700FF5700FF5700FF57
00FF5700FF6600FF6600FF6600FF6600FF6600FF6600FF7500FF6600FF7500FF7500FF75
00FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF85
00FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF9400FF9400FF9400FF9400FFA3
00FFA300FFA300FFB300FFB300FFC200FFD100FFE100B3FF00FFF000FFF000FFF000FFF0
00FFF000FFF000FFFF00FFFF00FFFF00F0FF00F0FF00D1FF0057FF0066FF0085FF0085FF
0047FF0500FF3300FF0038FF0066FF0075FFBD00FF0066FFDC00FF00A3FF00D1FF00E1FF
00E1FF00D1FF00C2FF0066FFFF000000B3FF00E1FF0038FF00FFF000FFD100FFC200FFB3
00FFB300FFA300FFA300FFA300FF9400FF9400FF9400FF8500FF8500FF8500FF8500FF85
00FF8500FF8500FF8500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF6600FF66
00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF5700FF5700FF57
00FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF47
00FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF47
00FF4700FF4700FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF2800FF2800FF2800FF3800FF3800FF2800FF2800FF2800FF2800FF2800FF38
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF3800FF2800FF28
00FF2800FF2800FF2800FF2800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF1900FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF28
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF3800FF3800FF3800FF3800FF4700FF4700FF4700FF57
00FF5700FF5700FF5700FF6600FF6600FF6600FF6600FF6600FF6600FF7500FF7500FF75
00FF8500FF8500FF9400FFA300FFB300FFC200FFD100FFD100FFF000F0FF0085FF2300FF
00C2FF0094FF00FFF000FFD100FFB300FFA300FFA300FF9400FF8500FF8500FF8500FF85
00FF7500FF7500FF7500FF7500FF7500FF7500B3FF00FF7500FF6600FF5700FF5700FF57
00FF4700FF4700FF4700FF3800FF3800FF2800FF2800FF2800FF2800FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0000FF0A05FF0005FF0000FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF2800FF28
00FF3800FF7500FFF000FF9400FF3800FF2800FF2800FF1900FF1900FF2800FF1900FF19
00FF1900FF1900FF2800FF2800FF2800FF3800FF4700FF6600FF7500FF9400FFD10047FF
00FFF000FF9400FF9400FF8500FF8500FF5700FF4700FF2800FF2800FF2800FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF2800FF2800FF2800FF2800FF3800FF3800FF3800FF4700FF5700A3FF00FFC2
0085FF00FFE100FF9400FF7500FF6600FF5700FF5700FF5700FF5700FF5700FF5700FF57
00FF6600FF6600FF6600FF7500FF7500FF8500FF8500FF9400FFA300FFA300FFB300FFB3
00FFC200FFD100FFE100FFF000F0FF00C2FF0066FF0085FF00D1FF00F0FF00FFFF00FFF0
00FFF000FFE100E1FF2300FF00D1FF00FFC200FFC200FF8500FF6600FF5700FF4700FF47
00FF3800FF3800FF2800FF28
00FF5700FF5700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF47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00FF8500FFB300FF5700FF5700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF47
00FF5700FF5700FF5700FF5700FF6600FF9400E1FF00FFD100FFE100A3FF00F0FF00FFC2
00FFB300FF9400FF7500FF6600FF5700FF5700FF4700FF4700FF4700FF4700FF4700FF47
00FF5700FF5700FF5700FF5700FF6600FF7500FF8500FF9400B3FF00C2FFFF00E600C2FF
5100FF00E1FF00FFD100FFD100FF7500FF6600FF5700FF4700FF3800FF3800FF2800FF28
00FF1900FF1900FF1900FF1900FF0A00FF0A00FF0A00FF0A00FF0A00FF0A05FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0005FF0005FF0005FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0000FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF1900FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF2800FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF47
00FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF5700FF5700FF5700FF5700FF57
00FF5700FF5700FF6600FF5700FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF66
00FF6600FF6600FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF8500FF75
00FF7500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF9400FF9400FF9400FFA3
00FFA300FFC200FFD100FFD100FFE100FFF0000AFF0075FF00D1FF00E1FF00D1FF00A3FF
0094FF00E1FF00F0FF00F0FF00F0FF00E1FF00D1FF0075FF5100FFDC00FF000AFF6100FF
2300FF2300FFFF007A7000FF4200FFFA00FF3300FF0047FF0085FF0094FF0094FF0038FF
00B3FF0094FF0500FF0094FF00D1FF00F0FF00FFF000FFE100FFD100FFC200FFC200FFB3
00FFB300FFA300FFA300FF9400FF9400FF9400FF9400FF8500FF8500FF8500FF8500FF85
00FF8500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF6600FF66
00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF5700FF5700FF57
00FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF4700FF4700FF47
00FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF47
00FF4700FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF2800FF3800FF3800FF38
00FF3800FF2800FF2800FF2800FF3800FF3800FF2800FF2800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF4700FF47
00FF4700FF5700FF5700FF4700FF4700FF4700FF3800FF3800FF3800FF3800FF4700FF47
00FF4700FF4700FF5700FF4700FF4700FF3800FF3800FF3800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF1900FF2800FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF0A
00FF1900FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF1900FF1900FF0A00FF0A00FF0A00FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF3800FF3800FF3800FF3800FF3800FF4700FF4700FF4700FF47
00FF4700FF5700FF5700FF5700FF5700FF5700FF6600FF6600FF6600FF6600FF7500FF75
00FF7500FF8500FFB300B3FFEB00FF000AFF00A3FF00E1FF00E1FF7000FF0019FF0057FF
0085FF00E1FF00FFFF00FFF000E1FF00FFFF00FFB300FF9400FF8500FF7500FF7500FF75
00FF6600FF6600FF6600FF6600FF6600FF6600FF5700FF5700FF5700FF5700FF4700FF47
00FF4700FF3800FF3800FF3800FF3800FF2800FF2800FF2800FF2800FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A05FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0000FF0A05FF0005FF0005FF0000FF0A05FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0000FF0A
05FF0005FF0000FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF2800FF6600FFB3
0085FFFF00C700FF8500FF6600FF4700FF3800FF3800FF3800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF3800FF3800FF3800FF4700FF5700FF7500FF9400FFE100B3FF
00D1FF00FF8500FF6600FF5700FF4700FF4700FF3800FF3800FF2800FF2800FF2800FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF28
00FF2800FF2800FF3800FF4700FF5700FF4700FF4700FF5700FF5700FF6600FF7500FFFF
00D1FF0066FF00FFE100FF9400FF7500FF6600FF6600FF6600FF6600FF6600FF6600FF75
00FF7500FF8500FF8500FF8500FF8500FF8500FF9400FFA300FFD100FFC200FFC200FFC2
00FFD100FFE100F0FF00E1FF00D1FF00C2FF0057FF0085FF00C2FF00D1FF00D1FF00C2FF
2300FFFA00FFFF00F500FFFF00FFD100FFB300FF9400FF8500FF6600FF5700FF5700FF47
00FF3800FF3800FF2800FF28
00FFC200FF8500FF6600FF5700FF5700FF4700FF4700FF4700FF4700FF4700FF4700FF57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00FFA300FF7500FF6600FF5700FF5700FF5700FF5700FF5700FF4700FF5700FF5700FF57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00FFB300FF7500FF6600FF6600FF6600FF5700FF5700FF5700FF5700FF5700FF5700FF57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00FFD100FF7500FF6600FF6600FF6600FF5700FF5700FF5700FF5700FF5700FF5700FF66
00FF6600FF6600FF6600FF6600FF7500FF7500FF8500FFA300FFE10019FF0066FF00FFFF
00F0FF00FF9400FF8500FF7500FF7500FF7500FF7500FF7500FF7500FF8500FFA30094FF
00FFF000FFF000FFB300FFB300FFE100FFE100B3FF3300FF00C2FF00FFE100FFC200FFC2
00FFC200FFD100A3FF00FFE100FFD100B3FF00FF7500FF6600FF3800FF2800FF2800FF19
00FF1900FF1900FF1900FF1900FF1900FF0A00FF0A00FF0A00FF0A00FF0A05FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
14FF0014FF0014FF0005FF0005FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0000FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF1900FF0A00FF0A00FF0A
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF2800FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF5700FF57
00FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF6600FF6600FF6600FF6600FF66
00FF6600FF6600FF6600FF6600FF6600FF6600FF7500FF7500FF7500FF7500FF7500FF75
00FF7500FF7500FF7500FF7500FF8500FF8500FF8500FF8500FF8500FF8500FF9400FF94
00FF9400FFA300FFB300FFC200FFC200FFD100FFF000FFF000FFF000FFF000FFFF00F0FF
00F0FF00D1FF00B3FF0047FF0057FF5100FFBD00FFAE00FF0500FF0038FF1400FFFF0000
FF001E7000FFFF003D9E00FF4200FFFF00A8CC00FF0028FF0075FF00A3FF00C2FF00D1FF
00D1FF00D1FF0075FF0038FFFF004C0075FF0057FF00D1FF00F0FF0038FF00C2FF00FFE1
00FFD100FFC200FFB300FFA300FF9400FF9400FF9400FF9400FF8500FF8500FF8500FF85
00FF8500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF6600FF66
00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF5700FF5700FF57
00FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF4700FF47
00FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF47
00FF4700FF4700FF4700FF4700FF4700FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF4700FF4700FF4700FF4700FF5700FF5700FF66
00FF8500F0FF00FFE100FFA300FF7500FF6600FF6600FF6600FF6600FF7500FF9400FFF0
00FFA30019FF00FFC200FF8500FF7500FF5700FF4700FF4700FF3800FF3800FF3800FF28
00FF3800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF1900FF1900FF1900FF28
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF0A00FF1900FF1900FF0A00FF0A00FF0A
00FF0A00FF0A00FF1900FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF19
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF2800FF1900FF1900FF1900FF1900FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF47
00FF4700FF4700FF4700FF4700FF5700FF5700FF5700FF5700FF5700FF6600FF6600FF66
00FF7500FF7500FF8500FF8500FFA300FFF000FFE100FFD100FFE100FFFF00C2FFBD00FF
00D1FF00FFFF00FFE100FFF000F0FF00B3FF00FFF000FF9400FF7500FF7500FF6600FF66
00FF6600FF5700FF5700FF5700FF5700FF4700FF4700FF4700FF4700FF4700FF4700FF38
00FF3800FF3800FF3800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF1900FF0A00FF1900FF1900FF1900FF2800FF2800FF38
00FF4700FF6600FF8500FFD100B3FF0094FF00A3FF00FFB300FF8500FF6600FF5700FF57
00FF4700FF4700FF4700FF4700FF5700FF5700FF6600FFA300FFB300FFFF0085FF0066FF
00A3FF00FFB300FF7500FF5700FF4700FF4700FF4700FF3800FF3800FF3800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF38
00FF3800FF4700FF4700FF6600FFC20028FF00FFF06100FF0500FF00FFE100FFD100FFC2
00D1FF00FFFF00FFB300FFA300FF9400FF9400FF8500FF8500FF8500FF9400FFD100C2FF
00FFE10094FF00FFFF00FFC200FFC200FFC200FFD100FFF000D1FF0057FF00A3FF00C2FF
0500FF00D1FF00C2FF00B3FF00B3FF0094FF0057FF0028FF6100FFCC00FFFF00D76100FF
00E1FF00FFD100FFC200FFA300FFA300FF9400FF9400FF8500FF6600FF6600FF5700FF47
00FF3800FF3800FF3800FF28
00FF9400FF7500FF7500FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF66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00FF8500FF7500FF7500FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF66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00FF8500FF8500FF7500FF7500FF7500FF6600FF6600FF7500FF6600FF7500FF7500FF75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00FF8500FF8500FF8500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF8500FF85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00FF9400FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF850085FF00E1FF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00FF9400FF9400FF9400FF8500FF8500FF9400FFA300FFA300FF9400FF9400FFD100FFF0
00FFA300FF9400FF9400FF9400FFA300FFA300B3FF00FFC200FFD100A3FF00A3FF00E1FF
00FFF000D1FF00F0FF0094FF00FFFF0500FF00E1FF0057FF00FFF000FFC200FFD100FFC2
00FFB300FFC200FFFF00FFFF0075FF9E00FF00FF9400FF7500FF6600FF6600FF5700FF57
00FF5700FF5700FF6600FF6600FF753300FF00FF5700FF4700FF2800FF2800FF2800FF19
00FF1900FF1900FF1900FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0005FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0005FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0005FF0005FF0005FF0005FF0005FF0014FF00
14FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF19
00FF0A00FF0A00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF2800FF1900FF1900FF1900FF1900FF1900FF1900FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF47
00FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF47
00FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF66
00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7500FF7500FF75
00FF7500FF7500FF7500FF7500FF7500FF7500FF8500FF8500FF8500FF8500FF8500FF85
00FF9400FF9400FF9400FF9400FFA300FFA300FFB300FFB300FFC200FFE100E1FF0047FF
FF000000A3FF00E1FF00F0FF00FFFF00FFFF00FFFF00FFFF00F0FF00F0FF00E1FF00D1FF
00C2FF0066FF0028FF4200FFAE00FF0047FF00B3FF00D1FF00E1FF00F0FF00F0FF00FFFF
00FFF000FFF000FFE100FFE100FFE100FFE100FFE100FFE100FFE100FFD100FFC200FFC2
00FFB300FFB300FFB300FFA300FFA300FF9400FF9400FF9400FF9400FF8500FF8500FF85
00FF8500FF8500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF75
00FF7500FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF57
00FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF57
00FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF47
00FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF3800FF38
00FF3800FF3800FF3800FF4700FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF4700FF3800FF3800FF3800FF4700FF3800FF4700FF4700FF47
00FF4700FF4700FF4700FF4700FF4700FF4700FF5700FF5700FF5700FF5700FF6600FF66
00FF7500FF7500FF8500FF9400FFB300FFE100FFFF00FFD100FFB300FFB300FF9400FF85
00FF7500FF7500FF6600FF5700FF5700FF4700FF4700FF4700FF3800FF3800FF3800FF38
00FF3800FF3800FF2800FF3800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF3800FF3800FF3800FF3800FF4700FFF000C2FF00FFA3
00FF7500FF5700FF5700FF4700FF4700FF4700FF4700FF4700FF5700FF8500FF7500FF75
00FFF0FA00FF00FFA300FF94FF006B00FF5700FF4700FF3800FF3800FF2800FF2800FF28
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF1900FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF1900FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF1900FF1900FF1900FF1900FF0A00FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF47
00FF4700FF4700FF4700FF4700FF5700FF5700FF5700FF6600FF6600FF7500FF7500FF75
00FF8500FF8500FF9400FF9400FFA300FFA300FFB300FFD1FF00F500C2FF0019FF1400FF
0075FFFF00B80075FF00F0FF00FFB300FFA300FF9400FF9400FF8500FF8500FF7500FF75
00FF6600FF6600FF5700FF5700FF4700FF4700FF4700FF4700FF4700FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF2800FF3800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF1900FF2800FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF0A00FF1900FF0A00FF0A
00FF0A00FF1900FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF1900FF0A00FF0A00FF0A00FF0A00FF1900FF0A00FF0A
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF2800FF2800FF2800FF2800FF38
00FF3800FF4700FF5700FF5700FF6600FF7500FF8500FFC200FFF000B3FF00E1FF0057FF
00FFFF00FFD100FFE100FFB300FF9400FFA300FFB300E1FF00C2FF00FFD100FFE100FFD1
00FF7500FF7500FF6600FF5700FF5700FF5700FF4700FF4700FF4700FF4700FF4700FF47
00FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF5700FF5700FF5700FF4700FF47
00FF5700FF5700FF5700FF5700FF6600FF6600FF7500FF8500FF8500FF9400FFB300B3FF
00E1FF00F0FF0019FF1400FFFF007A0500FF0075FF0057FFFF00C79E00FFAE00FF00A3FF
00C2FF0066FF1400FF00F0FF00FFE100FFC200FFB300FFA300FFB300FFA300FFA300FFA3
00FFB300FFC200FFD100FFF01400FF0038FF00FFF000FFE100FFC200FFC200FFE16100FF
00B3FF00E1FF0038FF00B3FF00FFF000FFD100FFF000FFA300FF9400FF6600FF6600FF57
00FF5700FF5700FF5700FF57
00FFB300FFA300FF9400FF9400FF9400FFA300FFE100FFD100FFB300FFB300F0FF00D1FF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00FFFF00FFD100FFA300FFA300FFA300FFB300F0FF00A3FF00FFE100FFD10075FF00A3FF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00D1FF00FFC200FFB300FFB300FFB300FFB300FFE10094FF00D1FF00FFFF0038FF00FFFF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00FFF000FFD100FFC200FFC200FFC200FFC200FFD100FFFF00B3FF1400FF00E1FF00FFF0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00FFF000FFE100FFE100FFD100FFE100FFD100FFE100FFF000E1FF7000FF00E1FF00FFFF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1400FF00FFFF0066FF00E1FF00E1FF00FFF000FFF00085FF00C2FFFF004C00B3FF0094FF
00B3FF00F0FF00E1FF0085FF2300FF0066FF00F0FF00FFF000FFD100FFF000FFD100FFA3
00FF9400FF8500FF8500FF7500FF7500FF7500FF7500FF7500FF6600FF6600FF6600FF66
00FF6600FF6600FF6600FF5700FF5700FF4700FF4700FF4700FF4700FF3800FF3800FF38
00FF3800FF3800FF2800FF3800FF2800FF2800FF2800FF2800FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A05FF0005FF0005FF0005FF0005FF0005FF0005FF0000FF0A05FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0005FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0005FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0005FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0005FF0005FF0005FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0000FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF1900FF0A00FF0A00FF0A00FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF2800FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF2800FF1900FF1900FF1900FF1900FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF4700FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF4700FF47
00FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF47
00FF4700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF57
00FF5700FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7500FF75
00FF7500FF7500FF7500FF7500FF7500FF8500FF8500FF8500FF8500FF8500FF8500FF85
00FF9400FF9400FF9400FF9400FF9400FF9400FFA300FFA300FFA300FFB300FFB300FFB3
00FFC200FFC200FFC200FFC200FFD100FFD100FFD100FFE100FFF000FFF000FFFF00D1FF
0066FF0085FF0085FF0047FF1400FF0057FF0094FF00B3FF00B3FF1400FF00C2FF00F0FF
00FFF000FFE100FFD100FFD100FFD100FFC200FFC200FFC200FFB300FFB300FFB300FFA3
00FFA300FFA300FFA300FFA300FF9400FFA300FF9400FF9400FF9400FF9400FF8500FF85
00FF8500FF8500FF8500FF8500FF8500FF8500FF7500FF7500FF7500FF7500FF7500FF75
00FF7500FF7500FF7500FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF66
00FF5700FF5700FF5700FF6600FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF57
00FF5700FF5700FF5700FF4700FF4700FF4700FF4700FF5700FF4700FF4700FF4700FF47
00FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF47
00FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF47
00FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF47
00FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF5700FF57
00FF5700FF6600FF7500FFFF00FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF85
00FF9400FFE11400FF00F0FF000AFFFF00B80075FF00FFFF00FFB300FF9400FF7500FF75
00FF6600FF6600FF5700FF5700FF5700FF4700FF4700FF4700FF4700FF4700FF4700FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF4700FF4700FF4700FF4700FF5700FF5700FF6600FF75
00FF940085FF00F0FF1400FF00FFB300FFE100F0FF000AFF00F0FF00FFB300FF9400FF94
00E1FF00FF9400FF6600FF4700FF4700FF3800FF3800FF3800FF3800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF4700FF4700FF4700FF4700FF5700FF5700FF5700FF6600FF6600FF7500FF8500FF94
00FFA300FFC200F0FF00A3FF000AFF00D1FF00E1FF00C2FF0075FF0019FFBD00FF000AFF
000AFF0028FF0075FF00C2FF00A3FF00E1FF0019FF00FFFF00FFD100FFB300FF9400FF85
00FF7500FF7500FF6600FF5700FF5700FF5700FF4700FF4700FF4700FF4700FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF1900FF1900FF1900FF1900FF2800FF1900FF2800FF1900FF28
00FF1900FF1900FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF3800FF38
00FF3800FF3800FF4700FF4700FF4700FF4700FF5700FF5700FF6600FF6600FF7500FF75
00FF8500FF8500FF9400FFA300FFB300FFD14200FF0047FF00FFFF00FFD100FFA300FF94
00FF8500FF8500FF8500FF7500FF7500FF7500FF6600FF6600FF6600FF6600FF6600FF75
00FF7500FF8500F0FF000AFF00FFD100FFB300FFD18000FF00E1FF00FFA300FF9400FF85
00FF8500FF9400FF9400FFC200B3FF0047FF00E1FF00FFF000FFFF0094FF00E1FF00C2FF
0075FF0028FF0085FF0028FFFF002E0500FF0085FF00D1FF00FFE100FFB300FFA300FF94
00FF8500FF8500FF8500FF8500FF7500FF6600FF6600FF6600FF6600FF6600FF6600FF66
00FF8500FFC200FFD100FF8500FF7500FF7500FF8500FFC200FF7500FF6600FF6600FF66
00FF6600FF7500FF7500FF8500FF8500FF8500FF9400FFB300FFD100A3FF00C2FF00FFF0
0085FF00FFB300FFC200F0FF
0075FF0075FF00A3FF0066FF00E1FF00F0FF00E1FF0085FF0075FF0500FFEB00FF0019FF
0094FF00D1FF0094FFFF00E60057FF4200FF0500FF00FFD100FFC200FFB300FFA300FF94
00FF8500FF8500FF8500FF7500FF7500FF7500FF6600FF6600FF6600FF6600FF6600FF57
00FF5700FF5700FF5700FF5700FF4700FF4700FF4700FF4700FF3800FF3800FF3800FF38
00FF3800FF3800FF2800FF2800FF2800FF2800FF2800FF2800FF1900FF2800FF1900FF19
00FF1900FF1900FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0005FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0005FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0005FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0005FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0005FF0005FF0005FF0005FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0000FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF2800FF1900FF1900FF2800FF1900FF19
00FF1900FF2800FF1900FF1900FF1900FF2800FF2800FF1900FF1900FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF3800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF4700FF3800FF3800FF3800FF3800FF4700FF4700FF47
00FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF47
00FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF57
00FF5700FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7500FF7500FF7500FF75
00FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF8500FF8500FF8500FF8500FF85
00FF8500FF8500FF9400FF9400FF9400FF9400FFA300FFA300FFA300FFB300FFB300FFB3
00FFB300FFC200FFC200FFC200FFC200FFD100FFD100FFE100FFE100FFF000FFFF0047FF
0057FF00C2FF00B3FF0075FF000AFF0047FF0057FF00C2FF00D1FF00E1FF00F0FF00FFFF
00FFF000FFE100FFD100FFD100FFD100FFC200FFC200FFC200FFB300FFB300FFB300FFA3
00FFA300FFA300FFA300FFA300FF9400FF9400FF9400FF9400FF9400FF9400FF8500FF85
00FF8500FF8500FF8500FF8500FF8500FF8500FF7500FF8500FF7500FF7500FF7500FF75
00FF7500FF7500FF7500FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF66
00FF6600FF6600FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF57
00FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF4700FF4700FF4700FF4700FF47
00FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF47
00FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF47
00FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF47
00FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF5700FF4700FF5700FF5700FF57
00FF6600FF6600FF8500FFF000FF8500FF8500FF7500FF7500FF7500FF8500FF8500FF85
00FF9400FFB300FFC200FFFF9E00FF00D1FF00FFF000F0FF00C2FF00FFB300FF8500FF75
00FF6600FF6600FF5700FF5700FF5700FF5700FF4700FF4700FF4700FF4700FF4700FF38
00FF4700FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF28
00FF2800FF2800FF3800FF2800FF2800FF2800FF2800FF2800FF2800FF3800FF2800FF28
00FF3800FF2800FF2800FF3800FF2800FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF4700FF4700FF4700FF4700FF5700FF5700FF5700FF6600FF75
00FF8500FF9400FFC200C2FF00D1FF0075FF00FFF000FFD100FFE100FFA300FF8500FF75
00FF7500FFF000FF5700FF4700FF4700FF3800FF3800FF3800FF3800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF47
00FF4700FF4700FF4700FF4700FF4700FF5700FF5700FF5700FF6600FF7500FF8500FF85
00FF9400FFA300FFC200FFD100FFFF1400FF0066FF0075FF0057FF1400FFFF00D77000FF
3300FFDC00FFCC00FFFF00E60066FF00B3FF0047FF00F0FF00FFE100FFC200FFA300FFA3
00FF8500FF7500FF6600FF6600FF5700FF5700FF4700FF4700FF4700FF4700FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF1900FF1900FF28
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF2800FF1900FF19
00FF2800FF1900FF2800FF2800FF2800FF2800FF2800FF3800FF3800FF3800FF4700FF47
00FF3800FF2800FF2800FF2800FF2800FF2800FF1900FF2800FF1900FF2800FF1900FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF3800FF3800FF3800FF38
00FF3800FF3800FF4700FF4700FF4700FF4700FF5700FF5700FF5700FF6600FF6600FF75
00FF7500FF8500FF8500FF940066FF00E1FF00B3FF0047FF9E00FF5100FF00FFE100FFA3
00FF9400FF9400FF9400FF9400FF8500FF8500FF8500FF7500FF7500FF7500FF7500FF75
00FF7500FF9400FFB300FFE10066FF00F0FF00FFFF0085FF00FFC200FFA300FFA300FF94
00FFA300FFA300FFA300FFC200FFE100E1FF0500FF0085FF0094FF0019FF0500FF4200FF
FF006B0075FF000AFFFF00003300FF0028FF00E1FF0066FF0047FF00FFB300FF9400FF85
00FF8500FF7500FF7500FF6600FF6600FF6600FF5700FF5700FF5700FF5700FF5700FF66
00FF7500FFC200FF9400FF6600FF6600FF6600FF6600FF6600FF5700FF5700FF5700FF57
00FF5700FF6600FF6600FF6600FF7500FF7500FF8500FFA300FFD10085FF00FFB300FFA3
00FF9400FF8500FF9400FFA3
0075FFFF00F5FF00F50066FF00C2FF00A3FF00C2FF0094FF9E00FFFF0000DC00FF0057FF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00D1FF0075FF8000FF0500FF0047FF0075FF0066FF0047FFFA00FF000AFF8F00FF0019FF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0085FF0075FF0057FF0085FF0019FF0019FF3300FFFF00C70038FF0038FF8000FFEB00FF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00F0FF0038FF00C2FF00C2FF0094FF0094FF0075FF8F00FF0075FF0038FF0500FFFF00F5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00FFF000B3FF00F0FF00E1FF00D1FF00C2FF00B3FF00A3FF0094FF0085FF0047FF2300FF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00FFE100FFF000FFFF00F0FF00E1FF00D1FF00C2FF00B3FF0094FF0085FF0066FF0028FF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00FFD100FFE100FFF000FFFF00E1FF00D1FF00C2FF00A3FF0094FF0085FF0066FF1400FF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00FFD100FFE100FFF000F0FF00C2FF0085FF0094FF0085FF0047FF0047FF7000FF0038FF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00FFE100FFE100FFF000F0FF00A3FFFF00D7000AFF0028FF000AFFFF00D70038FF0085FF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00FFF000FFF000FFFF00F0FF00D1FF0085FF0038FFCC00FFDC00FFFA00FF6100FF00A3FF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00FFFF00FFFF00F0FF00D1FF00C2FF00A3FF000AFFFF007AFF00006100FF0047FF00A3FF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00F0FF00F0FF00E1FF5100FF0085FF0085FF0047FFEB00FF6100FF000AFF9E00FF000AFF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00B3FF00B3FF00C2FF0094FF0500FF0057FFFF00990047FF2300FF1400FF0085FF3300FF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DC00FF0057FF0028FF0085FF0057FF0028FF0057FF0075FF0085FF00A3FF00B3FF00C2FF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00C2FF000AFF6100FF5100FF8000FF0028FF0075FF0085FF00A3FF00B3FF00C2FF00D1FF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00B3FF0094FF000AFF8F00FF8000FF2300FF0066FF0085FF00A3FF00B3FF00C2FF00D1FF
00E1FF00F0FF00FFFF00FFFF00FFE100FFD100FFC200FFB300FFB300FFA300FFA300FF94
00FF8500FF8500FF8500FF7500FF7500FF7500FF6600FF6600FF6600FF6600FF5700FF57
00FF5700FF4700FF4700FF4700FF4700FF3800FF3800FF3800FF3800FF3800FF3800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A05FF0000FF0A00FF0A05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0000FF0A00FF0A05FF0005FF0005FF0005FF0005FF0000FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF2800FF2800FF2800FF2800FF2800FF3800FF3800FF4700FF4700FF6600E1FF00FFD1
00C2FF00C2FF00FFC200FFA300FF8500FF7500FF6600FF5700FF5700FF4700FF4700FF47
00FF4700FF4700FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF4700FF4700FF3800FF3800FF3800FF3800FF47
00FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF47
00FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF5700FF5700FF5700FF5700FF57
00FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF6600FF6600FF66
00FF6600FF6600FF7500FF7500FF8500FFA30066FF00FFB300FFA300FFA300FF9400FFA3
00FF9400FF9400FF9400FFA300FFA300FFA300FFB300FFB300FFB300FFB300FFA300FFA3
00FFA300FFA300FFA300FFA300FFA300FFA300FFB300FFB300FFB300FFB300FFB300FFB3
00FFC200FFC200FFC200FFC200FFD100FFE100FFF000FFFF00F0FF00E1FF00F0FF00E1FF
00E1FF00D1FF00C2FF00B3FF0094FF7000FFFF00995100FF0057FF0094FF00B3FF00C2FF
00E1FF00E1FF00F0FF00FFFF00FFFF00FFF000FFF000FFE100FFE100FFE100FFD100FFD1
00FFD100FFD100FFC200FFC200FFC200FFC200FFC200FFC200FFC200FFC200FFD100FFD1
00FFE100FFF000FFFF00D1FF00A3FF8F00FF0500FF8000FF0085FF00FFFF00FFC200FFB3
00FFA300FF9400FF9400FF9400FF8500FF8500FF8500FF8500FF7500FF7500FF7500FF75
00FF7500FF7500FF7500FF7500FF7500FF7500FF6600FF6600FF6600FF6600FF6600FF66
00FF6600FF6600FF6600FF6600FF6600FF5700FF5700FF5700FF5700FF5700FF5700FF57
00FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF57
00FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF57
00FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF57
00FF6600FF5700FF5700FF6600FF6600FF6600FF6600FF6600FF7500FF7500FF7500FF85
00FF8500FF8500FF9400FF9400FFA300FFA300FFB300FFB300FFB300FFC200FFD100FFE1
00FFF00085FF00A3FF3300FF00A3FF00E1FF00FFFF00FFE100FFD100FFC200FFB300FFB3
00FFA300FFA300FFA300FFA300FF9400FF9400FF8500FF8500FF7500FF6600FF6600FF66
00FF5700FF5700FF5700FF5700FF5700FF5700FF4700FF5700FF4700FF4700FF4700FF47
00FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF5700FF57
00FF5700FF5700FF5700FF6600FF6600FF8500FF9400FFC20094FF0094FFFF0000FF0000
0500FF0047FF00D1FF000AFF0075FF00F0FF00D1FF2300FF00B3FF0066FF0047FF00E1FF
00FFF000FFD100FFC200FFB300FFA300FF9400FF9400FF9400FF9400FF9400FF9400FF94
00FF6600FF6600FF5700FF4700FF4700FF4700FF4700FF4700FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF1900FF19
00FF2800FF2800FF2800FF1900FF1900FF1900FF1900FF1900FF2800FF2800FF1900FF19
00FF1900FF1900FF1900FF1900FF2800FF1900FF1900FF1900FF1900FF1900FF2800FF28
00FF1900FF1900FF1900FF1900FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF3800FF2800FF2800FF2800FF3800FF2800FF2800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF47
00FF4700FF4700FF4700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF6600FF66
00FF6600FF6600FF7500FF7500FF8500FF8500FF9400FFA300FFC200F0FF00B3FF00F0FF
00B3FF0094FF1400FF5100FF00FFFF00FFFF00E1FF0094FF00FFE100A3FF00FF9400FF75
00FF7500FF7500FF6600FF6600FF6600FF6600FF6600FF5700FF5700FF5700FF5700FF57
00FF5700FF5700FF5700FF5700FF5700FF4700FF5700FF4700FF4700FF4700FF5700FF57
00FF5700FF5700FF4700FF4700FF4700FF4700FF5700FF5700FF5700FF5700FF5700FF57
00FF5700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF57
00FF5700FF5700FF6600FF6600FF7500FF7500FF94000AFF00FFFF00F0FF0094FF00D1FF
00D1FF00FFD100FFC200FFD10500FF0047FF00C2FF00FFB300FFA300FF9400FF8500FF75
00FF7500FF6600FF6600FF6600FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF57
00FF6600FF6600FF7500FFA300C2FF00B3FF00FFC200FFB300FFB300FFE1000AFF00FFF0
00FFC200FFA300FFA300FF9400FF9400FF9400FF9400FF9400FFA300FFA300FFB300FFB3
00FFC200FFC200FFD100FFE100FFF000FFFF00E1FF0057FF0075FF0019FFFF00F5FF0000
FF00F5BD00FF7000FF00D1FF00FFF000FFF000FFE100FFD100FFC200FFB300FFA300FFA3
00FF9400FF9400FF8500FF8500FF8500FF8500FF8500FFA300FFD10500FF00A3FF00FF85
00FF6600FF5700FF5700FF4700FF4700FF4700FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF4700FF4700FF5700FF6600FFC200FF8500FF5700FF3800FF2800FF28
00FF2800FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF0A00FF1900FF0A00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF2800FF2800FF3800FFE100FFE100FFC200FFA300FFB300FFC200FFE100FFC200FFE1
00FFF000D1FF00FFB300FF85
00C2FF0038FFFF00003300FF3300FF000AFF0038FF0075FF0085FF0094FF00B3FF00B3FF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00E1FF0094FF000AFF0028FF3300FFFF00000500FF0057FF0047FF1400FF0085FF0066FF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00A3FF0075FFFF00B80075FF0500FF2300FF000AFF0500FFFF0000AE00FF0019FF6100FF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1400FF7000FF00A3FF00A3FF0075FF000AFFBD00FF8F00FF0028FF0075FF00A3FF000AFF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0500FF00A3FF00E1FF0094FF0057FF0057FFFF002E2300FF0038FF00C2FF00E1FF00D1FF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0075FF00E1FF00FFFF00F0FF00A3FF00C2FFFF003D00B3FF0066FF00F0FF00FFFF00F0FF
00A3FF0057FF00B3FF0500FF3300FF0066FF00A3FF00F0FF00E1FF00C2FF00F0FF8000FF
00FFF000FFB300FFA300FFA300FFA300FFA300FFB300FFD100D1FF00B3FF00FFD100FF85
00FF7500FF6600FF5700FF5700FF5700FF4700FF4700FF4700FF3800FF3800FF3800FF38
00FF3800FF3800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF1900FF1900FF1900FF2800FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF0A00FF0A00FF0A00FF0A00FF1900FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A05FF0005FF0005FF00
05FF0005FF0005FF0005FF0000FF0A05FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0000FF0A05FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0000FF0A00FF0A05FF0005FF0005FF0005FF00
05FF0005FF0000FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF2800FF2800FF28
00FF3800FF4700FF6600FF5700FF5700FF6600FF7500FFB300FF8500FF8500FF9400FF94
00FFC2FF001E00FFFF00FF9400FF8500FF7500FF7500FF6600FF6600FF6600FF5700FF57
00FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF4700FF47
00FF4700FF5700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF47
00FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF47
00FF4700FF4700FF4700FF3800FF3800FF4700FF4700FF4700FF4700FF4700FF4700FF47
00FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF47
00FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF47
00FF4700FF4700FF4700FF4700FF4700FF5700FF5700FF5700FF5700FF5700FF5700FF57
00FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF6600FF6600FF6600FF6600FF66
00FF6600FF7500FF7500FF7500FF8500FFB300FFD16100FF0038FF00FFE100F0FF3300FF
FF00D70094FF00B3FF00B3FF3300FF00B3FF00E1FF00FFFF00FFF000FFE100FFE100FFD1
00FFD100FFD100FFD100FFD100FFD100FFC200FFC200FFC200FFC200FFC200FFC200FFC2
00FFD100FFD100FFD100FFD100FFD100FFE100FFE100FFF000FFF000FFFF00FFFF00F0FF
00F0FF00E1FF00D1FF00C2FF00A3FF0094FF6100FFFF004C8F00FF0075FF00A3FF00B3FF
00C2FF00D1FF00E1FF00E1FF00F0FF00F0FF00F0FF00F0FF00FFFF00FFF000FFF000FFF0
00FFF000FFE100FFE100FFE100FFE100FFE100FFE100FFE100FFF000FFF000FFFF00E1FF
00B3FF0057FF0038FF0075FF0085FF00F0FF00FFE100FFD100FFD100FFC200FFB300FFB3
00FFA300FFA300FFA300FFA300FF9400FF9400FF9400FF9400FF9400FF9400FF9400FF85
00FF8500FF9400FF8500FF8500FF8500FF9400FF8500FF8500FF8500FF7500FF7500FF75
00FF7500FF7500FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF66
00FF6600FF6600FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF57
00FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF57
00FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF6600FF6600FF66
00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7500FF7500FF7500FF7500FF75
00FF8500FF8500FF8500FF8500FF9400FF9400FFA300FFA300FFB300FFC200C2FF1400FF
00F0FF00E1FF00C2FF0019FF00A3FF00E1FF00F0FF00F0FF00F0FF0500FF00FFB300FFA3
00FF9400FF9400FF9400FF8500FF8500FF7500FF7500FF7500FF7500FF6600FF6600FF66
00FF6600FF6600FF6600FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF57
00FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF66
00FF6600FF6600FF6600FF6600FF7500FF7500FF8500FF8500FF8500FF9400FF9400FFA3
00FFB300FFB300FFC200FFE100FFFF00F0FF00C2FF0085FF0019FF0500FFFF00E64200FF
00A3FF0094FF0066FF0094FF0038FF00F0FF00FFE100FFC200FFA300FF9400FF9400FF85
00FF7500FF6600FF6600FF5700FF5700FF5700FF5700FF4700FF4700FF4700FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF3800FF2800FF2800FF2800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF4700FF3800FF3800FF4700FF47
00FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF57
00FF5700FF5700FF5700FF5700FF5700FF5700FF6600FF6600FF6600FF6600FF6600FF66
00FF6600FF7500FF7500FF7500FF7500FF8500FF8500FF8500FF9400FF9400FFB300FFC2
00FFFF0057FF2300FFFF003D00A3FF00B3FF00FFFF00FFB300FFA300FF9400FF9400FF94
00FF8500FF8500FF8500FF8500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF75
00FF7500FF7500FF6600FF7500FF6600FF6600FF6600FF6600FF7500FF7500FF8500FFC2
00FFFF0085FF0038FF00FFA300FF9400FF9400FFA300FFD10085FF00FFFF0038FF00FFC2
00FF7500FF7500FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF66
00FF7500FF7500FF7500FF7500FF8500FF8500FF8500FF8500FF9400FFA300FFA300FFB3
00FFC200C2FF00B3FF0066FF00E1FF00FFE100FFC200FFC200FFB300FFA300FFA300FF94
00FF9400FF9400FF9400FFA300E1FF00FFA300FFA300E1FF00D1FF00FFB300FF9400FF94
00FF9400FF9400FFA300FFB300FFB300FFB300FFC200F0FF00B3FF00C2FF0057FF0047FF
FF003D00B3FF00E1FF00E1FF0019FF00D1FF0057FFFF00B80066FF0075FF0028FF0047FF
0500FFFF0000FF0000FF00B8EB00FF0057FF0057FF0075FF0019FF0028FF000AFFFF004C
2300FF0066FF00A3FF00C2FF00E1FF00B3FF0019FF00FFFF00FFC200FFA300FF9400FF85
00FF7500FF6600FF6600FF6600FF6600FF5700FF5700FF5700FF4700FF4700FF4700FF47
00FF3800FF3800FF3800FF3800FF3800FF2800FF2800FF2800FF2800FF2800FF2800FF19
00FF2800FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF0A00FF19
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF1900FF1900FF1900FF1900FF2800FF2800FF2800FF3800FF3800FF47
00FF6600FF9400FFC200FFD1
00FFFF00FFE100FFE100FFE100FFFF00D1FF1400FF00E1FF00FFFF00FFF000FFE100FFFF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00FFC200FFC200FFD100FFE100FFFF00C2FF0075FF00F0FF00FFF000FFE100FFD100FFE1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00FFB300FFB300FFC200FFE100E1FF0028FF00E1FF2300FF00FFF000FFD100FFC200FFC2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00FFA300FFA300FFB300FFE12300FF00FFF000FFE100D1FF00FFFF00FFC200FFB300FFB3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00FF9400FF9400FFB34200FF00D1FF00FFC200FFB300E1FF00E1FF00FFC200FFA300FFA3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00FF8500FF9400FFA300FFF000FFC200FFA300FF9400FFB30066FF00FFA300FF9400FF94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00FF8500FF8500FF9400FFC200FF9400FF8500FF8500FF9400FF9400FF8500FF8500FF94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00FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF8500FF7500FF8500FF8500FF85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00FF7500FF6600FF7500FF6600FF6600FF7500FF7500FF7500FF7500FF7500FF7500FF85
00FF8500FF8500FF9400FF9400FFA300FFB300FFC200FFD100FFF000F0FF00D1FF00B3FF
0057FF0028FF1400FF0500FF0038FF0028FF0057FF00FFD100FFC200FFB300FFB300FFA3
00FF9400FF9400FF8500FF8500FF7500FF6600FF6600FF5700FF5700FF5700FF4700FF47
00FF4700FF4700FF4700FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF0A00FF0A00FF19
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A05FF0005FF0005FF00
05FF0005FF0005FF0005FF0000FF0A05FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0000FF0A05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0000FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF2800FF2800FF2800FF2800FF28
00FF2800FF3800FF3800FF3800FF3800FF4700FF4700FF4700FF5700FF5700FF5700FF66
00FF7500FF8500FFA300FFD100C2FF00FFF000F0FF0500FF00C2FF00FFF000FFD100FFFF
00FFB300FFB300FFA300FFA300FFA300FFA300FFD10047FFFF00B85100FF00FFB300FFA3
00FFA300FFA300FFB300FFD100D1FFFF00000028FF00FFD100FFA300FF8500FF8500FF75
00FF6600FF6600FF6600FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF4700FF47
00FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF47
00FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF47
00FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF5700FF5700FF5700FF57
00FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF57
00FF5700FF5700FF5700FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF75
00FF7500FF7500FF7500FF7500FF7500FF7500FF8500FF8500FF8500FF9400FF9400FF94
00FFA300FFA300FFB300FFB300FFC200FFC200FFD100E1FF00FFFF00C2FF00B3FF00E1FF
00B3FF0094FF4200FF0066FF0066FF0047FFEB00FF00E1FF00FFFF00FFFF00FFFF00FFF0
00FFF000FFFF00FFFF00FFFF00F0FF00D1FF0066FF0019FFFF006B000AFF000AFF0038FF
0057FF0066FF0019FF0047FF5100FF0038FF0038FF4200FF4200FF6100FF2300FF000AFF
0028FF0500FF8F00FF000AFF0500FFFF000F0028FF0057FF0085FF0094FF00A3FF00B3FF
00B3FF00B3FF00C2FF00A3FF0028FF2300FF0085FF00A3FF9E00FF0066FF0028FF7000FF
0085FF00B3FF00C2FF00D1FF00E1FF00D1FF00E1FF00C2FF00F0FF00FFFF00F0FF00A3FF
00A3FF0047FF00D1FF00FFFF00FFFF00FFFF00B3FF00E1FF00A3FF0019FFFF00000047FF
FF00000028FF00D1FF00FFFF00E1FF00FFD100FFC200FFB300FFB300FFA300FFA300FF94
00FF9400FF8500FF8500FF8500FF8500FF7500FF7500FF7500FF7500FF6600FF6600FF75
00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF66
00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF66
00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF66
00FF6600FF6600FF6600FF7500FF7500FF7500FF7500FF7500FF8500FF8500FF8500FF85
00FF9400FFA300FFC200FFE100D1FF0019FFAE00FF0094FF00A3FF00F0FF00FFFF00FFFF
00F0FF0094FF0085FF0066FF1400FF0075FF0066FF000AFF00C2FF00E1FF00C2FF1400FF
00F0FF00FFE100FFD100FFC200FFB300FFA300FFA300FF9400FF8500FF8500FF8500FF75
00FF7500FF7500FF7500FF7500FF7500FF6600FF6600FF6600FF6600FF7500FF6600FF75
00FF6600FF7500FF6600FF7500FF7500FF7500FF7500FF7500FF7500FF8500FF8500FF94
00FFA300FFFFFF000000B3FF00FFE100FFC200FFB300FFB300FFB300FFC200FFC200FFD1
00FFF000F0FF0057FF1400FF00A3FF00B3FF00D1FF0500FF00F0FF00FFE100FFC200FFB3
00FFA300FF9400FF9400FF9400FF9400FF9400FF8500FF9400FF9400FF9400FFB300FF94
00FF8500FF7500FF7500FF7500FF7500FF6600FF6600FF5700FF5700FF4700FF4700FF47
00FF4700FF4700FF4700FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF2800FF2800FF2800FF2800FF3800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF3800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF3800FF3800FF2800FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF4700FF4700FF4700FF4700FF4700FF57
00FF5700FF6600FF7500FFC200FFE100FF8500FF7500FF6600FF5700FF5700FF5700FF57
00FF5700FF5700FF5700FF5700FF4700FF5700FF4700FF5700FF5700FF5700FF5700FF57
00FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF6600FF6600FF6600FF66
00FF7500FF8500FFB300FFE100FF9400FF8500FF8500FF8500FF8500FF8500FF8500FF85
00FF8500FF9400FF9400FFA300FFD11400FF00FFF000FFD100FFD100FFE100F0FF0075FF
FF003D0094FF00FFFF00FFE100FFD100FFE100C2FF0085FF00FFFF00B3FF00A3FF8F00FF
0038FFFF002E0019FF00C2FF00A3FF00B3FF00E1FF00C2FF0047FF0028FF0075FF00B3FF
00FFFF00FFFF00FFE100FFE100FFD100FFF00075FF00E1FF00C2FF00FFE100FFD100FFE1
00D1FF00E1FFFF000000B3FF0066FF0075FF0094FF0085FF0066FF00FFE100FFD100FFE1
0066FF00FFF01400FF00FFE100FFC200FFC200FFC200FFD100FFE100FFFF00B3FF0057FF
00F0FF00FFF000FFE100FFF000FFF00085FF00FFF000FFE100FFF000FFFF00F0FF00D1FF
0085FF8F00FF000AFF3300FF000AFF0038FF9E00FF00C2FF00C2FF0057FF0057FF00F0FF
00E1FF0057FF00A3FF00F0FF00D1FF2300FF0038FF00C2FF00FFFF00FFE100FFD100FFC2
00FFB300FFC20066FF00FFC200FFD100FFB300FFC200FFC200FFD100FFE100F0FFEB00FF
00FFFF00FFE100FFC200FFB300FFA300FF9400FF9400FF9400FF8500FF8500FF8500FF85
00FF9400FFA300FFD14200FF00FFD100FFB300FFE1FF001E00E1FF00FFB300FFB300FFB3
00FFC200FFE100F0FFFF00F52300FF0066FF00E1FF00FFC200FF9400FF8500FF8500FF75
00FF7500FF7500FF6600FF6600FF6600FF5700FF5700FF4700FF4700FF4700FF3800FF38
00FF3800FF3800FF2800FF2800FF2800FF1900FF1900FF1900FF1900FF1900FF1900FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A05FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0000FF0A00FF0A00FF0A00FF1900FF3800FF570500FF00FF75
00FF5700FF3800FF3800FF57
00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7500FF7500FF75
00FF8500FF8500FF9400FF9400FFA300FFB300FFB300FFD100C2FF0019FF00A3FF00A3FF
0057FFFF00C70019FF0038FF0094FF0094FF00FFFF00FFD100FFB300FFB300FFA300FF94
00FF9400FF8500FF8500FF7500FF7500FF6600FF6600FF5700FF5700FF5700FF4700FF47
00FF4700FF4700FF4700FF4700FF4700FF4700FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF2800FF2800FF2800FF2800FF2800FF2800FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A05FF0005FF0005FF00
05FF0005FF0005FF0005FF0000FF0A05FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0000FF0A00FF0A05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0000FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF2800FF2800FF2800FF2800FF28
00FF3800FF3800FF3800FF3800FF4700FF4700FF4700FF4700FF5700FF5700FF5700FF66
00FF6600FF7500FF8500FFD100D1FF00FFC200FFF000E1FF0066FFBD00FF00F0FF00D1FF
0085FF00FFD100FFB300FFB300FFB300FFB300FFC200FFFF0075FF00FFF000FFC200FFB3
00FFC200FFE100FFF01400FF0038FF0085FF000AFF0066FF00FFE100FF8500FF7500FF75
00FF6600FF6600FF6600FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF47
00FF4700FF5700FF4700FF4700FF4700FF5700FF4700FF4700FF4700FF4700FF4700FF47
00FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF47
00FF4700FF4700FF5700FF4700FF4700FF4700FF4700FF4700FF5700FF5700FF5700FF57
00FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF6600FF5700FF57
00FF5700FF5700FF5700FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF66
00FF7500FF7500FF7500FF7500FF7500FF7500FF8500FF8500FF8500FF8500FF9400FF94
00FF9400FFA300FFA300FFB300FFB300FFC200FFC200FFD100FFE10057FF00F0FF00F0FF
00E1FF00C2FF0094FF7000FF8000FF0094FF00C2FF00E1FF00F0FF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00F0FF00F0FF00E1FF00B3FF00A3FF0057FF0066FF0057FF2300FF
3300FF0047FF0028FFFF00E6FF006B0019FF0019FF9E00FFAE00FFFF00F54200FF0500FF
000AFF3300FFAE00FF8000FF7000FF5100FF000AFFFF00F50057FF0075FF0094FF0085FF
0085FF0028FF00A3FF0094FF0075FFFF005C0038FF1400FFFF00F50028FF0085FF0094FF
2300FF0057FF0057FF0075FF00C2FF00A3FF0085FF0075FF00D1FF00E1FF00E1FF00C2FF
0075FF0094FF00D1FF00E1FF00E1FF5100FF0028FF00B3FF0085FF000AFFFF00000500FF
00A3FF00C2FF00FFFF00FFE100FFD100FFC200FFB300FFA300FFA300FFA300FF9400FF94
00FF8500FF8500FF8500FF8500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF66
00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF66
00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF66
00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF66
00FF6600FF6600FF6600FF7500FF7500FF7500FF7500FF7500FF7500FF8500FF8500FF85
00FF9400FF9400FFA300FFC200FFF000FFFF00E1FF0038FF0019FF00A3FF00E1FF00E1FF
00D1FF0028FF3300FF2300FFAE00FF6100FFFF00F50075FF00A3FF0038FF0075FF00B3FF
00F0FF00FFFF00FFF000FFF000A3FF00FFD1000AFF00FFB300FFA300FF8500FF8500FF75
00FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF6600FF7500FF6600FF75
00FF6600FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF8500FF8500FF8500FF94
00FFA300D1FF00D1FF0075FF00FFE100FFD100FFC200FFC200FFC200FFC200FFE100F0FF
00FFFF00E1FF0085FFFF000F0085FF00F0FF00F0FF0057FF00E1FF00FFD100FFB300FFA3
00FFA300FF9400FF9400FF9400FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF75
00FF7500FF7500FF6600FF6600FF6600FF6600FF5700FF5700FF5700FF4700FF4700FF47
00FF4700FF4700FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF2800FF2800FF2800FF28
00FF2800FF3800FF2800FF2800FF2800FF2800FF2800FF3800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF38
00FF2800FF2800FF2800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF4700FF4700FF4700FF4700FF5700FF57
00FF6600FF7500FF8500FFE100E1FF00FFD100FF7500FF6600FF6600FF5700FF5700FF57
00FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF57
00FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF6600FF6600FF6600FF6600FF75
00FF8500FFD100D1FF00FFD100FFA300FF9400FF9400FF9400FF8500FF8500FF8500FF94
00FF9400FFA300FFB300FFC200FFD10038FF00B3FF00FFE100FFF000E1FF00B3FF2300FF
3300FF00D1FF00FFE100FFD100FFC200FFC200FFD100FFD100FFE100FFF000E1FF9E00FF
00C2FF00B3FF00C2FF0075FF8F00FF4200FF0066FF0066FF2300FFFA00FFBD00FF00A3FF
00D1FF00C2FF0500FF00FFFF00FFF000FFFF00D1FF0094FF00F0FF00FFF000FFF000FFF0
00F0FF0066FF0066FF0019FFFF00D78F00FFBD00FF00A3FF00E1FF00FFFF00FFF000FFFF
00E1FF0085FF00E1FF00FFE100FFD100FFE100E1FF00FFF000FFF00075FF00B3FF0028FF
0038FF0047FF00FFFF00E1FF00B3FF0094FF00FFFF00FFFF00F0FF00D1FF00E1FF00D1FF
00A3FF0066FF7000FFFF00001400FF0066FF00A3FF00D1FF00E1FF00E1FF00FFFF00FFF0
00FFFF0047FF00F0FF00FFF000FFF000FFFF00D1FF00C2FF00FFFF00FFE100FFC200FFB3
00FFA300FFA300FFA300FFA300FFA300FFA300FFA300FFB300FFC200FFD100FFFF00A3FF
00E1FF00FFF000FFD100FFB300FFA300FF9400FF8500FF8500FF8500FF7500FF8500FF85
00FF8500FF9400C2FF00FFC200FFA300FF9400FFA300C2FF00FFB300FFA300FFA300FFA3
00FFC200F0FF00A3FF0066FF2300FF00F0FF00FFE100FFB300FFA300FF9400FF8500FF85
00FF7500FF7500FF7500FF6600FF6600FF6600FF5700FF5700FF5700FF4700FF4700FF47
00FF3800FF3800FF2800FF2800FF2800FF2800FF1900FF1900FF1900FF1900FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A05FF0005FF0000FF0A05FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0000FF0A00FF0A00FF2800FF6600E1FF00FF7500FF38
00FF2800FF2800FF2800FF28
00FF6600FF5700FF5700FF5700FF5700FF6600FF6600FF6600FF6600FF7500FF7500FF75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00FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF6600FF6600FF6600FF6600FF75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00FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF6600FF6600FF6600FF75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00FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF6600FF6600FF75
00FF8500FF9400FFA300FFB300C2FF00FFD100FFF000FFF000FFFF0066FF0085FF00B3FF
0094FF0085FF00A3FF0085FF0019FF1400FF00D1FF00FFFF00C2FF00FFE100FFB300FFA3
00FF9400FF8500FF8500FF7500FF7500FF6600FF6600FF6600FF6600FF5700FF5700FF57
00FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF6600FF66
00FF7500FFB300FFC200E1FF00FFD100FF6600FF4700FF3800FF3800FF2800FF2800FF28
00FF2800FF2800FF2800FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF0A00FF0A00FF0A00FF1900FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
00FF0A05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0000FF0A05FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0000FF0A05FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0000FF0A05FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0000FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF3800FF3800FF3800FF3800FF3800FF4700FF4700FF4700FF5700FF5700FF57
00FF6600FF6600FF7500FF7500FF8500FF9400FFA300FFE100D1FF00FFFF0094FFFF0000
0094FF00D1FF00D1FFFF00B800A3FF00E1FF00D1FFEB00FF00C2FF00FFFF00FFF000C2FF
00FFE100FFE10085FF00FFC200FFB300FFA300FFA300FF9400FF8500FF8500FF7500FF75
00FF6600FF6600FF6600FF6600FF6600FF5700FF5700FF6600FF5700FF5700FF5700FF57
00FF5700FF5700FF5700FF5700FF5700FF5700FF4700FF4700FF5700FF5700FF4700FF47
00FF4700FF4700FF5700FF5700FF4700FF4700FF4700FF4700FF5700FF5700FF5700FF47
00FF4700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF57
00FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF57
00FF5700FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7500FF75
00FF7500FF7500FF7500FF7500FF7500FF8500FF8500FF8500FF8500FF8500FF9400FF94
00FF9400FFA300FFA300FFA300FFB300FFB300FFB300FFC200FFD100FFD100FFD100FFE1
00FFF000FFFF00FFFF00F0FF00D1FF0075FF0028FF0028FF00C2FF00C2FF00D1FF00C2FF
0047FF0094FF0038FF00B3FF00B3FF00B3FF0085FF0075FF0085FF0075FFDC00FF3300FF
FF00B8FF0000FF0000FF007AFF00D7FF00008F00FFFF0000EB00FFFF00C7FF006BFF0000
BD00FFDC00FFEB00FFFF0000FF0000FF008AFF004CFF008ACC00FF5100FF000AFFDC00FF
0038FF5100FF0028FF00A3FF00A3FF0094FF0028FF00C2FF00D1FF00E1FF00F0FF00F0FF
00F0FF00F0FF00E1FF00D1FF0094FF0028FF0028FF00C2FF00C2FF0094FF00A3FF0075FF
0057FF0047FF00B3FF00C2FF00E1FF00E1FF0075FF00F0FF00FFFF00FFFF00F0FF0085FF
00B3FF00F0FF00F0FF00FFE100FFC200FFB300FFA300FF9400FF9400FF9400FF8500FF85
00FF8500FF8500FF8500FF8500FF8500FF7500FF7500FF7500FF7500FF7500FF7500FF75
00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF66
00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF66
00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7500FF75
00FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF8500FF8500FF8500FF8500FF85
00FF9400FF9400FFA300FFB300FFB300FFE100FFF00066FF0075FF0094FF00E1FF00E1FF
00E1FF0057FF0066FF0075FF0066FF1400FF0057FF0094FF5100FF00F0FF00FFFF00FFF0
00FFE100FFE100FFD100FFD100FFD100FFB300FFB300FFA300FF9400FF9400FF9400FF85
00FF8500FF8500FF7500FF8500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF75
00FF7500FF7500FF7500FF8500FF8500FF8500FF8500FFA300A3FF3300FF00E1FF00D1FF
00FFFF00E1FF00F0FF00C2FF0094FF00F0FF00FFFF00FFFF00C2FF00F0FF00D1FF0085FF
FF002E2300FF0028FF00C2FF00FFF000FFD100FFC200FFB300FFB300FFA300FF9400FF94
00FF8500FF8500FF8500FF8500FF7500FF7500FF7500FF7500FF7500FF6600FF6600FF66
00FF6600FF6600FF6600FF5700FF5700FF5700FF5700FF5700FF4700FF4700FF4700FF47
00FF4700FF4700FF4700FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF2800FF2800FF3800FF3800FF3800FF3800FF2800FF2800FF28
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF47
00FF3800FF3800FF4700FF4700FF4700FF4700FF4700FF4700FF5700FF5700FF6600FF66
00FF7500FF9400FFB30038FF00F0FF00FFB300FF9400FF8500FF7500FF7500FF7500FF66
00FF6600FF6600FF6600FF6600FF6600FF5700FF5700FF5700FF5700FF5700FF5700FF57
00FF5700FF6600FF6600FF6600FF6600FF6600FF6600FF7500FF7500FF8500FF8500FF85
00FF9400FFA300FFB300FFE10047FF00FFFF00FFD100FFC200FFB300FFB300FFB300FFB3
00FFB300FFC200FFD100FFE100F0FF00D1FF0075FF8F00FFFA00FF00E1FF00FFF000FFD1
00FFC200FFB300FFA300FFA300FF9400FF9400FF9400FF9400FF9400FFA300FFA300FFA3
00FFA300FFB300FFB300FFB300FFC200FFD100FFF000E1FF0075FF00F0FF00FFF000FFE1
00FFF000FFD100FFD100FFE100FFF000E1FF0047FF00E1FF00F0FF00D1FF00E1FF00B3FF
0085FFAE00FF4200FFFF006B0038FF0085FF00C2FF00E1FF00F0FF00A3FF00F0FF00E1FF
0094FF00C2FF00F0FF00FFFF00FFFF0028FF0085FF00F0FF00C2FFAE00FF5100FF0057FF
0066FF00F0FF00F0FF0047FF0094FF00D1FF00FFFF0047FF6100FF00C2FF0085FFFA00FF
5100FFDC00FF8F00FFAE00FF000AFF0038FF9E00FF0019FF0085FF00A3FFFF00E600FFC2
00FFB300FFA300FFA300FFA300FFB3FF0000000AFF00FFE100FF9400FF9400FF8500FF85
00FF8500FF7500FF7500FF7500FF8500FF8500FF9400FFB300FFD10038FF00D1FF00FFA3
00FF9400FF9400E1FF00FFFF00E1FF00FF9400FF8500FF6600FF6600FF6600FF6600FF66
00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7500FF7500FF7500FF7500FF85
00FF8500FF9400FFA300FFB300FFC200FFE10094FF00B3FFAE00FF0075FFFF000000C2FF
00E1FF00FFE100FFE100FFD100FFF000C2FF00FFC200FF9400FF7500FF7500FF7500FFC2
00FFE100FF5700FF4700FF3800FF2800FF2800FF2800FF1900FF1900FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0014FF0014FF0014FF0005FF0014FF0014FF0014FF0005FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF00
00FF4700FF4700FF4700FF5700FF4700FF4700FF5700FF5700FF5700FF6600FF6600FF75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00FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF5700FF5700FF5700FF6600FF75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00FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF5700FF5700FF6600FF85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00FF4700FF3800FF4700FF4700FF4700FF4700FF4700FF4700FF5700FF5700FF750066FF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00FF3800FF3800FF3800FF3800FF3800FF3800FF4700FF4700FF4700FF5700FF6600FF85
FF00C700FF8500FF8500FF7500FF8500FF8500FFA300FFD10075FF00F0FF00FFB300FFA3
00FFA300FFA300FFD100B3FF00FFFF00A3FF00F0FF0057FF2300FF00E1FF3300FF00FFF0
00FFD100FFC200FFE19E00FF00FFFF00FFA300FF9400FFA300FF9400FF8500FF7500FF75
00FF6600FF6600FF6600FF6600FF6600FF6600FF7500FF8500FF9400FFB300FFE10075FF
0075FF00C2FF00FFC200FF8500FF6600FF5700FF4700FF4700FF3800FF3800FF3800FF38
00FF3800FF3800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A05FF0005FF0005FF0005FF0005FF0005FF0005FF0000FF0A00FF0A05FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0000FF0A05FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0000FF0A05FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0000FF0A00FF0A05FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0000FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF3800FF3800FF3800FF3800FF4700FF4700FF4700FF5700FFFF00FFB300FFA3
00FFD100D1FF00FFD100FFD10038FF00FFC200FFC200FFC200FFD100FFFF00C2FF0075FF
FF0000FF003D5100FF000AFF0019FF0047FF00A3FF8000FF0057FF00FFE100FFC200FFC2
00FFB300FFA300FFA300FF9400FF9400FF8500FF8500FF8500FF8500FF7500FF7500FF75
00FF7500FF7500FF6600FF6600FF6600FF6600FF6600FF6600FF5700FF6600FF5700FF57
00FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF57
00FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF57
00FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF57
00FF5700FF5700FF5700FF5700FF5700FF5700FF6600FF5700FF5700FF5700FF6600FF66
00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7500FF7500FF7500FF75
00FF7500FF7500FF8500FF8500FF8500FF9400FF9400FF9400FF9400FF9400FFA300FFA3
00FFB300FFC200FFFF00FFD100FFD100FFD100FFD100FFD100FFF000C2FF00E1FF00F0FF
00F0FF00B3FF0075FF0085FF3300FF0028FF0066FF00C2FF00D1FF00D1FF00C2FF00B3FF
000AFF0057FF0085FF00A3FF0094FF0028FF0038FF0057FF0066FF0057FF0038FF0019FF
FF006BFF002EFF007AFF0000FF00C7EB00FF9E00FF9E00FFAE00FFAE00FFFF00009E00FF
8F00FF6100FF8000FFFF00F5FF0000FF0000AE00FF7000FF0500FF0047FF0066FF0085FF
00A3FF00B3FF00C2FF00C2FF00E1FF00E1FF00F0FF00FFFF00FFFF00FFFF00FFF000FFF0
00FFF000FFF000FFE100FFE100FFE100FFE100FFE100FFE100FFE100FFF000FFF000F0FF
00B3FF00FFF000FFE100FFD100FFD100FFD100FFD100FFC200FFC200FFC200FFC200FFD1
00FFD100C2FF00FFE100FFB300FFA300FFA300FF9400FF9400FF9400FF8500FF8500FF85
00FF8500FF8500FF8500FF8500FF8500FF8500FF7500FF7500FF7500FF7500FF7500FF75
00FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF6600FF6600FF6600FF6600FF66
00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF66
00FF6600FF6600FF6600FF7500FF6600FF6600FF7500FF7500FF7500FF7500FF7500FF75
00FF7500FF7500FF7500FF7500FF7500FF7500FF8500FF8500FF8500FF8500FF8500FF85
00FF9400FF9400FFA300FFB300FFB300FFC200FFC200FFC200FFC200FFC200FFD100FFD1
00FFE100FFFF00B3FF0047FF0075FF0028FFFF00C7FF00A80075FFFF00B80019FF00FFFF
00FFD100FFC200FFC200FFB300FFB300FFA300FFA300FFA300FFA300FF9400FF9400FF94
00FF9400FF9400FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF85
00FF8500FF9400FF8500FF9400FF9400FF9400FF9400FFA300FFA300FFB300FFC200FFC2
00FFD100FFE100FFF000FFFF00A3FFFF002E5100FF9E00FFAE00FFAE00FF5100FF0047FF
0066FF00D1FF00FFFF00FFE100FFE100FFD100FFC200FFC200FFB300FFA300FFA300FF94
00FF8500FF8500FF7500FF7500FF7500FF7500FF7500FF6600FF6600FF6600FF6600FF66
00FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF4700FF4700FF4700FF4700FF47
00FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF4700FF3800FF4700FF4700FF4700FF4700FF4700FF4700FF47
00FF4700FF4700FF4700FF4700FF5700FF5700FF5700FF5700FF6600FF6600FF6600FF75
00FF9400FFC200E1FF0066FF4200FF4200FF8000FF00F0FF00FFF000FFF000E1FF00FFA3
00FF9400FF8500FF7500FF7500FF7500FF7500FF6600FF6600FF6600FF6600FF6600FF66
00FF6600FF7500FF7500FF7500FF7500FF7500FF8500FF8500FF9400FFB300B3FF00D1FF
00F0FF0047FF0085FF0094FF00B3FF0075FF00D1FF00F0FF00D1FFFF00C700F0FF00D1FF
00A3FF000AFFFF004C00B3FF00F0FF00FFE100FFD100FFC200FFD100F0FF00D1FF00FFB3
00FF9400FF9400FF8500FF8500FF8500FF8500FF7500FF7500FF7500FF7500FF7500FF85
00FF8500FF8500FF8500FFA300FFE100FFD100FFA300FF9400FF9400FFA300FFB300FF94
00FF9400FF8500FF8500FF9400FF9400FF9400FF9400FFA300FFA300FFB300FFB300FFC2
00FFD100FFF000A3FF0066FF00E1FF00FFE100FFD100FFC200FFB300FFA300FFA300FFA3
00FF9400FF9400FF9400FF9400FF9400FF9400FFB300F0FF6100FF00E1FF00FFC200FFE1
000AFF00FFF000FFB300FFA300FFA300FFA300FFB30019FF00FFE100FFD10094FF00D1FF
00FFF000FFF00057FF0028FF00C2FF00FFF000FFD100FFC200FFB300FFB300FFA300FF94
00FF8500FF8500FF8500FF7500FF7500FF7500FF6600FF6600FF6600FF6600FF5700FF57
00FF5700FF5700FF5700FF5700FF5700FF5700FF6600FF7500B3FF00FF9400FF8500FF57
00FF5700FF5700FF5700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF47
00FF4700FF4700FF4700FF5700FF5700FF5700FF5700FF5700FF6600FF6600FF6600FF75
00FF9400C2FF00FFE100FFE10075FF00F0FF00FFB300FF9400FF8500FF7500FF7500FF75
00FF7500FF8500FFE100FF8500FFC200FF8500FF8500FF9400FFA300E1FF00C2FF00E1FF
00F0FF0085FF00FFC20085FF00FF5700FF5700FF4700FF4700FF2800FF1900FF0A00FF0A
00FF0A05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0014FF0014FF0014FF00
05FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF00
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF4700FF4700FF4700FF5700FF57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00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF4700FF4700FF57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00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF4700FF47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00FF2800FF2800FF2800FF3800FF2800FF3800FF3800FF3800FF3800FF3800FF3800FF47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00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF3800FF3800FF3800FF3800FF38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00FF2800FF2800FF2800FF2800FF2800FF2800FF3800FF2800FF3800FF3800FF3800FF38
00FF3800FF3800FF4700FF4700FF4700FF5700FF5700FF5700FF5700FF6600FF6600FF66
00FF6600FF7500FF8500FF9400FFA300FFE100FFE100FFF000FFFF00E1FF0085FFFF00A8
0019FF0085FF00B3FF00F0FF00FFE100FFD100FFC200FFB300FFA300FFA300FF9400FF94
00FF9400FF9400FF9400FF9400FF9400FF9400FFA300FFB300FFD100D1FF00B3FF00FFD1
00FFB300FF9400FF8500FF7500FF7500FF6600FF6600FF6600FF6600FF6600FF6600FF66
00FF6600FF6600FF7500FF5700FF5700FF5700FF6600FFD100FFA300FF5700FF4700FF47
00FF3800FF3800FF2800FF2800FF2800FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A05FF00
05FF0005FF0005FF0005FF0000FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF1900FF1900FF0A00FF0A00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF3800FF3800FF3800FF3800FF3800FF3800FF4700FF4700FF4700FF5700FF5700FF66
00FF6600FF7500FF8500FFA300FFB3000AFF0028FF00FFFF00FFD100FFC200FFC200FFD1
00FFD100FFE100FFF000FFFF0066FF1400FF0028FFFF00C700C2FF00E1FF00E1FF0019FF
00FFFF00FFD100FFC200FFB300FFA300FF9400FF9400FF8500FF8500FF8500FF8500FF75
00FF7500FF7500FF7500FF7500FF7500FF6600FF7500FF6600FF6600FF6600FF6600FF66
00FF6600FF6600FF6600FF6600FF6600FF6600FF5700FF5700FF5700FF6600FF5700FF57
00FF5700FF6600FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF57
00FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF6600FF5700FF57
00FF5700FF5700FF5700FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF66
00FF6600FF6600FF6600FF6600FF6600FF6600FF7500FF7500FF7500FF7500FF7500FF75
00FF8500FF8500FF9400FFA300FFB300B3FF00C2FF00D1FF00FFF000FFFF2300FF00F0FF
0019FF00A3FF8000FFFF00000028FF9E00FFFF00990057FF0094FF0500FF00A3FF0057FF
0075FF00C2FF00F0FF00FFFF00FFFF00FFF000FFF000FFF000FFF000FFF000FFF000FFFF
00FFFF00FFFF00F0FF00F0FF00E1FF00C2FF00B3FF0066FF0066FF9E00FF2300FF0019FF
0028FF0057FF0066FF0038FF1400FF0038FF4200FF0057FF0047FF0028FF1400FFFF00C7
000AFF0038FF0057FF0066FF0075FF0085FF0094FF0094FF0094FF0094FF0075FFFF0000
0019FF0085FF00C2FF00E1FF00F0FF00FFFF00FFF000FFF000FFE100FFE100FFE100FFE1
00FFE100FFD100FFD100FFD100FFD100FFD100FFD100FFC200FFC200FFC200FFC200FFC2
00FFC200FFC200FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA300FFA300FFA3
00FFA300FFA300FFA300FF9400FF9400FF9400FF9400FF9400FF9400FF8500FF8500FF85
00FF8500FF8500FF8500FF8500FF8500FF8500FF7500FF7500FF7500FF8500FF7500FF75
00FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF75
00FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF75
00FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF75
00FF7500FF7500FF7500FF7500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF85
00FF9400FF9400FF9400FF9400FF9400FFA300FFA300FFA300FFB300FFB300FFB300FFC2
00FFD100FFD100FFE100FFF000FFFF00F0FF00B3FF0094FF8000FFFF000000B3FF00D1FF
00D1FF00A3FF4200FF00FFFF00FFF000FFE100FFD100FFC200FFB300FFB300FFA300FFA3
00FFA300FFA300FF9400FF9400FF9400FF9400FF9400FFA300FF9400FFA300FFA300FFA3
00FFA300FFB300FFC200FFE11400FF00FFFF00FFD100FFD100FFD100FFD100FFE100FFFF
0094FF0085FF8000FFEB00FFFA00FF0066FF0066FF00D1FF00E1FF0094FF00F0FF00FFFF
00FFFF00F0FF00C2FF2300FF00F0FF00FFF000FFD100FFC200FFB300FFA300FF9400FF94
00FF8500FF8500FF7500FF7500FF7500FF6600FF6600FF6600FF6600FF6600FF6600FF57
00FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF4700FF4700FF4700FF47
00FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF38
00FF3800FF3800FF3800FF4700FF3800FF3800FF3800FF3800FF3800FF4700FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF4700FF3800FF3800FF4700FF4700FF4700FF4700FF47
00FF4700FF4700FF4700FF4700FF5700FF5700FF5700FF6600FF8500FFA300FF7500FF75
00FF6600FF6600FF6600FF6600FF7500FF6600FF6600FF7500FF7500FF7500FF8500FF85
00FF8500FF9400FFB33300FF00D1FF00E1FF1400FF7000FF00E1FF00B3FF00FFD100FFB3
00FFA300FF9400FF9400FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF85
00FF8500FF8500FF8500FF9400FF9400FF9400FF9400FFA300FFA300FFA300FFB300FFB3
00FFE100FFE100FFE100FFF000F0FF00D1FF00A3FF0047FF000AFFAE00FF5100FF0075FF
0028FF0094FF00FFE100FFD100FFC200FFB300FFA300FFA300FF9400FF8500FF8500FF85
00FF7500FF7500FF7500FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF66
00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF66
00FF6600FF6600FF6600FF6600FF7500FF7500FF8500FF9400FFA300FFC200FFE100A3FF
00FFFF00FFE100FFA300FFA300FFA300FFB300FFF0FF002E00F0FF00FFF000FF8500FF75
00FF7500FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF66
00FF6600FF6600FF7500FF7500FF7500FF7500FF7500FF8500FF8500FF8500FF9400FFA3
00FFB300FFC200FFE100E1FF0047FF00F0FF0019FF0066FF0038FF00FFFF00FFD100A3FF
00FFB300FF9400FF8500FF7500FF7500FF6600FF6600FF5700FF5700FF5700FF4700FF47
00FF4700FF4700FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF4700FF4700FF4700FF4700FF5700FF6600FF7500FF9400D1FF
00FFB300FFC200FFD100E1FF0085FF00FFD100FFB300FFA300FF9400FF6600FF5700FF47
00FF4700FF4700FF3800FF3800FF3800FF3800FF3800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF3800FF6600FF4700FF1900FF0A00FF0A05FF0005FF00
05FF0005FF0005FF0005FF0005FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0023FF0023FF00
23FF0023FF0014FF0023FF0023FF0023FF0023FF0014FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0014FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF00
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF3800FF3800FF38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00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF3800FF2800FF38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00FF2800FF1900FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF38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00FF1900FF1900FF1900FF1900FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28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00FF1900FF1900FF1900FF1900FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF38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00FF1900FF1900FF1900FF2800FF1900FF1900FF2800FF2800FF2800FF2800FF2800FF28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00FF1900FF1900FF1900FF1900FF1900FF2800FF1900FF2800FF2800FF2800FF2800FF28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00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF2800FF2800FF2800FF2800FF28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00FF1900FF1900FF1900FF1900FF1900FF1900FF2800FF1900FF2800FF2800FF2800FF28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00FF0A00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF2800FF2800FF2800FF38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00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF2800FF2800FF28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00FF0A00FF0A00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF2800FF2800FF28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00FF0A00FF0A00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF2800FF2800FF28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00FF0A00FF0A00FF0A00FF1900FF1900FF1900FF1900FF1900FF2800FF2800FF2800FF28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00FF0A00FF0A00FF0A00FF1900FF1900FF1900FF1900FF1900FF1900FF2800FF2800FF28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00FF0A00FF0A00FF0A00FF0A00FF1900FF1900FF1900FF1900FF1900FF2800FF2800FF38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00FF0A00FF0A00FF0A00FF0A00FF1900FF1900FF1900FF1900FF1900FF2800FF2800FF38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00FF0A00FF0A00FF0A00FF1900FF1900FF1900FF1900FF1900FF1900FF2800FF3800FF66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00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF1900FF1900FF1900FF2800FF3800FF66
00F0FF0094FF00FFD100FF940075FF00FFFF5100FF0066FF5100FF00C2FF00E1FF00A3FF
2300FF0075FF0038FF4200FF8000FF00C2FF00D1FF00FFE100FFE100FFFF0075FF0094FF
8000FF6100FF00A3FF00A3FF0019FFFF0000CC00FF6100FF9E00FF0500FF0085FF0094FF
00C2FF00FFFF00FFE100FFD100FFC200FFC200FFB300FFA300FF9400FF9400FF8500FF85
00FF7500FF7500FF7500FF7500FF6600FF6600FF6600FF6600FF5700FF5700FF5700FF57
00FF4700FF4700FF4700FF4700FF4700FF4700FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF0A00FF1900FF1900FF1900FF19
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF1900FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF2800FF2800FF2800FF2800FF28
00FF2800FF3800FF3800FF3800FF5700FF7500FF6600FF4700FF4700FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF4700FF4700FF47
00FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF5700FF5700FF5700FF57
00FF5700FF5700FF5700FF5700FF6600FF6600FF6600FF6600FF7500FF7500FF8500FF94
00FF9400FFA300FFC200FFC200FFE100FFF000E1FF0057FFFF0000FF00990066FF0066FF
9E00FFFF004CBD00FF0019FF0038FF0085FF0019FF00B3FF00FFFF00FFF000FFE100FFE1
00FFD100FFD100FFD100FFC200FFC200FFC200FFC200FFB300FFA300FFA300FF9400FF94
00FF9400FF8500FF8500FF8500FF8500FF7500FF7500FF7500FF7500FF7500FF7500FF75
00FF7500FF7500FF7500FF7500FF7500FF6600FF6600FF6600FF7500FF6600FF6600FF66
00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7500FF6600FF6600FF6600FF66
00FF6600FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF75
00FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF8500FF8500FF8500FF85
00FF8500FF8500FF8500FF8500FF8500FF8500FF9400FF9400FF9400FF9400FF9400FF94
00FF9400FF9400FF9400FF9400FFA300FFA300FFA300FFA300FFA300FFA300FFA300FFB3
00FFB300FFB300FFB300FFB300FFB300FFB300FFC200FFC200FFC200FFC200FFD100FFD1
00FFD100FFD100FFE100FFE100FFE100FFF000FFF000FFF000FFFF00FFFF00FFFF00FFFF
00F0FF00F0FF00F0FF00E1FF00E1FF00D1FF00C2FF00B3FF00B3FF00A3FF0085FFFF00D7
4200FF9E00FFFF0000DC00FF0047FF0085FF0094FF00B3FF00B3FF00C2FF00C2FF00D1FF
00D1FF00E1FF00E1FF00E1FF00E1FF00D1FF00C2FF0085FFFF00A80028FF0075FF00D1FF
00E1FF00FFFF00FFE100FFE100FFD100FFD100FFC200FFC200FFC200FFC200FFC200FFB3
00FFB300FFB300FFB300FFB300FFB300FFB300FFA300FFA300FFA300FFA300FFA300FFA3
00FFA300FFA300FFA300FF9400FF9400FF9400FFA300FF9400FF9400FF9400FF9400FF94
00FF9400FF9400FF9400FF9400FF9400FF9400FF9400FF9400FF9400FF8500FF8500FF85
00FF9400FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF85
00FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF85
00FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF9400FF8500FF8500FF94
00FF9400FF9400FF9400FF9400FF9400FF9400FF9400FF9400FF9400FF9400FF9400FF94
00FFA300FF9400FF9400FFA300FFA300FFA300FFA300FFA300FFA300FFA300FFA300FFB3
00FFB300FFB300FFB300FFB300FFC200FFC200FFC200FFC200FFD100FFD100FFD100FFE1
00FFE100FFF000FFFF00FFFF00E1FF00D1FF0057FF0038FF0075FF00B3FF00B3FFFF00B8
0085FF0500FF4200FFFF00A80075FF00A3FF0028FF00B3FF00C2FF00B3FF1400FF0094FF
1400FF00B3FF00FFF000FFE100FFE100FFD100FFD100FFD100FFD100FFE100FFFF0085FF
00D1FF00C2FF00FFF000FFC200FFB300FFA300FFA300FFA300FF9400FF9400FF9400FF94
00FF9400FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF7500FF7500FF75
00FF7500FF7500FF7500FF7500FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF66
00FF6600FF6600FF6600FF5700FF5700FF5700FF6600FF5700FF5700FF5700FF5700FF57
00FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF57
00FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF4700FF4700FF5700FF5700FF57
00FF4700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF57
00FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF66
00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7500FF7500FF7500FF7500FF75
00FF8500FF8500FF8500FF9400FF9400FF9400FF9400FFA300FFA300FFA300FFA300FFB3
00FFB300FFC200FFC200FFD100FFD100FFE100FFF000FFFF00F0FF00C2FF0047FF0057FF
CC00FF0057FF0057FF0019FF7000FFBD00FFBD00FF0038FF0066FF0028FF0028FFEB00FF
0057FF00A3FF00D1FF00D1FFFF000000E1FF00FFF000FFE100FFE100FFE100FFE100FFFF
0094FF5100FF00FFE100FFB300FF9400FF9400FF8500FF8500FF8500FF7500FF7500FF75
00FF7500FF6600FF6600FF6600FF6600FF6600FF6600FF5700FF5700FF5700FF5700FF57
00FF5700FF5700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF47
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF2800FF2800FF3800FF2800FF2800FF2800FF3800FF2800FF28
00FF3800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF4700FF4700FF4700FF5700FF5700FF6600FF85
00FFB300FFD100FF8500FF6600FF5700FF4700FF3800FF3800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF0A00FF0A00FF0A00FF19
00FF0A00FF0A00FF0A00FF1900FF0A00FF0A00FF0A00FF1900FF0A00FF0A00FF1900FF0A
00FF0A00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF2800FF2800FF28
00FF2800FF2800FF2800FF3800FF3800FF3800FF4700FF5700FF8500FFA31400FF00FF85
00FF6600FF5700FF4700FF3800FF2800FF1900FF0A00FF0A05FF0005FF0005FF0005FF00
05FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF00
00FF0A00FF0A00FF0A00FF0A00FF1900FF1900FF1900FF1900FF1900FF2800FF2800FF38
00FF5700FF7500FFA300FFF000FFD100FFB300FFB300FFF000FFFF00FFC200FFB300FFC2
0057FF00FFFF00FFD100FFF000B3FF00E1FF3300FF00B3FF00F0FF0094FF0066FF0057FF
00E1FFFA00FF00E1FF00E1FF0047FF0019FF0047FF0066FF0085FF0038FF2300FF0028FF
0019FF00FFFF00FFE100FFD100FFC200FFB300FFB300FFA300FFA300FF9400FF8500FF85
00FF7500FF7500FF7500FF6600FF6600FF6600FF6600FF5700FF5700FF5700FF5700FF57
00FF5700FF4700FF4700FF4700FF4700FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF1900FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF1900FF1900FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF3800FF3800FF3800FF4700FF6600C2FF00FF6600FF5700FF4700FF4700FF4700FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF4700FF3800FF3800FF3800FF3800FF4700FF3800FF3800FF4700FF4700FF47
00FF4700FF4700FF4700FF4700FF4700FF5700FF4700FF4700FF4700FF5700FF5700FF57
00FF5700FF5700FF5700FF6600FF6600FF6600FF6600FF6600FF7500FF7500FF8500FF85
00FF9400FF9400FFA300FFC200FFD100FFF000E1FFFF000000D1FF00D1FF00C2FF00A3FF
3300FF3300FF0047FF4200FF0057FF00B3FF00C2FF00C2FF00FFFF00FFF000FFE100FFD1
00FFD100FFC200FFC200FFC200FFC200FFB300FFB300FFA300FFA300FFA300FF9400FF94
00FF9400FF8500FF8500FF8500FF8500FF7500FF7500FF7500FF7500FF7500FF7500FF75
00FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF6600FF66
00FF6600FF7500FF7500FF6600FF6600FF6600FF6600FF7500FF7500FF6600FF6600FF66
00FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF75
00FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF8500FF8500FF85
00FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF9400FF9400FF9400FF94
00FF9400FF9400FFA300FFA300FFA300FFA300FFA300FFA300FFA300FFA300FFA300FFA3
00FFA300FFB300FFB300FFB300FFB300FFB300FFB300FFC200FFC200FFD100FFD100FFD1
00FFD100FFE100FFE100FFE100FFF000FFF000FFFF00FFFF00FFFF00FFFF00F0FF00F0FF
00F0FF00F0FF00F0FF00E1FF00E1FF00D1FF00C2FF00C2FF00B3FF00A3FF0094FF0066FF
6100FF1400FF5100FF0028FF000AFF0075FF0094FF00A3FF00B3FF00C2FF00C2FF00D1FF
00D1FF00D1FF00D1FF00D1FF00D1FF00A3FF00B3FF0038FF5100FF0500FF00B3FF00F0FF
00FFFF00FFF000FFE100FFD100FFD100FFD100FFC200FFC200FFC200FFC200FFB300FFB3
00FFB300FFB300FFB300FFB300FFB300FFA300FFA300FFA300FFA300FFA300FFA300FFA3
00FFA300FFA300FFA300FFA300FFA300FFA300FF9400FF9400FF9400FF9400FF9400FF94
00FF9400FF9400FF9400FF9400FF9400FF9400FF9400FF9400FF9400FF9400FF8500FF94
00FF9400FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF85
00FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF85
00FF8500FF8500FF8500FF8500FF9400FF9400FF8500FF9400FF9400FF9400FF9400FF94
00FF9400FF9400FF9400FF9400FF9400FF9400FF9400FF9400FF9400FF9400FF9400FF94
00FF9400FFA300FFA300FFA300FFA300FFA300FFA300FFA300FFA300FFB300FFB300FFB3
00FFB300FFB300FFB300FFC200FFC200FFC200FFC200FFD100FFD100FFD100FFD100FFE1
00FFE100FFF000FFF000FFFF00F0FF00E1FF00D1FF00B3FF0038FF0075FF4200FFFF008A
0038FF0047FF0085FF0028FF0085FF00D1FF00E1FF00E1FF00E1FF00A3FF1400FF00D1FF
00E1FF00E1FF00FFF000FFE100FFD100FFD100FFD100FFD100FFD100FFD100FFD100FFE1
00FFF04200FF00FFE100FFC200FFA300FFA300FFA300FF9400FF9400FF9400FF9400FF85
00FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF7500FF7500FF7500FF7500FF85
00FF7500FF7500FF7500FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF66
00FF6600FF6600FF6600FF6600FF6600FF6600FF5700FF5700FF5700FF5700FF5700FF57
00FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF57
00FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF57
00FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF57
00FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF66
00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7500FF7500FF7500FF7500FF85
00FF8500FF8500FF8500FF8500FF9400FF9400FF9400FF9400FFA300FFA300FFA300FFB3
00FFB300FFB300FFC200FFD100FFD100FFE100FFF000FFFF00F0FF00D1FF00B3FF0094FF
0047FFFF007A0019FF7000FF8F00FFDC00FFAE00FF4200FF4200FFFF00000019FF0047FF
0019FF0075FF00E1FF00F0FF00F0FF00FFFF00FFE100FFD100FFD100FFD100FFD100FFF0
00FFE100FFE10066FF00FFB300FF9400FF9400FF8500FF8500FF7500FF7500FF7500FF75
00FF6600FF6600FF6600FF6600FF6600FF5700FF5700FF5700FF5700FF5700FF5700FF57
00FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF28
00FF2800FF2800FF3800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF3800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF3800FF2800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF4700FF4700FF4700FF5700FF6600FF85
FF000000FFE100B3FF0075FF00FF5700FF4700FF3800FF3800FF2800FF2800FF2800FF28
00FF2800FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF1900FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF0A
00FF0A00FF1900FF0A00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF2800FF2800FF2800FF2800FF3800FF3800FF3800FF4700FF5700FF7500FFC200FFB3
00FFC200FFB300FFD100FF6600FFB300FF1900FF0A00FF0A05FF0005FF0005FF0005FF00
05FF0005FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
23FF0023FF0023FF0014FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF00
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF1900FF1900FF1900FF2800FF38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00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF1900FF1900FF1900FF1900FF2800FF28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00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF1900FF1900FF1900FF28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00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF0A00FF1900FF1900FF1900FF2800FF19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00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF1900FF1900FF1900FF19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00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF0A00FF1900FF1900FF1900FF28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00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF1900FF1900FF19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00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF1900FF1900FF1900FF19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00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF1900FF19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05FF0000FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF1900FF19
00FF1900FF1900FF1900FF2800FF2800FF2800FF2800FF3800FF3800FF3800FF4700FF57
00FF6600FFA300FFE17000FFDC00FF00FFD100FFA300FF9400FF8500FF7500FF7500FF75
00FF7500FF7500FF7500FF7500FF8500FF9400FFA300FFC200FFD100FFE100FFF000FFFF
00E1FF0094FFFF00F51400FF0057FF0057FF00E1FF00FFF000FFE100FFD100FFD100FFE1
00FFB300FFA300FF9400FF7500FF7500FF6600FF6600FF6600FF5700FF5700FF6600FF57
00FF4700FF4700FF4700FF4700FF4700FF4700FF3800FF3800FF3800FF4700FF3800FF38
00FF3800FF3800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF1900FF1900FF2800FF2800FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF3800FF3800FF3800FF4700FF4700FF4700FF57
00FF5700FF6600FF6600FF7500FF9400FFD19E00FF00FFD100FFA300FF8500FF7500FF75
00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF66
00FF6600FF6600FF6600FF7500FF7500FFA300FF8500FF6600FF6600FF6600FF5700FF57
00FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF6600FF6600FF6600FF66
00FF6600FF6600FF6600FF6600FF6600FF6600FF7500FF7500FF7500FF7500FF7500FF85
00FF8500FF8500FF8500FF9400FF9400FF9400FFA300FFA300FFB300FFB300FFC200FFC2
00FFD100FFE100FFF000F0FF00D1FF0075FFFF009900C2FF00E1FF00FFFF00FFF000FFE1
00FFD100FFD100FFC200FFC200FFB300FFB300FFA300FFA300FFA300FF9400FF9400FF94
00FF9400FF9400FF9400FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF85
00FF7500FF7500FF7500FF8500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF75
00FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF75
00FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF85
00FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF85
00FF8500FF8500FF8500FF8500FF9400FF9400FF9400FF9400FF9400FF9400FF9400FF94
00FF9400FF9400FF9400FFA300FFA300FFA300FFA300FFA300FFA300FFA300FFA300FFB3
00FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC200FFC200FFC200FFC200FFD1
00FFD100FFE100FFE100FFF000FFF000FFFF00FFFF00F0FF00E1FF00E1FF00D1FF00B3FF
00A3FF0085FF0028FF0028FF2300FF5100FFAE00FF9E00FFFF0000EB00FFCC00FFFA00FF
FF000FFF007AFF00D7FF005CFF00E6FF004CFF0000FF00007000FF0028FF0057FF0075FF
0085FF0094FF00A3FF00A3FF0094FF0019FF2300FF0066FF0019FFFF00E6FF002E5100FF
FF00000500FFFF0000FF00000028FF0066FF00B3FF0019FF0075FF0085FF00FFE100FFD1
00FFC200FFC200FFC200FFC200FFB300FFC200FFB300FFB300FFB300FFB300FFB300FFB3
00FFB300FFA300FFA300FFB300FFA300FFA300FFA300FFA300FFA300FFA300FFA300FFA3
00FFA300FFA300FFA300FFA300FFA300FFA300FFA300FFA300FFA300FFA300FFA300FFA3
00FFA300FFA300FFA300FFA300FFA300FF9400FFA300FFA300FF9400FFA300FFA300FFA3
00FFA300FFA300FFA300FFA300FFA300FFA300FFA300FFB300FFB300FFB300FFC200FFC2
00FFFF00F0FF00FFF000FFC200FFB300FFB300FFA300FFA300FFA300FFA300FFA300FFA3
00FFA300FFA300FFA300FFA300FFA300FFA300FFA300FFA300FFA300FFA300FFA300FFA3
00FFA300FFA300FFA300FFB300FFB300FFB300FFB300FFB300FFB300FFC200FFC200FFC2
00FFD100FFD100FFE100FFD100FFE100FFE100FFE100FFE100FFE100FFE100FFF000FFFF
00F0FF0094FF00A3FF0094FF0500FFBD00FFFF00007000FF0028FF0047FF00D1FF00FFFF
00FFF000FFE100FFE100FFD100FFD100FFD100FFD100FFC200FFC200FFC200FFC200FFB3
00FFB300FFB300FFB300FFB300FFB300FFA300FFA300FFA300FFA300FFA300FFA300FFA3
00FFA300FF9400FF9400FF9400FF9400FF9400FF9400FF9400FF8500FF8500FF8500FF85
00FF8500FF8500FF8500FF8500FF8500FF8500FF7500FF7500FF7500FF7500FF7500FF75
00FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF6600FF6600FF66
00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF66
00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF5700FF6600FF6600FF5700FF57
00FF5700FF6600FF5700FF5700FF6600FF6600FF5700FF6600FF6600FF6600FF6600FF66
00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7500FF6600FF6600FF7500FF75
00FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF75
00FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF8500FF8500FF8500FF8500FF85
00FF9400FF9400FFA300FFA300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC2
00FFC200FFC200FFD100FFD100FFE100FFF000FFFF00FFFF00E1FF00E1FF00D1FF00C2FF
00A3FFFF00990038FF0038FF0028FF0500FF3300FFAE00FFFF006BFA00FF4200FF0047FF
0075FF00B3FF00C2FF00C2FF00D1FF0047FF00FFFF00FFE100FFC200FFB300FFB300FFB3
00FFA300FFA300FFA300FF9400FF9400FF9400FF9400FF8500FF8500FF8500FF8500FF75
00FF7500FF7500FF6600FF6600FF6600FF5700FF5700FF5700FF5700FF4700FF4700FF47
00FF4700FF4700FF4700FF4700FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF2800FF2800FF2800FF2800FF3800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF1900FF1900FF1900FF2800FF28
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF2800FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A05FF0005FF0005FF0005FF0000FF0A05FF0005FF0005FF0005FF00
00FF0A05FF0005FF0005FF0000FF0A05FF0005FF0000FF0A05FF0005FF0000FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF5700FFA300FF19
00FF0A00FF0A05FF0005FF0005FF0005FF0005FF0005FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0023FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0042FF0042FF0042FF00
05FF0000FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF19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00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF19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00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF0A00FF0A00FF19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05FF0000FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF19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05FF0005FF0000FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF19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05FF0000FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A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00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A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05FF0000FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF19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05FF0005FF0000FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF0A00FF0A00FF0A00FF0A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05FF0005FF0000FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A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05FF0000FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A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00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF0A00FF0A00FF0A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05FF0000FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A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05FF0005FF0000FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A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05FF0005FF0000FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A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05FF0000FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF2800FF28
00FF2800FF2800FF2800FF2800FF3800FF2800FF3800FF3800FF3800FF3800FF3800FF47
00FF4700FF5700FF5700FF6600FF6600FF7500FF8500FF9400A3FF00FFA300FFA300FFB3
00FFB300FFB300FFB300FFC200FFC200FFE100B3FF00A3FF00B3FF5100FF0057FF000AFF
FF00B83300FF000AFF0085FF0085FF00E1FF00F0FF00A3FFFF008A00E1FF00E1FF00B3FF
00FFD100FFE10047FF00FFE100FFB300FFB30094FF00FF8500FF6600FF5700FF5700FF47
00FF4700FF4700FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF1900FF1900FF2800FF2800FF2800FF1900FF1900FF1900FF1900FF1900FF2800FF19
00FF1900FF1900FF1900FF1900FF1900FF2800FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF2800FF1900FF1900FF1900FF1900FF19
00FF1900FF2800FF1900FF1900FF1900FF1900FF1900FF1900FF2800FF1900FF1900FF19
00FF1900FF1900FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF4700FF4700FF4700FF47
00FF4700FF5700FF5700FF6600FF6600FF7500FF8500FF9400FFC200FFA300FFB300FFC2
00FFC200FFD100FFE100FFFF00C2FF0057FF5100FFFA00FF2300FF7000FF0038FF00B3FF
0094FF00D1FF00F0FF0075FF00E1FF00D1FF00E1FF00FFD100FFB300FFB300FFB300FFC2
00FFD10094FF3300FF00FFFF00FFC200FFC20057FF0019FF00C2FF00FFE100FFB300FFB3
00FFA300FFA300FF9400FF9400FF9400FF9400FF9400FF9400FF9400FF9400FF9400FF94
00FF9400FFA300FFA300FFA300FFA300FFA300FFA300FFB300FFB300FFC200FFC200FFD1
00FFE100FFF000FFF000F0FF00E1FF00A3FF0500FF0094FF00D1FF00F0FF00FFFF00FFF0
00FFE100FFD100FFD100FFD100FFC200FFC200FFC200FFB300FFB300FFB300FFA300FFA3
00FFA300FFA300FFA300FF9400FF9400FF9400FF9400FF9400FF9400FF9400FF9400FF94
00FF9400FF9400FF9400FF9400FF9400FF8500FF8500FF8500FF8500FF8500FF8500FF85
00FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF85
00FF9400FF8500FF8500FF8500FF9400FF8500FF8500FF9400FF9400FF9400FF9400FF94
00FF9400FF9400FF9400FF9400FF9400FFA300FFA300FFA300FFA300FFB300FFB300FFD1
00B3FF00FFFF00FFD100FFC200FFC200FFB300FFB300FFB300FFB300FFB300FFB300FFB3
00FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB3
00FFC200FFB300FFC200FFC200FFC200FFC200FFC200FFC200FFC200FFD100FFD100FFD1
00FFD100FFD100FFD100FFD100FFE100FFE100FFE100FFE100FFE100FFF000FFF000FFF0
00FFF000FFFF00FFFF00FFFF00F0FF00F0FF00E1FF00E1FF00D1FF00C2FF00B3FF0085FF
0038FF8F00FF0047FF0500FF5100FF5100FF4200FF4200FF0047FF0066FF0066FF0028FF
0047FF000AFF0075FF0094FF00D1FF00E1FF00F0FF00F0FF00FFFF00FFFF00FFFF00FFFF
00FFF000FFF000FFF000FFF000FFF000FFE100FFE100FFE100FFE100FFE100FFD100FFD1
00FFE100FFD100FFD100FFD100FFD100FFD100FFD100FFD100FFD100FFD100FFD100FFD1
00FFD100FFD100FFD100FFD100FFD100FFD100FFD100FFD100FFD100FFE100FFE100FFF0
00FFFF00A3FF0019FF0075FF00B3FF0057FF1400FF0057FF0085FF0057FF00A3FF00D1FF
0094FF0094FF00FFFF00FFE100FFE100FFD100FFD100FFD100FFD100FFD100FFD100FFD1
00FFE100FFE100FFF000FFF000FFFF00F0FF00E1FF00B3FF0094FF4200FF000AFF0094FF
00C2FF00D1FF00D1FF00E1FF00E1FF00FFFF00FFF000FFF000FFE100FFD100FFD100FFD1
00FFD100FFC200FFD100FFC200FFC200FFC200FFC200FFC200FFC200FFC200FFC200FFC2
00FFC200FFC200FFD100FFD100FFD100FFD100FFD100FFE100FFE100FFF000FFF000FFFF
00FFFF00F0FF00F0FF00E1FF00E1FF00D1FF00D1FF00C2FF00A3FF0075FF2300FF0038FF
8F00FF8F00FFCC00FFFF00006100FF0038FF0057FF7000FF0075FF0047FF0038FF00A3FF
00C2FF00E1FF00F0FF00FFFF00FFF000FFE100FFE100FFD100FFD100FFC200FFC200FFB3
00FFB300FFB300FFB300FFB300FFA300FFA300FFA300FFA300FFA300FFA300FFA300FFA3
00FFA300FFA300FF9400FF9400FF9400FF9400FF9400FF9400FF9400FF9400FF9400FF94
00FF8500FF8500FF8500FF8500FF9400FF8500FF8500FF8500FF8500FF8500FF8500FF85
00FF8500FF8500FF8500FF7500FF7500FF8500FF7500FF7500FF7500FF7500FF8500FF75
00FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF75
00FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF8500FF7500FF8500FF8500FF85
00FF8500FF9400FF9400FFA300FFD11400FF0019FF00FFB300FFA300FFA300FFA300FFA3
00FF9400FF9400FFA300FFA300FFA300FFA300FFB300FFB300FFC200FFE100FFF000E1FF
0066FF0500FF00F0FF00FFF000FFE100FFD100FFC200FFB300FFB300FFB300FFB300FFA3
00FFA300FFA300FFA300FFA300FFB300FFA300FFB300FFB300FFB300FFB300FFC200FFC2
00FFD100FFD100FFD100FFE100FFF000FFFF00F0FF00E1FF0066FF0038FF0057FFFF007A
FF006BCC00FF2300FF7000FF0057FF00B3FF00E1FF00F0FF00FFFF00FFF000FFE100FFE1
00FFD100FFD100FFC200FFC200FFC200FFB300FFB300FFB300FFB300FFB300FFB300FFB3
00FFB300FFB300FFB300FFB300FFC200FFD100FFF000E1FF00A3FF0047FF00C2FF00FFFF
00FFE100FFC200FFB300FFA300FF9400FF9400FF8500FF8500FF7500FF7500FF6600FF66
00FF6600FF5700FF5700FF5700FF5700FF4700FF4700FF4700FF4700FF4700FF4700FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF2800FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0014FF0014FF00
14FF0014FF0014FF0014FF0005FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0005FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
42FF0042FF0042FF0042FF00
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A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00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A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00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A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00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A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00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A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00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A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00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A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00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF19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00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A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00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A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00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A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00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF1900FF19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00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF19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00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF19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00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF0A00FF0A00FF0A00FF1900FF19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00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF1900FF1900FF1900FF19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00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF1900FF1900FF19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00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF4700FF4700FF4700FF4700FF5700FF5700FF5700FF5700FF66
00FF6600FF6600FF6600FF7500FF7500FF8500FF9400FFA300FFB300FFC200FFC200FFE1
00FFFF00D1FF000AFF00C2FF00B3FF00FFF000FFF00085FF00A3FF00D1FF00FFA300FF94
00FF8500FF7500FF7500FF6600FF6600FF6600FF5700FF5700FF5700FF5700FF5700FF57
00FF5700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF47
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF2800FF3800FF3800FF38
00FF2800FF2800FF3800FF2800FF2800FF2800FF3800FF3800FF2800FF2800FF2800FF38
00FF3800FF3800FF2800FF2800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF4700FF4700FF4700FF4700FF4700FF4700FF47
00FF4700FF4700FF4700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF6600FF66
00FF6600FF6600FF6600FF6600FF7500FF7500FF7500FF7500FF7500FF7500FF8500FF85
00FF9400FFD10094FF00A3FF00FFF0EB00FF00FFF000FFD100FFD100FFE100F0FF0057FF
00B3FF00FFF000FFE100FFD100FFD100FFD100FFD100FFD100FFD100FFE100FFE100FFF0
00FFFF00F0FF00D1FF00B3FFAE00FF0094FF0075FF00D1FF00C2FF0085FF0047FF00D1FF
00C2FF00B3FF0019FF0019FF0075FF0047FF0094FF0094FFFF006B0085FF0094FF4200FF
00A3FF0075FF0066FF00B3FF00D1FF00E1FF00F0FF00FFFF00FFF000FFF000FFE100FFE1
00FFE100FFD100FFD100FFD100FFD100FFC200FFC200FFC200FFC200FFC200FFC200FFB3
00FFC200FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA300FFA300FFB300FFA3
00FFA300FFA300FFA300FFA300FFA300FFA300FFA300FFA300FFA300FFA300FFA300FFA3
00FFA300FFA300FFA300FFA300FFA300FFA300FFB300FFB300FFB300FFB300FFB300FFC2
00FFD10047FF00E1FF00FFE100FFD100FFC200FFC200FFC200FFC200FFC200FFC200FFC2
00FFC200FFC200FFC200FFC200FFC200FFD100FFD100FFD100FFE100FFF000FFFF00FFFF
00F0FF00E1FF0094FFAE00FF7000FFFF00D70047FF0028FF4200FF00E1FF00F0FF00F0FF
00FFFF00FFFF00FFF000FFF000FFF000FFE100FFE100FFE100FFE100FFE100FFE100FFE1
00FFE100FFE100FFE100FFE100FFE100FFE100FFE100FFE100FFE100FFE100FFE100FFE1
00FFE100FFE100FFE100FFF000FFF000FFF000FFF000FFFF00FFFF00FFFF00F0FF00E1FF
00D1FF00D1FF00C2FF00B3FF00A3FF0085FF0047FFFF00A80019FF0066FF0075FF0075FF
0075FF0057FF0028FF1400FFCC00FF5100FFFF00F58F00FFFF0000CC00FFFF0000FF00F5
7000FF1400FF000AFFFF00B8000AFF8F00FFFF0000000AFF6100FFDC00FF0500FF0500FF
0028FF000AFF5100FF2300FFFF00D70019FF0500FF0038FF0047FF00C2FF00D1FF00E1FF
00F0FF00F0FF00F0FF00FFFF00FFFF00FFFF00FFF000FFFF00FFF000FFF000FFF000FFF0
00FFF000FFF000FFF000FFF000FFF000FFF000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00F0FF00F0FF00F0FF00E1FF00E1FF00D1FF00D1FF00C2FF0094FF0019FF000AFF
FF00007000FFFF00000028FF0075FF0094FF00A3FF00A3FF00B3FF00B3FF00A3FF0094FF
DC00FF0057FF0019FF3300FF4200FF0075FF0066FF5100FF0057FF00C2FF00D1FF00E1FF
00E1FF00E1FF00F0FF00F0FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF000FFF0
00FFF000FFFF00FFF000FFF000FFF000FFF000FFF000FFF000FFF000FFF000FFF000FFFF
00FFFF00F0FF00D1FF00D1FF00D1FF00D1FF00C2FF00C2FF00B3FF00A3FF0075FF0500FF
0038FF0075FF0085FF0085FF0075FFFF00E60057FF0047FFCC00FF1400FF000AFF0075FF
0085FF0094FF00B3FF00B3FF00C2FF00C2FF00C2FF00B3FF00C2FF00C2FF00F0FF00FFFF
00FFF000FFF000FFF000FFE100FFE100FFE100FFE100FFE100FFD100FFD100FFD100FFD1
00FFD100FFD100FFD100FFC200FFC200FFC200FFC200FFD100FFC200FFC200FFC200FFD1
00FFD100FFD100FFD100FFE100FFF000E1FF0075FF00B3FF7000FF00C2FF00FFE100FFC2
00FFC200FFB300FFB300FFB300FFB300FFA300FFA300FFA300FFA300FFA300FFA300FFA3
00FFA300FFA300FFA300FFA300FFA300FFA300FFA300FFA300FFA300FFA300FFA300FFA3
00FFA300FF9400FFA300FF9400FF9400FF9400FF9400FF9400FF9400FF9400FF9400FF94
00FF9400FF9400FF9400FF9400FF9400FF9400FF9400FFA300FFA300FFA300FFA300FFA3
00FFA300FFA300FFA300FFB300FFB300FFB300FFB300FFB300FFC200FFC200FFC200FFD1
00FFD100FFD100FFE100FFE100FFE100FFF000FFF000FFF000FFFF00F0FF00E1FF00C2FF
00B3FF0094FF0057FF8F00FF4200FF0047FF0094FF0094FF0075FF0057FFFF00000075FF
0094FF00A3FF0094FF0066FF0066FF0057FFFF002E0038FF0047FFFF00000500FF00D1FF
00D1FF00E1FF00C2FF0028FF0066FF00D1FF00FFF000FFE100FFD100FFC200FFB300FFB3
00FFB300FFB300FFA300FFA300FFA300FFA300FF9400FF9400FF9400FF9400FF8500FF85
00FF8500FF8500FF8500FF8500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF75
00FF7500FF7500FF7500FF6600FF7500FF6600FF7500FF6600FF7500FF7500FF7500FF75
00FF7500FF7500FF7500FF7500FF7500FF7500FF6600FF7500FF7500FF7500FF8500FFA3
00FFC2000AFF00FF9400FF6600FF5700FF4700FF4700FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF0A00FF0A00FF0A00FF0A00FF1900FF1900FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A05FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0014FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
23FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0042FF00
42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
42FF0042FF0042FF0042FF00
00FF0A00FF0A00FF0A00FF0A00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19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00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF1900FF1900FF1900FF1900FF1900FF19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00FF0A00FF1900FF0A00FF0A00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19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00FF0A00FF0A00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19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00FF0A00FF0A00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19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00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19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00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19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00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF2800FF28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00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF2800FF1900FF2800FF28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00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF2800FF2800FF2800FF28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00FF1900FF1900FF1900FF1900FF1900FF1900FF2800FF2800FF2800FF2800FF2800FF28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00FF1900FF1900FF1900FF2800FF1900FF2800FF2800FF2800FF2800FF2800FF2800FF28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00FF1900FF2800FF1900FF2800FF2800FF2800FF2800FF2800FF3800FF3800FF3800FF38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00FF1900FF1900FF2800FF2800FF2800FF2800FF2800FF2800FF3800FF3800FF4700FF47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00FF2800FF2800FF2800FF2800FF2800FF2800FF3800FF3800FF3800FF4700FF7500FF57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00FF2800FF2800FF2800FF2800FF2800FF3800FF3800FF4700FF4700FF6600FFA300FF57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00FF2800FF2800FF2800FF2800FF3800FF3800FF4700FF5700FF6600FFD10047FF00FF66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00FF2800FF2800FF2800FF3800FF3800FF3800FF4700A3FF00FFC200FFC200FFA300FF66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00FF2800FF2800FF3800FF3800FF3800FF4700FF5700FF6600FFA30057FF00FF9400FF75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00FF2800FF3800FF3800FF3800FF3800FF4700FF5700FF6600FF8500F0FF0019FF00FF85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00FF3800FF3800FF3800FF3800FF4700FF4700FF5700FF7500FF8500FFD10094FF00FFB3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00FF3800FF3800FF3800FF4700FF4700FF5700FF6600FFD100FFE100FFE1FF000000FFFF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00FF4700FF4700FF4700FF4700FF4700FF5700FF6600FF8500FFF00066FF0028FF00F0FF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00FF4700FF4700FF5700FF5700FF5700FF5700FF6600FF9400FFB300FFE1FF000000FFE1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00FF5700FF5700FF5700FF5700FF6600FF6600FF6600FF8500FF9400FFD1000AFF0019FF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00FF7500FF6600FF6600FF6600FF6600FF6600FF7500FF8500FFC200FFE1FF00E600FFE1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00FF9400FF9400FF9400FF8500FF7500FF7500FF8500FF9400FFC200B3FFFF00A800C2FF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00D1FF00A3FF00FFFF00FF9400FF8500FF8500FF8500FF9400FFC200FFFF0085FF00FFFF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00C2FF0066FF00FFD100FFB300FFA300FF9400FFA300FFA300FFD100F0FF00D1FF00FFD1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00D1FF00E1FF00A3FF00FFF00085FF00FFC200FFB300FFB300C2FF7000FF00C2FF00FFD1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00FFC200FFC200FFF00057FF00D1FF00FFE100FFE100FFD100C2FF0075FF00F0FF00FFD1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00FF9400FFA38F00FF00B3FF00C2FF9E00FF00D1FF00FFFF00A3FF0085FF00FFD100FFC2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00FF8500FF9400FFA300FFC200FFD100E1FF00C2FF0094FF00D1FF00FFF000FFD100FFC2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00FF8500FF8500FFA300FFA300FFB300FFC200FFE100FFFF0038FF00FFFF00FFD100FFC2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00FF8500FF8500FF9400FFA300FFA300FFC200FFD100C2FF0066FF0057FF00E1FF00FFD1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00FF8500FF8500FF9400FFA300FFB300FFC200FFD12300FF0094FF00B3FF00FFFF00FFE1
00FFE100F0FF00FFC200FFD100FFC200FFB300FFB300FFB300FFC200FFE100D1FF0047FF
00D1FF00FFF000FFE100FFF000B3FF00FFFF00C2FFFF006B7000FF6100FF0085FF00A3FF
00E1FF00A3FF1400FF0075FF0028FF00A3FF00D1FF00E1FF00FFD100FFC200FFB300FFA3
00FFA300FF9400FF9400FF8500FF8500FF8500FF8500FF7500FF7500FF7500FF7500FF75
00FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF85
00FF8500FF8500FF9400FF9400FFA300FFA300FFB300FFC200FFC200FFD100FFF000F0FF
00C2FF0075FF1400FFFF00E6BD00FF0057FF0066FF4200FF0057FF0057FFFF007A00B3FF
00E1FF00FFFF00FFE100FFE100FFD100FFF000FFF00075FF00B3FF00FFFF0047FF00A3FF
00FFFF00FFE100FFC200FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC200FFC2
00FFC200FFD100FFD100FFE100FFF000FFFF00C2FF0019FF00C2FF00F0FF00FFFF00FFF0
00FFE100FFE100FFF000FFD100FFC200FFC200FFB300FFB300FFB300FFA300FFA300FF94
00FF9400FF8500FF8500FF8500FF8500FF7500FF7500FF7500FF7500FF7500FF7500FF66
00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF57
00FF6600FF6600FF5700FF5700FF6600FF5700FF5700FF6600FF5700FF5700FF6600FF57
00FF5700FF6600FF5700FF5700FF6600FF5700FF5700FF6600FF6600FF6600FF6600FF66
00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF66
00FF6600FF6600FF6600FF6600FF7500FF6600FF6600FF6600FF6600FF6600FF6600FF75
00FF6600FF6600FF6600FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF75
00FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF8500FF8500FF8500FF8500FF85
00FF8500FF8500FF8500FF8500FF8500FF9400FF9400FF9400FF9400FF9400FF9400FF94
00FF9400FF9400FFA300FFA300FFA300FFA300FFA300FFA300FFA300FFA300FFA300FFA3
00FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC200FFC200FFC200FFC200FFC2
00FFD100FFD100FFD100FFD100FFE100FFE100FFE100FFF000FFF000FFF000FFFF00FFFF
00FFFF00F0FF00F0FF00E1FF00D1FF00D1FF00C2FF0085FF0019FF8F00FF8000FFEB00FF
1400FF0047FF0066FF0085FF0094FF0094FF0094FF0085FF0075FF000AFF0038FF0085FF
0085FF0066FF2300FF9E00FF1400FF0075FFBD00FF0038FF00D1FF00E1FF00F0FF00F0FF
00F0FF00F0FF00F0FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F0FF00FFFF00F0FF
00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00E1FF00E1FF00E1FF00E1FF00E1FF00E1FF
00D1FF00D1FF00D1FF00C2FF00C2FF00C2FF00B3FF0094FF0057FF0500FFFF00B80028FF
0028FF4200FFAE00FFFF00B8FF00E68000FF4200FF9E00FF8000FF8000FFFF00000057FF
0085FF00A3FF00B3FF00B3FF00B3FF00C2FF00C2FF00C2FF00C2FF00C2FF00B3FF00B3FF
00A3FF0094FF0066FF8000FF0075FF0085FF0094FF00A3FF00A3FF00A3FF00A3FF00A3FF
0094FF0094FF0075FF0057FF7000FFFF00A82300FF0057FF0066FF0075FF0085FF0094FF
0094FF0094FF00A3FF00A3FF00A3FF00A3FF00A3FF0094FF0094FF0094FF0094FF0085FF
0085FF0075FF0057FF0038FFEB00FF6100FF0500FF0019FF0028FF0019FF000AFF1400FF
4200FFFF00A86100FF3300FF1400FF0500FF000AFF1400FFFF00F50500FF0038FF0038FF
0038FF0019FF0028FF8000FF0019FF0066FF0075FF0085FF0085FF0085FF0085FF0085FF
0085FF0085FF0085FF0075FF0075FF0066FF0066FF0057FF0047FF0038FF2300FF8000FF
3300FF8F00FFFF00001400FF0500FF8000FF4200FFFA00FF0028FF0038FF0047FF0057FF
0057FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0057FF
0057FF0057FF0047FF0047FF0038FF0028FF000AFF3300FFFF006BFF00A8FF0000FF001E
BD00FFFF0000FF00E68F00FF0019FF0038FF0038FF0038FF0038FF0038FF0038FF0038FF
0038FF0038FF1400FF0500FF0028FF0028FF0028FF0028FF0019FF0500FF3300FF7000FF
9E00FF3300FF2300FF000AFF0028FF0038FF0038FF0038FF0038FF0038FF0047FF0047FF
0028FF2300FF0028FF0047FF0047FF0047FF0038FF0028FF0019FF5100FFFF00E64200FF
7000FFFF00B89E00FF2300FF0500FF0019FF0028FF0038FF0038FF0047FF0057FF0057FF
0066FF0075FF0075FF0075FF0075FF0085FF0075FF0075FF0075FF0066FF0066FF0047FF
0028FF4200FF0500FF0038FF0057FF0057FF0047FF0019FF5100FF2300FF000AFF1400FF
0075FF0085FF0094FF0094FF00A3FF00A3FF0094FF00A3FF0094FF0094FF0085FF0075FF
0075FF0057FF0028FF0500FFFF00A8FF00D7000AFF9E00FF0047FF0075FF0094FF00B3FF
00C2FF00C2FF00D1FF00D1FF00D1FF00E1FF00E1FF00E1FF00E1FF00F0FF00F0FF00F0FF
00F0FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF000FFF000FFF000FFF0
00FFF000FFF000FFF000FFF000FFF000FFF000FFF000FFF000FFF000FFFF00FFFF00FFFF
00F0FF00D1FF000AFF00E1FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00E1FF
00E1FF00D1FF00B3FFFF00000075FF0094FF0094FF0094FF000AFF0057FF0038FFAE00FF
8000FF1400FFCC00FFAE00FFEB00FF2300FFFF006B0028FF0057FF0094FF00A3FF00B3FF
00B3FF00B3FF00C2FF00D1FF00C2FF00E1FF00FFFF00FFF000FFF000FFE100FFD100FFD1
00FFD100FFD100FFC200FFC200FFC200FFC200FFC200FFC200FFC200FFC200FFC200FFC2
00FFC200FFC200FFD100FFD100FFD100FFD100FFE100FFE100FFE100FFF000FFFF00E1FF
0075FF1400FF0066FF00B3FF0057FFCC00FF3300FF00D1FF00FFFF0066FF00FFC200FF94
00FF8500FF8500FF7500FF7500FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF57
00FF5700FF5700FF5700FF5700FF5700FF5700FF4700FF4700FF4700FF4700FF4700FF47
00FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF1900FF1900FF2800FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A05FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0042FF0042FF0042FF0042FF00
42FF0042FF0042FF0042FF00
00FF8500FF9400FF9400FFA300FFB300FFD100FFE100FFFF00B3FF0047FF00B3FF00FFFF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00FF9400FF9400FFA300FFA300FFC200A3FF00FFFF00F0FF00A3FF1400FF00B3FF00D1FF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00FF9400FFA300FFA300FFB300FFD100FFFF0085FF00D1FF0085FF4200FF0047FF0075FF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00FFB300FFB300FFB300FFC20028FF0066FF0066FF0075FF6100FFBD00FFFF000FAE00FF
0057FF00B3FF00D1FF00F0FF00FFFF00FFFF00FFFF00C2FF0019FF0094FF0019FF0019FF
0057FFFF007A3300FF0085FF00FFFF00FFF000FFD100FFD100F0FF00FFC200FFB300FFB3
00FFB300FFC200FFC200FFE100F0FF0038FF00FFFF00D1FFFF008A00F0FF00FFFF00FFB3
00FF9400FF8500FF7500FF7500FF7500FF6600FF6600FF6600FF6600FF6600FF6600FF66
00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7500FF75
00FF7500FF8500FF8500FF9400FFD100FFFF00FFF000D1FF9E00FF00C2FF00A3FF00E1FF
0066FF00F0FF00FFF000FFE100FFD100FFD100FFE19E00FF0047FF0094FF00E1FF00F0FF
00E1FF00B3FF8F00FFFF00E60047FF0047FF6100FF3300FF0075FF0075FF00F0FF00FFFF
00FFF000FFE100FFE100FFE100FFD100FFE100FFF07000FF00E1FF00F0FF0500FF0057FF
00F0FF00F0FF00F0FF00D1FF00C2FF2300FF0085FF00A3FFCC00FF00FFFF00FFE100FFD1
00FFD100FFC200FFC200FFB300FFB300FFB300FFA300FFA300FFA300FFA300FFA300FF94
00FF9400FF8500FF8500FF8500FF8500FF8500FF7500FF7500FF7500FF7500FF7500FF75
00FF7500FF7500FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF66
00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF66
00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF75
00FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF75
00FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF75
00FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF75
00FF7500FF7500FF7500FF7500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF85
00FF8500FF8500FF8500FF8500FF9400FF9400FF9400FF9400FF9400FF9400FFA300FFA3
00FFA300FFA300FFA300FFA300FFA300FFA300FFA300FFB300FFB300FFB300FFB300FFB3
00FFB300FFB300FFB300FFB300FFC200FFC200FFC200FFC200FFC200FFC200FFC200FFD1
00FFD100FFD100FFD100FFD100FFE100FFE100FFE100FFE100FFF000FFFF00FFFF00F0FF
00E1FF00E1FF00D1FF00D1FF00C2FF00C2FF00B3FF00B3FF00A3FF0094FF0066FF0047FF
0028FF2300FFFF00008000FFFA00FFFF00C73300FFFF00000019FF7000FF0075FF0085FF
0085FF0094FF00A3FF00A3FF00B3FF00C2FF00C2FF00D1FF00D1FF00E1FF00E1FF00E1FF
00F0FF00E1FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF
00E1FF00E1FF00E1FF00E1FF00D1FF00D1FF00D1FF00D1FF00D1FF00D1FF00D1FF00D1FF
00C2FF00C2FF00C2FF00C2FF00C2FF00B3FF00B3FF0094FF5100FF0038FF0047FF0057FF
0047FF0038FF0019FFEB00FF9E00FF000AFF0028FF0047FF0066FF0075FF0085FF0085FF
0094FF0094FF00A3FF00A3FF00A3FF00A3FF00A3FF00A3FF00A3FF00A3FF00A3FF0094FF
0085FFFF00000019FF0028FF3300FF5100FF0038FF0066FF0075FF0075FF0085FF0085FF
0075FF0066FF0047FF0028FF1400FFFF00F52300FF0500FF1400FF0019FF0038FF0075FF
0085FF0085FF0085FF0085FF0094FF0094FF0085FF0085FF0085FF0085FF0085FF0075FF
0075FF0038FF0047FF0028FF0019FF1400FF3300FFFF006B8000FFFF00C7FF00E6FF00C7
FF0000FF0000FF0000FF0000FF00007000FF3300FF1400FF0500FF0500FF0500FF3300FF
0028FF0028FF0038FF0057FF0057FF0066FF0066FF0075FF0075FF0075FF0075FF0075FF
0075FF0075FF0075FF0075FF0066FF0066FF0066FF0057FF0057FF0057FF0047FF0038FF
0038FF0028FF0019FF1400FF9E00FF7000FF1400FF000AFF0019FF0028FF0038FF0047FF
0047FF0047FF0047FF0047FF0047FF0047FF0047FF0047FF0047FF0028FF1400FF2300FF
000AFF0019FF0028FF0028FF0028FF0019FF000AFF0500FF1400FF3300FF7000FFEB00FF
6100FF3300FF2300FF0500FF000AFF000AFF000AFF000AFF000AFF1400FF8000FFCC00FF
3300FF3300FFBD00FF6100FF2300FF1400FF0500FF0500FF2300FFFF00009E00FFFF007A
FF0000AE00FFCC00FF4200FF1400FF0500FF0500FF2300FF8F00FF6100FF2300FF4200FF
FF00B88000FF0500FF000AFF000AFF0019FF0019FF000AFF0500FF1400FF4200FF9E00FF
FF00D76100FF4200FF3300FF7000FF3300FF0019FF0038FF0038FF0047FF0047FF0057FF
0057FF0057FF0057FF0066FF0066FF0066FF0066FF0066FF0057FF0057FF0057FF0047FF
0038FF0028FF0019FF1400FF7000FF1400FF000AFF0028FF0047FF0047FF0066FF0066FF
0075FF0075FF0075FF0085FF0085FF0085FF0075FF0066FF0057FF0038FFFF00000019FF
0028FFFA00FFEB00FF000AFF0038FF0057FF0075FF0085FF0094FF0094FF00A3FF00B3FF
00B3FF00C2FF00C2FF00C2FF00D1FF00D1FF00D1FF00D1FF00E1FF00E1FF00E1FF00F0FF
00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00F0FF00F0FF00E1FF2300FF00D1FF00E1FF00E1FF00E1FF00D1FF
00C2FF0085FF2300FF0075FF00A3FF00C2FF00D1FF00D1FF00D1FF00D1FF00D1FF00D1FF
00C2FF00A3FF0085FF0075FF0047FF4200FFFF001EFF00C7000AFF0047FFBD00FF0085FF
0094FF0094FF0057FF00A3FF00A3FF00B3FF00B3FF00A3FF0094FF2300FF0075FF00A3FF
00B3FF00C2FF00D1FF00D1FF00C2FF00F0FF00F0FF00C2FF00FFF000FFD100FFD100FFC2
00FFC200FFC200FFC200FFC200FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB3
00FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC200FFC200FFD100C2FFBD00FF
00FFE100FFD100FFD100FFC200FFB300FFA300FFA300FFA300FFB300FFD100FFD100FFE1
00FFC200FF8500FF7500FF7500FF6600FF6600FF6600FF6600FF6600FF5700FF5700FF57
00FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF4700FF4700FF4700FF4700FF47
00FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF47
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
42FF0042FF0042FF0042FF00
00FFC200FFC200FFC200FFD100FFE100F0FF00C2FF0028FF8F00FFFF00F59E00FF5100FF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00FFE100FFD100FFD100FFE100FFF000F0FF00C2FF0047FF0019FF0038FF5100FF0019FF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00FFF000FFE100FFFF0500FF00F0FF0038FF0075FFFA00FF0075FF0057FF7000FF4200FF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00F0FF00F0FF00B3FF0085FFFF008A0500FFBD00FF0085FF00B3FF0500FF0075FF4200FF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0047FF00C2FF0085FFBD00FF0047FF0094FF0075FFFF00E600D1FF00C2FF0047FF0066FF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4200FFFF00E69E00FF00A3FF0075FF00F0FF00FFFF00F0FF00F0FF00E1FF00C2FF0085FF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FF00990057FF00E1FF00E1FF00F0FF00FFF000FFE100FFF000F0FF00D1FF00A3FF1400FF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000AFF00C2FF00FFFF00FFF000FFE100FFD100FFD100FFE100E1FF6100FF00B3FF0085FF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00A3FF00D1FF00FFF000FFD100FFC200FFC200FFC200FFE10047FF00FFFF00F0FF0038FF
00F0FF00D1FF0075FF8F00FF00E1FF00FFF000FFFF00F0FF00FFB300FFA300FF9400FF94
00FF9400FF8500FF8500FF8500FF7500FF7500FF7500FF6600FF6600FF6600FF6600FF66
00FF6600FF6600FF7500FF8500FFC200FF7500FF6600FF6600FF6600FF5700FF5700FF57
00FF5700FF5700FF5700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF47
00FF4700FF4700FF4700FF4700FF4700FF5700FF5700FF5700FF5700FF5700FF5700FF57
00FF6600FF5700FF5700FF6600FF6600FF6600FF6600FF6600FF6600FF7500FF7500FF75
00FF7500FF7500FF7500FF8500FF8500FF8500FF8500FF8500FF9400FF9400FFA300FFC2
00FFC200FFC200FFC200FFE100D1FF0094FF00FFF000FFE100FFE100FFE100FFF000FFF0
00FFFF00F0FF00F0FF00D1FF0094FF0094FF0094FF0085FF0066FF0047FF0028FF8000FF
3300FF8F00FFFA00FFCC00FF5100FFEB00FF2300FF0028FF0500FF0066FF0094FF8F00FF
00B3FF00A3FF0057FF00E1FF00FFD100FFC200FFB300FFB300FFB300FFB300FFA300FFA3
00FFA300FFA300FFA300FF9400FF9400FF9400FF9400FF9400FF8500FF8500FF8500FF85
00FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF7500FF8500FF7500FF8500FF85
00FF8500FF8500FF8500FF8500FF8500FF9400FF9400FFB300B3FF00FFA300FF9400FF85
00FF9400FF8500FF8500FF8500FF8500FF8500FF8500FF9400FF9400FF9400FFA300FFB3
00FFC200FFD10047FF5100FF00E1FF00FFC200FFB300FFA300FFA300FF9400FF9400FF94
00FF9400FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF85
00FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF85
00FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF9400FF9400FF9400FF94
00FF9400FF9400FF9400FF9400FFA300FFA300FFB300FFC200FFE10019FF00E1FF0019FF
00F0FF00FFFF00FFF000FFF000FFF000FFFF00FFF000FFE100FFF000E1FF0038FF00FFE1
00FFE100FFD100FFE100FFD100FFD100FFD100FFD100FFD100FFD100FFD100FFD100FFE1
00FFD100FFE100FFE100FFE100FFE100FFE100FFF000FFF000FFF000FFFF00FFFF00F0FF
00E1FF00D1FF00A3FF0066FF0057FFFF00000028FF0075FF0085FF0094FF0085FF0057FF
0066FF0047FF0028FF0047FF0038FF000AFF8000FF5100FFBD00FF9E00FF0047FF0066FF
0066FF2300FF1400FF0085FF0094FF00A3FF00A3FF00B3FF00B3FF00C2FF00C2FF00C2FF
00C2FF00C2FF00C2FF00C2FF00C2FF00C2FF00A3FF2300FF4200FF0094FF00A3FF00B3FF
00B3FF00A3FF00A3FF0094FF0085FF0066FF0028FF3300FF0038FF0057FF0075FF0085FF
0094FF0094FF0094FF0094FF0094FF0094FF0094FF0085FF0085FF0075FF0057FF0047FF
0019FFFF00E63300FF5100FFFF008AFF0000FF0000FF000FFF006B3300FF1400FF1400FF
4200FF0019FF0019FF0057FF0066FF0066FF0075FF0075FF0075FF0075FF0075FF0075FF
0075FF0075FF0066FF0066FF0057FF0057FF0047FF0038FF0038FF0019FF000AFF1400FF
6100FF3300FF0500FF0019FF0028FF0038FF0047FF0047FF0057FF0057FF0057FF0066FF
0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0057FF0057FF
0057FF0057FF0057FF0047FF0047FF0038FF0038FF0028FF0019FF2300FF8000FFFF00C7
8000FF9E00FFFF008AFF0000FF0000FF00B8FF00F59E00FF9E00FF7000FF3300FF0500FF
0028FF0038FF0038FF0038FF0038FF0038FF0038FF0038FF0038FF0019FF0028FF0038FF
0038FF0038FF0028FF2300FFBD00FFFF00008F00FF0500FF000AFF0019FF0019FF0019FF
0019FF000AFF0500FFFA00FF7000FF6100FF9E00FFFF004CFF008ACC00FFFF00C7FA00FF
4200FF2300FF1400FF1400FF1400FF2300FF3300FF4200FF5100FF8F00FFFF0099FF0099
8000FF5100FF5100FF8000FF6100FF7000FFFF004C8000FF7000FF7000FF9E00FFBD00FF
FF0099DC00FFFF00008F00FF8000FF8000FF9E00FFEB00FFFF007AFF007ACC00FFBD00FF
CC00FFFF008AFF00F5FF005CFF008AFF004CFF0000FF0000FF0000FF0000FF0000FF000F
FF005CFF0000FF003DFF0000FF0000FF0000FF0000FF0000FF004CFF004CFF0099FF00E6
FF003DDC00FFAE00FF8F00FF8F00FF8000FF8F00FFBD00FFFF0000FF008AFF00998F00FF
6100FF4200FF3300FF3300FF2300FF1400FF1400FF1400FF1400FF1400FF2300FF4200FF
CC00FFBD00FF6100FF7000FFFF00C77000FF3300FF1400FF0500FF0500FF1400FF2300FF
8F00FFCC00FFCC00FFFF0000FA00FFAE00FF8F00FF2300FF1400FF0500FF1400FF5100FF
EB00FF5100FFBD00FF3300FF0500FF000AFF000AFF0500FF2300FF4200FFFF00007000FF
3300FF8F00FF000AFF0038FF0047FF0057FF0057FF0066FF0075FF0075FF0075FF0075FF
0075FF0075FF0057FFBD00FFFA00FF0028FF0075FF0085FF0094FF00A3FF00A3FF0085FF
0038FF0066FFDC00FF0085FF00B3FF00C2FF00D1FF00D1FF00D1FF00D1FF00D1FF00D1FF
00D1FF00D1FF00D1FF00D1FF00C2FF00C2FF00C2FF00B3FF00A3FF00A3FF0094FF0085FF
0075FF0057FF0019FFDC00FF1400FF0500FFFF00E6000AFF0500FF0500FFDC00FF4200FF
0038FF0047FF4200FF0085FF00A3FF00C2FF00C2FF00D1FF00D1FF00D1FF00E1FF00F0FF
00F0FF00F0FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F0FF0047FF00D1FF
00B3FF00E1FF00D1FF00A3FF00D1FF00FFF000FFD100FFD100FFC200FFC200FFB300FFB3
00FFB300FFB300FFB300FFB300FFA300FFA300FFA300FFA300FFA300FFA300FFA300FFA3
00FFA300FF9400FF9400FF9400FF9400FF9400FF9400FF9400FF9400FF9400FF9400FF94
00FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF7500FF7500FF7500FF7500FF75
00FF7500FF7500FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF5700FF57
00FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF57
00FF5700FF5700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF47
00FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF1900FF2800FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF00
0019FF00C2FF00E1FF00FFD100FFB300FFB300FFB300FFC200FFE100FFD100FFF00085FF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00FFF000FFE10038FF00FFD100FFA300FFA300FFA300FFA300FFB300FFB300FFC200FFD1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00FFC200FFB300FFC200FFB300FF9400FF9400FF9400FFA300FFA300FFA300FFB300FFC2
00FFC200FFE10066FF3300FF00E1FF00FFE100FFC200FFB300FFA300FF9400FF9400FF85
00FF8500FF7500FF7500FF7500FF6600FF6600FF6600FF6600FF5700FF5700FF5700FF57
00FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF4700FF4700FF4700FF4700FF47
00FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF47
00FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF57
00FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF6600FF6600FF6600FF66
00FF6600FF6600FF6600FF7500FF7500FF7500FF7500FF7500FF8500FF8500FF8500FF85
00FF9400FF9400FFA300FFB300FFB300FFC200FFC200FFC200FFC200FFC200FFD100FFD1
00FFE100FFF000FFFF00F0FF00E1FF00C2FF00B3FF0094FF0066FF0019FF8F00FFFF008A
FF0000FF0000CC00FF000AFF0500FFAE00FF0057FF00B3FF00C2FF00D1FF00D1FF00E1FF
00F0FF00FFFF00FFF000FFE100FFD100FFD100FFC200FFC200FFC200FFC200FFC200FFC2
00FFD100E1FF00D1FF00FFC200FFB300FFA300FFA300FFA300FFA300FFA300FF9400FF94
00FF9400FF9400FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF85
00FF8500FF9400FF9400FF9400FFA300FFC200FFF06100FF00FFD100FFB300FFA300FFA3
00FFA300FF9400FF9400FF9400FF9400FFA300FF9400FFA300FFA300FFC200FFE100D1FF
00C2FF00D1FF0085FF00A3FF00F0FF00FFFF0085FF00FFE100FFB300FFA300FFA300FF94
00FF9400FF9400FF9400FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF85
00FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF85
00FF8500FF8500FF8500FF9400FF8500FF8500FF9400FF9400FF9400FF9400FF9400FF94
00FF9400FF9400FFA300FFA300FFA300FFA300FFB300FFC200FFC200FFD100FFE100FFF0
0085FF00A3FF000AFF0085FF00B3FF0094FF0057FF2300FF0085FF00C2FF00FFFF00FFF0
00FFF000FFE100FFE100FFE100FFE100FFE100FFE100FFE100FFE100FFE100FFE100FFE1
00FFE100FFE100FFE100FFE100FFE100FFF000FFF000FFF000FFF000FFFF00FFFF00F0FF
00A3FF00B3FF00B3FF0500FF0085FF00B3FF00B3FF00B3FF00B3FF00B3FF00A3FF00A3FF
0094FF0094FF0085FF0075FF0066FF0047FF0019FF1400FFAE00FF5100FFAE00FF1400FF
FA00FF8F00FF4200FF2300FF6100FFFF006B0066FF0085FF00A3FF00B3FF00B3FF00B3FF
00B3FF00B3FF00B3FF00B3FF00B3FF00A3FF0094FFFF00B80019FFFF00000019FF0057FF
0075FF0085FF0085FF0075FF0075FF0047FF0019FFFF007A000AFF0038FF0057FF0066FF
0075FF0075FF0085FF0085FF0085FF0085FF0085FF0075FF0066FF0057FF0038FF0019FF
0028FF0019FF000AFF0500FFFF00007000FFFF00005100FF2300FF0500FF0019FF0028FF
0038FF0038FF0047FF0057FF0057FF0057FF0066FF0066FF0066FF0066FF0066FF0066FF
0066FF0057FF0057FF0057FF0057FF0047FF0047FF0038FF0028FF0019FF000AFF1400FF
6100FF6100FF1400FF000AFF0019FF0028FF0038FF0038FF0047FF0047FF0047FF0057FF
0057FF0057FF0057FF0057FF0057FF0057FF0057FF0047FF0047FF0038FF0500FF0038FF
0038FF0038FF0038FF0038FF0038FF0038FF0028FF0028FF000AFFFF00008000FF4200FF
3300FF5100FF7000FFDC00FFFF00F57000FF4200FF3300FF2300FF0500FF0500FF000AFF
0019FF0019FF0028FF0028FF0028FF0028FF0019FF000AFF6100FF8F00FFAE00FFFF00C7
0500FF000AFF0500FF1400FFBD00FFFF0000FF00008000FF1400FF0500FF0500FF0500FF
0500FF0500FF2300FF6100FF7000FF7000FF8F00FFBD00FFFF008AAE00FF9E00FF6100FF
5100FF4200FF4200FF5100FF5100FFBD00FFDC00FF7000FF8000FF8F00FFFF00E6FF0000
FF0000BD00FF9E00FFAE00FFDC00FFFF000FDC00FFBD00FFAE00FFBD00FFCC00FFFF00D7
FF00A8FF00A8FA00FFCC00FFBD00FFBD00FFDC00FFEB00FFEB00FFFF00E6FF0000FF007A
FF008AFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00A8FF00E6EB00FFEB00FFFF00E6FF0000FF006BFF00D7CC00FF8000FF7000FF
6100FF5100FF5100FF5100FF4200FF3300FF3300FF4200FF3300FF3300FF4200FF4200FF
6100FF8000FFFF00C78F00FF6100FF5100FF4200FF3300FF3300FF3300FF4200FF5100FF
5100FF6100FFBD00FFFA00FFCC00FF8000FF6100FF6100FF6100FFFF00E67000FF7000FF
EB00FF9E00FF6100FF5100FF4200FF4200FF4200FF6100FFDC00FFFF0000FF00006100FF
1400FF000AFF0019FF0028FF0028FF000AFF0038FF0047FF0057FF0057FF0057FF0066FF
0057FF0057FF0047FF3300FFFF0000000AFF0057FF0057FF0066FFFF00007000FF5100FF
2300FF0047FF0038FF4200FF00A3FF00B3FF00C2FF00C2FF00C2FF00C2FF00C2FF00C2FF
00C2FF00C2FF00C2FF00C2FF00B3FF00B3FF00A3FF00A3FF00A3FF0094FF0085FF0075FF
0047FF2300FF2300FF6100FFFF00A8FF0000FF0000BD00FFFF00B8000AFF0028FF0047FF
0075FF0094FF00A3FF00B3FF00B3FF00C2FF00D1FF00E1FF00E1FF00F0FF00F0FF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFF000FFF000FFF000FFF000FFF000FFF000FFE100FFE1
00FFE100FFE100FFE100FFF000FFF000FFD100FFD100FFC200FFC200FFB300FFB300FFB3
00FFB300FFB300FFB300FFB300FFA300FFA300FFA300FFA300FFA300FFA300FFA300FFA3
00FF9400FF9400FF9400FF9400FF9400FF9400FF9400FF9400FF9400FF8500FF8500FF85
00FF8500FF8500FF8500FF8500FF8500FF7500FF7500FF7500FF7500FF7500FF7500FF75
00FF7500FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF66
00FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF57
00FF5700FF5700FF5700FF5700FF5700FF5700FF4700FF4700FF4700FF4700FF4700FF47
00FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF47
00FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF3800FF4700FF38
00FF3800FF4700FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A05FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0042FF0042FF00
00FFA300FF9400FF9400FF9400FF9400FF9400FF9400FF9400FFA300FFA300FFA300FFB3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00FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF9400FF9400FF9400FFA300FFB3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00FF7500FF7500FF7500FF7500FF8500FF8500FF8500FF8500FF9400FFA300FFA300FFB3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00FF7500FF7500FF7500FF7500FF7500FF7500FF8500FF8500FF9400FF9400FFA300FFB3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00FF6600FF6600FF6600FF7500FF7500FF7500FF7500FF8500FF8500FF9400FFA300FFC2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00FF6600FF6600FF6600FF6600FF6600FF7500FF7500FF8500FF8500FFC200FFD100FFD1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00FF6600FF6600FF6600FF6600FF6600FF6600FF7500FF8500FF8500FFA300F0FF00F0FF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00FF5700FF5700FF6600FF6600FF6600FF6600FF7500FF7500FF8500FFA30028FF00D1FF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00FF5700FF5700FF5700FF5700FF6600FF6600FF7500FF8500FF8500FF9400FFB300E1FF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00FF5700FF5700FF5700FF5700FF5700FF6600FF7500FF7500FF8500FFA300FFC200E1FF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00FF4700FF5700FF5700FF5700FF5700FF6600FF7500FF9400FFD100FFB300FFD100A3FF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00FF4700FF4700FF5700FF5700FF5700FF6600FF7500A3FF00C2FF00E1FF00FFFF0085FF
AE00FF00FFD100FFC200FF7500FF6600FF6600FF5700FF5700FF5700FF5700FF5700FF66
00FF750066FF00FF7500FF6600FF5700FF4700FF4700FF4700FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF5700FF5700FF57
00FF5700FF5700FF6600FF6600FF6600FF7500FF7500FF7500FF7500FF8500FF8500FF85
00FF9400FF9400FFA300FFA300FFA300FFB300FFB300FFB300FFC200FFC200FFC200FFD1
00FFD100FFE100FFF000E1FF0019FF00B3FF0028FF0066FF0085FF00B3FF00D1FF00D1FF
00D1FF00B3FF0057FF3300FF00A3FF00D1FF00F0FF00F0FF00FFFF00FFFF00F0FF00D1FF
0019FF0028FF0075FF0094FF0075FFFF00000066FFDC00FF8F00FF8000FFFF0000FF003D
000AFF0038FF0085FF00D1FF00F0FF00FFFF00FFF000FFF000FFE100FFE100FFD100FFD1
00FFC200FFC200FFC200FFC200FFC200FFC200FFC200FFC200FFC200FFB300FFB300FFC2
00FFC200FFC200FFC200FFC200FFD100FFD100FFE100FFE100FFF000F0FF0085FF0038FF
FF009900B3FF00E1FF00F0FF00F0FF00E1FF0085FF0028FFFF005C0094FF00A3FF00E1FF
00F0FF00C2FF0066FF00A3FF00FFE100FFC200FFC200FFC200FFB300FFB300FFB300FFB3
00FFA300FFA300FFA300FFA300FFA300FFA300FFA300FFA300FF9400FF9400FF9400FF94
00FF9400FF9400FF9400FF9400FF9400FF9400FF9400FF9400FF9400FF9400FF9400FF94
00FF9400FFA300FFA300FFA300FFA300FFA300FFA300FFB300FFB300FFC200FFD100FFC2
00FFC200FFC200FFC200FFC200FFC200FFC200FFC200FFD100FFD100FFD100FFD100FFE1
00FFE100FFE100FFF000FFFF00F0FF00C2FF9E00FF0094FF0094FF0057FF6100FF8000FF
0094FF00B3FF00D1FF00D1FF00E1FF00E1FF00F0FF00F0FF00F0FF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF
00E1FF00E1FF00E1FF00D1FF00D1FF00D1FF00D1FF00C2FF00C2FF00C2FF00C2FF00B3FF
00B3FF00B3FF00A3FF00A3FF0094FF0094FF0085FF0075FF0066FF0057FF0047FF0038FF
0019FF1400FFFF00008000FF8000FF6100FF7000FF7000FF6100FF2300FF0500FF0038FF
0047FF0057FF0066FF0066FF0066FF0066FF0066FF0066FF0057FF0057FF0047FF0047FF
0047FF0038FF0028FF0019FF1400FF2300FF9E00FFFF00A83300FF0500FF000AFF000AFF
0019FF000AFF0500FF5100FFFF00004200FF3300FF9E00FF9E00FF3300FF1400FF1400FF
0500FF0500FF1400FF3300FFBD00FF7000FFAE00FFFA00FFFF00B8FF007A7000FF5100FF
4200FF3300FF2300FF2300FF2300FF2300FF3300FF3300FF5100FF7000FFFF00007000FF
5100FF4200FF3300FF2300FF2300FF2300FF2300FF3300FF3300FF5100FF7000FF9E00FF
FF00B8FF00C78F00FF7000FF5100FF4200FF3300FF2300FF2300FF1400FF1400FF1400FF
2300FF2300FF3300FF5100FF6100FF9E00FFFF00A8FF00D7AE00FF6100FF4200FF3300FF
2300FF2300FF2300FF1400FF1400FF1400FF1400FF2300FF2300FF3300FF3300FF4200FF
5100FF6100FF8000FF9E00FFEB00FFFF0000FF00C7AE00FF8F00FF8000FF6100FF5100FF
4200FF4200FF3300FF3300FF3300FF3300FF3300FF4200FF8F00FF9E00FF6100FF6100FF
6100FF6100FF7000FF8F00FFAE00FFEB00FFFF0000FF00E6FF0099FF00B8AE00FFAE00FF
BD00FFCC00FFEB00FFFF00D7FF003DFF005CFF00D7FF00A8FF0000FF008AFF006BFF006B
FF0000FF0000FF002EFF002EFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF000FFF001EFF0000FF0000FF0000FF004CFF007AFF00A8FF00B8FF00C7FF00D7FF00D7
FF008AFF0000FF0000FF0000FF001EFF00C7FF00E6FF00F5FF00C7FF0000FF0099FF003D
FF00C7FF00D7FF00C7FF00A8FF004CFF0000FF004CFF005CFF003DFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000FFF0000FF002EFF001EFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FA00FFBD00FF8F00FF
FF00D74200FF2300FF1400FF4200FFFA00FF2300FF0028FF0038FF0047FF0057FF0057FF
0066FF0066FF0066FF0066FF4200FF0038FF0057FF0047FFCC00FFFF00000057FF0057FF
0057FF0038FF000AFF1400FF000AFF2300FFBD00FFFF00D7FF0000AE00FF2300FF0019FF
0038FF0057FF0066FF0085FF0094FF0094FF00A3FF00A3FF00A3FF00A3FF00A3FF00A3FF
0094FF0057FF000AFF4200FFBD00FF0075FF0075FF0094FF00C2FF00E1FF00F0FF00FFFF
00FFF000FFF000FFF000FFE100FFE100FFE100FFE100FFD100FFD100FFD100FFD100FFD1
00FFD100FFD100FFC200FFC200FFC200FFC200FFC200FFC200FFB300FFB300FFB300FFB3
00FFB300FFB300FFB300FFA300FFA300FFA300FFA300FFA300FFA300FFA300FF9400FF94
00FF9400FF9400FF9400FF9400FF9400FF9400FF8500FF8500FF8500FF8500FF8500FF85
00FF8500FF8500FF8500FF8500FF8500FF7500FF7500FF7500FF7500FF7500FF7500FF75
00FF7500FF7500FF7500FF7500FF6600FF6600FF6600FF6600FF7500FF6600FF6600FF66
00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF66
00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF66
00FF6600FF6600FF6600FF7500FF7500FF947000FF00FFFF00FFB300FFB300FFB300FFA3
00FFB300FFD1000AFF00A3FF00FFB300FFA300FF9400FF9400FF9400FFA300FFFF00F0FF
00FFFF00FFF00057FF00C2FF00FFC200FFC200FFD100B3FF00FFF000F0FF7000FF00FFE1
00A3FF00FF9400FFC200D1FF0500FF00FF4700FF3800FF3800FF2800FF2800FF2800FF19
00FF2800FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A05FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF00
00FF4700FF4700FF4700FF4700FF5700FF5700FF6600FF7500FF9400D1FF00E1FF0075FF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00FF4700FF4700FF4700FF4700FF4700FF5700FF5700FF6600FF9400FFA300FFE1AE00FF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00FF4700FF4700FF4700FF4700FF4700FF4700FF5700FF5700FF6600FF8500FFC200C2FF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00FF3800FF4700FF3800FF4700FF4700FF4700FF5700FF5700FF6600FF7500FFB30075FF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00FF3800FF3800FF3800FF3800FF4700FF4700FF4700FF5700FF6600FF7500FFB300FFFF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00FF3800FF3800FF3800FF3800FF3800FF4700FF4700FF5700FF6600E1FF00F0FF00FF94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00FF3800FF3800FF3800FF3800FF3800FF3800FF4700FF4700FF6600FFFF00FFC200FF66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00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF4700FFB300FF8500FF5700FF47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00FF2800FF2800FF2800FF2800FF3800FF3800FF3800FF3800FF4700FF4700FF4700FF38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00FF2800FF2800FF2800FF2800FF2800FF2800FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF3800FF2800FF2800FF2800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF4700FF4700FF4700FF4700FF4700FF6600FF6600FF66
00FF7500FF7500FF8500FF8500FFA300FFD100FFFF0066FF00C2FF0047FF0094FF00FFF0
00FFD100FFC200FFB300FFC200FFD100FFB300FFB300FFA300FFA300FFB300FFB300FFC2
00FFD100FFF00028FFFF00B800C2FF00A3FF00FFD100FFC200FFC200FFB300FFB300FFB3
00FFA300FFA300FFA300FFA300FFA300FFA300FFA300FFA300FFB300FFB300FFC200FFC2
7000FF00F0FF00D1FF0028FF0019FF00D1FF00E1FF00C2FF3300FF00D1FF00F0FF00FFFF
00FFF000FFF000FFFF0057FF00F0FF000AFF00F0FF00E1FF0047FF0085FF0085FF0057FF
2300FF4200FFFF006BFF00003300FF5100FF00C2FF00C2FF00D1FF00E1FF00E1FF00F0FF
00F0FF00D1FF1400FF0075FF00A3FF0028FF0085FF00B3FF00B3FF00A3FF1400FF0047FF
1400FF0094FF00B3FF00D1FF00E1FF00F0FF00FFFF00FFFF00FFF000FFF000FFF000FFE1
00FFE100FFE100FFD100FFD100FFD100FFC200FFC200FFC200FFC200FFC200FFC200FFB3
00FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB3
00FFA300FFB300FFA300FFA300FFA300FFA300FFB300FFA300FFB300FFB300FFB300FFB3
00FFB300FFB300FFB300FFB300FFC200FFC200FFC200FFD100FFD100FFE100FFFF00A3FF
0094FF0085FF3300FF1400FF0038FFFA00FF0500FF0085FF00A3FF0094FF7000FF0019FF
00A3FF00C2FF00C2FF00C2FF00C2FF00C2FF00C2FF00C2FF00B3FF00A3FF0085FF0500FF
FF00F50066FF0085FF00B3FF00B3FF00C2FF00C2FF00D1FF00D1FF00D1FF00D1FF00D1FF
00D1FF00D1FF00D1FF00D1FF00D1FF00D1FF00C2FF00B3FF0094FF00B3FF00B3FF00B3FF
00B3FF00A3FF0094FF0085FF0028FF000AFFFF0000FF00F58F00FF0019FF0066FF0075FF
0085FF0085FF0085FF0085FF0085FF0075FF0075FF0075FF0066FF0057FF0057FF0047FF
0047FF0038FF0028FF000AFF2300FFFF00005100FF7000FFFF00E6BD00FF8F00FF2300FF
1400FF1400FF0500FF0500FF0500FF0500FF1400FF2300FF3300FF4200FF7000FFEB00FF
FF00D78F00FF8F00FF9E00FFEB00FFFA00FFCC00FFEB00FFFA00FFFF00C7FF0000FF00A8
FF003DFF0000FF0000FF0000FF002EFF006BFF002EFF008AFF00A8FF0099FF00E6FF006B
FF004CFF00F5EB00FFFF00A8DC00FFFF00B8FA00FFEB00FFFF00F5FF00B8FF002EFF0099
FF00D7FF00C7FF008AFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF003DFF005CFF007AFF00C7FF00D7FF00A8FF0000
FF002EFF005CFF00E6FF00B8FF00A8FF00A8FF00F5FF006BFF002EFF00F5EB00FFFF00A8
DC00FFFA00FFDC00FFEB00FFFF0000FF002EFF00D7DC00FFBD00FFAE00FF9E00FF9E00FF
9E00FFAE00FFFF00E6FF001EEB00FFFF00E6FF00A8CC00FFAE00FF9E00FF8F00FF8F00FF
8F00FF9E00FFFF00F5FF006BFF00D7FF00A8FF0000FF0000FF005CFF00F5EB00FFCC00FF
BD00FFAE00FFAE00FFAE00FFAE00FFBD00FFCC00FFCC00FFEB00FFFF00C7FF001EFF007A
FF005CFF003DFF00D7FF00C7FF00A8FF004CFF0000FF003DFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF003DFF004CFF0000FF0000FF008AFF00A8FF00C7FF0000
FF003DFF00C7EB00FFCC00FF8000FF8F00FF8000FF8000FFFF00008000FF6100FF6100FF
EB00FFFF008AFF00B8FF00009E00FF7000FF3300FF4200FF4200FF2300FF4200FFFF00A8
FF00F5AE00FFEB00FFBD00FF0066FF0075FF0085FF0094FF0094FF0094FF0094FF00A3FF
00A3FF00A3FF00B3FF00B3FF00C2FF00C2FF00D1FF00D1FF00D1FF00D1FF00E1FF00E1FF
00E1FF00E1FF00E1FF00E1FF00F0FF00F0FF00F0FF00F0FF00FFFF00FFFF00FFFF00FFFF
00FFF000FFF000FFF000FFF000FFF000FFE100FFE100FFE100FFE100FFE100FFE100FFE1
00FFE100FFE100FFE100FFD100FFD100FFD100FFD100FFD100FFE100FFD100FFE100FFE1
00FFE100FFE100FFE100FFFF00D1FF00FFE100FFC200FFC200FFB300FFB300FFB300FFA3
00FFA300FFA300FFA300FF9400FF9400FF9400FF9400FF9400FF9400FF9400FF9400FF94
00FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF75
00FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF75
00FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF75
00FF7500FF7500FF7500FF7500FF7500FF7500FF8500FF8500FF8500FF8500FF9400FF94
00FF9400FF9400FF9400FF9400FFA300FFA300FFA300FFB300FFF000FFFF00FFF000FFF0
00FFFF00E1FF00A3FF0066FFFA00FFFF00000057FF00D1FF00FFFF00FFE100FFD100FFC2
00FFE100FFFF00FF9400FF7500FF6600FF5700FF5700FF4700FF4700FF4700FF4700FF47
00FF3800FF3800FF3800FF3800FF3800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A05FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0005FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0014FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0014FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0023FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF00
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28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00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28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00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28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00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28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00FF2800FF1900FF1900FF1900FF1900FF2800FF1900FF1900FF1900FF1900FF1900FF19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00FF2800FF1900FF1900FF1900FF1900FF2800FF1900FF1900FF1900FF1900FF1900FF19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00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19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00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19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00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19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00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19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00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19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00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19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00FF1900FF1900FF1900FF0A00FF0A00FF1900FF1900FF0A00FF0A00FF1900FF1900FF0A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00FF0A00FF1900FF0A00FF0A00FF0A00FF1900FF0A00FF0A00FF0A00FF0A00FF1900FF0A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00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A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00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A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00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A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00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A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00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A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00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF0A00FF0A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00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A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00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A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00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A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00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A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00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A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05FF0005FF0000FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A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05FF0005FF0005FF0000FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A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05FF0005FF0005FF0005FF0000FF0A05FF0005FF0005FF0005FF0000FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF4700FF3800FF3800FF4700FF4700FF47
00FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF5700FF57
00FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF6600FF6600FF66
00FF6600FF6600FF6600FF7500FF7500FF8500FF8500FF9400FF9400FFA300FFB300FFC2
00FFD100FFFF0075FFFF00000066FF8F00FFFA00FF00B3FF000AFF00A3FF0075FF00C2FF
00E1FF00D1FF00A3FF00C2FF00D1FF00C2FF00C2FF0094FF0066FF00C2FF00D1FF00E1FF
00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00D1FF0500FF00E1FF00F0FF00F0FF00E1FF
00E1FF00F0FF00FFFF00F0FF00F0FF00F0FF00F0FF00E1FF00E1FF00D1FF00C2FF00C2FF
00C2FF00B3FF0085FF0047FF0038FF0028FF1400FFFA00FFFF00E6FF006BEB00FF8000FF
000AFF0047FF0066FF0085FF0094FF00A3FF00B3FF00A3FF0066FF0094FF00C2FF00C2FF
00B3FF00D1FF00E1FF00E1FF00F0FF00F0FF00E1FF00E1FF00D1FF00A3FF0066FF00A3FF
00C2FF00D1FF00D1FF00C2FF0094FF0500FF8000FF0019FF2300FF00A3FF00D1FF00E1FF
00E1FF00F0FF00F0FF00F0FF00F0FF00F0FF00E1FF00E1FF00E1FF00E1FF00E1FF00D1FF
00D1FF00C2FF00C2FF00B3FF00B3FF00A3FF0085FF0066FF5100FF4200FF1400FF0028FF
0057FF0066FF0066FF0066FF0057FF0057FF0047FF0038FF0500FFEB00FF5100FF1400FF
0500FF1400FF2300FF3300FF5100FF7000FF9E00FFFF0000FF0099FF006BFF0099FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF001EFF0000FF0000FF007AFF004CFF0000
FF007AFF0099FF00A8FF008AFF0099FF0000FF003DFF0099FF00A8FF00A8FF0000FF008A
FF007AFF005CFF0000FF0000FF0000FF003DFF003DFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF001EFF002EFF002E
FF006BFF007AFF0099FF00A8FF00A8FF008AFF00E6FA00FFEB00FFDC00FFCC00FFBD00FF
BD00FFAE00FF9E00FF8000FF7000FF6100FF6100FF5100FF4200FF4200FF3300FF3300FF
2300FF1400FF1400FF1400FF0500FF0500FF000AFF000AFF0019FF0019FF0019FF0019FF
0019FF0019FF000AFF000AFF0500FFFF00001400FF0500FF1400FF6100FFBD00FF7000FF
BD00FFFF00A89E00FFBD00FFAE00FFFF0000FF008AFA00FF2300FF000AFF000AFF2300FF
0038FF0066FF0075FF0085FF0094FF0094FF00A3FF00B3FF00B3FF00B3FF00B3FF00C2FF
00C2FF00C2FF00C2FF00C2FF00C2FF00C2FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF
00A3FF00A3FF0094FF0085FF0075FF0038FF000AFF0066FF0085FF0085FF0085FF0075FF
0066FF0085FF0075FF0047FF000AFF0047FF000AFF1400FFDC00FF0028FF7000FF0019FF
0047FF0085FF00B3FF00D1FF00F0FF00F0FF00FFFF00FFFF00FFFF00FFF000FFF000FFF0
00FFE100FFD100FFC200FFC200FFC200FFB300FFB300FFB300FFB300FFB300FFB300FFA3
00FFA300FFB300FFA300FFA300FFA300FFA300FFA300FFA300FFA300FFA300FFA300FFA3
00FFA300FFA300FFA300FFA300FFA300FFA300FFA300FFB300FFB300FFB300FFB300FFB3
00FFC200FFC200FFD100FFE100FFF000FFFF00F0FF00C2FF00A3FF3300FF0075FF0094FF
00C2FF7000FF00C2FF00FFF000FFD100FFC200FFB300FFA300FFA300FF9400FF9400FF94
00FF9400FF8500FF8500FF8500FF8500FF7500FF7500FF7500FF7500FF7500FF6600FF66
00FF6600FF6600FF6600FF6600FF6600FF6600FF5700FF6600FF5700FF5700FF5700FF57
00FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF6600FF5700FF57
00FF5700FF5700FF5700FF5700FF6600D1FF00FF9400FFA300FF5700FF5700FF4700FF47
00FF4700FF4700FF4700FF4700FF5700FF5700FF660038FF00C2FF00FFA300FF6600FF57
00FF4700FF3800FF3800FF3800FF2800FF2800FF2800FF2800FF2800FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A05FF0005FF0005FF0005FF0005FF0005FF0005FF00
00FF0A05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0005FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF00
05FF0005FF0005FF0005FF0000FF0A05FF0005FF0005FF0005FF0005FF0000FF0A00FF0A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05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0000FF0A00FF0A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05FF0005FF0005FF0000FF0A05FF0005FF0005FF0005FF0005FF0005FF0000FF0A05FF00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05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0000FF0A05FF00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05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00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05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0000FF0A05FF0005FF00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05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00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05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00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05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00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05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00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05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00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05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00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05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00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05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00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05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00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05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00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05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00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05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00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05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00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14FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00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14FF0014FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00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14FF0014FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00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14FF0014FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00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14FF0014FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00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14FF0014FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00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14FF0005FF0005FF0005FF0005FF0005FF0014FF0005FF0005FF0005FF0005FF0005FF00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14FF0005FF0005FF0014FF0014FF0014FF0014FF0014FF0014FF0005FF0005FF0005FF00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05FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0005FF0005FF0005FF00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14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0005FF0005FF00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14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0000FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF4700FF4700FF4700FF4700FF4700FF4700FF47
00FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF5700FF5700FF57
00FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF6600FF6600FF66
00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7500FF7500FF7500FF7500FF75
00FF7500FF7500FF7500FF7500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF85
00FF9400FF9400FF9400FF9400FF9400FF9400FF9400FF9400FF9400FF9400FF9400FFA3
00FFA300FFA300FFA300FFA300FFA300FFA300FFB300FFB300FFB300FFB300FFB300FFB3
00FFB300FFC200FFC200FFC200FFC200FFC200FFC200FFD100FFD100FFD100FFD100FFD1
00FFD100FFD100FFE100FFE100FFE100FFE100FFF000FFF000FFF000FFFF00FFFF00FFFF
00E1FF00C2FF0085FF1400FF0094FF0019FF00B3FF00C2FF00C2FF00C2FF00D1FF00D1FF
00C2FF00C2FF00C2FF00C2FF00C2FF00B3FF00B3FF00B3FF00A3FF0094FF0094FF0094FF
0094FF0094FF0094FF0085FF0075FF0057FF000AFFFF00001400FF0019FF1400FF4200FF
000AFF0019FF0019FF0019FF1400FF1400FF0500FFAE00FF0500FF000AFF0500FF3300FF
2300FF4200FF7000FF3300FF3300FF3300FF4200FF6100FFFF0000CC00FFFF002EFF0000
FF002EFF0099FF0000FF00A8FF0000FF00E6FF00E6FF00E6FF00D7FF00D7FF00B8FF0099
FF002EFF0000FF002EFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF001EFF005CFF00A8FF00B8FF00A8FF008A
FF0000FF00B8FF00C7FF0000FF0000FF0099EB00FFDC00FFDC00FFDC00FFFA00FFFF00C7
FF00B8FA00FFDC00FFBD00FFAE00FF9E00FF8F00FF8F00FF8F00FF9E00FFCC00FFCC00FF
FF003DDC00FF9E00FF8000FF6100FF5100FF4200FF3300FF3300FF2300FF2300FF2300FF
2300FF2300FF3300FFFF007AEB00FFFA00FFBD00FFDC00FFFF00B8AE00FF4200FF2300FF
1400FF0500FF0019FF0019FF0028FF0038FF0038FF0047FF0047FF0057FF0057FF0066FF
0066FF0066FF0066FF0066FF0075FF0066FF0066FF0057FF0038FFFF008A2300FF0047FF
0066FF0075FF0075FF0075FF0066FF0047FF3300FFFF00A88000FF00A3FF00B3FF00C2FF
00C2FF00D1FF00D1FF00D1FF00D1FF00D1FF00D1FF00D1FF00C2FF00C2FF00B3FF00B3FF
00A3FF0085FF0075FF0038FF3300FF0047FF0075FF0085FF0085FF0085FF0057FF7000FF
0047FF1400FFFF003D0019FF1400FF0019FF0038FF0075FF00A3FF00B3FF00C2FF00C2FF
00C2FF00B3FF0094FF3300FF0094FF00A3FF0085FF0094FF0094FF0500FF00F0FF00FFE1
00FFD100FFD100FFC200FFC200FFC200FFC200FFB300FFB300FFC200FFB300FFB300FFB3
00FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC200FFC200FFD100FFF000B3FF
00D1FF00FFE100FFC200FFC200FFD100FFD100FFC200FFB300FFB300FFB300FFB300FFB3
00FFB300FFB300FFB300FFC200FFD100FFF00019FF9E00FF00D1FF00FFD100FFC200FFC2
00FFC200FFC23300FF00FFB300FF9400FF8500FF8500FF7500FF7500FF7500FF7500FF75
00FF7500FF7500FF7500FF7500FF7500FF8500FF8500FF9400FF9400FFA300FFC20019FF
00B3FF00FF8500FF5700FF5700FF4700FF4700FF4700FF4700FF3800FF3800FF3800FF38
00FF3800FF3800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF1900FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF2800FF2800FF2800FF28
00FF3800FF3800FF3800FF4700FF5700FF7500FF8500FFB300A3FF00FFB300FF7500FF57
00FF5700FF4700FF3800FF3800FF2800FF2800FF1900FF1900FF1900FF1900FF1900FF19
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A05FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0000FF0A00FF0A00FF0A
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0005FF0005FF00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14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0005FF0005FF0005FF00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14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0005FF0005FF0005FF00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14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0005FF0005FF0005FF0005FF00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14FF0014FF0014FF0014FF0014FF0014FF0014FF0005FF0005FF0014FF0014FF0014FF00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14FF0014FF0014FF0014FF0014FF0014FF0005FF0014FF0014FF0014FF0014FF0014FF00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14FF0014FF0014FF0014FF0005FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00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14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00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14FF0005FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00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14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00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14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00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14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00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14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00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14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00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14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0005FF0005FF00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14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0005FF0014FF0014FF0014FF00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14FF0014FF0014FF0014FF0014FF0014FF0005FF0014FF0014FF0014FF0014FF0014FF00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14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00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14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00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14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00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14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00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14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00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14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00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14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00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14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00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14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00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14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00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14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00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14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0000FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF2800FF2800FF2800FF3800FF6600FFE100FF9400FF6600FF6600FF66
00FF6600FF6600FF7500FF6600FF5700FF5700FF4700FF4700FF4700FF5700FF5700FF57
00FF5700FF5700FF5700FF6600FF7500FFA39E00FF00F0FF00FFFF00FF9400FF9400FFA3
00FFE100F0FF0066FF00FFD100FFB300FFA300FF9400FF8500FF8500FF7500FF7500FF75
00FF7500FF7500FF7500FF7500FF6600FF7500FF6600FF6600FF7500FF6600FF7500FF75
00FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF75
00FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF75
00FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF85
00FF7500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF85
00FF9400FF9400FF9400FF9400FF9400FF9400FFA300FFA300FFA300FFA300FFA300FFA3
00FFB300FFB300FFB300FFC200FFC200FFC200FFD100FFE100FFF000FFF000FFF000FFFF
00F0FF00B3FF000AFF0075FF2300FF0075FF0075FF0047FFFF005C0038FF0075FF0094FF
0094FF0066FF00B3FF00C2FF00C2FF00D1FF00E1FF00E1FF00E1FF00E1FF00E1FF00E1FF
00E1FF00E1FF00E1FF00E1FF00E1FF00E1FF00E1FF00E1FF00D1FF00D1FF00D1FF00C2FF
00A3FF0075FF0028FF0019FF0047FF1400FF0019FF0047FF0047FF7000FFDC00FF0019FF
0038FF0500FF4200FF0500FF6100FF5100FFFF00F55100FFFF0000FF006B5100FF3300FF
3300FF6100FFFA00FF5100FF2300FF1400FF1400FF0500FF1400FF1400FF2300FF9E00FF
FF00004200FF3300FF3300FF3300FF3300FF4200FF4200FFBD00FFFF006BFF007AFF007A
FF0099FF0000FF00E6FA00FFFF00C7FF0000FF0000FF006BFF003DFF0099FF0099FF006B
FF002EFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF000FFF003DFF006BFF007AFF006BFF00E6BD00FF
9E00FF8F00FF7000FF6100FF5100FF5100FF5100FFFF00A85100FF1400FF000AFF0028FF
0038FF0038FF0057FF0066FF0066FF0066FF0075FF0075FF0066FF0047FF0038FF8F00FF
8F00FF6100FF0094FF00B3FF00C2FF00D1FF00D1FF00E1FF00E1FF00F0FF00F0FF00F0FF
00F0FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF000FFF000FFF000FFF000FFF000FFF0
00FFF000FFF000FFFF0047FF00E1FF00E1FF0019FF00FFFF00FFF000FFF000D1FF00D1FF
00FFD100FFC200FFB300FFB300FFA300FFA300FFA300FF9400FF9400FF9400FF9400FF94
00FF9400FF9400FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF7500FF75
00FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF6600FF6600FF66
00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF5700FF57
00FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF47
00FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF47
00FF4700FF4700FF4700FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF2800FF2800FF2800FF3800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF1900FF1900FF1900FF2800FF2800FF2800FF1900FF19
00FF1900FF1900FF2800FF1900FF1900FF1900FF1900FF2800FF2800FF1900FF1900FF19
00FF1900FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF4700FF4700FF4700FF5700FF5700FF66
00FF7500FF7500FF8500FFA300FFA300FFA300FFA300FFB300FFD100FFF000C2FF00A3FF
00F0FF00FFF000FFE100FFD100E1FF00D1FF00FFB300FF9400FF8500FF8500FF8500FF66
00FF5700FF5700FF4700FF4700FF4700FF4700FF4700FF4700FF3800FF4700FF3800FF38
00FF4700FF4700FF4700FF4700FF4700FF4700FF5700FF5700FF7500B3FF8F00FF00FFF0
00FF9400FF8500FF8500FF8500FF9400FFA300FFD100FFFF0047FFFA00FF00F0FF00FFD1
00FFB300FF9400FF8500FF85
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00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14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00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14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00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14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00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14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00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14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00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14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0005FF0014FF0014FF0014FF00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14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00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14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00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14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0000FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF19
00FF1900FF1900FF1900FF1900FF1900FF2800FF2800FF3800FF3800FF3800FF4700FF57
00FF6600FF7500FFA300FFF000FFFF00FFA300FFA300FFB300FFB300FFD100FFFF00B3FF
00FFFF0085FF0066FF00A3FFEB00FF9E00FF0500FF0047FF0028FF000AFF8F00FF1400FF
0066FF00A3FF00D1FF00FFFF00FFF000FFE100FFF000A3FF00F0FF00D1FF0094FF00FFD1
00FFC200FFB300FFB300FFB300FFB300FFC200FFE100E1FF2300FF00A3FF00FFE100FFE1
00D1FF000AFF00B3FF00FFFF00F0FF00E1FF00FFB300FFA300FF9400FF9400FF9400FF94
00FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF85
00FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF85
00FF8500FF8500FF8500FF8500FF9400FF8500FF9400FF9400FF9400FF9400FF9400FF94
00FF9400FF9400FF9400FFA300FFA300FFA300FFA300FFB300FFC200FFD100FFD100FFC2
00FFD100FFD100FFD100FFD100FFE100FFF00094FF00FFF000FFF000FFF000FFF000FFFF
00FFFF00FFFF00F0FF00F0FF00F0FF00E1FF00E1FF00D1FF00D1FF00C2FF00B3FF00A3FF
0094FF0057FF9E00FF6100FF0085FF0094FF00A3FF00A3FF00B3FF00B3FF00B3FF00B3FF
00B3FF00B3FF00B3FF00B3FF00A3FF00A3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A3FF
00A3FF00A3FF00A3FF00A3FF0094FF0094FF0094FF0085FF0085FF0085FF0075FF0075FF
0075FF0066FF0066FF0066FF0057FF0057FF0047FF0047FF0038FF0038FF0038FF0028FF
0019FF0019FF000AFF0500FF1400FF3300FF5100FF8000FFCC00FF8000FF7000FF8000FF
9E00FFEB00FFFF005CFF00F5FF00F5FF004CFF004CFF00A8FF008AFF0000FF00E6FA00FF
FA00FFFF006BFA00FFFA00FFFF00E6FF00D7FF00B8FF006BFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF001EFF004CFF006BFF008AFF005CFF0000FF006B
FF0000EB00FFCC00FFCC00FFFF00C7BD00FF9E00FFFF00F5AE00FF5100FF4200FF4200FF
6100FFAE00FFFF002EFF00997000FF3300FF4200FF1400FF0038FF0047FF0047FF0057FF
0066FF0066FF0075FF0085FF0094FF0094FF00A3FF00B3FF00B3FF00C2FF00C2FF00C2FF
00D1FF00D1FF00D1FF00D1FF00D1FF00D1FF00C2FF0094FF0066FF0038FF3300FF0066FF
0094FF00B3FF0038FF00C2FF00F0FF00FFFF00FFF000FFE100FFE100FFD100FFD100FFC2
00FFC200FFC200FFB300FFB300FFB300FFA300FFA300FFA300FFA300FFA300FF9400FF94
00FF9400FF9400FF9400FF9400FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF85
00FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF75
00FF7500FF7500FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF66
00FF5700FF5700FF6600FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF57
00FF5700FF5700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF47
00FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF3800FF3800FF3800FF38
00FF3800FF4700FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF2800FF2800FF2800FF3800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF5700FF5700FF57
00FF5700FF6600FF7500FF7500FF8500FF8500FF8500FF8500FF9400FF9400FFA300FFB3
00FFD100FFF000FFFF0094FF00E1FF00FFE100FFD100FFC200FFE100FFC200FF9400FF85
00FF7500FF7500FF7500FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF75
00FF7500FF9400FFA300FF9400FF9400FF9400FFA300FFC20038FF00FFF000FFFF00D1FF
0047FF7000FF0047FF1400FF00F0FF00FFE100FFD100FFE100FFC200FFE100FF8500FF75
00FF5700FF5700FF4700FF47
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00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14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00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14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00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14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00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14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0000FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF2800FF2800FF2800FF3800FF4700FF5700FF75
00FFB300FF6600FF6600FF5700FF5700FF5700FF5700FF6600FF5700FF5700FF6600FF66
00FF7500FF8500FF8500FF9400FF9400FFA300FFB300FFD100FFF000D1FF0066FF00D1FF
0085FF00A3FF00FFFF00FFF000FFF000F0FF00C2FF8F00FF000AFF00A3FFFF005C8F00FF
0047FF0500FF0075FF00C2FF00E1FF00B3FF0075FF00A3FF0038FF0094FF00E1FF00FFFF
00FFF000FFE100FFD100FFC200FFC200FFC200FFB300FFB300FFA300FFA300FFA300FFA3
00FF9400FF9400FF9400FF9400FF9400FF9400FF9400FF9400FF9400FF9400FF9400FF94
00FF9400FF9400FF8500FF9400FF9400FF8500FF9400FF9400FF8500FF9400FF9400FF94
00FF9400FF9400FF9400FF9400FF9400FF9400FF9400FF9400FF9400FF9400FF9400FF94
00FFA300FFA300FFA300FFA300FFA300FFB300FFB300FFC200FFD100FFFF00A3FF00C2FF
0085FFFF00D70066FF0066FF8000FF2300FF0057FF00A3FF0085FF0094FF00B3FF0094FF
0047FF0057FF0085FF0094FF0085FF0085FF0038FF0028FF0047FF0028FF1400FFFF0000
000AFF0019FF0066FF0066FF0038FF2300FFFF00000019FF0047FF0057FF0057FF0047FF
0019FF1400FFFF007A2300FF0057FF0075FF0085FF0085FF0094FF0094FF0094FF0094FF
0085FF0085FF0085FF0085FF0085FF0085FF0085FF0075FF0075FF0075FF0075FF0066FF
0066FF0066FF0066FF0057FF0047FF4200FF000AFF0019FF000AFF5100FF000AFF000AFF
000AFF000AFF000AFF000AFF0500FF0500FF1400FF1400FF2300FF3300FF3300FF4200FF
5100FF5100FF6100FF7000FF8000FF8F00FF9E00FFFF006BEB00FFDC00FFDC00FFFA00FF
FF00E6FF00E6FF00A8FF008AFF007AFF008AFF006BFF006BFF005CFF003DFF000FFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF003DFF0099FF00D7FF00E6FF006BEB00FFDC00FFCC00FFEB00FFFF0000FF00F5
9E00FF8000FF5100FF4200FF2300FF1400FF1400FF1400FFDC00FF0500FF0038FF0047FF
0057FF0066FF0066FF0075FF0075FF0075FF0075FF0075FF0085FF0085FF0075FF5100FF
0038FF8F00FF0075FF0085FF0085FF0075FF0075FF0028FF0038FF0094FF00B3FF00C2FF
00D1FF00E1FF00E1FF00F0FF00F0FF00FFFF00FFFF00FFFF00FFF000FFF000FFF000FFE1
00FFE100FFE100FFD100FFD100FFD100FFC200FFC200FFC200FFC200FFB300FFB300FFA3
00FFA300FFA300FF9400FF9400FF9400FF8500FF8500FF8500FF8500FF8500FF8500FF85
00FF8500FF8500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF75
00FF7500FF7500FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF66
00FF6600FF6600FF6600FF6600FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF57
00FF5700FF5700FF5700FF5700FF5700FF4700FF4700FF4700FF5700FF4700FF4700FF47
00FF4700FF4700FF4700FF4700FF4700FF4700FF5700FF4700FF4700FF4700FF4700FF47
00FF4700FF4700FF4700FF4700FF4700FF3800FF3800FF3800FF4700FF3800FF3800FF38
00FF4700FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF5700FF57
00FF5700FF5700FF5700FF6600FF6600FF6600FF6600FF7500FF7500FF8500FFA300B3FF
EB00FF00D1FF00C2FF0066FF00C2FF0085FF0066FF00B3FF00FFFF00FFD100FFC200FFB3
00FFA300FF9400FF9400FF8500FF8500FF8500FF8500FF8500FF8500FF9400FFA300FFB3
00FFE100FFFF0057FF00B3FF0019FF0028FFFF000000C2FF00FFE100FFE10057FF00FFB3
00FFA300FFA300FFA300FFA300F0FF00D1FF7000FF00FFC200FF9400FF7500FF6600FF57
00FF4700FF4700FF4700FF38
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00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14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00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14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00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14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00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14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00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14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00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14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00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14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00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14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0000FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF3800FF3800FF3800FF3800FF3800FF47
00FF4700FF4700FF5700FF5700FF5700FF5700FF6600FF7500FF9400FFF000FFA300FF94
00FF8500FF7500FF7500FF7500FF8500FF7500FF8500FF8500FF8500FF9400FFB300F0FF
00FFF000B3FF0057FF7000FF00A3FF00A3FF00F0FF00FFFF00FFFF00FFF000FFFF00F0FF
00B3FF0047FF8F00FF0075FF4200FF0094FF0085FF0047FF00E1FF00F0FF00F0FF00C2FF
8000FF00D1FF00A3FF00A3FF7000FF0028FF00FFF000FFD100FFC200FFB300FFB300FFA3
00FFB300FFA300FFA300FFA300FFA300FFA300FFA300FFA300FFA300FFA300FFA300FFA3
00FFA300FFA300FFA300FFA300FFA300FFA300FFA300FFA300FFA300FFA300FFA300FFA3
00FFA300FFB300FFB300FFB300FFB300FFB300FFB300FFC200FFC200FFC200FFD100FFD1
00FFD100FFD100FFD100FFE100FFE100FFF000FFF000FFF000FFF000FFFF00FFFF00FFFF
00FFFF00F0FF00F0FF00F0FF00F0FF00F0FF00E1FF00E1FF00E1FF00E1FF00E1FF00D1FF
00D1FF00D1FF00C2FF00C2FF00B3FF00B3FF00A3FF0094FF0085FF1400FF6100FF0066FF
0066FF0066FF0057FF0038FF0028FF2300FFFF00008000FFFF00E68F00FFFF00E6EB00FF
4200FF1400FF000AFF0019FF0028FF0038FF0038FF0038FF0047FF0038FF0038FF0038FF
0038FF0028FF000AFF9E00FFFF00E6FF00008F00FF8000FF5100FF6100FF7000FFFF000F
8F00FF6100FF5100FF5100FF4200FF5100FF5100FF6100FF8F00FFFF0000FF00D7FF0000
CC00FFDC00FFFF00C7FF00F5DC00FFCC00FFCC00FFDC00FFDC00FFFF00F5FF006BFF0000
FF0000FF0000FF003DFF0000FF001EFF000FFF005CFF004CFF0000FF002EFF002EFF000F
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF002EFF0099CC00FF8F00FF6100FF4200FF
BD00FF000AFF0019FF0028FF0038FF0047FF0038FF2300FF0066FF0085FF0094FF00A3FF
00A3FF00B3FF00B3FF00C2FF00D1FF00D1FF00D1FF00D1FF00D1FF00D1FF00D1FF00D1FF
00D1FF00D1FF00D1FF00D1FF00C2FF00A3FF9E00FF00A3FF000AFF00D1FF00F0FF00F0FF
00F0FF00E1FF0057FF00B3FF00FFFF00FFF000FFD100FFD100FFC200FFC200FFB300FFB3
00FFB300FFA300FFA300FFA300FF9400FF9400FF9400FF9400FF9400FF9400FF9400FF94
00FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF85
00FF8500FF8500FF8500FF7500FF7500FF8500FF7500FF7500FF7500FF7500FF7500FF75
00FF7500FF6600FF7500FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF66
00FF6600FF6600FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF57
00FF5700FF5700FF5700FF5700FF5700FF5700FF4700FF4700FF4700FF5700FF4700FF47
00FF4700FF4700FF4700FF4700FF5700FF4700FF4700FF4700FF4700FF4700FF4700FF47
00FF4700FF5700FF4700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF57
00FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF47
00FF4700FF4700FF4700FF5700FF5700FF5700FF6600FFB300FF7500FF6600FF7500FF75
00FF940094FF0066FF00FF7500FF6600FF5700FF5700FF4700FF4700FF4700FF4700FF47
00FF4700FF4700FF4700FF4700FF4700FF4700FF3800FF3800FF4700FF4700FF3800FF38
00FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF47
00FF4700FF4700FF4700FF4700FF4700FF5700FF5700FF5700FF5700FF5700FF5700FF57
00FF5700FF5700FF5700FF6600FF6600FF6600FF6600FF6600FF7500FF7500FF7500FF75
00FF8500FF8500FF8500FF8500FF9400FF9400FFA300FFA300FFB300FFC200FFD100FFE1
00FFFF00C2FF0094FF0094FF00F0FF0057FF7000FF00FFE100FFE100C2FF00FFE100FFC2
00FFB300FFA300FFA300FFA300FFA300FFB300FFF000FFD100FF8500FF7500FF6600FF66
00FF6600FF5700FF6600FF5700FF5700FF5700FF5700FF4700FF4700FF4700FF4700FF47
00FF3800FF3800FF3800FF38
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00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14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00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14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00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14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00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14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00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14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00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14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00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14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00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14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00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14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF38
00FF3800FF3800FF3800FF3800FF3800FF4700FF3800FF4700FF4700FF4700FF4700FF57
00FF4700FF4700FF5700FF5700FF5700FF5700FF5700FF5700FF6600FF6600FF6600FF66
00FF7500FF7500FF7500FF7500FF7500FF8500FF8500FF8500FF8500FF8500FF9400FF94
00FFA300FFA300FFB300FFC200FFC200FFE10057FF0066FF00FFFF00FFF000FFFF00F0FF
0094FF00C2FF0085FF6100FF0085FF00C2FF00A3FF00B3FF00F0FF00F0FF00B3FF00FFE1
00FFD100FFC200FFC200FFC200FFC200FFC200FFB300FFB300FFB300FFB300FFB300FFB3
00FFB300FFB300FFC200FFC200FFC200FFC200FFC200FFC200FFD100FFD100FFD100FFD1
00FFD100FFD100FFD100FFC200FFD100FFD100FFD100FFD100FFD100FFD100FFD100FFD1
00FFD100FFD100FFE100FFE100FFE100FFE100FFE100FFF000FFF000FFF000FFF000FFF0
00FFF000FFFF00FFFF00FFFF00FFFF00FFFF00F0FF00F0FF00E1FF00E1FF00E1FF00C2FF
00B3FF00B3FF00B3FF00B3FF00A3FF00A3FF00A3FF00A3FF00A3FF00A3FF0094FF0094FF
0094FF0085FF0085FF0075FF0075FF0066FF0057FF0057FF0047FF0047FF0038FF0028FF
0019FF3300FF5100FF2300FF3300FFBD00FF8000FFFF0099AE00FF8F00FFCC00FFCC00FF
8000FF5100FF4200FF3300FF3300FF3300FF4200FF5100FF8000FFEB00FFFF00D79E00FF
8F00FF9E00FFAE00FFCC00FFFA00FFFF00C7FF0000FF0000FF005CFF00D7FF00C7FF008A
FF005CFF00A8FF00A8FF008AFF000FFF007AFF005CFF000FFF0000FF0000FF003DFF004C
FF003DFF001EFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000FFF003D
FF005CFF006BFF005CFF0000FF0099FF00B8FF00B8FF00B8FF00A8FF008AFF000FFF0000
FF008AFF00C7FF00D7FF00E6FF00C7FF008AFF004CFF001EFF0099FF00C7FF00D7FF00A8
FF005CFF00A8FF00E6FF00D7FF0000FF0000FF004CFF00E6FF00B8FF0099FF008AFF00D7
FF00C7FF008AFF0000FF006BFF0000FF0000FF0000FF0000FF0000FF0000FF001EFF00D7
FF00E6DC00FFFF00E68000FFFF00D79E00FF7000FF0500FF0038FF0066FF0075FF0094FF
00A3FF00B3FF00C2FF00D1FF00E1FF00E1FF00F0FF00F0FF00F0FF00F0FF00FFFF00FFFF
00FFFF00FFF000FFF000FFF000FFF000FFE100FFE100FFE100FFE100FFE100FFD100FFD1
00FFD100FFD100FFD100FFC200FFC200FFC200FFC200FFC200FFB300FFB300FFB300FFB3
00FFB300FFB300FFA300FFA300FFA300FFA300FFA300FFA300FFA300FFA300FFA300FFA3
00FF9400FFA300FF9400FF9400FF9400FF9400FFA300FFA300FFA300FFA300FFA300FFA3
00FFB300FFD100FFF000FFE100FFF000E1FF0094FF00FFF000FFC200FFB300FFA300FFA3
00FF9400FF9400FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF85
00FF9400FFA300FFB300FF9400FF9400FF8500FF8500FF7500FF7500FF7500FF6600FF66
00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF5700FF5700FF6600FF5700FF57
00FF6600FF5700FF5700FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF66
00FF7500FF7500FF8500FF8500FFA300FFC200F0FF00A3FF00FFE100FFB300FFA300FF94
00FF8500FF8500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF75
00FF7500FF8500FFFF00B3FF00E1FF0085FF00C2FF1400FF0057FF00FFFF00FFD100FFD1
00FFFF7000FF00FF8500FF7500FF7500FF6600FF6600FF6600FF5700FF5700FF5700FF57
00FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF4700FF5700FF5700FF4700FF47
00FF5700FF5700FF4700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF57
00FF5700FF5700FF5700FF5700FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF66
00FF6600FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF8500FF8500FF85
00FF8500FF9400FF9400FFA300FFD100F0FF0038FF00D1FF00FFFF00F0FF00C2FF5100FF
00B3FF00F0FF00FFF000FFD100FFD100FFC200FFB300FF9400FF9400FF8500FF8500FF85
00FF7500FF7500FF7500FF7500FF6600FF6600FF6600FF6600FF6600FF5700FF5700FF57
00FF5700FF5700FF5700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF47
00FF3800FF3800FF3800FF38
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF4700FF4700FF4700FF47
00FF4700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF6600FF6600FF6600FF66
00FF6600FF7500FF7500FF7500FF7500FF7500FF8500FF8500FF8500FF8500FF9400FF94
00FF9400FFA300FFA300FFB300FFC200FFD1000AFF0075FF00FFE100FFE100FFE100FFF0
00FFFF00E1FF00A3FF0057FF0057FF8000FF0066FF0066FF0057FFFF000000E1FF00FFF0
00FFD100FFD100FFC200FFC200FFC200FFC200FFC200FFC200FFC200FFC200FFC200FFC2
00FFC200FFC200FFC200FFC200FFC200FFC200FFC200FFD100FFD100FFE100FFFF00FFE1
00FFD100FFD100FFD100FFD100FFD100FFD100FFD100FFD100FFD100FFD100FFD100FFE1
00FFD100FFE100FFE100FFE100FFE100FFE100FFF000FFF000FFF000FFF000FFF000FFF0
00FFFF00FFFF00FFFF00FFFF00FFFF00F0FF00F0FF00F0FF00E1FF00E1FF00D1FF00B3FF
0047FF00A3FF00A3FF00A3FF0085FF0075FF0094FF0094FF0094FF0094FF0094FF0094FF
0094FF0085FF0085FF0075FF0075FF0066FF0066FF0057FF0047FF0047FF0038FF0038FF
0028FF000AFF0500FF0500FF1400FF3300FF5100FF9E00FFFF00C7FF000FFF004C8F00FF
7000FF5100FF4200FF4200FF4200FF5100FFFF007A8F00FF8F00FFBD00FFFF00E6AE00FF
AE00FFAE00FFCC00FFDC00FFEB00FFFF00D7FF005CFF0000FF00A8FF00B8FF006BFF007A
FF0000FF006BFF001EFF004CFF0000FF005CFF003DFF0000FF0000FF0000FF001EFF002E
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF005CFF007AFF008AFF008AFF00A8FF00C7FF00C7FF00C7FF00B8FF003DFF008AFF00A8
FF0000FF00B8FF00E6FF00F5FF00E6FF00A8FF006BFF0000FF0099FF00E6FF00E6FF002E
FF00D7FF0000FF00F5FA00FFFF00D7FF006BFF00F5FA00FFFF00B8FF00F5FF0000FA00FF
FF00E6FF000FFF006BFF00B8FF008AFF0000FF0000FF0000FF0000FF0000FF0099FF00F5
8000FF4200FF7000FF0500FFFF008A0019FF0019FFBD00FF0500FF0038FF0066FF0085FF
0094FF00A3FF00C2FF00D1FF00E1FF00E1FF00F0FF00F0FF00F0FF00FFFF00FFFF00FFFF
00FFFF00FFF000FFF000FFF000FFF000FFE100FFE100FFE100FFE100FFD100FFD100FFD1
00FFD100FFD100FFC200FFC200FFC200FFC200FFC200FFB300FFB300FFB300FFB300FFB3
00FFB300FFB300FFA300FFA300FFA300FFA300FFA300FFA300FFA300FFA300FFA300FFA3
00FFA300FFA300FFA300FFA300FFA300FFA300FFA300FFA300FFA300FFA300FFA300FFB3
00FFC200FFD1FA00FF00C2FF00F0FF0094FFFF006B00FFFF00FFE100FFC200FFB300FFA3
00FF9400FF9400FF9400FF9400FF8500FF8500FF8500FF8500FF8500FF8500FF9400FF94
00FF9400FFC200FFD100FFA300FFA300FFA300FFA300FF8500FF7500FF7500FF7500FF66
00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF66
00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF75
00FF7500FF8500FF9400FF9400FFA300FFC200E1FF000AFF00FFFF00FFD100FFFF00FFC2
00FF9400FF9400FF8500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF75
00FF8500FF9400FFB300C2FF00E1FF00FFFF00B3FF8000FF1400FF0085FF00FFFF0075FF
00F0FF00FFA300FF8500FF7500FF7500FF6600FF6600FF6600FF6600FF5700FF5700FF57
00FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF57
00FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF57
00FF5700FF5700FF5700FF6600FF6600FF6600FF6600FF6600FF6600FF7500FF7500FF75
00FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF8500FF8500FF8500FF85
00FF9400FF9400FFA300FFB300FFC200FFE100F0FF6100FF00D1FF00B3FF0038FF0028FF
00B3FF00F0FF00FFFF00FFF00066FFDC00FF00FFE100FFA300FF9400FF9400FF8500FF85
00FF7500FF7500FF7500FF7500FF6600FF6600FF6600FF6600FF6600FF6600FF5700FF57
00FF5700FF5700FF5700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF38
00FF3800FF3800FF3800FF38
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0005FF0014FF0014FF00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14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00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14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00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14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00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14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00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14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00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14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00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14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00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14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00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14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00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14FF0014FF0014FF0014FF0014FF0014FF0014FF0005FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0000FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF4700FF4700FF4700FF4700FF47
00FF4700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF6600FF6600FF6600FF66
00FF6600FF6600FF7500FF7500FF7500FF7500FF8500FF8500FF8500FF8500FF8500FF94
00FF9400FF9400FF9400FFA300FFA300FFA300FFB300FFB300FFB300FFB300FFC200FFC2
00FFC200FFD100FFE100FFE100FFF000FFFF00F0FF00E1FF00C2FF0075FF0094FF00A3FF
00B3FF0085FF00B3FF00C2FF00B3FF0047FF0019FF00B3FF00D1FF00E1FF00E1FF00D1FF
00C2FF00D1FF00D1FF00B3FF00A3FF2300FF0028FF0094FF00B3FF00C2FF00D1FF00E1FF
00E1FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00E1FF00B3FF0038FF
3300FF00C2FF00C2FF00A3FF0057FF6100FF0085FF00B3FF00C2FF00D1FF00D1FF00D1FF
00E1FF00E1FF00E1FF00D1FF00D1FF00D1FF00D1FF00C2FF00B3FF00A3FF0075FF000AFF
FF00B88F00FF000AFF1400FF0028FF8000FF000AFF1400FF8000FF000AFF0019FF0028FF
0028FF0038FF0038FF0028FF0019FF4200FFEB00FFBD00FF4200FF4200FFFF00D78F00FF
4200FF3300FF3300FF3300FF3300FF4200FF5100FFDC00FFFF007AAE00FF8F00FF8F00FF
8F00FF9E00FFAE00FFCC00FFDC00FFFA00FFFF00E6FF00C7FF008AFF002EFF000FFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF005CFF008AFF00B8
FF00A8EB00FFCC00FFBD00FFCC00FFDC00FFFF0000EB00FFBD00FFDC00FFEB00FFFF00C7
CC00FF7000FF6100FF6100FF6100FF8000FFFF0099FF00C7FF0000FF0000FF00F5BD00FF
8F00FF5100FF4200FF3300FF2300FF1400FF1400FF1400FF1400FF1400FF3300FF8000FF
7000FF2300FF1400FF3300FF8F00FF1400FF0019FF0028FF0028FF000AFFFF00009E00FF
8000FFEB00FF2300FF4200FF2300FF3300FF8000FF6100FF0057FF0085FF0094FF0094FF
00A3FF00A3FF00B3FF00B3FF00C2FF00C2FF00C2FF00C2FF00D1FF00C2FF00B3FFFF0000
FF00000047FF00C2FF00E1FF00F0FF00F0FF00F0FF00FFFF00FFFF00FFF000FFF000FFF0
00FFE100FFE100FFE100FFE100FFE100FFE100FFE100FFE100FFE100FFE100FFE100FFE1
00FFD100FFD100FFD100FFD100FFD100FFD100FFD100FFD100FFD100FFD100FFC200FFC2
00FFC200FFC200FFC200FFC200FFC200FFC200FFC200FFC200FFC200FFC200FFD100FFD1
00FFD100FFE100FFE100FFF000F0FF00E1FF00A3FF1400FF00A3FF00E1FF00FFFF00FFF0
00FFF000FFF000FFF000FFFF00F0FF00B3FF000AFF0019FF00A3FF00F0FF00FFF000FFE1
00FFD100FFD100FFD100FFD100FFB300FFA300FF9400FF9400FF8500FF8500FF8500FF85
00FF8500FF8500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF75
00FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF8500FF8500FF8500FF8500FF85
00FF8500FF9400FF9400FF9400FFA300FFA300FFB300FFD100FFFF00B3FF00C2FF00B3FF
4200FF0085FF00F0FF00FFE100FFD100FFD100FFC200FFC200FFC200FFC200FFE100B3FF
00FFFF00E1FF1400FF0094FF00E1FF00F0FF0094FF00E1FF00FFD100FFB300FFA300FF94
00FF9400FF8500FF8500FF8500FF7500FF7500FF7500FF7500FF7500FF7500FF6600FF66
00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF66
00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7500FF7500FF7500FF7500FF75
00FF7500FF7500FF8500FF8500FF8500FF9400FFA300FFD100E1FFCC00FFBD00FFFF00F5
00E1FF00FFF000FFD100FFC200FFB300FFB300FFB300FFA300FFA300FFA300FFB300FFB3
00FFB300FFB300FFC200FFD100FFE10047FFAE00FF00B3FF00D1FF0094FF3300FF00A3FF
00D1FF00E1FF00A3FF0094FF00FFD100FFC200FFB300FFB300FFA300FFA300FFA300FF94
00FF9400FF9400FF9400FF9400FFB300FFB300FF9400FF8500FF7500FF7500FF6600FF66
00FF6600FF6600FF6600FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF4700FF47
00FF4700FF4700FF4700FF47
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0005FF0005FF0014FF00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14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0005FF0005FF00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14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0000FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF4700FF4700FF4700FF4700FF4700FF57
00FF5700FF5700FF5700FF5700FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF66
00FF7500FF7500FF7500FF8500FF8500FF8500FF8500FF8500FF9400FF9400FF9400FF94
00FF9400FF9400FFA300FFA300FFB300FFB300FFC200FFC200FFC200FFC200FFD100FFD1
00FFE100F0FF0047FF00F0FF00F0FF00B3FF000AFF5100FF00A3FF00D1FF00E1FF00E1FF
0066FF0094FF00C2FF00B3FF0085FF1400FF0500FF7000FFCC00FF5100FF7000FFFF00D7
0047FFBD00FF0047FF0500FFFF007AFA00FF8000FF000AFF0028FF2300FF00A3FF00B3FF
00B3FF9E00FF00A3FF0066FF0094FF00C2FF00D1FF00D1FF00D1FF00C2FF00B3FF00A3FF
0066FFFA00FF0047FF5100FF0028FF0085FF0094FF00B3FF00B3FF00C2FF00C2FF00C2FF
00C2FF00C2FF00C2FF00C2FF00C2FF00C2FF00C2FF00C2FF00B3FF00B3FF00A3FF0094FF
0085FF0075FF0066FF0057FF0057FF0047FF0047FF0038FF0019FF3300FFFF00D79E00FF
3300FF1400FF0500FF0500FF0500FF0500FF1400FF2300FF4200FF6100FF9E00FFFF00E6
CC00FF8F00FF6100FF6100FF7000FFFA00FFEB00FFBD00FFCC00FFFF00A8EB00FFBD00FF
BD00FFBD00FFDC00FFEB00FFFF00E6FF008AFF007AFF0099FF008AFF006BFF003DFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF005CFF00A8FF00D7FF00F5FA00FFEB00FF
DC00FFAE00FF9E00FF9E00FF9E00FFAE00FFEB00FFFF00A8BD00FF8000FF6100FF5100FF
4200FF4200FF3300FF3300FF4200FF4200FF5100FF6100FF8000FFFF00F5FF0000FF003D
FF00E6FF00D78F00FF4200FF1400FF0500FF000AFF0019FF0019FF0019FF000AFF4200FF
FF00007000FF0028FF0047FF0047FF0047FF0057FF0047FF0047FF0047FF0038FF0028FF
000AFF3300FFDC00FFFF002E7000FF5100FFFA00FF0038FF0047FF0057FF0066FF0057FF
2300FF0047FF0066FFFF00B80066FF0094FF00A3FF00B3FF00B3FF00A3FF0094FF0066FF
8F00FF0066FF00A3FF00A3FF00A3FF0085FFFF008A0075FF00D1FF00E1FF00FFFF00FFFF
00FFF000FFF000FFF000FFF000FFF000FFF000FFF000FFF000FFFF00E1FF3300FF00E1FF
00FFFF00FFF000FFF000FFF000FFF000FFFF00F0FF00B3FF00C2FF00F0FF00FFE100FFE1
00FFD100FFD100FFD100FFD100FFD100FFD100FFD100FFD100FFD100FFD100FFD100FFD1
00FFE100FFE100FFE100FFF000FFFF00F0FF00E1FF00C2FF0047FF0500FF00C2FF00D1FF
00B3FF00B3FF0057FF5100FFFA00FF00C2FF00E1FF00D1FF0038FF00FFF000FFD100FFC2
00FFC200FFB300FFB300FFA300FFA300FFA300FF9400FF9400FF9400FF9400FF8500FF85
00FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF85
00FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF85
00FF9400FF9400FF9400FF9400FFA300FFA300FFB300FFB300FFC200FFD100FFD100FFF0
00E1FF00A3FFFF00E6000AFF00D1FF00FFFF00FFF000FFF000FFF000F0FF00E1FF0094FF
FF002E0085FF00C2FF00FFF000FFD100FFD100FFC200FFC200FFB300FFB300FFA300FF94
00FF9400FF8500FF8500FF8500FF8500FF8500FF7500FF7500FF7500FF7500FF7500FF75
00FF7500FF7500FF7500FF6600FF7500FF6600FF6600FF6600FF6600FF7500FF6600FF75
00FF6600FF7500FF7500FF7500FF7500FF7500FF7500FF8500FF8500FF8500FF8500FF85
00FF8500FF9400FF9400FF9400FF9400FFA300FFA300FFB300FFC200FFE100FFFF00B3FF
0057FF00E1FF0047FF00FFF000FFE100FFC200FFC200FFC200FFC200FFB300FFC200FFC2
00FFC200FFC200FFD100FFF000D1FF0085FF00A3FF00C2FF0094FF8000FF0500FFDC00FF
0057FF0094FF0038FF0500FF8000FF00F0FF00FFE100FFC200FFB300FFB300FFB300FFB3
00FFB300FFD10066FF2300FF0094FF00FFF000FFA300FF9400FF8500FF8500FF8500FF75
00FF7500FF7500FF6600FF6600FF6600FF6600FF6600FF5700FF5700FF5700FF5700FF57
00FF5700FF5700FF5700FF47
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00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14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0000FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF4700FF4700FF4700FF4700FF4700FF4700FF5700FF5700FF57
00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7500FF75
00FF7500FF7500FF8500FF8500FF9400FFE100FFA300FFA300FFA300FFA300FFA300FFA3
00FFA300FFA300FFB300FFB300FFC200FFE12300FF00E1FF00FFF000FFE100FFE100FFF0
00F0FF000AFF000AFF0094FF0085FFFF000000A3FF00A3FF00E1FF00FFFF00FFFF00FFFF
00FFFF00FFFF00F0FF0066FF2300FF0500FF00A3FF00D1FF00D1FF0094FF0019FF0057FF
0085FF0085FF0066FF0028FF5100FFFF0099DC00FF6100FF0038FF0057FF0057FF000AFF
0075FF0047FF0019FF0075FF0094FF00B3FF00B3FF00B3FF0094FF00A3FF00A3FF0094FF
0085FF0057FF3300FF1400FF0075FF0085FF0094FF00A3FF00A3FF00B3FF00B3FF00B3FF
00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A3FF00A3FF0094FF
0094FF0085FF0075FF0075FF0066FF0057FF0057FF0038FF0038FF000AFF0500FF3300FF
AE00FFFF00E68F00FF5100FF3300FF3300FF4200FF7000FF6100FF7000FF8F00FFFF00F5
DC00FFBD00FF8F00FF8000FF8F00FF9E00FFBD00FFDC00FFFA00FFFF007AFF00E6FA00FF
EB00FFEB00FFFA00FFFF00E6FF003DFF0099FF008AFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF000FFF0000FF001EFF0099FF007AFF0000FF008AFF00D7FF00E6DC00FF
CC00FFBD00FF9E00FF8F00FF8000FF7000FF8000FFEB00FF8F00FFFA00FF5100FF3300FF
3300FF2300FF2300FF2300FF3300FF3300FF5100FFFF00E6FF00D7FF003DBD00FFDC00FF
FA00FF7000FF4200FF3300FF1400FF000AFF0019FF0019FF0028FF0028FF0038FF0028FF
0028FF8000FF0047FF0057FF0066FF0066FF0066FF0066FF0066FF0057FF0038FF0500FF
6100FF000AFF4200FF0028FF0028FF0019FF6100FFFF00A88F00FF000AFF0019FF1400FF
5100FF0500FF0038FF0057FF0075FF0085FF0094FF0094FF0094FF0085FF0085FF0075FF
0038FF0028FF0028FFEB00FF0019FF2300FF00A3FF00B3FF00D1FF00F0FF00F0FF00FFFF
00FFFF00FFFF00FFF000FFF000FFF000FFFF00FFFF00F0FF00D1FF8000FF8000FF0075FF
00B3FF00F0FF00F0FF00F0FF00E1FF0094FF0019FF0028FF1400FF00F0FF00FFF000FFE1
00FFE100FFE100FFD100FFD100FFD100FFD100FFD100FFD100FFD100FFE100FFE100FFE1
00FFE100FFF000FFF000FFF000FFFF00F0FF00F0FF00D1FF00C2FF0085FF6100FF1400FF
0085FF0019FF00C2FF0075FF00E1FF00FFFF00FFF000FFF000FFE100FFE100FFC200FFC2
00FFB300FFB300FFB300FFA300FFA300FFA300FF9400FF9400FF9400FF9400FF9400FF85
00FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF85
00FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF9400FF8500FF9400FF9400FF94
00FF9400FF9400FF9400FFA300FFA300FFA300FFB300FFB300FFB300FFC200FFC200FFD1
00FFE100E1FF00F0FF00C2FF7000FF0075FF00D1FF00E1FF00C2FF0047FF0075FF00D1FF
00F0FF00C2FF00D1FF00FFD100FFC200FFC200FFB300FFB300FFA300FFA300FF9400FF94
00FF9400FF9400FF8500FF8500FF8500FF8500FF8500FF7500FF7500FF7500FF7500FF75
00FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF75
00FF7500FF7500FF7500FF7500FF8500FF8500FF8500FF9400FFD100FFE100FFA300FFA3
00FF9400FF9400FFA300FFA300FFA300FFA300FFB300FFB300FFC200FFE100E1FF1400FF
2300FFFF00E600A3FF00B3FF00F0FF00FFE100FFD100FFD100FFC200FFC200FFC200FFC2
00FFD100FFD100FFD100FFE100FFF000FFFF00F0FF00E1FF00C2FF00A3FF0500FF0047FF
00B3FF00D1FF00E1FF00F0FF00FFF000FFE100FFD100FFD100FFC200FFC200FFC200FFC2
00FFD100FFF000F0FF000AFF00FFFF00FFE100FFC200FFA300FF9400FF9400FF9400FF94
00FF9400FFA300FF9400FF8500FF7500FF7500FF6600FF6600FF6600FF5700FF5700FF57
00FF5700FF5700FF5700FF57
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00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14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
00FF0A00FF0A05FF0005FF0005FF0005FF0005FF0000FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF1900FF1900FF1900FF1900FF1900FF1900FF2800FF1900FF1900FF28
00FF2800FF2800FF2800FF2800FF3800FF2800FF3800FF3800FF3800FF3800FF3800FF38
00FF4700FF3800FF4700FF4700FF4700FF4700FF4700FF5700FF5700FF5700FF6600FF85
00FFB300FF8500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF75
00FF8500FF8500FF8500FF9400FFB30085FF00FFF000FFD100FFC200FFB300FFB300FFB3
00FFB300FFB300FFC200FFE100FFF000FFF000C2FF0075FF00E1FF00FFFF00F0FF00A3FF
00D1FF0075FF1400FF0019FFFF005C00A3FF00D1FF00F0FF00FFF000FFF000FFF000FFE1
00FFE100FFF000FFF000FFFF00FFFF00FFFF00FFFF00FFFF00F0FF00F0FF00E1FF00D1FF
00C2FF00B3FF0094FFAE00FF0028FF7000FFBD00FF9E00FF0038FF0038FF0028FF0019FF
000AFFFF00F5FA00FF000AFF1400FF0057FF0057FF000AFF0038FF0066FF0066FFDC00FF
4200FF000AFFAE00FF0019FF0028FF0057FF0075FF0085FF0094FF0094FF0094FFFF0000
0094FF0094FF0066FF0066FF0094FF00A3FF00A3FF00A3FF00A3FF0094FF0094FF0094FF
0085FF0085FF0075FF0075FF0066FF0057FF0038FF0038FF0028FF0019FF000AFF5100FF
6100FF8F00FFFF0000AE00FF7000FF8F00FFDC00FFFF00009E00FF9E00FFDC00FFFF00B8
FF008AEB00FFCC00FFAE00FFAE00FFAE00FFBD00FFCC00FFEB00FFFF0000FF004CFF007A
FF00D7FF00E6FF00E6FF00E6FF00D7FF00B8FF0099FF008AFF006BFF003DFF001EFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF000FFF005CFF008AFF00B8FF00D7FF00E6FF00F5FF00C7FF002EFF001EFF007A
FF00D7FF00F5CC00FF8000FF7000FF6100FF5100FF5100FF5100FF4200FF3300FF2300FF
2300FF1400FF1400FF1400FF1400FF2300FF9E00FF4200FF3300FFFF007A4200FF5100FF
8F00FFDC00FFEB00FF3300FF1400FF0500FF000AFF0028FF0038FF0038FF0047FF0047FF
0057FF0057FF0066FF0066FF0066FF0075FF0075FF0075FF0075FF0066FF0047FF0019FF
0066FF0066FF6100FF0066FF0066FF0057FF0038FF000AFF0019FF4200FFFF008AFF0000
FF00005100FF0028FF0038FF0057FF0066FF0066FF0038FF0038FF0019FF0047FF0028FF
FA00FF0057FF0075FF0094FF00A3FF00B3FF00C2FF00D1FF00E1FF00E1FF00F0FF00F0FF
00F0FF00FFFF00FFFF00F0FF00FFFF00F0FF00F0FF00F0FF00E1FF00B3FF0075FF7000FF
0057FF00C2FF00D1FF00C2FF0075FF0038FF0066FF00B3FF00C2FF00E1FF00FFFF00FFF0
00FFE100FFE100FFE100FFE100FFE100FFE100FFE100FFE100FFE100FFE100FFF000FFF0
00FFF000FFF000FFFF00FFFF00F0FF00F0FF00B3FF00B3FF0094FF2300FF00A3FF00D1FF
00E1FF00F0FF00FFFF00FFFF00FFF000FFE100FFE100FFE100FFD100FFD100FFC200FFC2
00FFB300FFB300FFB300FFA300FFA300FFA300FFA300FF9400FF9400FF9400FF9400FF94
00FF9400FF9400FF9400FF9400FF8500FF9400FF8500FF8500FF8500FF9400FF8500FF85
00FF9400FF9400FF9400FF9400FF9400FF9400FF9400FF9400FF9400FF9400FF9400FF94
00FF9400FF9400FFA300FFA300FFA300FFA300FFB300FFB300FFB300FFC200FFC200FFD1
00FFD100FFE100FFF000FFFF00F0FF00D1FF0094FF00A3FF00C2FF00F0FF00F0FF00FFF0
00FFE100FFE100FFD100FFC200FFC200FFB300FFB300FFA300FFA300FFA300FF9400FF94
00FF9400FF9400FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF7500FF75
00FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF75
00FF7500FF8500FF7500FF8500FF8500FF9400FFB38F00FF0094FF00FFFF00FFD100FFC2
00FFD100FFC200FFFF00FFC200FFB300FFC200FFB300FFC200FFD100FFE100FFF000F0FF
00A3FF2300FF0094FF00F0FF00FFF000FFE100FFE100FFE100FFD100FFD100FFD100FFD1
00FFD100FFE100FFE100FFF000FFF000FFFF00F0FF00E1FF00A3FF0019FF6100FFBD00FF
0057FF00C2FF00F0FF00FFFF00FFF000FFF000FFE100FFE100FFD100FFD100FFD100FFE1
00FFE100FFFF0019FF0094FF0094FF00FFE100FFC200FFB300FFB300FFC20057FF4200FF
00FFF00038FF00FFE100FFC200FF9400FF8500FF7500FF6600FF6600FF6600FF6600FF66
00FF6600FF5700FF5700FF66
14FF0014FF0005FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00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14FF0014FF0014FF0005FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00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14FF0014FF0014FF0014FF0005FF0005FF0014FF0014FF0014FF0014FF0014FF0014FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0000FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF2800FF2800FF28
00FF2800FF2800FF2800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF4700FF47
00FF4700FF4700FF4700FF4700FF5700FF5700FF5700FF5700FF6600FF6600FF8500FFB3
00F0FF00D1FF00FFFF00F0FF00FF9400FF8500FF8500FF8500FF8500FF8500FF8500FF94
00FF940038FF00FFC200FFC200FFD100FFFF3300FF00C2FF00FFE100FFD100FFD100FFD1
00FFD100FFD100FFE100FFF000FFFF00E1FF00A3FF2300FF0028FF0047FF0038FF000AFF
0075FF4200FF00F0FF00F0FF00E1FF00C2FF00FFF000FFE100FFE100FFD100FFD100FFD1
00FFD100FFD100FFD100FFD100FFD100FFE100FFE100FFE100FFF000FFFF00F0FF00E1FF
00D1FF00B3FF00A3FF0085FFBD00FF0066FF00A3FF0094FF00C2FF00C2FF00B3FF0094FF
FF00F50066FF0038FF00A3FF00A3FF0094FF8F00FF9E00FF0057FF0047FF0038FF000AFF
FA00FFFF00F5FF00009E00FF7000FF0019FF0038FF0047FF0057FF0057FF0057FF0028FF
AE00FF2300FF0038FF0066FF0075FF0085FF0085FF0085FF0075FF0075FF0047FF0038FF
0066FF0066FF0066FF0057FF0057FF0038FF0028FF0500FF8000FF5100FF2300FF4200FF
8F00FFAE00FF9E00FFDC00FFFF006BFF0000FF0000FF0000FF0000FF00B8FF00D7FF000F
FF0000FF0099FF00F5FF00C7FF007AFF00A8FF003DFF00E6FF00F5FF00C7FF0000FF0000
FF0000FF004CFF008AFF0099FF008AFF0000FF002EFF0000FF001EFF001EFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00B8FF008AFF0099EB00FFCC00FFBD00FFBD00FFDC00FFFF00B8FF00E6
DC00FFFF0099FF00E6DC00FFEB00FF8F00FF6100FF4200FF4200FF3300FF2300FF2300FF
1400FF0500FF0500FF000AFF000AFF000AFF000AFF000AFF000AFF000AFF0500FF1400FF
4200FF7000FFFF0000FF00008F00FF7000FFFF008AFF00B80038FF0047FF0047FF0057FF
0057FF0066FF0066FF0075FF0075FF0085FF0085FF0085FF0094FF0085FF0094FF0094FF
0094FF0094FF0094FF0094FF0085FF0085FF0066FF0038FF000AFF6100FF0500FF0028FF
0038FF0019FF3300FF0500FF8000FFDC00FF1400FF7000FF7000FFDC00FFFF004CFF003D
6100FF8000FF1400FF0075FF0094FF00A3FF00B3FF00C2FF00C2FF00C2FF00D1FF00C2FF
00D1FF00D1FF00D1FF00B3FF00D1FF00E1FF00E1FF00D1FF00D1FF00C2FF00B3FF0094FF
000AFF0047FF4200FF0038FF0066FF00B3FF00C2FF00E1FF00F0FF00F0FF00FFFF00FFFF
00FFF000FFF000FFF000FFF000FFF000FFF000FFF000FFF000FFFF00FFFF00E1FF6100FF
00C2FF00E1FF00E1FF00E1FF00E1FF00D1FF00A3FF0075FF6100FF0047FF1400FF00C2FF
00F0FF00FFFF00FFFF00FFF000FFE100FFE100FFE100FFD100FFD100FFC200FFC200FFC2
00FFB300FFB300FFB300FFB300FFB300FFA300FFA300FFA300FFA300FFA300FFA300FF94
00FF9400FF9400FFA300FFA300FFA300FF9400FF9400FF9400FFA300FFA300FFA300FFA3
00FFA300FFB300FFD1DC00FF00FFA300FFA300FFA300FFA300FFA300FFA300FFA300FFA3
00FFA300FFA300FFA300FFB300FFA300FFB300FFB300FFB300FFC200FFC200FFC200FFD1
00FFD100FFE100FFF000F0FF00E1FF00C2FF1400FF00B3FF00F0FF00FFFF00FFF000FFE1
00FFD100FFD100FFD100FFC200FFB300FFB300FFB300FFA300FFA300FFA300FFA300FF94
00FF9400FF9400FF9400FF9400FF9400FF8500FF8500FF8500FF8500FF8500FF8500FF85
00FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF85
00FF8500FF8500FF8500FF8500FF9400FF9400FFA300FFB300FFD100FFF000D1FFEB00FF
BD00FF00D1FF00FFFF00FFF000FFF000FFF000FFF000FFE100FFE100FFF000FFF000E1FF
00B3FF0038FF0094FF00B3FF00E1FF00FFFF00FFF000FFF000FFE100FFE100FFE100FFF0
00FFF000FFF000FFFF00C2FF0075FF00B3FF00D1FF00C2FF00B3FFFF00F51400FF0057FF
0075FF00C2FF00D1FF00D1FFBD00FF00B3FF00F0FF00F0FFFF000000F0FF00FFFF00FFFF
00F0FF00F0FF00B3FF0094FF00E1FF00E1FFFF00E600C2FF5100FF0075FF00A3FF00FFFF
6100FF00FFC200FFA300FF9400FF8500FF7500FF7500FF7500FF7500FF6600FF6600FF66
00FF6600FF6600FF6600FF66
14FF0014FF0014FF0014FF0014FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00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14FF0014FF0014FF0014FF0014FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00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14FF0014FF0014FF0014FF0014FF0014FF0005FF0005FF0005FF0005FF0005FF0005FF00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14FF0014FF0014FF0014FF0014FF0014FF0005FF0005FF0005FF0005FF0005FF0005FF00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14FF0014FF0014FF0014FF0014FF0014FF0005FF0005FF0005FF0005FF0005FF0005FF00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14FF0014FF0014FF0014FF0014FF0014FF0005FF0005FF0005FF0005FF0005FF0005FF00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14FF0014FF0014FF0014FF0014FF0014FF0005FF0005FF0005FF0005FF0005FF0005FF00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14FF0014FF0014FF0014FF0014FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00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05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00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05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0000FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF2800FF2800FF2800FF28
00FF3800FF3800FF4700FF4700FF5700FF6600FF8500FF9400E1FFFA00FF00FFD100FFA3
00FFA300FFA300FFD100C2FF00FFF000FFD100FFD10057FF00E1FF00FFFF00E1FF2300FF
FF0000BD00FF2300FF0094FF00B3FF00C2FF0057FF0500FFFF0000FF00005100FF0075FF
0057FF00D1FF0094FF0028FF00E1FF00E1FF00D1FF0075FF00A3FF000AFF00C2FF00F0FF
00FFFF00FFE100FFE100FFD100FFC200FFC200FFC200FFC200FFC200FFD100FFC200FFB3
00FFB300FFB300FFB300FFA300FFA300FFA300FFA300FFA300FFA300FFA300FFA300FFA3
00FFA300FFA300FFA300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC200FFC2
00FFC200FFC200FFD100FFD100FFD100FFD100FFD100FFD100FFE100FFE100FFE100FFE1
00FFE100FFF000FFF000FFFF00F0FF00A3FF00E1FF00E1FF00E1FF00D1FF00B3FF0085FF
0500FF0085FF00B3FF00B3FF00C2FF00C2FF00B3FF00B3FF00B3FF00A3FF00A3FF0075FF
0085FF0094FF0094FF0085FF0075FF0019FF3300FF0038FFDC00FF1400FF0028FF0028FF
0500FF000AFF1400FF000AFF1400FF3300FFFF00F54200FF4200FF6100FF8F00FFBD00FF
DC00FFFF00B8FF004CFF0099FF0099FF004CFF000FFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF001EFF002EFF003DFF004CFF005CFF004CFF004CFF003D
FF0000FF0000FF000FFF005CFF0099FF00A8FF00C7FF00D7FF00D7FF00D7FF00C7FF0099
FF0099FF00D7FF00A8FF0099FA00FFFA00FFFF00F5FF00C7FF0000FF000FFA00FFCC00FF
AE00FF9E00FF8F00FF8000FF8000FF9E00FFFA00FFFA00FF4200FF3300FF2300FF2300FF
2300FF1400FF1400FF2300FF3300FF5100FF8F00FFFF00007000FF1400FF000AFF0019FF
0028FF0038FF0047FF0047FF0047FF0057FF0057FF0057FF0057FF0057FF0057FF0057FF
0057FF0047FF0047FF0028FF0500FF5100FF4200FF6100FF0047FF0057FF0066FF0075FF
0075FF0085FF0075FF0066FF000AFFFF002E0066FF0019FF5100FF0075FF00C2FF00C2FF
00D1FF00D1FF00D1FF00D1FF00D1FF00D1FF00D1FF00D1FF00D1FF00D1FF00C2FF00C2FF
00C2FF00B3FF0094FF0085FF0066FF1400FF0028FF0075FFDC00FFFF00C70028FF0094FF
00B3FF00C2FF00D1FF00D1FF00D1FF00D1FF00C2FF00B3FF0019FF0047FF0085FF000AFF
0085FF0094FF00A3FF0094FF0075FF0057FF000AFFEB00FFFF008AFF0000FF00F5AE00FF
7000FFFF00000038FF8F00FF0028FF2300FFDC00FF6100FF2300FFFF00D74200FF0047FF
0057FF0085FF0085FF5100FF0047FF0038FF0094FF0094FF0085FF8000FF0038FF0038FF
000AFF7000FFDC00FFBD00FF4200FF8F00FFFF00D7FF0000FF0000FF0000FF0000FF0099
FF00A80038FF0094FF00B3FF00B3FF00D1FF00E1FF00E1FF00E1FF00F0FF00F0FF00E1FF
00C2FF0075FF0075FF0094FF0500FF00B3FF00F0FF00FFF000FFE100FFE100FFE100FFE1
00FFE100FFE100FFE100FFF000FFF000FFFF00E1FF00C2FF0066FF0075FFFA00FF00A3FF
00D1FF00F0FF00FFFF00FFF000FFE100FFE100FFD100FFE100FFD100FFD100FFD100FFD1
00FFD100FFE100C2FF0085FF0094FF00D1FF00E1FF00D1FF00A3FFFF00000094FF00C2FF
00D1FF00C2FF00B3FF00B3FF0094FF0038FF5100FF0019FF0094FF00A3FF00C2FF00C2FF
00C2FF0085FF0047FF00C2FF00C2FF00A3FF8F00FF00E1FF00FFF000FFD100FFD100FFC2
00FFC200FFC200FFC200FFC200FFD100F0FF00A3FF0085FF000AFF00FFE100FFD100FFD1
00FFFF0085FF0038FF00B3FF00FFD100FFC200FFB300FFB300FFA300FFA300FFA300FFA3
00FFA300FFA300FFA300FFA300FFB300FFB300FFB300FFB300FFB300FFC200FFC200FFC2
00FFC200FFD100FFD100FFE100FFE100FFF000FFF000FFF000FFFF00F0FF00F0FF00D1FF
00A3FF0085FF0066FFAE00FFFF0000FA00FF0047FF0085FF00A3FF00A3FF00B3FF00A3FF
0094FF0047FF0066FF0085FF0085FF0075FF0057FF0038FF0019FF7000FFDC00FFFF0000
9E00FF4200FF5100FFAE00FFFF0000EB00FF7000FF9E00FF000AFF0500FFFA00FF5100FF
FF006B8F00FF0094FF00B3FF00D1FF00FFFF00FFF000FFF000FFF000E1FF00FFE100FFD1
00FFC200FFC200FFB300FFB300FFB300FFB300FFB300FFD100FFB300FFB300FFB300FFC2
0094FF00FFC200FFB300FFA3
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0000FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF2800FF2800FF2800FF2800FF28
00FF3800FF3800FF3800FF4700FF4700FF5700FF6600FF7500FF9400FFD10094FF00FFD1
0094FF00FFE100F0FF0075FF0500FF8F00FF00E1FF1400FF5100FFCC00FFFF00E60057FF
CC00FF4200FFCC00FF3300FF0028FF5100FF0075FF0085FF0094FF0066FF0085FF00E1FF
00FFFF00FFFF0038FF00F0FF00FFF000FFF000FFFF00F0FF00C2FFEB00FF00D1FF00F0FF
00FFF000FFE100FFD100FFC200FFC200FFC200FFB300FFB300FFB300FFB300FFB300FFB3
00FFB300FFB300FFA300FFA300FFA300FFA300FFA300FFA300FFA300FFA300FFA300FFA3
00FFA300FFA300FFA300FFA300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC2
00FFC200FFC200FFC200FFC200FFD100FFD100FFD100FFD100FFD100FFD100FFE100FFE1
00FFE100FFF000FFF000FFF000FFFF00FFFF00F0FF00F0FF00F0FF00E1FF00B3FF0500FF
DC00FF0085FF00B3FF00C2FF00C2FF00C2FF00C2FF00C2FF00B3FF00B3FF00B3FF00A3FF
00A3FF00A3FF0094FF0094FF0085FF0075FF0066FF0057FFCC00FF0500FF0038FF0038FF
0038FF0028FF0028FF0019FF000AFF0500FF2300FF2300FF3300FF8F00FFFF0099FF0000
FF00B8FF00A8FF00F5FF00E6FF00C7FF0099FF006BFF002EFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF001EFF002EFF004CFF005CFF006BFF007AFF007AFF005C
FF002EFF0000FF0000FF004CFF008AFF0099FF00B8FF00D7FF00E6FF00F5FF00E6FF0000
FF0099FF00F5FA00FFFF001EDC00FFDC00FFFF00F5FF00B8FF007AFF004CFF00F5FA00FF
FF00A89E00FF8000FF7000FF7000FF6100FF6100FF5100FF3300FF2300FF2300FF2300FF
1400FF1400FF1400FF1400FF2300FFDC00FF8000FF8000FFFF00D74200FFBD00FF0019FF
0038FF0038FF0047FF0057FF0057FF0057FF0057FF0066FF0066FF0066FF0066FF0066FF
0057FF0057FF0047FF2300FFFA00FFAE00FFFF006B8000FF0019FF0057FF0075FF0075FF
0085FF0085FF0094FF0085FF0085FF0094FF0094FF0075FF0047FF00B3FF00C2FF00D1FF
00D1FF00D1FF00D1FF00D1FF00E1FF00E1FF00E1FF00D1FF00D1FF00D1FF00D1FF00D1FF
00C2FF00B3FF0094FF000AFF0028FF2300FF0075FF0094FF0085FF3300FF0500FF0085FF
00B3FF00C2FF00D1FF00E1FF00E1FF00E1FF00D1FF00C2FF3300FF00A3FF00B3FF0066FF
0085FF00B3FF00B3FF00A3FF0057FFBD00FF6100FF0500FF8000FFEB00FFFF00991400FF
FF00E60019FF0047FF0066FF0066FFCC00FF0038FF0019FFFF0000FF00B85100FFBD00FF
9E00FF0047FF0057FF0028FF4200FF0066FF0075FF0075FF0047FF0028FF3300FF0028FF
000AFF2300FF9E00FFBD00FFCC00FFAE00FFFF0000FF006BDC00FFFF005CAE00FFBD00FF
3300FF0047FF0075FF0047FF00A3FF00C2FF00C2FF00A3FF00B3FF00B3FF00D1FF00D1FF
00C2FF00A3FF0028FF0066FF00B3FF00E1FF00F0FF00FFFF00FFF000FFF000FFF000FFE1
00FFF000FFF000FFF000FFF000FFFF00FFFF00F0FF00D1FF00B3FFFF000F00A3FF00D1FF
00E1FF00F0FF00FFFF00FFF000FFE100FFE100FFE100FFE100FFE100FFD100FFD100FFE1
00FFE100FFF000FFFF0094FFFF00E600A3FF0094FF00C2FF00A3FFBD00FF0085FF00B3FF
00C2FF00B3FF00B3FF000AFF0075FF0057FFAE00FF0047FF0075FF1400FF0085FF0094FF
00A3FF0085FF0057FF0057FFFF00990085FF00C2FF00E1FF00FFF000FFE100FFD100FFD1
00FFC200FFC200FFD100FFD100FFE100F0FF00C2FF0028FF00F0FF00FFF000FFE100FFF0
00F0FF0047FF0094FF0057FF00FFE100FFC200FFB300FFB300FFB300FFB300FFA300FFA3
00FFA300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC200FFC200FFC200FFC2
00FFD100FFD100FFD100FFE100FFE100FFF000FFF000FFF000FFFF00FFFF00F0FF00D1FF
0075FF0066FF0500FF0028FFFF005C8F00FF0038FFAE00FF0075FF0094FF0094FF0028FF
0075FF0038FF0047FF0075FF0075FF0066FF0047FF0038FF3300FF6100FFFF00F5FF0000
FF00B80500FF0500FF4200FF3300FFFF00001400FF0019FF0038FF000AFF2300FF0019FF
FF00C70057FF0094FF00C2FF00E1FF00F0FF00FFFF00FFFF00F0FFFF009900FFF000FFE1
00E1FF00FFD100FFC200FFB300FFB300FFC200FFD10038FF00FFE100FFC200FFD10075FF
00C2FF00FFD100FFB300FFB3
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00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05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00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05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00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05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00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05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00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05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00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05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00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05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00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05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00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05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0000FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF2800FF2800FF2800FF28
00FF2800FF2800FF3800FF3800FF3800FF4700FF4700FF4700FF4700FF4700FF4700FF47
00FF4700FF5700FF5700FF5700FF5700FF6600FF7500FF9400FFD100A3FF00E1FF00FFB3
00FF9400FF9400FFB300FFFF0019FF0047FF00FFC200FF9400FF9400FF8500FF8500FF85
00FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF94
00FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF85
00FF8500FF8500FF9400FF8500FF8500FF8500FF8500FF9400FF9400FF9400FF9400FF94
00FF9400FF9400FF9400FF9400FF9400FFA300FFA300FFA300FFA300FFA300FFA300FFB3
00FFB300FFB300FFB300FFB300FFB300FFC200FFC200FFC200FFD100FFC200FFD100FFD1
00FFD100FFD100FFD100FFE100FFE100FFE100FFE100FFF000FFF000FFF000FFF000FFF0
00FFFF00FFFF00FFFF00F0FF00F0FF00F0FF00E1FF00D1FF00C2FF0085FF1400FF1400FF
FF008A000AFF0028FF1400FFAE00FF0047FF0057FF0057FF0066FF0066FF0057FF0057FF
0047FF0038FF0019FF5100FF3300FF4200FF3300FF3300FF4200FF5100FF6100FF7000FF
8F00FFAE00FFBD00FFCC00FFEB00FFFF00F5FF00E6FF00C7FF0099FF003DFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF005CFF008AFF005CFF007AFF002EFF00A8
FF00D7EB00FFDC00FFCC00FFCC00FFCC00FFDC00FFEB00FFFF0099FF00F5DC00FFCC00FF
FF0000EB00FFFF00B8FF00B89E00FF6100FF5100FF5100FF5100FF5100FF5100FF6100FF
7000FF8000FFFF00A8FF004CFF0000FF0000FF0000FF00E68000FF6100FF4200FF2300FF
1400FF0500FF000AFF000AFF0019FF0028FF0028FF0038FF0038FF0047FF0047FF0057FF
0057FF0057FF0066FF0066FF0075FF0075FF0075FF0085FF0085FF0085FF0094FF0094FF
0094FF0094FF0094FF0094FF0094FF0094FF0094FF0085FF0057FF0500FF0066FF0075FF
0085FF0066FF1400FF0094FF00C2FF00D1FF00E1FF00E1FF00E1FF00F0FF00F0FF00F0FF
00F0FF00F0FF00F0FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFF000FFF000FFF000FFF000FFF000FFE100FFE1
00FFE100FFE100FFE100FFE100FFE100FFE100FFE100FFF000FFF000FFF000FFF000FFFF
00F0FF00E1FF00C2FF0094FF4200FF0038FF0094FF00D1FF00D1FF00C2FF0019FF0066FF
0057FF00C2FF00E1FF00F0FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F0FF
00E1FF00B3FF0047FF0038FF0500FF0094FF5100FF0066FF0094FF0094FF0094FF0075FF
0028FFEB00FF0500FF0075FF0094FF00A3FF00A3FF0094FF0057FF0047FF00B3FF00D1FF
00D1FF0075FF00FFFF00FFFF00FFFF00FFF000FFF000FFFF00F0FF00E1FF0047FF0057FF
00C2FF0038FF4200FF00B3FF00FFFF00FFF000FFF000FFF000F0FF00F0FF00F0FF00D1FF
00F0FF00F0FF00D1FF00B3FF8F00FF0085FF0038FF0028FF0075FF0057FF0085FF0066FF
00C2FF00C2FF00D1FF00B3FF0085FFFF00000085FF00A3FF0094FF00A3FF0085FF0500FF
7000FFFF0000FF00000038FF0019FF0047FF0019FFFF00A81400FFFF001EEB00FF3300FF
8000FFFA00FFCC00FF8F00FFFA00FF3300FF4200FF0047FF0066FF0066FFFF00D70094FF
00B3FF00B3FF00B3FF0075FF0085FF2300FF00B3FF00A3FF0094FF0028FFAE00FF5100FF
0057FFBD00FFFF00E60028FF0047FF0038FF000AFFFF00B8FF003DCC00FF5100FF1400FF
0038FF0085FF0019FF00A3FF0066FF1400FF00C2FF00E1FF00E1FF00F0FF00E1FF00D1FF
00C2FF0085FF0038FF0094FF00C2FF00E1FF00F0FF00FFFF00FFFF00FFFF00FFFF00FFFF
00F0FF00B3FF00B3FF00C2FF00C2FF00B3FF0500FFFF007A0057FF0094FF00B3FF00B3FF
00B3FF00A3FF00A3FF0085FF0066FF0057FF0047FF0019FF4200FFEB00FFEB00FFFF008A
FF0000FF0000FF0000FA00FFFF00008000FF0500FF0019FF6100FF0047FF0094FF00B3FF
00C2FF00D1FF00D1FF00D1FF00C2FF0085FF0094FF00A3FF00F0FF00FFFF00FFF000FFE1
00FFE100FFE100FFE100FFF000E1FF0075FF00C2FF00FFFF00F0FF00E1FF00FFE100FFE1
00FFE100FFF000FFF000FFFF00F0FF0019FF0085FF3300FF0085FF00B3FF00D1FF00D1FF
00A3FF0047FF00A3FF0085FF
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00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05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00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05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00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05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00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05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0000FF0A05FF0005FF00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05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00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05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0000FF0A05FF00
05FF0005FF0005FF0005FF0005FF0005FF0000FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF4700FF4700FF4700FF4700FF5700FF4700FF4700FF4700FF5700FF5700FF57
00FF5700FF5700FF5700FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF66
00FF6600FF6600FF6600FF6600FF6600FF6600FF7500FF6600FF6600FF6600FF6600FF75
00FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF75
00FF7500FF7500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF85
00FF8500FF9400FF9400FF9400FF9400FF9400FF9400FFA300FFA300FFA300FFA300FFB3
00FFB300FFB300FFC200FFC200FFC200FFD100FFE100C2FF00FFF000FFF000FFE100FFF0
00FFF000FFF000FFF000FFF000FFF000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00F0FF00F0FF00F0FF00F0FF00E1FF00E1FF00E1FF00D1FF00C2FF0094FF0094FF
0047FF0047FF0047FF9E00FFFF00F5FF00003300FF000AFF000AFF1400FF5100FFFF0000
FF00D78000FF7000FFBD00FF8F00FF5100FF5100FF5100FF6100FF8000FF9E00FFBD00FF
CC00FFFF00F5FF00A8FF0000FF006BFF008AFF004CFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF002EFF004CFF004CFF006BFF00B8FF00D7FF00E6FF00F5FF00F5FA00FFEB00FFDC00FF
CC00FFBD00FFAE00FF9E00FF9E00FF8F00FF8000FF8000FF8000FF8000FF8F00FF8000FF
7000FFBD00FF5100FF3300FF2300FF2300FF2300FF1400FF1400FF1400FF1400FF1400FF
FA00FF2300FF1400FF0500FF1400FF0500FF1400FF1400FF2300FF3300FF5100FFBD00FF
FF006BFF0000FF0000FF00F55100FF3300FF1400FF0500FF000AFF000AFF000AFF000AFF
1400FFFF00007000FF0028FF0047FF0057FF0066FF0075FF0085FF0094FF0094FF0094FF
00A3FF00A3FF00A3FF00B3FF00B3FF00B3FF00C2FF00C2FF00C2FF00C2FF00D1FF00D1FF
00D1FF00D1FF00D1FF00E1FF00E1FF00E1FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF
00F0FF00FFFF00FFFF00FFFF00FFFF00FFF000FFF000FFF000FFF000FFF000FFF000FFE1
00FFE100FFE100FFE100FFE100FFE100FFE100FFD100FFD100FFD100FFD100FFE100FFD1
00FFD100FFD100FFD100FFD100FFD100FFD100FFD100FFD100FFD100FFD100FFD100FFE1
00FFF000B3FF00E1FF00F0FF00FFF000FFE100FFD100FFD100FFD100FFD100FFD100FFD1
00FFD100FFD100FFD100FFD100FFD100FFD100FFD100FFD100FFD100FFD100FFD100FFD1
00FFE100FFE100FFE100FFE100FFF000FFF000FFF000FFFF00FFFF00F0FF00E1FF00D1FF
0047FF0066FF4200FF0075FF0057FF00B3FF00F0FF00FFFF00FFFF00FFF000FFF000FFE1
00FFE100FFD100FFD100FFD100FFC200FFC200FFC200FFC200FFC200FFC200FFB300FFB3
00FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC200FFD100FFE1
00FFF000F0FF00B3FF000AFFDC00FF00FFFF00FFFF0038FF0075FF0094FF00F0FF00FFF0
00FFE100FFD100FFD100FFD100FFD100FFD100FFE100FFE100FFE100FFFF00F0FF00D1FF
0500FF0057FF6100FF1400FF0075FF0094FF0075FF0075FFFF00E60075FF0028FFFF0000
0057FF0075FF9E00FF00B3FF00C2FF00C2FF00B3FF0057FF0038FF00B3FF00C2FF00C2FF
00A3FF0028FF00D1FF00FFFF00FFE100FFE100FFD100FFD100FFE100FFD100FFE100FFE1
00FFE100FFF000FFFF00F0FF00D1FF00A3FF0038FF00A3FF00D1FF00F0FF00FFFF00FFF0
00FFF000FFF000FFE100FFE100FFE100FFE100FFF000FFFF00F0FF00D1FF0094FF0057FF
0085FF00B3FF00C2FF00C2FF0094FF0028FF0066FF0075FF0066FF6100FFFF00F50057FF
0075FF0075FF0066FF0028FF0057FF0047FF0019FFFF003D8000FF0019FF0028FF0028FF
0019FF1400FFDC00FFDC00FF5100FFAE00FF6100FF0038FF0038FF0066FF0075FF0066FF
0028FF0057FF0075FF0066FF00A3FF0094FF0085FF0066FF3300FFBD00FFFF00A80047FF
0057FF0094FF00D1FF00F0FF00F0FF00FFFF00FFF000FFF000FFE100FFE100FFD100FFD1
00FFC200FFC200FFB300FFB300FFB300FFA300FFA300FFA300FFA300FFA300FFA300FFA3
00FFA300FFA300FFC200F0FF00FFC200FFB300FFB300FFB300FFE100FFC200FFB300FFB3
00FFB300FFB300FFB300FFC2
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0000FF0A05FF00
05FF0005FF0005FF0005FF0005FF0000FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF3800FF3800FF3800FF3800FF3800FF38
00FF4700FF3800FF3800FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF5700FF57
00FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF6600FF6600FF6600FF6600FF66
00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF75
00FF6600FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF75
00FF7500FF7500FF8500FF7500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF85
00FF9400FF9400FF9400FF9400FF9400FF9400FF9400FFA300FFA300FFA300FFB300FFB3
00FFB300FFC200FFC200FFC200FFD100FFE100FFFF4200FF00F0FF00FFFF00FFF000FFF0
00FFF000FFF000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00F0FF00F0FF00F0FF00F0FF00F0FF00E1FF00E1FF00E1FF00D1FF00B3FF0075FF2300FF
4200FF5100FFFF001EFF00F5EB00FF2300FF0019FF0038FF0028FF0500FF5100FF4200FF
8F00FF8000FFFF00F5FF0000FF00B88F00FF8F00FF7000FF7000FF8000FF8F00FFAE00FF
CC00FFEB00FFFF00E6FF005CFF0000FF001EFF002EFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF003DFF005CFF007AFF0099FF00B8FF00C7FF00D7FF00F5FA00FFEB00FFDC00FFCC00FF
CC00FFBD00FFAE00FF9E00FF9E00FF8F00FF8000FF7000FF7000FF7000FF6100FF6100FF
5100FF5100FF4200FF3300FF2300FF2300FF1400FF1400FF1400FF0500FF0500FF0500FF
0500FF0500FF0500FF000AFF0500FF0500FF0500FF1400FF1400FF3300FF5100FF8000FF
FF0000FA00FFCC00FFFF006B8F00FF6100FF3300FF2300FF3300FF2300FF1400FF1400FF
2300FF6100FF0500FF0019FF0028FF0028FF0047FF0066FF0085FF0085FF0094FF0094FF
00A3FF00A3FF00B3FF00B3FF00B3FF00B3FF00C2FF00C2FF00C2FF00C2FF00D1FF00D1FF
00D1FF00D1FF00E1FF00E1FF00E1FF00E1FF00F0FF00F0FF00F0FF00F0FF00F0FF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF000FFF000FFF000FFF000FFE100FFE1
00FFE100FFE100FFE100FFE100FFE100FFD100FFD100FFD100FFD100FFD100FFD100FFD1
00FFD100FFD100FFD100FFD100FFD100FFC200FFD100FFD100FFD100FFD100FFD100FFE1
00FFF000FFFF00FFE100FFE100FFE100FFD100FFD100FFD100FFD100FFC200FFC200FFC2
00FFD100FFD100FFD100FFC200FFC200FFD100FFD100FFD100FFD100FFD100FFD100FFD1
00FFD100FFE100FFE100FFE100FFE100FFF000FFF000FFF000FFFF00FFFF00F0FF00E1FF
00C2FF00A3FF4200FF0094FF00C2FF00E1FF00F0FF00FFFF00FFFF00FFFF00FFF000FFE1
00FFD100FFD100FFD100FFD100FFC200FFC200FFC200FFC200FFB300FFB300FFC200FFB3
00FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC200FFC200FFFF
0085FF00D1FF8000FF00D1FF00FFFF00FFF000FFF000FFFF00D1FF000AFF00C2FF00F0FF
00FFE100FFD100FFD100FFD100FFC200FFC200FFD100FFD100FFE100FFF000B3FF0075FF
0057FF00A3FF00B3FF0038FF0094FF00B3FF00B3FF00B3FF00A3FF0094FF0047FF3300FF
0057FF0094FF00B3FF00C2FF00D1FF00D1FF00C2FF0094FF0028FF00B3FF00E1FF00F0FF
00E1FF00F0FF0075FF00FFF000FFD100FFD100FFD100FFD100FFD100FFD100FFD100FFE1
00FFE100FFF000FFFF00E1FF0066FF1400FF00B3FF0057FF0075FF00E1FF00FFFF00FFF0
00FFE100FFE100FFD100FFD100FFD100FFE100FFE100FFFF00E1FF000AFF0057FF0094FF
0066FF00C2FF00E1FF00E1FF4200FF00C2FF0094FF00B3FF0075FF8000FF0019FFBD00FF
0047FF0500FF0028FFBD00FF0038FF0038FFAE00FFFF00005100FFFF0099CC00FF000AFF
0500FFFF000FCC00FFFF00008000FF1400FF000AFF0047FF0066FF0075FF0085FF0085FF
0057FF0066FF00A3FF00B3FF00B3FF00B3FF00A3FF0075FF0038FF0500FF0500FF0038FF
0094FF00C2FF00D1FF00E1FF00F0FF00FFFF00FFFF00FFF000FFF000FFE100FFD100FFD1
00FFC200FFC200FFB300FFB300FFA300FFA300FFA300FFA300FF9400FF9400FF9400FF94
00FF9400FFA300FFB300FFA300FFA300FFA300FFA300FFA300FFA300FFA300FFA300FFA3
00FFA300FFA300FFB300FFB3
05FF0005FF0005FF0000FF0A05FF0005FF0005FF0005FF0005FF0005FF0000FF0A00FF0A
05FF0005FF0005FF0005FF0005FF0000FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF57
00FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF6600FF66
00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF66
00FF6600FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF75
00FF7500FF7500FF7500FF7500FF7500FF8500FF8500FF8500FF8500FF8500FF8500FF85
00FF8500FF8500FF9400FF9400FF9400FF9400FF9400FFA300FFA300FFB300FFB300FFB3
00FFC200FFC200FFC200FFD100FFE100FFF000F0FF000AFF00C2FF00F0FF00FFFF00FFFF
00FFFF00FFFF00FFFF00E1FF0094FF00E1FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF
00F0FF00F0FF00F0FF00E1FF00E1FF00E1FF00E1FF00D1FF00D1FF00C2FF0094FF0085FF
3300FF0038FF0047FF2300FF0028FF0047FF0047FF0047FF0038FF0028FF000AFF0500FF
1400FF4200FF8F00FFFF003DFF006BFA00FFDC00FF8F00FF8F00FFAE00FF9E00FFAE00FF
FF0099FF00F5FF00E6FF00B8FF008AFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF000FFF004CFF007AFF008AFF00A8FF00A8FF0099FF00E6FF00F5FA00FFEB00FFDC00FF
CC00FFBD00FFBD00FFAE00FF9E00FF8F00FF8000FF7000FF7000FF6100FF6100FF5100FF
4200FF4200FF3300FF3300FF2300FF1400FF1400FF1400FF0500FF0500FF0500FF0500FF
000AFF000AFF000AFF000AFF000AFF000AFF000AFF0500FF2300FF4200FF7000FFAE00FF
8F00FFFF00E67000FF9E00FFFF00008F00FF5100FF5100FFCC00FFFF00F54200FF4200FF
8000FFFF004C7000FF5100FF3300FFFF00A8FF00F5DC00FF0075FF0085FF0094FF0094FF
00A3FF00A3FF00A3FF00B3FF00B3FF00B3FF00C2FF00C2FF00C2FF00C2FF00D1FF00D1FF
00D1FF00E1FF00E1FF00E1FF00E1FF00E1FF00F0FF00F0FF00F0FF00F0FF00F0FF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFF000FFF000FFF000FFF000FFF000FFF000FFF000FFE1
00FFE100FFE100FFE100FFE100FFE100FFD100FFD100FFD100FFD100FFD100FFD100FFD1
00FFD100FFC200FFD100FFC200FFD100FFC200FFC200FFC200FFC200FFC200FFD100FFD1
00FFD100FFD100FFD100FFD100FFD100FFC200FFD100FFC200FFC200FFC200FFC200FFC2
00FFC200FFC200FFC200FFC200FFC200FFC200FFD100FFC200FFD100FFD100FFD100FFD1
00FFD100FFD100FFE100FFE100FFE100FFE100FFF000FFF000FFFF00FFFF00F0FF00E1FF
00D1FF0094FFEB00FF0057FF00C2FF00E1FF00F0FF00FFFF00FFFF00FFF000FFE100FFE1
00FFD100FFD100FFD100FFC200FFC200FFC200FFB300FFB300FFB300FFB300FFB300FFB3
00FFA300FFA300FFA300FFA300FFB300FFA300FFA300FFB300FFB300FFB300FFC200FFD1
00C2FF0066FF3300FF00E1FF00FFE100FFD100FFD100FFF00057FF1400FF0094FF00FFFF
00FFD100FFC200FFC200FFC200FFC200FFC200FFC200FFD100FFE100FFFF00A3FF1400FF
00E1FF00E1FF00D1FF0047FF00A3FF00D1FF00D1FF00D1FF00B3FF00A3FF0038FFCC00FF
0047FF00A3FF00C2FF00D1FF00E1FF00E1FF00D1FF0047FFFF00F5DC00FF00F0FF00FFFF
00FFF000FFF000F0FF00FFD100FFD100FFC200FFC200FFC200FFC200FFC200FFD100FFD1
00FFE100FFF000E1FF00A3FF3300FF0038FF00E1FF00D1FF0038FFBD00FF00F0FF00FFF0
00FFE100FFD100FFD100FFD100FFD100FFD100FFE100FFF0CC00FF0075FF00D1FF00C2FF
FF009900D1FF00F0FF00F0FF00F0FF00E1FF00E1FF00D1FF00B3FF0075FF0066FF1400FF
2300FF000AFF8000FF0500FF0019FF0500FFEB00FFFF00C7FF00B8FF003D4200FF2300FF
3300FF8F00FFFF0000FF002EFF00001400FF0019FF0038FF0057FF0075FF0094FF0094FF
0094FF00A3FF00B3FF00C2FF00C2FF00C2FF0094FF2300FF0047FF0066FF0066FF000AFF
0066FF00A3FF00D1FF00E1FF00E1FF00F0FF00F0FF00FFFF00FFF000FFF000FFE100FFD1
00FFC200FFC200FFB300FFB300FFA300FFA300FFA300FF9400FF9400FF9400FF9400FF94
00FF9400FF9400FF9400FF9400FF9400FF9400FF9400FF9400FF9400FF9400FF9400FF94
00FFA300FFA300FFA300FFB3
05FF0005FF0005FF0000FF0A05FF0005FF0005FF0005FF0005FF0005FF0000FF0A00FF0A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05FF0005FF0005FF0000FF0A00FF0A05FF0005FF0005FF0005FF0000FF0A00FF0A00FF0A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05FF0005FF0000FF0A00FF0A00FF0A00FF0A05FF0005FF0000FF0A00FF0A00FF0A00FF0A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05FF0000FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A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00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A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00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A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00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A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00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A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00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A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00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A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00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A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00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A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00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A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00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF0A00FF0A00FF0A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00FF0A00FF0A00FF0A00FF1900FF0A00FF0A00FF0A00FF0A00FF1900FF0A00FF0A00FF0A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00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A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00FF0A00FF0A00FF1900FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF1900FF1900FF0A00FF0A00FF0A00FF0A00FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF2800FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF28
00FF2800FF1900FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF3800FF2800FF2800FF2800FF2800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF4700FF4700FF4700FF47
00FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF47
00FF5700FF5700FF5700FF5700FF5700FF5700FF6600FF5700FF5700FF6600FF6600FF66
00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7500FF7500FF75
00FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF8500FF85
00FF8500FF8500FF8500FF8500FF8500FF9400FF9400FF9400FF9400FF9400FF9400FF94
00FFA300FFA300FFA300FFB300FFB300FFB300FFC200FFC200FFD100FFD100FFE100FFF0
00FFF000FFFF00FFFF00E1FF0038FF0094FF00B3FF0094FF0057FFFF006B1400FF0075FF
00A3FF00B3FF00C2FF00C2FF00B3FF00B3FF00A3FF00A3FF0094FF0094FF0094FF0094FF
0085FF0085FF0066FF0057FF0057FF0057FF0047FF0028FF000AFF1400FF2300FF3300FF
7000FF9E00FFFF00E6FF005CFF007AFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF000FFF0000FF001EFF003DFF0000FF004CFF0000FF008AFF0000FF00B8FF00A8FF004C
FF00B8FF00D7FF00D7FF006BFF001EFF008AFF00B8FF00F5FA00FFFA00FFFF003DFF003D
EB00FFEB00FFFF006BFA00FFFA00FFFA00FFFF00F5FF00D7FF0099FF0000FF0000FF006B
FF00A8FF00B8FF0000FF007AFF004CFF000FFF001EFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF002EFF004C
FF006BFF006BFF00A8FF00C7FF00D7FF00E6FF00F5EB00FFDC00FFCC00FFCC00FFFA00FF
FF00D7FF005CFF00E6AE00FFEB00FF4200FF3300FF3300FF2300FF2300FF2300FF2300FF
2300FF2300FF6100FF8000FF7000FF7000FFEB00FFFF00D75100FF000AFF0019FF0038FF
0047FF0057FF0066FF0066FF0066FF0066FF0066FF0075FF0075FF0075FF0075FF0075FF
0075FF0075FF0075FF0085FF0085FF0085FF0094FF0094FF0094FF0094FF0094FF0094FF
0085FF0085FF0085FF0075FF0057FF0019FF6100FF4200FF0500FF2300FF0047FF0057FF
0057FF0057FF0047FF0028FFFF00F5FF00000500FF0047FF0066FF0075FF0075FF0075FF
0057FF000AFF000AFFAE00FF8F00FF9E00FFFF00007000FF000AFF0028FF0019FF0500FF
0019FFFF00C7FF008A2300FFCC00FFFA00FF7000FF0019FF2300FF0057FF0066FF2300FF
CC00FF0085FF00B3FF00E1FF00F0FF00FFF000FFE100FFE100FFD100FFD100FFC200FFC2
00FFB300FFB300FFB300FFB300FFA300FFA300FFA300FFA300FFA300FFA300FFA300FFA3
00FFA300FF9400FFA300FFA300FF9400FF9400FFA300FF9400FF9400FF9400FF9400FF94
00FFA300FF9400FF9400FFA300FFA300FFA300FFA300FFA300FFA300FFA300FFB300FFB3
00FFB300FFC200FFC200FFD100FFE100FFF000FFFF0066FF0500FF0019FF0066FF00FFF0
00FFE100FFD100FFC200FFB300FFA300FFA300FFA300FF9400FF9400FF9400FF9400FF94
00FF9400FF9400FFA300FFB300FFF000FFC200FF9400FF9400FF8500FF8500FF7500FF75
00FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF75
00FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF85
00FF8500FF8500FF8500FF8500FF8500FF9400FF9400FFA300FFA300FFA300FFB300FFB3
00FFC200FFC200FFD100FFF000D1FF0094FFFF00A80094FF00E1FF00FFF000FFE100FFE1
00FFE100FFF0FA00FF0066FF00B3FFBD00FF2300FF00E1FF00FFFF0085FF00FFF000FFC2
00FFB300FFA300FFA300FF9400FF9400FF8500FF8500FF8500FF8500FF8500FF7500FF75
00FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF75
00FF7500FF7500FF7500FF8500FF8500FF8500FF8500FF9400FFA300FFC200F0FF00B3FF
00F0FF0085FF0028FF00D1FFFF00C700A3FF00FFE100FFE100FFF000FFF000F0FF00A3FF
00B3FF00F0FF00FFF000FFE100FFE100FFD100FFD100FFD100FFD100FFD100FFE100FFE1
00FFF000FFFF00F0FF00D1FF00B3FF1400FFCC00FF0047FF0066FF00B3FF00B3FF1400FF
0066FF00F0FF00FFE100FFC200FFC200FFB300FFB300FFB300FFB300FFA300FFA300FFB3
00FFB300FFB300FFD13300FF00FFFF00F0FF00FFF00057FF00FFFF00FFB300FFA300FF85
00FF7500FF7500FF6600FF6600FF6600FF6600FF5700FF5700FF5700FF5700FF5700FF57
00FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF66
00FF6600FF6600FF7500FF75
00FF1900FF1900FF1900FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A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00FF1900FF1900FF1900FF1900FF0A00FF0A00FF0A00FF1900FF1900FF0A00FF0A00FF0A
00FF0A00FF1900FF1900FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF1900FF0A00FF0A
00FF0A00FF0A00FF0A00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF2800FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF47
00FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF57
00FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF57
00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF75
00FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF8500FF8500FF85
00FF8500FF8500FF9400FF8500FF8500FF9400FF9400FF9400FF9400FF9400FF9400FFA3
00FFA300FFA300FFB300FFB300FFB300FFC200FFC200FFD100FFD100FFE100F0FF0038FF
00E1FF00E1FF00D1FF00B3FF0075FFFF00D7000AFF0500FF8000FF0094FF0057FF00B3FF
00C2FF00D1FF00D1FF00D1FF00D1FF00C2FF00C2FF00C2FF00C2FF00B3FF00B3FF00A3FF
00A3FF0094FF0085FF0085FF0075FF0066FF0057FF0028FF000AFF3300FFFA00FFFF00E6
FF00C7FF008AFF00D7FF00C7FF0000FF0000FF0000FF0000FF0000FF0000FF001EFF003D
FF008AFF007AFF004CFF00B8FF00D7FF00B8FF000FFF007AFF00E6FA00FFFF00B8FA00FF
FF00E6EB00FFEB00FFFF00E6FF00A8FF0000FF0000FA00FFDC00FFCC00FFCC00FFBD00FF
BD00FFBD00FFBD00FFCC00FFCC00FFEB00FFFF007AFF0099FF0000FF006BFF00D7FF00E6
FF00E6FF00E6FF00D7FF00B8FF0099FF006BFF000FFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF000FFF0000FF0000FF008AFF00A8FF002EFF007AFF00B8FF000FFF00A8FF00A8FA00FF
BD00FF9E00FF8000FF6100FF5100FF4200FF3300FF2300FF2300FF1400FF1400FF1400FF
1400FF0500FF0500FF0500FF0500FF1400FF8000FF4200FF0500FF0500FFFF007A0038FF
0057FF0057FF0066FF0066FF0066FF0075FF0075FF0075FF0075FF0085FF0085FF0085FF
0085FF0085FF0094FF0094FF0094FF0094FF0094FF0094FF00A3FF00A3FF00A3FF00A3FF
0094FF0094FF0085FF0075FF1400FFCC00FF0047FF0066FF0066FF2300FF0500FF0075FF
0085FF0085FF0075FF0019FF0038FF0047FF0047FFFF00C7CC00FF0028FF4200FFFA00FF
0028FF0038FF0500FF0066FF0075FF0075FF0019FF0028FF0047FF00A3FF00A3FF00A3FF
0094FF0066FF2300FF0075FF00A3FF00B3FF00A3FF0075FF0075FF0075FFAE00FFDC00FF
2300FF0028FF9E00FF0094FF5100FF00A3FF00FFFF00FFFF00E1FF5100FF00FFD100FFC2
00FFB300FFB300FFB300FFA300FFA300FFA300FFA300FFA300FFA300FFA300FF9400FF94
00FFA300FF9400FF9400FF9400FF9400FF9400FF9400FF9400FF9400FF9400FF9400FF94
00FF9400FF9400FF9400FF9400FF9400FF9400FF9400FFA300FFA300FFA300FFA300FFB3
00FFB300FFD100FFE100FFFF00FFFF00FFFF00F0FF00B3FF0057FF0075FF00C2FF00F0FF
00C2FF0094FF00FFE100FFB300FFA300FF9400FF9400FF9400FF9400FF8500FF8500FF85
00FF8500FF8500FF8500FF9400FF9400FF8500FF8500FF8500FF7500FF7500FF7500FF75
00FF7500FF7500FF7500FF7500FF6600FF6600FF7500FF6600FF6600FF7500FF6600FF66
00FF7500FF6600FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF75
00FF8500FF8500FF8500FF8500FF8500FF9400FF9400FFA300FFA300FFC200FFFF00E1FF
00FFF000FFE100FFF000D1FF00B3FF0057FF00D1FFFF00C700FFFF00FFD100FFC200FFC2
00FFC200FFC200FFD100FFE100FFF000E1FF0085FF0019FF6100FF00A3FF0038FF4200FF
00FFE100FFB300FFA300FF9400FF9400FF8500FF8500FF8500FF8500FF7500FF7500FF75
00FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF75
00FF7500FF7500FF7500FF7500FF8500FF8500FF8500FF9400FFA300FFB300FFE100F0FF
2300FF0047FF00FFFF00FFD100FFC200FFC200FFC200FFC200FFC200FFE100F0FF0075FF
3300FF00A3FF00FFF000FFD100FFC200FFC200FFC200FFC200FFC200FFC200FFD100FFE1
00A3FF0075FFFF00E6FF002E0057FF0047FF0028FFCC00FFCC00FF0075FF0085FF0066FF
00D1FF00FFF000FFD100FFC200FFB300FFB300FFB300FFA300FFA300FFA300FFA300FFA3
00FFA300FFA300FFA300FFA300FFA300FFA300FFA300FFB300D1FF00FFB300FF8500FF75
00FF7500FF6600FF6600FF6600FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF57
00FF5700FF5700FF4700FF5700FF4700FF4700FF4700FF4700FF4700FF5700FF4700FF57
00FF5700FF5700FF5700FF66
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF0A00FF0A00FF0A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00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF0A00FF0A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00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19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00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19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00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19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00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19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00FF1900FF2800FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19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00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19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00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19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00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19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00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19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00FF1900FF1900FF2800FF1900FF1900FF1900FF1900FF2800FF1900FF1900FF1900FF19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00FF2800FF2800FF2800FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19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00FF2800FF2800FF2800FF1900FF1900FF1900FF2800FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF2800FF1900FF1900FF1900FF1900FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF3800FF2800FF2800FF2800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF47
00FF3800FF3800FF3800FF3800FF4700FF4700FF5700FF4700FF4700FF4700FF4700FF47
00FF4700FF4700FF4700FF4700FF4700FF4700FF5700FF5700FF5700FF5700FF5700FF57
00FF5700FF5700FF5700FF5700FF5700FF5700FF6600FF6600FF6600FF6600FF6600FF75
00FF7500FF7500FF7500FF7500FF7500FF7500FF8500FF8500FF8500FF8500FF8500FF85
00FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF9400FF8500FF8500FF94
00FF9400FF9400FF9400FF9400FF9400FF9400FF9400FF9400FF9400FFA300FFA300FFA3
00FFA300FFA300FFA300FFB300FFB300FFB300FFB300FFB300FFB300FFC200FFC200FFC2
00FFD100FFD100FFD100FFD100FFD100FFE100FFE100FFE100FFE100FFE100FFF000FFF0
00FFF000FFF000FFFF00FFFF00FFFF00F0FF00F0FF00F0FF00E1FF00E1FF00D1FF00D1FF
00C2FF00B3FF00B3FF00A3FF00A3FF0094FF0094FF0085FF0085FF0075FF0066FF0057FF
0038FF0019FF0500FF2300FFFF00A84200FF8000FF000AFF000AFF000AFF1400FFFF0000
8F00FF1400FF1400FFFF00008F00FF2300FF0500FF000AFF000AFF000AFF0500FF1400FF
2300FF8000FF8F00FFFF006BFF003DFF007AAE00FFFF00B8DC00FFFF00C78F00FF2300FF
1400FF1400FF1400FF1400FF1400FF2300FF2300FF3300FF3300FF4200FF5100FF6100FF
CC00FFFF008AFF001EFF00F5AE00FF8F00FF8000FF8000FF8000FF8F00FF9E00FFAE00FF
CC00FFEB00FFFF004CFF00A8FA00FFFF00F5FF0099FF004CFF00A8FF006BFF005CFF0000
FF00A8FF00C7FF00C7FF00B8FF007AFF006BFF0000FF0099FF00C7FF00D7FF00D7FF00D7
FF00B8FF0099FF008AFF005CFF0000FF002EFF0000FF008AFF0099FF0099FF006BFF0000
FF003DFF004CFF000FFF0000FF002EFF002EFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF001EFF006BFF008AFF0099FF005CFA00FFCC00FFAE00FF9E00FF9E00FF
8000FF7000FF7000FF7000FF6100FF7000FF7000FF9E00FFCC00FF7000FF5100FF5100FF
AE00FF9E00FFAE00FFFF0000FF0000DC00FF7000FF3300FF2300FF0500FF000AFF000AFF
1400FF2300FF6100FFFF0000FF0000FF00E68000FFFF005CFF00F58F00FFFA00FF9E00FF
AE00FFFF00000500FF0047FF0075FF0085FF0094FF00B3FF00C2FF00C2FF00D1FF00D1FF
00D1FF00D1FF00D1FF00D1FF00E1FF00E1FF00E1FF00E1FF00E1FF00E1FF00E1FF00E1FF
00E1FF00E1FF00D1FF00D1FF00D1FF00C2FF00B3FF0075FF000AFF9E00FFFF00D73300FF
FF006B5100FF0028FF0075FF0094FF00B3FF00C2FF00D1FF00D1FF00D1FF00E1FF00F0FF
00FFFF00FFF000FFF000FFE100FFE100FFE100FFD100FFD100FFD100FFC200FFC200FFC2
00FFC200FFB300FFB300FFB300FFB300FFB300FFA300FFA300FFA300FFA300FFA300FFA3
00FF9400FF9400FF9400FF9400FF9400FF9400FF9400FF9400FF9400FF9400FF8500FF85
00FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF85
00FF8500FF8500FF8500FF8500FF7500FF8500FF8500FF7500FF7500FF8500FF7500FF85
00FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF9400FF9400FFF000FFC200FFA3
00FF8500FF7500FF7500FF7500FF7500FF6600FF6600FF6600FF6600FF6600FF6600FF66
00FF6600FF6600FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF57
00FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF57
00FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF6600FF5700FF6600FF6600FF66
00FF6600FF6600FF7500FF7500FF8500FF8500FF9400FFE100C2FF00FFFF00FFFF00C2FF
0057FF0028FF00B3FF0038FF00FFF000FFC200FFA300FF8500FF7500FF7500FF6600FF66
00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7500FF7500FF94
00FFC2FA00FF00FFB300FFA300FFA300FFA300FF6600FF6600FF5700FF5700FF5700FF57
00FF5700FF5700FF5700FF5700FF5700FF4700FF5700FF4700FF4700FF5700FF5700FF47
00FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF57
00FF5700FF5700FF5700FF5700FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF66
00FF6600FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF8500FF8500FF8500FF94
00FF9400FFA300FFA300FFB300FFE10075FF0019FF00FFFF00FFFF00E1FF0085FF7000FF
00D1FF00FFF000FFE100FFD100FFD100FFC200FFB300FFA300FF9400FF8500FF8500FF75
00FF7500FF7500FF7500FF7500FF7500FF6600FF6600FF6600FF6600FF6600FF6600FF57
00FF5700FF5700FF5700FF5700FF4700FF4700FF4700FF4700FF4700FF4700FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF2800FF28
00FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF1900FF1900FF1900FF1900FF28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00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF1900FF1900FF1900FF1900FF19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00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF1900FF1900FF1900FF2800FF19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00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF19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00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28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00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28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00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28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00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28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00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28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00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28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00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28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00FF3800FF3800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28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00FF3800FF3800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28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00FF3800FF3800FF3800FF3800FF3800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF3800FF2800FF2800FF2800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF4700FF4700FF4700FF4700FF5700FF6600FF7500F0FF00FF8500FF6600FF5700FF57
00FF5700FF5700FF5700FF5700FF5700FF4700FF5700FF4700FF4700FF5700FF4700FF47
00FF5700FF4700FF4700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF57
00FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF6600FF6600FF66
00FF6600FF6600FF6600FF6600FF6600FF6600FF7500FF7500FF7500FF8500FF8500FF85
00FF9400FF9400FFA300FFE100F0FF0085FF0047FF0057FFFF000000A3FF00D1FF00FFFF
00FFE100FFE100FFD100FFC200FFC200FFB300FFB300FFB300FFB300FFB300FFB300FFB3
00FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC2
00FFC200FFC200FFC200FFC200FFD100FFF00066FF00FFF000FFE100FFE100FFE100FFE1
00FFE100FFE100FFE100FFE100FFF000FFF000FFF000FFF000FFFF00FFFF00E1FF00A3FF
0094FF0066FF0094FF0085FF0075FF0019FF0047FF0066FF0075FF0085FF0075FFFF003D
0066FF0066FF0057FFFF00D7000AFF8F00FF4200FF8F00FF7000FF2300FF0028FF0047FF
0066FF0085FF0094FF0094FF00A3FF00A3FF00A3FF00A3FF00A3FF00A3FF0094FF0094FF
0094FF0085FF0066FF0057FF0047FF0038FF0019FFFA00FFFF008AFF00E61400FF0019FF
0019FF9E00FFFF00002300FF0019FF0038FF0047FF0047FF0057FF0057FF0057FF0057FF
0057FF0057FF0057FF0057FF0057FF0057FF0047FF0047FF0047FF0047FF0500FF0500FF
2300FF0019FF0019FF0019FF0019FF0019FF0019FF000AFF000AFF0500FF5100FF8000FF
EB00FFEB00FF8F00FF8000FFAE00FFCC00FFFF00F5FF00C7AE00FFAE00FFEB00FF7000FF
5100FF5100FF5100FF5100FF6100FF8000FFFA00FFFF00B89E00FF8000FF8000FF8F00FF
EB00FFFF005CFF0000AE00FF9E00FF9E00FF9E00FF9E00FFAE00FFAE00FFBD00FFCC00FF
DC00FFEB00FFEB00FFFA00FFFF00F5FF00C7FF00B8FF00A8FF0099FF007AFF002EFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF002EFF00A8FF005CBD00FFBD00FF9E00FF8000FFFF006B
AE00FF8000FFFF00F57000FF4200FF2300FF1400FF000AFF0019FF0028FF0038FF0047FF
0047FF0057FF0057FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF
0057FF0047FF0500FF2300FFDC00FF0019FF0019FF4200FF8F00FF2300FF4200FF0019FF
0066FF0094FF00A3FF00B3FF00C2FF00D1FF00D1FF00E1FF00E1FF00E1FF00F0FF00F0FF
00F0FF00F0FF00F0FF00F0FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F0FF00F0FF00F0FF00E1FF
00D1FF00C2FF0094FF4200FF0075FF00A3FF00A3FF0047FF0075FF9E00FF0019FF00B3FF
00E1FF0047FF0094FF00FFF000FFD100FFB300FFB300FFA300FFA300FFA300FF9400FF94
00FF9400FF9400FF9400FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF85
00FF8500FF7500FF7500FF7500FF8500FF7500FF7500FF7500FF7500FF7500FF7500FF75
00FF7500FF7500FF7500FF7500FF6600FF6600FF6600FF6600FF7500FF6600FF6600FF66
00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF5700FF57
00FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF57
00FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF47
00FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF47
00FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF47
00FF4700FF4700FF4700FF4700FF5700FF5700FF5700FF7500FF7500FF6600FF6600FF57
00FF5700FF5700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF3800FF4700FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF4700FF4700FF4700FF4700FF4700FF4700FF47
00FF4700FF4700FF4700FF4700FF4700FF5700FF5700FF5700FF5700FF5700FF5700FF57
00FF5700FF5700FF6600FF6600FF6600FF6600FF6600FF7500FF7500FF7500FF8500FF85
00FF9400FF9400FF9400FFA300FFC200E1FF00D1FF00FFFF00B3FF5100FF00D1FF00F0FF
00FFD100FFC200FFC200FFC200FFD10094FF0094FF00FFFF00F0FF000AFF0500FF00C2FF
0085FF9E00FF00E1FF00FFF000FFD100FFB300FFA300FF9400FF9400FF9400FF9400FFA3
00A3FF00FFFF00FF9400FF7500FF6600FF6600FF5700FF5700FF5700FF4700FF4700FF47
00FF3800FF3800FF3800FF3800FF3800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF1900FF1900FF1900FF19
00FF3800FF3800FF3800FF3800FF3800FF2800FF2800FF2800FF3800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF3800FF2800FF2800FF2800FF2800FF3800FF2800FF2800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF4700FF47
00FF4700FF4700FF5700FF5700FF5700FF7500FFE100FFC200FF8500FF6600FF6600FF57
00FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF4700FF57
00FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF57
00FF5700FF5700FF5700FF5700FF5700FF5700FF6600FF5700FF5700FF6600FF6600FF66
00FF6600FF6600FF6600FF6600FF7500FF7500FF7500FF7500FF7500FF8500FF8500FF85
00FF9400FF9400FFA300FFB300FFE10028FF00E1FF00D1FF00A3FF0028FF0057FF00C2FF
00FFF000FFE100FFD100FFD100FFC200FFC200FFB300FFC200FFB300FFB300FFB300FFB3
00FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC200FFC2
00FFC200FFC200FFD100FFD100FFE100FFFFFA00FF00F0FF00FFF000FFF000FFF000FFE1
00FFF000FFE100FFF000FFF000FFF000FFF000FFF000FFF000FFFF00F0FF00D1FF00A3FF
0028FFFF007A3300FF8F00FF8000FF0500FF1400FF0047FF0066FF0047FF0047FF1400FF
0038FF0057FF0038FF3300FFCC00FF5100FF000AFF0019FF0019FF6100FF7000FFAE00FF
DC00FF0075FF0094FF00A3FF00A3FF00A3FF00A3FF00A3FF00A3FF00A3FF00A3FF0094FF
0094FF0085FF0066FF5100FF0019FF0019FF3300FFFF00004200FF8F00FF0038FF0038FF
0028FF000AFFAE00FF5100FFFF005C0038FF0047FF0057FF0057FF0057FF0066FF0066FF
0066FF0066FF0066FF0066FF0057FF0057FF0057FF0057FF0057FF0047FF0047FF0038FF
0028FF0028FF0028FF0028FF0028FF0019FF0019FF0019FF000AFF0500FF1400FF2300FF
5100FF8F00FFDC00FFBD00FFFF00C7FF00E6FF0000DC00FF9E00FF8000FF7000FF6100FF
5100FF4200FF4200FF4200FF5100FF7000FFFF00A89E00FF7000FF6100FF7000FFAE00FF
DC00FFFF003DBD00FF9E00FF8F00FF8F00FF8F00FF9E00FFAE00FFAE00FFBD00FFBD00FF
CC00FFDC00FFEB00FFFA00FFFF00F5FF008AFF007AFF0099FF006BFF000FFF0000FF0000
FF0000FF001EFF000FFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF006BFF0099FF003DAE00FF8F00FF8000FF6100FF6100FF
5100FF5100FF8F00FFCC00FF7000FF2300FF0500FF000AFF0028FF0038FF0038FF0047FF
0057FF0057FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0075FF0075FF0066FF
0066FF0047FF2300FF0047FF000AFF0047FF0047FF0019FF000AFFDC00FFFF00001400FF
0038FF0066FF0085FF0075FF00A3FF00C2FF00D1FF00E1FF00E1FF00E1FF00F0FF00F0FF
00F0FF00F0FF00F0FF00F0FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFF000FFF000FFF000FFF000FFF000FFFF00FFF000FFF000FFFF
00FFFF00FFF000FFF000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F0FF00E1FF
00D1FF00B3FF0066FF1400FF0094FF00C2FF00D1FF00E1FF00D1FF5100FF00B3FF0019FF
0019FF00D1FF00FFF000FFD100FFC200FFB300FFA300FFA300FFA300FF9400FF9400FF94
00FF9400FF9400FF9400FF9400FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF85
00FF8500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF75
00FF7500FF7500FF7500FF7500FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF66
00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF5700FF5700FF6600FF5700FF57
00FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF57
00FF5700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF47
00FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF47
00FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF47
00FF4700FF4700FF4700FF4700FF4700FF4700FF5700FF5700FF5700FF5700FF5700FF47
00FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF3800FF4700FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF4700FF3800FF3800FF3800FF3800FF4700FF3800FF3800FF4700FF4700FF4700FF47
00FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF5700FF5700FF5700FF57
00FF5700FF5700FF6600FF6600FF6600FF6600FF6600FF7500FF7500FF8500FF8500FF85
00FF9400FF9400FFA300FFB300FFD100FFFF7000FF00B3FF4200FF0085FF00FFF000FFD1
00FFC200FFB300FFB300FFB300FFC200FFD100FFE100FFD100FFE100D1FF00E1FF000AFF
FF0000FF00990047FF00FFFF00FFD100FFC200FFB300FFB300FFA300FFA300FFA300FFB3
00FFFF00F0FF00FFA300FF8500FF7500FF7500FF6600FF6600FF5700FF4700FF4700FF47
00FF4700FF3800FF3800FF3800FF3800FF3800FF2800FF2800FF2800FF2800FF2800FF28
00FF1900FF1900FF1900FF19
00FF3800FF3800FF3800FF3800FF3800FF2800FF2800FF3800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF4700FF4700FF47
00FF4700FF4700FF5700FF5700FF6600FF7500FFB300FFFF00FF9400FF7500FF6600FF66
00FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF57
00FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF57
00FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF6600FF6600FF6600FF6600FF66
00FF6600FF6600FF6600FF6600FF7500FF7500FF7500FF7500FF7500FF8500FF8500FF85
00FF9400FF9400FFA300FFB300C2FF00C2FF00FFF000F0FFFF002E3300FF0094FF00E1FF
00FFFF00FFF000FFE100FFD100FFD100FFC200FFC200FFB300FFB300FFC200FFB300FFB3
00FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC200FFC200FFC2
00FFC200FFC200FFD100FFD100FFF00038FF3300FF00D1FF00F0FF00FFFF00FFFF00FFF0
00FFF000FFF000FFF000FFF000FFF000FFF000FFF000FFFF00FFFF00F0FF00E1FF00D1FF
0094FF0085FF9E00FF0066FF0066FF0057FF2300FF0500FF0038FF0028FFBD00FFAE00FF
0028FF0028FF0500FFCC00FF4200FFFF005C0038FF0047FF0038FFDC00FF0047FF0057FF
0057FF0075FF00A3FF00A3FF00A3FF00B3FF00B3FF00B3FF00B3FF00A3FF00A3FF0094FF
0094FF0075FF0066FF0028FF6100FFFA00FF8F00FF000AFF0019FF0047FF0047FF0047FF
0038FF7000FF5100FFFF00C77000FF0028FF0047FF0057FF0057FF0066FF0066FF0066FF
0066FF0066FF0066FF0066FF0066FF0066FF0066FF0057FF0057FF0047FF0047FF0047FF
0038FF0038FF0038FF0028FF0028FF0028FF0019FF0019FF000AFF000AFF0500FF2300FF
EB00FFFF008AAE00FFFF00D7FF003DFF0000FF0000FF00D78F00FF7000FF6100FF5100FF
4200FF4200FF4200FF4200FF4200FF9E00FF8F00FF5100FF5100FF5100FF6100FF8000FF
FF00E6FF00B8AE00FF8F00FF8F00FF8F00FF8F00FF8F00FF9E00FFAE00FFBD00FFBD00FF
CC00FFDC00FFEB00FFFF00F5FF00E6FF00A8FF000FFF005CFF004CFF0000FF0000FF003D
FF003DFF004CFF003DFF002EFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00E6DC00FFAE00FF9E00FF7000FF5100FF4200FF
4200FF4200FF6100FFFF00F5AE00FF6100FF2300FF000AFF0019FF0038FF0038FF0047FF
0057FF0057FF0066FF0066FF0066FF0075FF0075FF0075FF0075FF0075FF0075FF0075FF
0075FF0066FF0066FF0066FF0066FF0066FF0066FF0057FF0038FF1400FF0500FFFF004C
0500FFFF00000028FF0066FF00B3FF00C2FF00D1FF00E1FF00E1FF00E1FF00F0FF00F0FF
00F0FF00F0FF00F0FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFF000FFF000FFF000FFF000FFF000FFF000FFF000FFF000FFF000FFF000FFF0
00FFF000FFF000FFF000FFF000FFF000FFF000FFF000FFF000FFFF00FFFF00F0FF00E1FF
00D1FF0500FF0066FF00A3FFFF00E600C2FF00F0FF00FFFF00F0FF00F0FF00F0FF00F0FF
00B3FF00B3FF00FFF000FFD100FFC200FFB300FFA300FFA300FFA300FF9400FF9400FF94
00FF9400FF9400FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF85
00FF8500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF75
00FF7500FF7500FF7500FF7500FF7500FF6600FF6600FF6600FF6600FF6600FF6600FF66
00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF5700FF5700FF5700FF5700FF57
00FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF4700FF57
00FF5700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF47
00FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF47
00FF4700FF4700FF4700FF4700FF4700FF3800FF4700FF4700FF4700FF4700FF4700FF47
00FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF47
00FF4700FF4700FF4700FF4700FF4700FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF4700FF3800FF3800FF3800FF4700FF4700FF4700FF47
00FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF5700FF5700FF5700FF5700FF57
00FF5700FF5700FF5700FF6600FF6600FF6600FF7500FF7500FF8500FF8500FF8500FF94
00FF9400FF9400FFA300FFB300FFE100E1FF00C2FF8000FF0028FF00F0FF00FFE100FFC2
00FFB300FFA300FFA300FFA300FFA300FFA300FFB300FFC200FFC200FFD100FFFF00A3FF
0075FF0075FF0019FF0094FF2300FF00FFE10085FF00FFD100FFC200FFB300FFB300FFC2
0085FF00F0FF00FFB300FF9400FF9400FF94DC00FF00FF7500FF5700FF5700FF4700FF47
00FF4700FF3800FF3800FF3800FF3800FF3800FF2800FF2800FF2800FF2800FF2800FF28
00FF1900FF1900FF1900FF19
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF2800FF2800FF2800FF28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00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF2800FF2800FF2800FF38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00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38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00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38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00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF2800FF2800FF3800FF3800FF2800FF2800FF2800FF2800FF3800FF2800FF28
00FF2800FF2800FF3800FF3800FF2800FF2800FF2800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF4700FF3800FF3800FF4700FF4700FF4700FF4700FF4700FF5700FF57
00FF6600FF7500FF9400C2FF00FFFF00FFE10057FF00FFB300FFA300FF8500FF8500FF75
00FF7500FF7500FF6600FF6600FF6600FF6600FF6600FF6600FF5700FF6600FF5700FF57
00FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF66
00FF5700FF5700FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF66
00FF7500FF7500FF7500FF8500FF8500FF8500FF8500FF8500FF9400FF9400FF9400FF94
00FFA300FFA300FFA300FFB300FFB300FFC200FFC200FFE100C2FF0094FF00A3FF0028FF
0094FF00D1FF00F0FF00FFFF00FFF000FFE100FFD100FFD100FFD100FFC200FFD100FFC2
00FFC200FFC200FFC200FFC200FFC200FFC200FFC200FFC200FFD100FFD100FFD100FFE1
00FFF000FFF000FFF000FFF000FFFF00F0FF00D1FF0094FFBD00FF0038FF00C2FF00E1FF
00E1FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00E1FF00D1FF00D1FF00D1FF00D1FF
00C2FF00B3FF3300FF0075FF0075FF0057FF0019FFFF00007000FF7000FFFF0000CC00FF
FF00007000FF000AFF9E00FF0047FF0085FF0094FF00A3FF00A3FF00B3FF00B3FF00B3FF
00C2FF00C2FF00C2FF00D1FF00D1FF00D1FF00C2FF00C2FF00C2FF00C2FF00B3FF00A3FF
5100FF0038FFBD00FF9E00FF0028FF0066FF0085FF0094FF0094FF0094FF0085FF0085FF
0075FF0047FF0019FFFA00FF000AFF4200FF0047FF0066FF0075FF0085FF0085FF0085FF
0085FF0085FF0085FF0075FF0075FF0075FF0066FF0066FF0066FF0066FF0057FF0057FF
0047FF0047FF0047FF0038FF0028FF0019FFEB00FFFF00003300FF2300FF2300FF4200FF
8000FFAE00FFFF008A8F00FF6100FF4200FF5100FF8F00FF8000FF3300FF2300FF2300FF
1400FF1400FF1400FF1400FF1400FF1400FF1400FF2300FF2300FF2300FF3300FF3300FF
4200FF4200FF5100FF6100FF7000FF7000FF8000FF8F00FFFF00A8FF00A8FF00B8FF007A
FF002EFF0000FF0000FF0099FF002EFF00C7FF00E6FF00E6FF00E6FF00E6FF00D7FF00C7
FF00B8FF00A8FF007AFF0000FF0000FF003DFF002EFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF002EFF003DFF002EFF0000FF0000FF0000FF001E
FF006BFF007AFF007AFF0000FF008AFF003DFF008AFF007AFF0000FF003DFF0099FF0099
FF00C7FF00B8FF008AFF004CFF0099FF00E6FF00E6FF00C7FF006BFF006BFF00F5FF00E6
FF00D7FF0000FA00FFFF001EFF00E6FF00F58F00FF7000FF6100FF4200FF3300FF2300FF
1400FF0500FF0500FF000AFF000AFF0019FF0019FF0028FF0038FF0038FF0047FF0057FF
0057FF0066FF0066FF0075FF0075FF0075FF0085FF0085FF0085FF0085FF0094FF0094FF
0094FF0094FF0094FF0094FF00A3FF00A3FF00A3FF00A3FF00A3FF00B3FF00B3FF00B3FF
00C2FF00C2FF00C2FF00C2FF00D1FF00D1FF00E1FF00E1FF00E1FF00F0FF00F0FF00F0FF
00F0FF00F0FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF000FFF000FFFF00FFF0
00FFF000FFF000FFF000FFF000FFF000FFF000FFF000FFE100FFE100FFE100FFE100FFE1
00FFE100FFE100FFE100FFE100FFE100FFE100FFE100FFE100FFE100FFE100FFE100FFF0
00A3FF00FFF000FFE100FFD100FFD100FFD100FFC200FFC200FFC200FFC200FFC200FFC2
00FFC200FFC200FFC200FFD1FF000000FFB300FFA300FFA300FF9400FF9400FF9400FF94
00FF9400FF9400FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF85
00FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF75
00FF7500FF7500FF7500FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF66
00FF6600FF6600FF6600FF6600FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF57
00FF5700FF5700FF5700FF5700FF5700FF5700FF4700FF4700FF4700FF4700FF4700FF47
00FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF47
00FF4700FF4700FF3800FF3800FF3800FF3800FF4700FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF2800FF2800FF3800FF2800FF2800FF2800FF3800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF3800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF3800FF3800FF2800FF2800FF2800FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF4700FF38
00FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF5700FF5700FF57
00FF5700FF5700FF6600FF6600FF6600FF7500FF7500FF8500FF9400FFA300FFD12300FF
00D1FF00FFF000FFF000F0FF0085FF0075FF0047FF00FFE100FFC200FFB300FFA300FF94
00FF8500FF8500FF8500FF8500FF7500FF7500FF7500FF7500FF8500FF8500FF8500FF85
00FF9400FF9400FF9400FFA300FFB300FFC200FFE10057FFEB00FFAE00FFDC00FFDC00FF
6100FF00C2FF00FFC200FFB300FF9400FF8500FF8500FF7500FF6600FF6600FF6600FF66
00FF5700FF5700FF5700FF5700FF5700FF4700FF3800FF3800FF2800FF2800FF2800FF28
00FF1900FF1900FF1900FF19
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38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00FF3800FF4700FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38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00FF4700FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38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00FF4700FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38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00FF4700FF4700FF4700FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38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00FF4700FF4700FF4700FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38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00FF4700FF4700FF4700FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38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00FF4700FF4700FF4700FF4700FF4700FF4700FF3800FF3800FF3800FF3800FF3800FF38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00FF4700FF4700FF4700FF4700FF4700FF4700FF3800FF3800FF3800FF4700FF3800FF38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00FF4700FF4700FF4700FF4700FF4700FF4700FF3800FF3800FF4700FF3800FF3800FF38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00FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF3800FF3800FF38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00FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF3800FF38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00FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF47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00FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF47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00FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF47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00FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF47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00FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF47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00FF4700FF4700FF4700FF5700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF47
00FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF47
00FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF57
00FF5700FF5700FF5700FF6600FF7500FFA300FFF00047FF00FFFF7000FF00FFD100FFC2
00FFA300FFB33300FF00FFA300FFB30066FF00FF9400FF9400FF8500FF8500FF8500FF85
00FF9400FF9400FFA300FFA300FFC200C2FF0094FF00D1FF0057FF3300FF0047FF00D1FF
00C2FF3300FF0057FF00FFFF00FFC200FFA300FFA300FF9400FF9400FF9400FF8500FF85
00FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF85
00FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF9400FF9400FF94
00FF9400FF9400FF9400FFA300FFA300FFA300FFA300FFA300FFB300FFB300FFB300FFC2
00FFC200FFC200FFD100FFD100FFD100FFE100FFF000F0FF00E1FF00E1FF00D1FF00D1FF
00B3FF0028FF0057FF000AFFBD00FF0057FF0066FF0075FF0057FF0075FF0057FF000AFF
0038FF0066FF0085FF0094FF00A3FF00B3FF00B3FF00A3FF0094FF0066FF0094FF0066FF
0038FF2300FFCC00FFFF00002300FF0066FF0085FF0094FF00A3FF0094FF0075FF0094FF
0057FF0094FF0066FF3300FF000AFF0075FF00A3FF00B3FF00C2FF00D1FF00E1FF00E1FF
00F0FF00FFFF00FFFF00FFFF00FFF000FFF000FFF000FFF000FFF000FFF000FFF000FFF0
00FFF000FFF000FFF000FFF000FFE100FFE100FFE100FFF000FFE100FFE100FFF000FFF0
00FFF000FFF000FFF000FFF000FFF000FFF000FFF000FFF000FFF000FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00F0FF00F0FF00F0FF00F0FF00E1FF00E1FF00E1FF00E1FF
00E1FF00E1FF00E1FF00D1FF00D1FF00D1FF00D1FF00C2FF00C2FF00B3FF00A3FF0085FF
0038FF0047FF5100FF0057FF0066FF0066FF0066FF0057FF0047FF0019FF6100FF1400FF
BD00FF8000FF1400FFFF00E60028FF0028FF0028FF0019FF2300FF4200FF0019FF0028FF
000AFFAE00FF1400FF0038FF0057FF0057FF0066FF0066FF0066FF0066FF0066FF0066FF
0066FF0066FF0057FF0057FF0057FF0047FF0047FF0047FF0038FF0019FF0500FFBD00FF
5100FF5100FF2300FF0500FF0500FF0500FF0500FF0500FF1400FF1400FF1400FF2300FF
3300FF3300FF5100FF7000FF8F00FF8000FF8F00FF9E00FF9E00FFBD00FFEB00FFFF00C7
FF002EFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF003DFF006BFF007AFF008A
FF004CFF00A8FF00B8FF0099FF00D7CC00FFBD00FFCC00FFCC00FFEB00FFFF00A8FA00FF
BD00FFAE00FF9E00FFAE00FFFF00F5FA00FFBD00FF5100FF4200FF4200FF4200FF4200FF
4200FF5100FF6100FF8000FFEB00FF8F00FF6100FF6100FF7000FF7000FFFF00B8FF00B8
FF008A6100FF4200FF000AFF0028FF0028FF0038FF0038FF0038FF0038FF0038FF0038FF
0038FF0038FF0028FF0028FF0019FF000AFF0500FF3300FF5100FFEB00FF8F00FF8F00FF
8F00FF6100FFBD00FF8F00FF7000FF9E00FF000AFF0028FF0028FF0019FF0038FF0038FF
0057FF0057FF0057FF0047FF0019FFFF00000028FF0057FF0066FF0038FF2300FF000AFF
0075FF0094FF00A3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A3FF0094FF
0075FF6100FF0500FF0066FF5100FF00C2FF00D1FF00E1FF00F0FF00F0FF00FFFF00FFFF
00FFFF00FFF000FFF000FFF000FFE100FFE100FFE100FFE100FFE100FFD100FFD100FFD1
00FFD100FFD100FFD100FFD100FFD100FFC200FFC200FFC200FFC200FFC200FFC200FFB3
00FFB300FFB300FFB300FFB300FFB300FFB300FFA300FFA300FFA300FFA300FFA300FFA3
00FFA300FFA300FFA300FF9400FF9400FF9400FF9400FF9400FF9400FF9400FF9400FF94
00FF9400FF9400FF8500FF8500FF8500FF8500FF9400FF8500FF8500FF8500FF8500FF85
00FF8500FF8500FF8500FF8500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF75
00FF7500FF7500FF7500FF7500FF7500FF7500FF6600FF6600FF6600FF6600FF6600FF66
00FF6600FF6600FF6600FF6600FF6600FF5700FF5700FF6600FF5700FF5700FF5700FF57
00FF5700FF5700FF5700FF5700FF5700FF4700FF4700FF4700FF4700FF4700FF4700FF47
00FF4700FF4700FF4700FF4700FF4700FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF2800FF2800FF2800FF2800FF28
00FF3800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF19
00FF1900FF1900FF1900FF1900FF2800FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF28
00FF1900FF1900FF1900FF1900FF1900FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF38
00FF3800FF3800FF3800FF3800FF3800FF4700FF4700FF4700FF4700FF5700FF5700FF66
00FF7500FF7500FF8500FFA300FFC200FFFF0057FF00FFFF00D1FF00D1FF00B3FF0057FF
FF00000057FF00B3FF00E1FF00FFFF00FFF00094FF00B3FF00FFD100FFC200FF8500FF75
00FF6600FF5700FF4700FF4700FF3800FF3800FF3800FF3800FF3800FF3800FF2800FF38
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF3800FF3800FF47
00FF660094FF00FF9400FF5700FF5700FF4700FF6600FF7500FFA300FF5700FF5700FF57
00FF5700FF850075FF0075FF00FFB300B3FF00FFC200FF7500FF6600FF5700FF5700FF47
00FF3800FF2800FF2800FF19
00FF5700FF5700FF5700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF47
00FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF47
00FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF5700FF5700FF57
00FF5700FF5700FF5700FF6600FF6600FF7500FF9400FFA300FFB300FFE1FF00D700FFFF
00FFC200FFD100A3FF00FFD10047FF00FFD100FFA300FF9400FF9400FF9400FF9400FF94
00FF9400FF9400FFA300FFA300FFB300FFD100FFF000FFFF00C2FFFF00D700C2FF00F0FF
00FFFF00FFFF00B3FF00FFE100FFF000FFB300FFA300FF9400FF9400FF9400FF9400FF85
00FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF85
00FF8500FF8500FF8500FF8500FF8500FF9400FF9400FF9400FF9400FF9400FF9400FF94
00FF9400FF9400FFA300FFA300FFA300FFA300FFA300FFA300FFB300FFB300FFB300FFC2
00FFC200FFC200FFD100FFD100FFD100FFE100FFF000F0FFFA00FF0047FF00B3FF00B3FF
00B3FF0094FF0075FF0028FF8F00FF0028FF000AFF0019FF0028FF0057FF0019FFFF0000
0500FF0066FF0085FF0085FF0094FF0094FF0094FF0047FF0047FF0028FF0066FF0038FF
FF00002300FFAE00FF0028FFBD00FF0066FF0094FF00A3FF00B3FF00B3FF00B3FF00B3FF
00B3FF00A3FF0094FF0075FFFF00000075FF0085FF00A3FF00B3FF00C2FF00D1FF00E1FF
00F0FF00FFFF00FFFF00FFF000FFF000FFF000FFF000FFE100FFE100FFF000FFE100FFE1
00FFF000FFE100FFE100FFE100FFE100FFE100FFE100FFE100FFE100FFE100FFF000FFE1
00FFF000FFF000FFF000FFF000FFF000FFF000FFF000FFF000FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00E1FF00E1FF
00E1FF00E1FF00D1FF00D1FF00D1FF00D1FF00D1FF00C2FF00C2FF00B3FF00A3FF0085FF
0066FF2300FF2300FF0038FF0047FF0057FF0057FF0047FF0019FFAE00FFFF00B8FF0000
FF008A6100FF0019FF0028FF0038FF0047FF0038FF0028FF2300FF3300FF0028FF0047FF
0047FF0038FF1400FF000AFF0057FF0066FF0066FF0066FF0075FF0066FF0066FF0066FF
0066FF0066FF0066FF0057FF0057FF0057FF0047FF0047FF0038FF3300FF2300FF1400FF
0500FF0500FF000AFF000AFF000AFF000AFF0500FF0500FF0500FF1400FF1400FF2300FF
3300FF3300FF4200FF5100FF6100FF7000FF8000FF8F00FF9E00FFBD00FFFF00C7FF00B8
FF00C7FF005CFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A8FF00A8
FF0000FF00C7FF00F5EB00FFCC00FFBD00FFBD00FFBD00FFBD00FFFF00F5FF0000FF00D7
BD00FF8F00FF8000FF7000FF7000FF7000FF6100FF4200FF4200FF3300FF3300FF3300FF
4200FF4200FF5100FF8000FFFF001ECC00FF5100FF4200FF3300FF5100FF5100FF4200FF
8000FFFF00004200FF000AFF0019FF0028FF0038FF0038FF0047FF0038FF0047FF0047FF
0038FF0038FF0038FF0028FF0019FF0019FF000AFF1400FFFF00E6FF00C74200FF8000FF
3300FF2300FF3300FFBD00FFFF00007000FF1400FF000AFF0500FF5100FF2300FF0500FF
0047FF0047FF0047FF0038FF0028FF9E00FF0019FF0038FF7000FF1400FF7000FF0019FF
0085FF0094FF00A3FF00A3FF00A3FF00B3FF00B3FF00B3FF00A3FF00A3FF00A3FF0075FF
000AFF3300FF0057FF0094FF00A3FF00C2FF00D1FF00E1FF00E1FF00F0FF00F0FF00F0FF
00FFFF00FFFF00FFF000FFF000FFF000FFE100FFE100FFE100FFE100FFE100FFD100FFD1
00FFD100FFD100FFD100FFD100FFC200FFC200FFC200FFC200FFC200FFC200FFC200FFB3
00FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA300FFA300FFA300FFA300FFA3
00FFA300FFA300FFA300FFA300FFA300FFA300FF9400FF9400FF9400FF9400FF9400FF94
00FF9400FF9400FF9400FF8500FF9400FF8500FF8500FF8500FF8500FF8500FF8500FF85
00FF8500FF8500FF8500FF8500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF75
00FF7500FF7500FF7500FF7500FF7500FF6600FF6600FF6600FF6600FF6600FF6600FF66
00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF5700FF5700FF5700FF5700FF57
00FF5700FF5700FF5700FF5700FF5700FF4700FF4700FF4700FF4700FF4700FF4700FF47
00FF4700FF4700FF4700FF4700FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF2800FF1900FF1900FF1900FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF4700FF4700FF4700FF5700FF5700FF66
00FF6600FF7500FF9400FFB300E1FF0500FF00E1FF00FFE100FFE100F0FF0094FF0019FF
4200FFFF0000FF00D71400FF000AFF0094FF00FFFF00FFC200FFA300FF8500FF7500FF66
00FF5700FF4700FF4700FF4700FF3800FF3800FF3800FF3800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF3800FF3800FF38
00FF7500FF5700FFA300FF4700FF4700FF3800FF470085FF00FF5700FF4700FF4700FF47
00FF4700FF5700FF6600FF9400FF853300FF6100FF00FF9400FF8500FF9400FF8500FFB3
00FF6600FF4700FF3800FF19
00FF5700FF5700FF5700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF47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00FF5700FF5700FF5700FF5700FF4700FF5700FF4700FF4700FF4700FF5700FF4700FF47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00FF5700FF5700FF5700FF5700FF5700FF5700FF4700FF4700FF4700FF4700FF4700FF47
00FF5700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF47
00FF4700FF4700FF4700FF4700FF5700FF4700FF5700FF5700FF5700FF5700FF5700FF57
00FF5700FF6600FF6600FF6600FF6600FF7500FF7500FF8500FF9400FFB300FFD100FFF0
000AFF5100FF8000FF00F0FF00FFE100FFD100FFC200FFB300FFB300FFB300FFB300FFA3
00FFA300FFB300FFB300FFB300FFC200FFE10085FF00E1FF0500FF8F00FF00F0FF00FFF0
00FFD100FFD100FFC200FFB300FFB300FFA300FFA300FFA300FF9400FF9400FF9400FF94
00FF9400FF9400FF8500FF9400FF8500FF9400FF8500FF8500FF8500FF8500FF9400FF94
00FF9400FF9400FF9400FF9400FFA300FFA300FFB300FFC200FFB300FFA300FFA300FFA3
00FFA300FFA300FFA300FFA300FFB300FFB300FFB300FFB300FFC200FFC200FFD100FFD1
00FFD100FFD100FFE100FFE100FFE100FFF000FFFF00D1FF00A3FF0085FF0047FF1400FF
1400FF0028FF2300FF7000FF9E00FFFF003DFF0000AE00FF5100FF5100FFFF00B84200FF
0500FF0019FF000AFF3300FF2300FF0038FF0038FF3300FF3300FF0019FF1400FFFF005C
0094FF00B3FF00B3FF000AFF0038FF00C2FF00D1FF00D1FF00E1FF00E1FF00E1FF00D1FF
00D1FF00C2FF0094FF1400FF0047FF00B3FF00B3FF0094FF0019FF0066FFFF003D000AFF
0019FF00F0FF00FFFF00FFF000FFE100FFE100FFE100FFE100FFE100FFE100FFD100FFD1
00FFE100FFD100FFE100FFD100FFE100FFD100FFE100FFE100FFE100FFE100FFE100FFE1
00FFE100FFE100FFE100FFE100FFF000FFF000FFF000FFF000FFF000FFF000FFF000FFFF
00FFFF00FFFF00FFFF00FFFF00F0FF00F0FF00F0FF00F0FF00F0FF00E1FF00E1FF00E1FF
00E1FF00D1FF00D1FF00D1FF00D1FF00D1FF00C2FF00C2FF00C2FF00B3FF00A3FF00A3FF
0085FF0066FF0047FF0019FF4200FF000AFF0500FF3300FF2300FF7000FF7000FF1400FF
0500FF9E00FF0038FF0057FF0066FF0066FF0066FF0066FF0047FF0500FF0066FF0075FF
0075FF0075FF0075FF0085FF0075FF0085FF0085FF0075FF0075FF0075FF0075FF0075FF
0075FF0075FF0066FF0066FF0066FF0057FF0057FF0057FF0057FF0047FF0047FF0038FF
0038FF0038FF0028FF0028FF0019FF0019FF000AFF0500FF1400FF4200FF4200FF4200FF
4200FF4200FF5100FF7000FF8000FF8000FF9E00FFFF00C7FF00A8FF00F5FF006BFF006B
FF005CFF008AFF008AFF002EFF002EFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000FFF0000FF0000FF0000FF001E
FF003DFF003DFF0000FF0000FF004CFF006BFF002EFF000FFF007AFF00A8FF00D7FF00F5
FA00FFEB00FFDC00FFCC00FFAE00FF9E00FF9E00FF8F00FF8F00FF8F00FF9E00FFBD00FF
EB00FFFF005CFF00F56100FF4200FF3300FF3300FF3300FF2300FF2300FF2300FF2300FF
2300FF3300FF4200FF7000FF8000FFCC00FF5100FF3300FF1400FF000AFF000AFF0019FF
0019FF0028FF0028FF000AFF0038FF0047FF0047FF0057FF0057FF0057FF0047FF0057FF
0047FF0047FF0047FF0038FF0028FFCC00FF8F00FF7000FF1400FFEB00FF4200FF0019FF
0028FF0038FF0038FF0038FF0028FF0019FF1400FF7000FFFF00F5FF005C7000FFCC00FF
0500FFFF003D8000FF2300FF4200FF7000FF000AFF0028FF0047FF0057FF0066FF0075FF
0085FF0085FF0094FF0094FF0094FF0094FF0094FF0094FF0094FF0094FF0085FF0066FF
3300FF0500FF0075FF0094FF00A3FF00B3FF00B3FF00B3FF00A3FF0075FF0085FF00A3FF
0066FF00C2FF00D1FF00FFFF00FFF000FFF000FFE100FFE100FFE100FFE100FFE100FFE1
00FFD100FFD100FFD100FFD100FFD100FFD100FFC200FFC200FFC200FFC200FFC200FFC2
00FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA300FFA300FFA3
00FFA300FFA300FFA300FFA300FFA300FF9400FF9400FF9400FF9400FF9400FF9400FF94
00FF9400FF9400FF9400FF9400FF9400FF8500FF9400FF8500FF8500FF8500FF8500FF85
00FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF7500FF7500FF8500FF7500FF75
00FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF6600FF6600FF7500FF66
00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF5700FF5700FF5700FF57
00FF5700FF5700FF5700FF5700FF5700FF5700FF4700FF4700FF4700FF4700FF4700FF47
00FF4700FF4700FF4700FF4700FF4700FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF2800FF2800FF3800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF1900FF1900FF1900FF1900FF1900FF1900FF28
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF4700FF4700FF4700FF5700FF57
00FF7500FFB300FFC200E1FF00FFE100FFA300FFA300FFA300FFB300FFC200FFE100C2FF
0500FF00E1FF00FFFF00FFC200FFB300FFB300F0FF00FFFF5100FFFF00E600FF9400FF66
00FF5700FF4700FF4700FF3800FF3800FF3800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF1900FF1900FF1900FF1900FF1900FF2800FF1900FF1900FF19
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF3800FF3800FF4700FF5700FF9400FFF000FF9400FF6600FF5700FF4700FF38
00FF3800FF3800FF6600FF19
00FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF4700FF4700FF47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00FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF57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00FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF57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00FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF57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00FF5700FF5700FF6600FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF57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00FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF57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00FF6600FF6600FF5700FF5700FF6600FF5700FF5700FF5700FF5700FF5700FF5700FF57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00FF6600FF6600FF6600FF6600FF6600FF5700FF6600FF5700FF5700FF5700FF5700FF57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00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF5700FF6600FF5700FF5700FF57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00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF66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00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF66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00FF6600FF7500FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF66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00FF7500FF7500FF7500FF7500FF6600FF7500FF6600FF6600FF6600FF6600FF6600FF66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00FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF75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00FF8500FF8500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF75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00FF8500FF8500FF9400FF8500FF8500FF7500FF7500FF7500FF7500FF7500FF7500FF75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00FFA300FFB34200FF00FF9400FF8500FF8500FF8500FF8500FF7500FF7500FF7500FF85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00FFD10075FF00FFC200FF9400FF9400FF8500FF8500FF8500FF8500FF8500FF8500FF85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00E1FF00FFE100FFB300FFA300FF9400FF9400FF8500FF8500FF8500FF9400FF8500FF94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0500FF00FFF000FFC200FFA300FFA300FF9400FF9400FF9400FF9400FF9400FF9400FF94
00FFA300FFD100FFC200FFF0FF00E600E1FF00FFC200FFA300FF9400FF9400FF8500FF85
00FF8500FF8500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF75
00FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF9400FF9400FF9400FF9400FF94
00FFA300FFA300FFA300FFA300FFB300FFB300FFB300FFB300FFC200FFD10057FF0057FF
0047FF00E1FF00F0FF00F0FF00E1FF00D1FF00A3FF0085FF0038FF0500FF0075FF00A3FF
00B3FF00C2FF00C2FF00C2FF00B3FF0094FF1400FF0075FF0038FF3300FF00A3FF00C2FF
00E1FF00F0FF00F0FF00FFFF00FFFF00FFFF00F0FF00E1FF0057FF0057FF0019FF0094FF
00A3FF0038FF0057FFFF00E61400FF0047FF0019FF1400FF5100FF7000FFFF00D73300FF
0028FF0094FF00D1FF00F0FF00F0FF00F0FF00FFFF00FFF000FFE100FFE100FFD100FFE1
00FFE100FFF00066FF00FFF000FFD100FFD100FFD100FFD100FFD100FFD100FFC200FFC2
00FFD100FFD100FFD100FFD100FFD100FFE100FFE100FFE100FFF000FFF000FFFF00F0FF
00F0FF00E1FF00C2FF0085FF0047FF00B3FF00D1FF00E1FF00F0FF00F0FF00FFFF00FFFF
00FFF000FFE100FFE100FFD100FFD100FFD100FFC200FFC200FFC200FFB300FFB300FFB3
00FFB300FFB300FFB300FFB300FFA300FFA300FFA300FFA300FFA300FFA300FFA300FFA3
00FFA300FFA300FFA300FFA300FFA300FFA300FFA300FFA300FFA300FFA300FFA300FFA3
00FFB300FFB300FFB300FFB300FFB300FFB300FFC200FFC200FFC200FFD100FFD100FFE1
00FFFF00B3FF0085FF3300FF00B3FF00D1FF00C2FF00A3FF0500FF0047FF0500FF0057FF
0028FF0094FF0094FF4200FF0066FFFF00000500FF00C2FF00E1FF00E1FF00E1FF00E1FF
00E1FF00E1FF00E1FF00E1FF00E1FF00D1FF00D1FF00C2FF00A3FF0094FF0075FF0500FF
DC00FF0500FF0085FF0094FF00A3FF00B3FF00C2FF00C2FF00D1FF00D1FF00D1FF00D1FF
00D1FF00E1FF00E1FF00E1FF00D1FF00E1FF00D1FF00E1FF00D1FF00D1FF00D1FF00D1FF
00C2FF00C2FF00B3FF00A3FF0094FF0075FF0038FF7000FF1400FF3300FF0038FF0066FF
0075FF0085FF0085FF0085FF0085FF0075FF0075FF0066FF0057FF0047FF0028FF1400FF
FF00B86100FF000AFF0038FF0047FF0057FF0057FF0057FF0057FF0057FF0057FF0047FF
0047FF0028FF0019FF5100FFFF00005100FF7000FF2300FF2300FF3300FF6100FFDC00FF
6100FF5100FF5100FF5100FF7000FF8F00FFCC00FFEB00FFFF0000FF00B8FF008AFF0000
FF0000FF000FFF0000FF004CFF00A8FF008AFF0000FF007AFF00D7FF00E6FF00B8FF007A
FF007AFF00B8FF00E6FF00E6FF002EFF0000FF0000FF0000FF00B8FF00E6FF00E6FF00E6
FF00B8FF003DFF008AFF008AFF001EFF00B8FF00C7FF00D7FF00C7FF00B8FF00A8FF0099
FF007AFF002EFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000F
FF000FFF0000FF0000FF001EFF004CFF006BFF008AFF0099FF00A8FF00B8FF00C7FF00C7
FF00C7FF00A8FF00B8FF00D7FF00E6FF00D7FF00C7FF0099FF0000FF008AFF000FFF0000
FF00E6FF00D7FF00B8FF0000FF0000FF000FFF007AFF001EFF00F5FF00F58000FF6100FF
5100FF4200FF4200FF4200FF4200FF4200FF4200FF5100FF5100FF7000FF8F00FFFF00C7
CC00FFBD00FF7000FF6100FF6100FF6100FF8000FFFF00F5FF0000CC00FF8000FF8F00FF
8000FFFF00F5BD00FFFF00C77000FF0500FF0019FF0028FF0038FF0038FF0038FF0038FF
0038FF0047FF0047FF0047FF0047FF0047FF000AFF0047FF0057FF0057FF0066FF0075FF
0075FF0085FF0085FF0094FF00A3FF00A3FF00A3FF00B3FF00B3FF00B3FF00C2FF00C2FF
00C2FF00C2FF00C2FF00C2FF00C2FF00C2FF00C2FF00C2FF00C2FF00C2FF00C2FF00C2FF
00C2FF00C2FF00C2FF00C2FF00C2FF00B3FF00B3FF00A3FF00A3FF00A3FF0094FF0085FF
0075FF0066FF0047FF000AFF0028FF0057FF0075FF0085FF0094FF00A3FF00A3FF00A3FF
00A3FF00A3FF0085FF00A3FF00A3FF00A3FF00A3FF0094FF0085FF0066FFFF00007000FF
FF0000FF0000FF00B80019FF0038FF0028FF0028FF0085FF0085FF1400FF0047FF7000FF
0057FF0066FF0047FF9E00FF3300FF0085FF00A3FF00B3FF00C2FF00D1FF00E1FF00F0FF
00F0FF00FFFF00FFF000FFF000FFE100FFE100FFE100FFD100FFD100FFD100FFD100FFC2
00FFC200FFC200FFC200FFC200FFC200FFC200FFC200FFC200FFC200FFC200FFC200FFC2
00FFC200FFD100FFD100FFF000B3FF00FFFF00FFF000FFF000FFFF00C2FF0085FF0028FF
00FFF000FFE100FFD100FFD100FFD100FFD100FFE100FFE100FFE100FFF000FFF000FFFF
00F0FF00D1FF0066FF0038FF00E1FF00FFFF00FFF000FFE100FFE100FFD100FFD100FFC2
00FFC200FFC200FFE100FFD100FFE100D1FF00FFD100FFC200FFC200FFC200FFD100FFD1
00FFF000FFFF0057FF0085FF0075FF00E1FF00C2FF00FFD100FFB300FFA300FF8500FF75
00FF7500FF6600FF6600FF5700FF5700FF5700FF4700FF4700FF4700FF4700FF4700FF38
00FF3800FF3800FF3800FF3800FF3800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF0A00FF0A00FF0A00FF0A00FF0A
00FF1900FF0A00FF0A00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF28
00FF2800FF2800FF3800FF4700FF4700FF5700FF6600FF7500FF9400FFE1000AFF00E1FF
00D1FF00FFD10057FF00FFD17000FF00FFF000E1FF00B3FF00B3FF00C2FF00FFE100FFF0
00E1FF0094FF0066FF0019FF0500FF00D1FF00FFE100FFB300FFB300B3FF00FFF0000AFF
00FFD100FF9400FF9400FF5700FF3800FF2800FF2800FF1900FF1900FF0A00FF0A00FF0A
00FF0A00FF0A05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0014FF0014FF0005FF0014FF0014FF0014FF0005FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF00
0085FF00FFFF00FFE100FFB300FFA300FFA300FFA300FF9400FF9400FF9400FF9400FFA3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0066FF00A3FF00E1FF00FFE100FFB300FFA300FFA300FFA300FFA300FFA300FFA300FFB3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9E00FF0047FF00C2FF00B3FF00FFD100FFB300FFA300FFA300FFA300FFA300FFB300FFC2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FA00FF00C2FF00FFFF00FFE100FFC200FFC200FFB300FFB300FFB300FFB300FFB300FFC2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0057FF00A3FF00FFFF00FFE100FFD100FFC200FFB300FFB300FFB300FFC200FFC200FFD1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0066FF0047FF00C2FF00FFF000FFD100FFC200FFC200FFC200FFC200FFC200FFE100E1FF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0075FF9E00FF0047FF0075FF00FFF000FFD100FFD100FFD100FFD100FFD100FFF00066FF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0057FF0047FF00C2FF00E1FF00FFF000FFE100FFE100FFD100FFE100FFF00085FF0500FF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00B3FFFA00FF0094FF00F0FF00FFFF00FFF000FFE100FFF000FFF000FFF000F0FF00B3FF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00D1FF1400FF0085FF00C2FF00F0FF00FFF000FFF000FFF000FFFF00E1FF00D1FF0028FF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AE00FF0066FF4200FF0085FF00E1FF00F0FF00FFFF00F0FF00B3FF0057FF0075FF0028FF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00D1FF0094FFCC00FF00A3FF00D1FF00E1FF00F0FF00E1FF00B3FF1400FFAE00FF00A3FF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00E1FF00D1FF0075FF0500FF00B3FF00D1FF00C2FF0066FF0047FF0047FF0066FF4200FF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00F0FF00D1FF00A3FF0057FF0066FF00A3FF0085FFEB00FF0066FF00B3FF00A3FF0057FF
00F0FF00FFF000FFF000FFE100FFD100FFD100FFC200FFC200FFC200FFB300FFB300FFB3
00FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB3
00FFC200FFD100FFD100FFF000FFFF00D1FF00C2FF00B3FF0085FF0075FF00C2FF00D1FF
00E1FF00E1FF00E1FF00E1FF00E1FF00C2FF0094FF4200FF0047FF0066FF0019FF2300FF
0066FF0085FF3300FF9E00FF00B3FF00C2FF00C2FF00C2FF00B3FF00A3FF0094FF0038FF
0028FF6100FF0047FF0057FF0057FF0047FF000AFFDC00FFFF00004200FF000AFF0028FF
0500FF0019FF0085FF0085FF0066FF0066FF0094FF0085FF0047FF00D1FF00FFFF00FFD1
00FFC200FFC200FFC200FFC200FFC200FFB300FFB300FFC200FFC200FFD100FFE100E1FF
00F0FF00FFD100FFB300FFA300FFA300FF9400FF9400FF9400FF9400FF9400FF9400FF94
00FF8500FF8500FF8500FF8500FF9400FF8500FF9400FF9400FF9400FF9400FFA300FFA3
00FFA300FFB300FFD100FFF000FFF000FFF000F0FF00C2FF0500FF0075FF00F0FF00FFE1
00FFD100FFC200FFB300FFB300FFB300FFB300FFA300FFB300FFB300FFC20094FF00C2FF
00FFFF0038FF00E1FF00A3FF0038FF00FFFF00FFE100FFD100FFC200FFB300FFA300FFA3
00FF9400FF9400FF9400FF9400FF9400FF9400FF9400FF9400FF8500FF8500FF9400FF85
00FF8500FF8500FF8500FF8500FF8500FF9400FF8500FF9400FF9400FF9400FF9400FF94
00FF9400FF9400FF9400FF9400FFA300FFA300FFA300FFA300FFB300FFB300FFB300FFB3
00FFC200E1FF00FFD100FFC200FFC200FFC200FFB300FFB300FFB300FFB300FFB300FFC2
00FFC200FFC200FFC200FFC200FFC200FFC200FFD100FFD100FFD100FFE100FFE100FFF0
00FFFF00F0FF00F0FF00E1FF00D1FF00C2FF0057FF0075FF0019FF0057FF0085FF00A3FF
00A3FF0066FF0028FF00C2FF00E1FF00F0FF00F0FF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00E1FF00E1FF00E1FF00E1FF00E1FF
00E1FF00D1FF00D1FF00D1FF00C2FF00C2FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF
00A3FF00A3FF00A3FF00A3FF00A3FF0094FF0094FF0094FF0094FF0085FF0075FF0075FF
0066FF0066FF0057FF0057FF0047FF0047FF0047FF0038FF0038FF0028FF0019FF0500FF
6100FFDC00FF3300FF4200FFAE00FFFF008AAE00FF5100FF4200FF5100FFFF006B2300FF
1400FF0500FF0500FF0500FF0500FF0500FF1400FF1400FF2300FF3300FF4200FF4200FF
5100FF7000FF9E00FFFF007AAE00FF8F00FFEB00FF6100FF5100FF5100FF5100FF5100FF
6100FF9E00FFFF008AEB00FF8F00FF8000FF8000FFAE00FFFF00E6FF00B8BD00FF9E00FF
9E00FF9E00FF9E00FFAE00FFAE00FFBD00FFCC00FFDC00FFFA00FFFF00F5FF00C7FF001E
FF005CFF005CFF0000FF00D7FF00D7FF00D7FF00C7FF00A8FF007AFF0000FF007AFF0099
FF00A8FF00A8FF0000FF0099FF0099FF005CFF0000FF007AFF006BFF005CFF0000FF0000
FF0000FF0000FF0000FF0000FF000FFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000F
FF001EFF001EFF002EFF005CFF007AFF008AFF0099FF00A8FF00B8FF00B8FF00B8FF00B8
FF002EFF00B8FF00C7FF00D7EB00FFDC00FFBD00FFAE00FFAE00FF9E00FF9E00FF8F00FF
8F00FF8000FF8000FF7000FF6100FF6100FF6100FF5100FF4200FF4200FF3300FF3300FF
3300FF2300FF2300FF2300FF1400FF1400FF1400FF1400FF0500FF000AFF000AFF000AFF
0019FF0028FF0028FF0038FF0038FF0038FF0047FF0047FF0047FF0047FF0047FF0047FF
0047FF0047FF0047FF0047FF0038FF0038FF0028FF0019FF0500FF8000FFFF0000BD00FF
5100FF000AFF0047FF0057FF0066FF0075FF0085FF0085FF0094FF0094FF00A3FF00A3FF
00B3FF00B3FF00C2FF00C2FF00C2FF00D1FF00D1FF00D1FF00D1FF00E1FF00E1FF00E1FF
00E1FF00E1FF00E1FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF
00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00E1FF00D1FF00C2FF0085FF0094FF
0038FF00E1FF00F0FF00FFFF00FFFF00FFFF00FFF000FFF000FFF000FFF000FFF000FFF0
00FFF000FFF000FFF000FFF000FFF000FFF000FFF000FFF000FFF000FFFF00FFFF00FFFF
00F0FF00E1FF00E1FF8F00FF0094FF0094FF0028FF0028FF0085FF0085FF0500FF0019FF
00A3FF00C2FF00D1FF00E1FF00F0FF00F0FF00F0FF00F0FF00F0FF00E1FF00E1FF00D1FF
00C2FF0094FF0038FF0057FF0094FF0094FF0057FF0066FF7000FF2300FF0075FF00B3FF
00C2FF00D1FF00C2FF0094FF1400FF5100FF4200FF0094FF00A3FF00D1FF00C2FF0028FF
00B3FF0047FF00F0FF00FFF000FFF000FFF000FFF000FFFF00E1FF0066FF00F0FF00FFF0
00FFE100F0FF00FFD100FFC200FFB300FFB300FFB300FFB300FFC200FFC200FFD100FFF0
00D1FF00B3FF00FFF000FFD100FFC200FFD100FFE100B3FF00FFB300FFA300FF9400FF94
00FF9400FF9400FF9400FF9400FF9400FFA300FFA300FFB300FFE100FFFF4200FF00FFF0
00FFE100C2FF0038FF00FFF000FFE100FF9400FF8500FF8500FF7500FF7500FF7500FF75
00FF7500FF7500FF7500FF8500FFB30066FF0038FF00FFC200FF9400FF9400FF6600FF57
00FF4700FF3800FF3800FF3800FF2800FF3800FF2800FF2800FF2800FF2800FF2800FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A05FF0005FF0005FF0005FF0005FF0005FF0000FF0A00FF0A
00FF0A05FF0005FF0005FF0005FF0005FF0000FF0A00FF0A00FF0A05FF0005FF0005FF00
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF2800FF2800FF2800FF2800FF38
00FF3800FF3800FF4700FF5700FF7500FF7500FF9400A3FF00FFE100FF8500FF6600FF57
00FF4700FF3800FF3800FF2800FF2800FF1900FF1900FF0A00FF0A00FF0A05FF0005FF00
05FF0005FF0005FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF00
00E1FF00E1FF00C2FF0094FFCC00FF0019FF0038FF0085FF00A3FF00D1FF00E1FF00B3FF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00E1FF00D1FF00B3FF0094FF2300FF00A3FF00C2FF00C2FF00D1FF00E1FF00F0FF00FFFF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00D1FF00C2FF0085FF000AFF0057FF00B3FF00D1FF00E1FF00E1FF00F0FF00FFFF00FFFF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4200FF00A3FF0085FFFF00000066FF00B3FF00D1FF00E1FF00F0FF00FFFF00FFFF00FFF0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1400FF0085FF0038FF5100FF0094FF00B3FF00D1FF00E1FF00F0FF00FFFF00FFFF00FFF0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9E00FF0038FF0500FF000AFF0085FF0066FF00C2FF00E1FF00F0FF00F0FF00FFFF00FFF0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0047FFAE00FFFF0000FF00E61400FF0075FF00C2FF00E1FF00F0FF00FFFF00FFFF00FFFF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0057FF8000FF6100FF0047FF9E00FF0500FF0038FF00D1FF00F0FF00F0FF00FFFF00FFFF
00FFFF00FFF000FFF000FFF000FFE100FFE100FFE100FFE100FFE100FFE100FFE100FFE1
00FFE100FFF000F0FF0047FF00A3FF00E1FF00C2FF9E00FF0094FF00F0FF00F0FF00F0FF
00F0FF00E1FF00B3FF0066FF0019FF0028FF2300FF4200FF00A3FF00A3FF0028FF0028FF
0066FF0066FFFF00990085FF00A3FF0085FF00F0FF00FFFF00FFFF00FFF000FFE100FFE1
00FFE100FFD100FFD100FFD100FFE100FFE100FFFF1400FF0038FF00FFFF00FFF000FFFF
00D1FF0028FF00C2FF00FFFF00FFFF00FFFF00FFFF00F0FF00D1FF00B3FF0057FF6100FF
00C2FF00E1FF00F0FF00FFF000FFE100FFE100FFD100FFD100FFC200FFC200FFB300FFB3
00FFA300FFA300FFA300FFA300FFA300FF9400FF9400FF9400FF9400FF9400FF8500FF85
00FF8500FF8500FF8500FF8500FF8500FF7500FF8500FF7500FF7500FF7500FF7500FF75
00FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF8500FF8500FF85
00FF8500FF9400FF9400FFA300FFB300FFD100FFFF00F0FF00FFC200FFB300FFA300FF94
00FF9400FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF85
00FF9400FF9400FFE100FFC200FFB300FF9400FF9400FF9400FF8500FF8500FF8500FF85
00FF8500FF8500FF8500FF8500FF8500FF7500FF8500FF8500FF7500FF7500FF8500FF85
00FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF85
00FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF9400FF9400FF9400FF9400FF94
00FF9400FF9400FF9400FF9400FF9400FF9400FF9400FFA300FFA300FFA300FFA300FFA3
00FFA300FFA300FFA300FFB300FFB300FFB300FFC200FFC200FFD100FFD100FFE100FFF0
00FFFF0047FF00B3FF1400FF0019FF00B3FF00B3FF5100FF00A3FF00B3FF0047FF3300FF
00D1FF00FFFF00FFF000FFF000FFF000FFF000FFE100FFF000FFE100FFF000FFE100FFF0
00FFF000FFF000FFF000FFF000FFF000FFF000FFF000FFF000FFF000FFF000FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00E1FF00E1FF
00E1FF00E1FF00D1FF00D1FF00D1FF00D1FF00D1FF00D1FF00C2FF00C2FF00C2FF00B3FF
00B3FF00B3FF00A3FF00A3FF00A3FF0094FF0094FF0094FF0085FF0085FF0075FF0066FF
2300FFFA00FFFA00FF8F00FF2300FF3300FF8F00FFFF00C79E00FFEB00FFFF00F5FF0099
9E00FF5100FF2300FF0500FF0500FF0500FF5100FF0019FF0028FF0038FF0038FF0038FF
0038FF0038FF0038FF0028FF0019FF2300FFDC00FFFF00004200FF1400FF0500FF000AFF
0500FF0500FF2300FFCC00FFFF0099FA00FF4200FF2300FF1400FF1400FF1400FF1400FF
1400FF1400FF1400FF1400FF2300FF2300FF3300FF3300FF4200FF4200FF5100FF6100FF
8000FF8F00FF8F00FF9E00FFBD00FFDC00FFFF007AFF0099FF00F5FF00E6FF00D7FF00B8
FF003DBD00FFAE00FFAE00FFAE00FFAE00FFAE00FFBD00FFBD00FFCC00FFCC00FFDC00FF
DC00FFEB00FFFA00FFFF00F5FF00D7FF0099FF006BFF0000FF0000FF0000FF006BFF008A
FF0099FF00A8FF00A8FF0099FF006BFF0000FF002EFF003DFF003DFF000FFF0000FF000F
FF001EFF001EFF001EFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF001EFF004CFF005CFF006BFF007AFF007AFF006BFF006B
FF0000FF006BFF0099FF0000FF007AFF0000FF0000FF004CFF004CFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF003DFF0000FF006BFF0000FF00F5FA00FFBD00FF
EB00FFBD00FF8000FF6100FF4200FF3300FF2300FF1400FF0500FF0500FF000AFF0019FF
0028FF0028FF0038FF0047FF0047FF0057FF0057FF0057FF0066FF0066FF0066FF0066FF
0066FF0066FF0066FF0075FF0066FF0066FF0075FF0066FF0066FF0066FF0057FF000AFF
0500FF0047FF7000FF0047FF0047FF0500FF2300FF1400FFFF000FFF00001400FF000AFF
0047FF0085FF0085FF0075FF00B3FF00D1FF00D1FF00E1FF00E1FF00E1FF00F0FF00F0FF
00F0FF00F0FF00F0FF00F0FF00F0FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFF000FFF000FFF000FFF000FFF000FFF000FFF000FFF000FFF000FFE1
00FFF000FFE100FFE100FFE100FFE100FFE100FFE100FFE100FFE100FFD100FFD100FFD1
00FFD100FFD100FFD100FFD100FFD100FFD100FFE100FFD100FFE100FFE100FFE100FFF0
00FFFF00F0FF00C2FF3300FF00E1FF00FFFF00FFF000FFE100FFE100FFE100FFE100FFE1
00FFF000F0FF00FFF000FFE100FFE100FFD100FFD100FFD100FFD100FFD100FFD100FFD1
00FFD100FFD100FFD100FFE100FFE100FFE100FFF000FFF000FFF000FFFF00F0FF00D1FF
00B3FF0066FF0066FF00A3FF0047FF00F0FF00FFFF00FFF000FFE100FFD100FFD100FFD1
00FFC200FFC200FFC200FFB300FFB300FFB300FFB300FFA300FFA300FFA300FFA300FFA3
00FF9400FF9400FF9400FF9400FF9400FF9400FF9400FF8500FF8500FF8500FF8500FF85
00FF8500FF8500FF8500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF6600FF66
00FF6600FF6600FF6600FF6600FF7500FF7500FF7500FF7500FF857000FF00FF8500FF75
00FF6600FF5700FF5700FF5700FF5700FF4700FF4700FF4700FF4700FF4700FF4700FF47
00FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF6600FF57
00FF4700FF3800FF2800FF2800FF2800FF2800FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF0A00FF1900FF1900FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A05FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0000FF0A05FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0000FF0A05FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0000FF0A05FF0005FF0005FF0000FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF1900FF19
00FF2800FF2800FF3800FF4700FF5700FF6600FFA32300FF00FF9400FF6600FF3800FF38
00FF2800FF2800FF1900FF1900FF1900FF1900FF1900FF0A05FF0005FF0005FF0005FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0023FF0023FF0023FF00
14FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
33FF0033FF0033FF0023FF00
0019FF5100FF0057FF0075FF0085FF0075FF0085FF00A3FF00E1FF00F0FF00F0FF00FFFF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9E00FF7000FF8000FF0085FF00A3FF00A3FF00C2FF00D1FF00E1FF00F0FF00F0FF00F0FF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FA00FF0038FF0019FF0094FF00A3FF00B3FF00C2FF00D1FF00E1FF00E1FF00F0FF00F0FF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2300FF0047FF0075FF0094FF00A3FF00B3FF00C2FF00D1FF00D1FF00E1FF00E1FF00E1FF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0500FF0500FF0075FF0085FF0094FF00B3FF00C2FF00C2FF00D1FF00D1FF00D1FF00D1FF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000AFF0047FF0057FF000AFF0066FF00A3FF00B3FF00C2FF00C2FF00C2FF00C2FF00C2FF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9E00FF0019FF0019FF1400FF0066FF0085FF0057FF00B3FF00C2FF00C2FF00C2FF00B3FF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8000FF4200FF8000FF0500FFFF00A8DC00FF0066FF00A3FF00B3FF00B3FF00B3FF00A3FF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8000FF2300FF000AFF000AFF3300FF0057FF0075FF0094FF00A3FF00A3FF00A3FF00A3FF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6100FF6100FF0028FF0047FF0057FF0066FF0085FF0094FF0094FF00A3FF0094FF0094FF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DC00FF3300FF0019FF0047FF0057FF0066FF0075FF0085FF0094FF0094FF0085FF0085FF
0085FF0075FF0057FF1400FF000AFF0066FF0075FF0085FF0094FF0094FF0085FF0066FF
2300FFFF00000066FF00A3FF00B3FF0047FF00E1FF00F0FF00F0FF00F0FF00C2FF000AFF
00C2FF00FFF000FFD100FFD100FFC200FFC200FFB300FFB300FFB300FFB300FFB300FFC2
00FFD100FFF000A3FF00FFD100FFB300FFB300FFA300FFA300FFA300FFA300FF9400FF94
00FF9400FF9400FF9400FF9400FF9400FF9400FF9400FFA300FFA300FFA300FFA300FFA3
00FFA300FFB300FFB300FFB300FFC200FFD100FFE100FFF000FFFF00D1FF3300FF0047FF
00E1FF00FFF000FFF000FFFF00E1FF0047FF00A3FF0066FF000AFF00B3FF00C2FFFF000F
0094FFFF000000FFE100FFB300FFA300FFA300FF9400FF9400FF8500FF8500FF8500FF75
00FF7500FF7500FF7500FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF66
00FF6600FF6600FF6600FF5700FF6600FF6600FF5700FF5700FF6600FF5700FF5700FF66
00FF5700FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF66
00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF66
00FF6600FF6600FF6600FF6600FF6600FF7500FF6600FF6600FF6600FF6600FF6600FF66
00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7500FF7500FF7500FF7500FF75
00FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF75
00FF7500FF7500FF7500FF7500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF85
00FF8500FF8500FF8500FF8500FF9400FF8500FF9400FF9400FF9400FF9400FF9400FF94
00FF9400FF9400FF9400FF9400FFA300FFA300FFA300FFA300FFA300FFA300FFB300FFB3
00FFB300FFB300FFB300FFB300FFC200FFB300FFC200FFC200FFC200FFC200FFC200FFC2
00FFC200FFC200FFC200FFC200FFC200FFD100FFD100FFD100FFD100FFD100FFD100FFD1
00FFD100FFD100FFE100FFE100FFE100FFE100FFE100FFF000FFF000FFF000FFFF00E1FF
0066FF0085FF00C2FF00C2FF00A3FF0038FF0500FF0057FF00A3FF00B3FF00B3FF00C2FF
00C2FF00C2FF00C2FF00C2FF00C2FF00B3FF00B3FF00B3FF00B3FF00A3FF0094FFFA00FF
0028FF0019FF0500FF000AFF1400FF2300FF000AFF0019FF000AFF9E00FF0500FF2300FF
DC00FFFF00B83300FF5100FF3300FF1400FF0047FF0057FF0057FF0057FF0057FF0038FF
2300FF000AFF0057FF0066FF0075FF0066FF0075FF0075FF0075FF0075FF0075FF0075FF
0075FF0075FF0075FF0075FF0075FF0075FF0075FF0066FF0066FF0066FF0066FF0057FF
0057FF0057FF0057FF0047FF0047FF0047FF0038FF0038FF0028FF0028FF0019FF0019FF
000AFF000AFF0500FF1400FF2300FF3300FF4200FF7000FF8F00FFDC00FFFF008AFF0000
FF00C7FF006BAE00FF8000FF7000FF6100FF5100FF5100FF4200FF4200FF4200FF4200FF
4200FF5100FF7000FF9E00FFFF004CFF00F59E00FF8F00FF8F00FF8F00FFAE00FFBD00FF
FA00FFFF008AFF004CCC00FFBD00FFBD00FFBD00FFBD00FFCC00FFDC00FFFA00FFFF008A
FF002EFF004CFF003DFF008AFF004CFF0000FF0000FF002EFF0000FF0000FF0000FF0000
FF000FFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF002EFF004CFF006BFF007AFF008A
FF0099FF0099FF004CFF008AFF00D7FF00F5FA00FFEB00FFBD00FFAE00FF9E00FF9E00FF
9E00FF9E00FF9E00FFBD00FF8F00FFBD00FF5100FF4200FF3300FF2300FF2300FF2300FF
1400FF1400FF1400FF1400FF1400FF0500FF0500FF000AFF000AFF000AFF0500FF0019FF
0028FF0038FF0038FF0047FF0047FF0057FF0057FF0066FF0066FF0066FF0066FF0075FF
0075FF0075FF0085FF0085FF0085FF0085FF0085FF0094FF0094FF0094FF0094FF0094FF
00A3FF00A3FF00A3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C2FF00C2FF00C2FF
00D1FF00D1FF00D1FF00D1FF00E1FF00E1FF00E1FF00E1FF00E1FF00F0FF00F0FF00F0FF
00F0FF00F0FF00F0FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF000FFF0
00FFF000FFF000FFF000FFF000FFF000FFF000FFE100FFE100FFE100FFE100FFE100FFE1
00FFD100FFD100FFD100FFD100FFD100FFD100FFD100FFD100FFC200FFC200FFC200FFC2
00FFC200FFC200FFC200FFC200FFC200FFB300FFB300FFB300FFB300FFB300FFB300FFB3
00FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB3
00FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB3
00FFB300FFB300FFB300FFC200FFC200FFC200FFC200FFD100FFD100FFE100FFF000FFFF
00C2FF3300FF00C2FF00C2FF00A3FF0057FF7000FF0094FF00E1FF00F0FF00FFF000FFE1
00FFE100FFD100FFD100FFC200FFC200FFC200FFB300FFB300FFA300FFA300FF9400FF94
00FF9400FF9400FF8500FF8500FF8500FF8500FF7500FF7500FF7500FF7500FF7500FF75
00FF7500FF7500FF6600FF6600FF6600FF6600FF6600FF6600FF5700FF5700FF5700FF57
00FF5700FF5700FF5700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF47
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A05FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0000FF0A05FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0014FF0014FF0014FF0005FF0005FF0005FF0005FF0014FF00
14FF0014FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
00FF0A00FF0A00FF0A00FF1900FF280075FF00FF6600FF2800FF1900FF0A00FF0A05FF00
05FF0005FF0005FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0033FF0033FF0033FF00
33FF0033FF0033FF0023FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0023FF0033FF0033FF00
6100FF3300FF000AFF0038FF0047FF0066FF0075FF0075FF0075FF0075FF0028FF0066FF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8F00FF5100FF1400FF0500FF0500FF8F00FF0057FF0057FF1400FF0047FF1400FF0028FF
0057FF0047FF0019FF5100FF1400FF0028FF0057FF0047FF2300FF8F00FF0038FF6100FF
0028FF0075FF00A3FF00C2FF00E1FF00F0FF00FFFF00FFFF00FFF000FFF000FFF000FFFF
0075FF00FFE100FFC200FFC200FFB300FFB300FFB300FFA300FFA300FFB300FFA300FFB3
00FFB300FFD100FFC200FFB300FFA300FF9400FF9400FF9400FF9400FF9400FF9400FF94
00FF9400FF9400FF9400FF9400FF9400FF9400FF9400FF9400FF9400FFA300FFA300FFA3
00FFA300FFB300FFB300FFB300FFC200FFD100FFFF0500FF00B3FF0047FF00A3FF00FFFF
00FFF000FFE100FFD100FFD100FFD100FFE100FFE100FFFF00E1FF0075FFFF008A0075FF
00E1FF00FFF000FFE100FFC200FFC200FFC200FFB300FFC200FFA300FF8500FF8500FF75
00FF7500FF7500FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF66
00FF5700FF5700FF6600FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF57
00FF5700FF5700FF5700FF5700FF5700FF5700FF6600FF5700FF5700FF5700FF5700FF57
00FF5700FF5700FF5700FF5700FF5700FF5700FF6600FF5700FF6600FF6600FF6600FF66
00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF66
00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF75
00FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF75
00FF7500FF7500FF7500FF7500FF7500FF7500FF8500FF8500FF8500FF8500FF8500FF85
00FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF9400FF9400FF9400FF9400FF94
00FF9400FF9400FF9400FF9400FF9400FFA300FFA300FFA300FFA300FFA300FFA300FFA3
00FFA300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC200FFC200FFC2
00FFC200FFC200FFC200FFC200FFC200FFC200FFC200FFD100FFD100FFD100FFD100FFD1
00FFD100FFE100FFE100FFE100FFE100FFE100FFE100FFF000FFF000FFF000FFFF00F0FF
00D1FF1400FF0094FF0066FF0500FFFF00004200FF0057FF0085FF0094FF0094FF00A3FF
00A3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A3FF00A3FF00A3FF0094FF0075FF
0066FF0047FF0038FF0038FF0019FF2300FF8F00FF7000FF9E00FFDC00FFFF00E6FF008A
3300FF000AFF0019FF0019FF000AFF0047FF0057FF0066FF0075FF0075FF0075FF0066FF
0028FF0066FF0075FF0085FF0085FF0085FF0085FF0085FF0085FF0085FF0085FF0085FF
0085FF0085FF0075FF0075FF0075FF0075FF0075FF0066FF0066FF0066FF0066FF0066FF
0057FF0057FF0057FF0057FF0047FF0047FF0038FF0038FF0028FF0019FF1400FF1400FF
2300FF1400FF1400FF2300FF3300FF7000FF6100FF8F00FFFF000FEB00FF8F00FF8000FF
8F00FFDC00FFFF00F5FF005CFF00E66100FF4200FF4200FF3300FF3300FF3300FF3300FF
3300FF4200FF8000FFAE00FF6100FF6100FF6100FF6100FF7000FF8F00FF9E00FFEB00FF
FF0000FF0099EB00FFAE00FFAE00FFAE00FFAE00FFAE00FFBD00FFCC00FFEB00FFEB00FF
EB00FFFA00FFFF00F5FF00D7FF00B8FF0000FF002EFF008AFF008AFF006BFF006BFF006B
FF006BFF004CFF0000FF002EFF001EFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF002EFF000FFF0000FF001E
FF0000FF002EFF007AFF007AFF006BFF004CFF00D7FA00FFDC00FFBD00FFBD00FFBD00FF
CC00FFFF00E6FF00B8CC00FF9E00FF6100FF5100FF4200FF3300FF2300FF2300FF2300FF
1400FF1400FF0500FF0500FF0500FF000AFF000AFF0019FF0019FF0019FF0028FF0028FF
0028FF0038FF0047FF0047FF0047FF0057FF0057FF0057FF0066FF0066FF0066FF0066FF
0075FF0075FF0075FF0085FF0085FF0085FF0094FF0094FF0094FF0094FF00A3FF00A3FF
00A3FF00A3FF00A3FF00B3FF00B3FF00B3FF00B3FF00C2FF00C2FF00C2FF00C2FF00C2FF
00D1FF00D1FF00D1FF00D1FF00E1FF00E1FF00E1FF00E1FF00E1FF00E1FF00F0FF00E1FF
00F0FF00F0FF00F0FF00F0FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFF000FFF000FFF000FFF000FFF000FFF000FFE100FFE100FFE100FFE100FFE100FFE1
00FFD100FFD100FFD100FFD100FFD100FFD100FFC200FFC200FFC200FFC200FFC200FFC2
00FFC200FFC200FFC200FFB300FFB300FFC200FFB300FFB300FFB300FFB300FFB300FFB3
00FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA300FFB300FFB300FFA3
00FFB300FFA300FFA300FFB300FFA300FFA300FFB300FFB300FFB300FFB300FFB300FFB3
00FFB300FFB300FFB300FFB300FFB300FFC200FFC200FFC200FFC200FFD100FFD100FFE1
00FFFF00FFFF00FFFF00F0FF00E1FF00C2FF0038FF000AFF00A3FF0057FF00E1FF00FFFF
00FFF000FFF000FFF000FFFF00D1FF00E1FF00FFD100FFB300FFB300FFA300FFA300FF94
00FF9400FF9400FF8500FF8500FF8500FF8500FF8500FF7500FF7500FF7500FF7500FF75
00FF7500FF6600FF6600FF6600FF6600FF6600FF6600FF5700FF5700FF5700FF5700FF57
00FF5700FF5700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF1900FF1900FF1900FF28
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A05FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0014FF0014FF0014FF0014FF0005FF00
05FF0005FF0005FF0014FF0014FF0014FF0014FF0014FF0005FF0005FF0014FF0014FF00
14FF0014FF0014FF0005FF0005FF0014FF0014FF0014FF0014FF0005FF0014FF0014FF00
14FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0000FF0A00FF1900FF7500FF2800FF1900FF0A05FF0005FF0005FF0005FF00
05FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF00
FF00E66100FFFA00FFDC00FF3300FF0019FF0047FF0047FF0500FF0500FF8F00FF0028FF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7000FF000AFF1400FFDC00FFBD00FF2300FF1400FF0019FF0500FF7000FF1400FF0019FF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0038FF0038FF2300FFDC00FF1400FFAE00FFFF00003300FFCC00FFFF00004200FF1400FF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0047FF0057FF0047FF0038FF0038FF1400FF3300FFFF00E6FF003DFF00F5FF00D76100FF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0066FF0075FF0066FF0066FF0047FF0028FF000AFFFF00E6FF00B8FF0000DC00FF8F00FF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0075FF0085FF0075FF0066FF0047FF0028FF000AFF5100FF8000FFFF003DFF0000FF00D7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0094FF0094FF0094FFDC00FFFF00A8FF001E2300FF5100FFFF00E6FF0000DC00FFDC00FF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00B3FF00A3FF0094FF0085FF0057FF1400FF4200FF9E00FFFF0000FF00997000FF3300FF
000AFF0019FF0019FF0500FFFF00C70019FF0047FF0057FF0028FF0066FF0066FF0019FF
7000FF0057FF00B3FF00D1FF00F0FF00FFFF00FFF000FFF000FFE100FFD100FFD100FFC2
00FFC200FFB300FFB300FFB300FFA300FFA300FF9400FF9400FF9400FF8500FF8500FF85
00FF8500FF8500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF75
00FF7500FF7500FF7500FF7500FF7500FF8500FF8500FF8500FF8500FF8500FF9400FF94
00FFA300FFA300FFC20085FF0075FF00E1FFFA00FF0057FF00A3FF00A3FF00E1FF00FFD1
00FFB300FFA300FF9400FF9400FF8500FF8500FF8500FF8500FF8500FF9400FFA300FFD1
0094FF00FFC200E1FF00FFD100FFD100FFFF0066FF00E1FF00FFB300FF9400FF8500FF85
00FF7500FF6600FF6600FF6600FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF57
00FF5700FF5700FF5700FF5700FF4700FF4700FF5700FF4700FF4700FF4700FF5700FF47
00FF4700FF4700FF4700FF5700FF4700FF4700FF4700FF5700FF5700FF5700FF5700FF57
00FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF57
00FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF6600FF5700FF5700FF57
00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF66
00FF6600FF6600FF6600FF6600FF6600FF6600FF7500FF7500FF7500FF7500FF7500FF75
00FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF8500FF8500FF8500FF8500FF85
00FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF9400FF94
00FF9400FF9400FF9400FF9400FF9400FF9400FF9400FF9400FF9400FFA300FFA300FFA3
00FFA300FFA300FFA300FFA300FFA300FFA300FFB300FFB300FFB300FFB300FFB300FFB3
00FFB300FFB300FFC200FFC200FFC200FFC200FFC200FFC200FFD100FFD100FFD100FFD1
00FFD100FFD100FFD100FFE100FFE100FFE100FFE100FFE100FFF000FFF000FFF000FFFF
00FFFF00E1FF00E1FF00D1FF00B3FF00A3FF0094FF0057FF0075FF0028FF0038FF0500FF
000AFF0038FF0038FF0047FF0057FF0047FF1400FF8000FF3300FF1400FF0028FF0028FF
000AFF2300FF4200FF9E00FF1400FFDC00FF2300FF0038FF0057FF0057FF0047FF0028FF
9E00FF0028FF0057FF0066FF0057FF0066FFFF005C0085FF0094FF00A3FF00A3FF00A3FF
00B3FF00A3FF00A3FF00B3FF00A3FF00A3FF00A3FF00A3FF00A3FF00A3FF0094FF0094FF
0094FF0094FF0085FF0085FF0075FF0075FF0066FF0066FF0066FF0057FF0057FF0047FF
5100FF0028FF0038FF0028FF0028FF0028FF0019FF0019FF0019FF000AFF5100FF4200FF
7000FFFF00A87000FF5100FF6100FFFF00E68F00FFCC00FF5100FF0500FF000AFF000AFF
0019FF000AFF0019FF000AFF000AFF000AFF000AFF000AFF0500FF0500FF0500FF0500FF
1400FF1400FF1400FF2300FF2300FF2300FF3300FF3300FF4200FF4200FF5100FF5100FF
6100FF6100FF7000FF8000FF8000FF8F00FFFF00E6DC00FFFA00FFCC00FFCC00FFCC00FF
DC00FFEB00FFEB00FFFA00FFFF00F5FF00E6FF005CFF00B8FF00B8FF00B8FF00A8FF008A
FF005CFF004CFF002EFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF000FFF006BFF0099FF00C7FF00E6FF0000FF00E6
BD00FFAE00FF9E00FF8F00FF8000FF7000FF6100FF6100FF5100FF5100FF4200FF4200FF
5100FF8000FFFF00006100FF3300FF4200FF6100FF1400FF0500FF0500FF000AFF0500FF
CC00FF0500FF000AFF000AFF1400FF000AFF0028FF0028FF0028FF0028FF0019FF4200FF
9E00FF6100FF0019FF0028FF0028FF6100FF8F00FF0028FF0057FF0075FF0085FF0085FF
0094FF0094FF0094FF0094FF0094FF0094FF00A3FF00A3FF00B3FF00B3FF00B3FF00C2FF
00C2FF00C2FF00C2FF00C2FF00D1FF00D1FF00D1FF00D1FF00D1FF00D1FF00E1FF00D1FF
00E1FF00E1FF00E1FF00E1FF00E1FF00E1FF00E1FF00E1FF00E1FF00E1FF00D1FF00E1FF
00E1FF00E1FF00E1FF00F0FF00F0FF00FFFF00FFFF00FFFF00FFFF00FFFF00F0FF00FFFF
00FFF000FFF000FFE100FFE100FFD100FFD100FFD100FFD100FFC200FFC200FFC200FFC2
00FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA300FFA300FFA300FFA300FFA3
00FFA300FFA300FFA300FFA300FFA300FFA300FFA300FFA300FFA300FFA300FFA300FFA3
00FFA300FFA300FFA300FFA300FFA300FFA300FFA300FFA300FFA300FFA300FFA300FFA3
00FFA300FFA300FFA300FFA300FFA300FFB300FFB300FFB300FFB300FFC200FFC200FFD1
00FFE100FFF000FFF000FFFF00E1FF00E1FF00D1FF00C2FF0085FFFF0000000AFF1400FF
7000FF8000FF0038FF00A3FF00F0FF00FFFF00FFF000FFE100FFD100FFC200FFC200FFB3
00FFB300FFA300FFA300FFA300FFA300FFA300FFA300FFA300FF9400FF9400FF8500FF85
00FF7500FF7500FF7500FF7500FF6600FF6600FF6600FF6600FF5700FF5700FF5700FF57
00FF5700FF5700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0005FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0023FF00
23FF0014FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0033FF0033FF0033FF00
33FF0033FF0023FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF00
00B3FF00B3FF00A3FF0085FF0066FF0028FF000AFF6100FFEB00FFFF001EDC00FF2300FF
000AFF0038FF0047FF0028FF8000FFBD00FF0066FF0085FF0094FF0094FF0085FF9E00FF
0028FF0047FF0094FF0094FF00E1FF00F0FF00FFFF00FFF000FFF000FFE100FFE100FFD1
00FFD100FFC200FFB300FFB300FFA300FFA300FF9400FF9400FF8500FF8500FF8500FF85
00FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF75
00FF7500FF7500FF7500FF7500FF7500FF7500FF8500FF8500FF8500FF8500FF9400FF94
00FF9400FFA300FFC200FFE100FFE100FFFF00B3FF0075FF00F0FF00FFFF00D1FF00FFFF
00FFA300FF9400FF9400FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF9400FFA3
00FFA300FFA300E1FF00FFB300FFB30075FF00B3FF00F0FF00FFC200FFA300FF9400FF85
00FF7500FF7500FF6600FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF57
00FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF47
00FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF5700FF4700FF4700FF4700FF57
00FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF57
00FF5700FF5700FF6600FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF57
00FF5700FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF66
00FF6600FF6600FF6600FF6600FF6600FF7500FF7500FF7500FF7500FF7500FF7500FF75
00FF7500FF7500FF7500FF7500FF8500FF7500FF7500FF7500FF7500FF8500FF8500FF85
00FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF9400FF9400FF9400FF9400FF94
00FF9400FF9400FF9400FF9400FF9400FF9400FF9400FF9400FF9400FFA300FFA300FFA3
00FFA300FFA300FFA300FFA300FFA300FFA300FFA300FFB300FFB300FFB300FFB300FFB3
00FFB300FFC200FFC200FFC200FFC200FFC200FFC200FFC200FFD100FFD100FFD100FFD1
00FFD100FFD100FFE100FFE100FFE100FFE100FFE100FFE100FFF000FFF000FFF000FFFF
00F0FF3300FF00B3FF00B3FF000AFF0066FF0075FF3300FF0500FFEB00FF0500FF0038FF
1400FF8000FF4200FF0028FF0038FF0038FF0019FF3300FF8000FF1400FF000AFF000AFF
2300FFFF00007000FF0500FF0019FFFF00000038FF0057FF0066FF0066FF0057FF000AFF
AE00FF4200FF0066FF0075FF0085FF0085FF0066FF0094FF00A3FF00A3FF00B3FF00B3FF
00B3FF00B3FF00B3FF00B3FF00B3FF00A3FF00A3FF00A3FF00A3FF00A3FF00A3FF0094FF
0094FF0094FF0085FF0075FF0075FF0066FF0057FF0057FF0057FF0047FF0047FF0038FF
6100FF9E00FF0019FF0019FF0019FF9E00FF000AFF000AFF000AFF0500FFFF00A8BD00FF
CC00FF5100FF3300FF2300FF6100FF9E00FF3300FFBD00FFFF00F50500FF0019FF0019FF
0019FF0019FF0019FF0019FF0019FF000AFF000AFF000AFF000AFF0500FF0500FF0500FF
1400FF1400FF1400FF2300FF2300FF3300FF3300FF4200FF4200FF4200FF5100FF5100FF
6100FF7000FF7000FF8000FF8000FF8F00FFBD00FFFF0000FA00FFDC00FFDC00FFDC00FF
EB00FFFF00E6FF00F5FF00F5FF00F5FF00D7FF004CFF008AFF00A8FF00A8FF0099FF008A
FF006BFF004CFF002EFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF002EFF005CFF0099FF00B8FF0000FA00FF
CC00FFAE00FF9E00FF8F00FF8000FF7000FF7000FF6100FF6100FF5100FF5100FF5100FF
6100FF7000FFFF00007000FF7000FFFF002E5100FF2300FF0500FF0500FF0500FF1400FF
BD00FFAE00FF1400FF5100FF5100FF000AFF0019FF0019FF0019FF0019FF000AFF0500FF
EB00FFFF003D0500FF1400FF4200FF8F00FF5100FF0047FF0066FF0075FF0085FF0085FF
0085FF0094FF0085FF0085FF0085FF0075FF0085FF00A3FF00A3FF00B3FF00B3FF00B3FF
00C2FF00C2FF00C2FF00C2FF00C2FF00D1FF00D1FF00D1FF00D1FF00D1FF00D1FF00D1FF
00D1FF00D1FF00E1FF00E1FF00D1FF00E1FF00E1FF00D1FF00D1FF00A3FF00B3FF00D1FF
00D1FF00C2FF0075FF00D1FF00E1FF00F0FF00F0FF00F0FF00F0FF00E1FF00B3FF00A3FF
00FFFF00FFF000FFF000FFE100FFE100FFD100FFD100FFD100FFC200FFC200FFC200FFB3
00FFB300FFB300FFB300FFB300FFB300FFB300FFA300FFB300FFA300FFA300FFA300FFA3
00FFA300FFA300FFA300FFA300FFA300FFA300FFA300FFA300FFA300FFA300FF9400FF94
00FF9400FFA300FF9400FF9400FFA300FFA300FF9400FF9400FFA300FFA300FFA300FFA3
00FFA300FFA300FFA300FFA300FFA300FFA300FFB300FFB300FFB300FFC200FFC200FFD1
00FFF000B3FF00F0FF0500FF0075FF0094FF0094FF0094FF8000FF0085FF0075FF3300FF
0057FFDC00FF0085FF00C2FF00E1FF00FFFF00FFF000FFE100FFD100FFC200FFC200FFB3
00FFB300FFB300FFA300FFA300FFA300FFA300FFB300FFC200FFD100E1FF00FF9400FF85
00FF7500FF7500FF7500FF7500FF7500FF6600FF6600FF6600FF6600FF5700FF5700FF57
00FF5700FF5700FF5700FF4700FF5700FF4700FF4700FF4700FF4700FF4700FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A05FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0014FF0014FF0014FF0014FF0014FF0005FF0005FF0005FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0023FF00
23FF0023FF0014FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0023FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF00
00C2FF00B3FF00A3FF0085FF0075FF0047FF1400FFFF00C7FF003D6100FF2300FF4200FF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00C2FF0094FF0085FF0075FF0057FF4200FFAE00FFFF0000FF007AAE00FF0019FF9E00FF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00A3FF0038FF000AFF4200FF6100FF0028FF0057FF4200FF0500FFFF00000038FF0057FF
0066FF0094FF0094FF0085FF0019FF0057FF0085FF0019FF0075FF00D1FF00E1FF00E1FF
0085FF00B3FF00B3FF2300FF0057FF00A3FF0066FF1400FF2300FF0028FF8000FF0047FF
0066FF00D1FF0075FF0038FF00FFD100FFB300FFA300FF9400FF8500FF8500FF7500FF75
00FF7500FF7500FF7500FF7500FF7500FF7500FF6600FF7500FF6600FF6600FF6600FF66
00FF6600FF6600FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF8500FF8500FF94
00FF9400FFA300FFB300FFC200FFD100D1FF0057FF7000FF00E1FF00FFD100FFB300FFA3
00FF9400FF8500FF8500FF8500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF75
00FF7500FF7500FF7500FF7500FF8500FF9400FFB38000FF00FFB300FF9400FF8500FF94
00FF7500FF6600FF5700FF5700FF5700FF5700FF5700FF4700FF4700FF4700FF4700FF47
00FF5700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF47
00FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF57
00FF4700FF4700FF4700FF4700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF57
00FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF66
00FF5700FF5700FF5700FF5700FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF66
00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7500FF7500FF7500FF75
00FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF8500FF8500FF85
00FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF94
00FF9400FF9400FF9400FF9400FF9400FF9400FF9400FF9400FF9400FF9400FFA300FFA3
00FFA300FFA300FFA300FFA300FFA300FFA300FFA300FFB300FFB300FFB300FFB300FFB3
00FFB300FFC200FFC200FFC200FFC200FFC200FFD100FFD100FFD100FFD100FFD100FFD1
00FFE100FFE100FFE100FFE100FFE100FFE100FFF000FFF000FFF000FFF000FFFF00FFFF
00F0FF00E1FF00E1FF00D1FF00B3FF0085FF00A3FF00A3FF00A3FF0094FF0094FF0085FF
0075FF0057FF0028FF1400FF8000FFAE00FFDC00FFDC00FFDC00FFFF00E6FF00B8FF0000
FF00995100FF000AFF0028FF0047FF0066FF0075FF0075FF0085FF0085FF0085FF0075FF
0057FF8000FF0057FF0094FF00A3FF00A3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF
00C2FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A3FF00A3FF00A3FF0094FF
0094FF0085FF0085FF0075FF0057FF0028FFFF005C0019FF0019FF0500FF0500FF5100FF
FF0000FF00009E00FF5100FF5100FF6100FF3300FF7000FF7000FF9E00FF3300FF1400FF
0500FF000AFF0019FF0019FF000AFF1400FF0019FF0028FF0028FF0028FF0028FF0028FF
0028FF0028FF0028FF0028FF0019FF0019FF0019FF000AFF000AFF0500FF0500FF1400FF
1400FF2300FF2300FF3300FF3300FF3300FF4200FF4200FF4200FF5100FF6100FF7000FF
FF008AEB00FF9E00FF9E00FF9E00FFBD00FFEB00FFFF00E6FF0000FF00B8FF002EFF00C7
FF00A8FF003DFF002EFF006BFF004CFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00B8FF00E6
FA00FFFA00FFFA00FFFF00D7FF00B8CC00FFAE00FFBD00FFEB00FFFF00F5BD00FF9E00FF
FF00A8FF00B8FF002ECC00FF8F00FF7000FF5100FF5100FFAE00FFFF006B5100FF5100FF
7000FFFF00C78000FF5100FF3300FF1400FF1400FF1400FF3300FF8F00FF4200FF5100FF
FF00B85100FF1400FF000AFF0028FF0038FF0047FF0057FF0057FF0057FF0066FF0075FF
0075FF0075FF0066FF0057FF0019FF3300FF0057FF0075FF0075FF0057FF0057FF0500FF
0094FF00B3FF00B3FF00C2FF00C2FF00C2FF00C2FF00C2FF00C2FF00C2FF00C2FF00C2FF
00C2FF00C2FF00B3FF00A3FF00B3FF00B3FF00C2FF00B3FF00A3FF0085FF0028FF0038FF
CC00FF0500FF00A3FF00C2FF00C2FF00D1FF00D1FF00D1FF00C2FF00B3FF0066FF0085FF
00A3FF0075FF0028FF00F0FF00FFF000FFE100FFD100FFD100FFD100FFC200FFC200FFC2
00FFB300FFB300FFB300FFB300FFA300FFA300FFA300FFA300FFA300FFA300FFA300FFA3
00FFA300FFA300FFA300FF9400FF9400FF9400FFA300FF9400FF9400FF9400FF9400FF94
00FF9400FF9400FF9400FF9400FF9400FF9400FF9400FF9400FF9400FF9400FF9400FF94
00FF9400FFA300FFA300FFA300FFA300FFA300FFA300FFB300FFB300FFD100FFFF00E1FF
7000FF00D1FF00B3FF00FFFF00FFF000FFFF00E1FF0066FF00A3FF00F0FF00F0FF00F0FF
00E1FF0057FF3300FFFF00990057FF00C2FF00E1FF00F0FF0057FF00FFFF00FFE100FFE1
00FFD100FFC200FFC200FFC200FFD100FFE100D1FF0038FF00A3FF00FFB300FFA300FF94
00FF9400FF8500FF8500FF8500FF7500FF7500FF6600FF6600FF6600FF6600FF6600FF57
00FF5700FF5700FF5700FF5700FF4700FF4700FF4700FF4700FF4700FF4700FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0000FF0A05FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0023FF00
23FF0014FF0014FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF00
0066FF0038FF0500FF0094FF4200FF0075FF0085FF0075FF0057FF0500FF8000FF0075FF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1400FF0038FF00C2FF00A3FFFF008A0094FF00A3FF0094FF0075FF0028FF0500FF0057FF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00D1FF00E1FF00E1FF00A3FF000AFF00B3FF00C2FF00A3FFCC00FFAE00FF8F00FF2300FF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00FFFF00FFFF00F0FF0019FF00C2FF00D1FF00D1FF00C2FF0094FF0066FF4200FF0085FF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00FFF000FFF000FFF000FFFF00F0FF00F0FF00E1FF00D1FF00B3FF0066FFFF008A0075FF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00FFE100FFE100FFF000FFF000FFFF00F0FF00E1FF00B3FF0085FF0075FF9E00FF0047FF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00FFE100FFE100FFE100FFF000FFF000FFFF00F0FF00D1FF0085FF8F00FFEB00FF0047FF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00FFD100FFD100FFE100FFF000FFF000FFFF00F0FF00D1FF0019FF0075FFFF008A0075FF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00FFD100FFD100FFE100FFF000FFF000FFFF00F0FF00E1FF00C2FF0094FF1400FF0066FF
00B3FF00D1FF00E1FF00F0FF00FFFF00FFE100FFD100FFD100FFC200FFC200FFC200FFC2
00FFC200FFC200FFD100FFFF00E1FF00D1FF4200FF00D1FF00FFF000FFE100FFD100FFA3
00FF9400FF8500FF8500FF8500FF7500FF7500FF7500FF6600FF6600FF6600FF6600FF66
00FF6600FF5700FF6600FF5700FF5700FF6600FF5700FF5700FF5700FF5700FF5700FF57
00FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF6600FF6600FF6600FF66
00FF7500FF7500FF8500FF8500FF9400FFD10075FF6100FF00E1FF00FFA300FF8500FF75
00FF7500FF6600FF6600FF5700FF5700FF5700FF5700FF5700FF4700FF5700FF4700FF47
00FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF47
00FF4700FF4700FF4700FF4700FF4700FF3800FF3800FF4700FF3800FF3800FF3800FF47
00FF3800FF3800FF3800FF3800FF4700FF3800FF3800FF3800FF3800FF4700FF3800FF38
00FF3800FF3800FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF47
00FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF57
00FF4700FF4700FF4700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF57
00FF5700FF5700FF5700FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF66
00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7500FF7500FF7500FF75
00FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF8500FF8500FF85
00FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF9400FF9400FF9400FF9400FF94
00FF9400FF9400FF9400FF9400FF9400FF9400FF9400FF9400FFA300FFA300FFA300FFA3
00FFA300FFA300FFA300FFA300FFA300FFB300FFB300FFB300FFB300FFB300FFB300FFB3
00FFC200FFC200FFD100FFD100FFF00085FF00D1FF0047FF0075FF0094FF0047FF0075FF
00D1FF00E1FF00F0FF00F0FF00F0FF00FFFF00F0FF00F0FF00F0FF00F0FF00F0FF00E1FF
00D1FF5100FF0094FF00A3FF00B3FF00B3FF00A3FF0094FF0075FF0047FF0500FFEB00FF
FF00000500FF0038FF0066FF0075FF0066FF5100FF0075FF0066FF0075FF0066FF0047FF
0019FFAE00FF0038FF0066FF0075FF0085FF0085FF0094FF00A3FF00B3FF00B3FF00B3FF
00C2FF00C2FF00D1FF00D1FF00D1FF00D1FF00D1FF00D1FF00E1FF00D1FF00E1FF00D1FF
00E1FF00D1FF00D1FF00D1FF00D1FF00D1FF00C2FF00C2FF00B3FF00A3FF0094FF000AFF
5100FF5100FF0038FFFA00FF0500FF1400FF0085FF0094FF0094FF0094FF0094FF0085FF
0085FF0085FF0075FF0066FF0047FF0038FF0028FF000AFF7000FF5100FF000AFF0028FF
0038FF0047FF0057FF0057FF0057FF0057FF0057FF0066FF0057FF0057FF0057FF0057FF
0057FF0047FF0028FF6100FFFF005C7000FF1400FF5100FF2300FF2300FF000AFF0500FF
0500FF0500FF1400FF2300FF3300FF5100FF8F00FFFF00C7BD00FF7000FF6100FF6100FF
6100FF6100FF6100FF6100FF6100FF7000FF7000FF7000FF8000FF8F00FF8F00FF9E00FF
9E00FFAE00FFCC00FFFF00D7FF007AFF001EFF0000FF005CFF0099FF00A8FF0099FF008A
FF007AFF005CFF004CFF001EFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF004CFF007AFF00A8FF0099FF00F5EB00FFCC00FF
BD00FFAE00FFAE00FF9E00FF9E00FF8000FF6100FF5100FF4200FF3300FF3300FF3300FF
3300FF3300FF6100FF7000FF0500FF0500FF000AFF000AFF000AFF000AFF0500FF4200FF
0500FF0019FF0019FF0019FF0019FF0019FF0019FF0019FF000AFF1400FF4200FF7000FF
3300FF000AFF0019FF0038FF0047FF0047FF0047FF0038FF000AFF0028FF0019FF0038FF
0019FF0500FF3300FF8F00FF5100FFFF00A82300FF000AFF3300FF3300FFEB00FF9E00FF
FA00FFFF00D70028FF0047FF0057FF0066FF0057FF6100FFFF00008000FF0500FFFF007A
0085FF0094FF0085FF2300FF0094FF00A3FF00C2FF00C2FF00C2FF00C2FF8000FFCC00FF
00C2FF00D1FF00E1FF00F0FF00F0FF00F0FF00F0FF00E1FF00B3FF0057FF00D1FF00E1FF
4200FF00FFF000FFF000FFE100FFE100FFF000E1FF0038FF0085FF00FFF000FFC200FFB3
00FFB300FFB300FFA300FFA300FFA300FFA300FFA300FF9400FFA300FF9400FF9400FF94
00FF9400FF9400FF9400FF9400FF9400FF9400FF9400FF9400FF9400FF9400FF9400FF85
00FF8500FF8500FF8500FF9400FF8500FF8500FF8500FF9400FF8500FF8500FF8500FF85
00FF8500FF8500FF9400FF8500FF8500FF9400FF9400FF9400FF9400FF9400FF9400FF94
00FF9400FF9400FF9400FF9400FF9400FFA300FFA300FFA300FFA300FFA300FFB300FFB3
00FFB300FFC200FFC200FFD100FFD100FFE100FFF000FFFF00C2FF0019FF0057FFBD00FF
FF00B8CC00FFFF00E6FF006B6100FF0047FF0047FF00E1FF00FFF000FFE100FFD100FFC2
00FFB300FFB300FFA300FFA300FF9400FF9400FF9400FF8500FF8500FF8500FF8500FF85
00FF8500FF9400FFB300FFE10038FF00FFA300FF8500FF7500FF6600FF5700FF5700FF57
00FF4700FF4700FF4700FF3800FF3800FF3800FF3800FF3800FF2800FF2800FF3800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A05FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0014FF0014FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0023FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0042FF0042FF0042FF00
00FFC200FFD100FFE100FFF000FFFF00F0FF00E1FF00D1FF00B3FF0047FF0038FFFF002E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00FFC200FFD100FFE100FFFF0094FF000AFF00B3FF00C2FF00A3FFFF00E63300FFFF00F5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00FFC200FFD100D1FF0057FF3300FF0085FF0057FF0075FF0038FF1400FFFF004C0019FF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00FFB300FFC200FFD100FFE100FFF000F0FF00C2FF0047FF0094FF0019FF3300FF6100FF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00FFB300FFB300FFC200FFD100FFE100FFFF3300FF00C2FF00C2FF0094FFCC00FF0094FF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00FFB300FFB300FFB300FFC200FFD10085FF0075FF00F0FF00E1FF0085FFFF00C70038FF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00FFA300FFB300FFB300FFC200FFC200FFD100FFE100FFF000F0FF0085FF0057FF0094FF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00FFA300FFA300FFB300FFB300FFC200FFD100FFE100FFF000F0FF00D1FF000AFFFF00E6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00FFA300FFA300FFB300FFB300FFC200FFC200FFD100FFF04200FF0075FF0047FF0500FF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00FFA300FFA300FFB300FFB300FFC200FFD100FFD100FFF000F0FF0038FF0019FFCC00FF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00FFA300FFA300FFB300FFC200FFC200FFD100FFE100FFF000F0FF00D1FF0057FF0500FF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00FFA300FFB300FFB300FFC200FFD100FFE100FFF000FFF000FFFF00D1FF00A3FF0500FF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00FFA300FFB300FFC200F0FF00F0FF00FFFF00F0FF00FFFF00F0FF0094FF0075FF1400FF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00FFA300FFE100E1FF2300FF8F00FFCC00FF00B3FF00D1FF00D1FF0075FF8F00FF9E00FF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00FF9400FFA300FFD100C2FF00FFF000F0FF00B3FF0066FF1400FF0028FFEB00FFAE00FF
0066FF00B3FF00C2FF0075FF00F0FF00FFE100FFC200FFA300FFA300FF9400FF8500FF85
00FF8500FF8500FF7500FF7500FF7500FF7500FF7500FF6600FF6600FF6600FF6600FF66
00FF6600FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF4700FF47
00FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF3800FF38
00FF4700FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF2800FF3800FF3800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF3800FF28
00FF2800FF2800FF2800FF2800FF3800FF3800FF2800FF2800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF4700FF3800FF3800FF3800FF3800FF4700FF4700FF4700FF4700FF4700FF4700FF47
00FF4700FF4700FF4700FF4700FF4700FF4700FF5700FF5700FF5700FF5700FF5700FF57
00FF5700FF6600FF5700FF5700FF5700FF6600FF6600FF6600FF6600FF6600FF6600FF66
00FF7500FF7500FF7500FF7500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF85
00FF8500FF8500FF8500FF8500FF8500FF8500FF9400FF9400FF9400FF9400FF9400FF94
00FF9400FF9400FFA300FFA300FFA300FFA300FFA300FFB300FFB300FFB300FFB300FFB3
00FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB3
00FFB300FFB300FFB300FFC200FFC200FFC200FFC200FFC200FFC200FFC200FFD100FFD1
00FFD100FFD100FFE100FFE100FFE100FFF000FFFF00FFFF00F0FF00E1FF00E1FF00D1FF
00C2FF00A3FF0057FFFA00FF6100FFFF00A8FF0000FF0000FF00D7FF0000FF00993300FF
000AFF0028FF0085FF00A3FF00C2FF00C2FF00D1FF00D1FF00E1FF00E1FF00F0FF00F0FF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F0FF0038FF00E1FF
00F0FF00F0FF00FFFF00FFFF00FFFF00FFF000FFF000FFFF00FFFF00FFF000FFF000FFF0
00FFF000FFFF00FFF000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF
00F0FF00F0FF00E1FF00E1FF00E1FF00E1FF00E1FF00E1FF00D1FF00D1FF00C2FF00C2FF
00C2FF00C2FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A3FF00A3FF00A3FF00A3FF
00A3FF00A3FF0094FF0094FF0094FF0094FF0094FF0085FF0085FF0085FF0075FF0075FF
0075FF0066FF0066FF0066FF0066FF0057FF0057FF0057FF0047FF0047FF0047FF0038FF
0038FF0038FF0028FF0028FF0028FF0019FF0019FF000AFF0500FF0500FF6100FF3300FF
3300FF3300FF4200FF4200FF4200FF4200FF5100FF6100FF6100FF7000FF8000FF9E00FF
9E00FFBD00FFFF00C7FF0000FF007AFF001EFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF000FFF000FFF004CFF0000FF00C7FF00D7FF00D7FF00F5FF00F5FF00C7FF0000
FF00F5FF00C7FF004CFA00FFEB00FFFF0099FF00E6FF0000FF007AFF001EFF002EEB00FF
9E00FF6100FF4200FF3300FF1400FF0500FF000AFF0019FF0028FF0038FF0047FF0047FF
0057FF0066FF0066FF0066FF0075FF0075FF0075FF0075FF0085FF0085FF0085FF0094FF
0094FF0094FF00A3FF00A3FF00A3FF00B3FF00B3FF00B3FF00B3FF00C2FF00B3FF00C2FF
00C2FF00C2FF00C2FF00D1FF00D1FF00D1FF00D1FF00D1FF00D1FF00D1FF00D1FF00D1FF
00D1FF00D1FF00D1FF00C2FF00C2FF00C2FF00A3FF0085FF0066FF0038FF0019FF000AFF
7000FF8000FF000AFF0057FF0094FF00A3FF00B3FF00B3FF00B3FFFF00F500A3FF00E1FF
00E1FF00F0FF00FFFF00FFF000FFF000FFF000FFE100FFE100FFD100FFD100FFD100FFC2
00FFC200FFC200FFC200FFB300FFB300FFB300FFA300FFA300FFA300FFA300FFA300FFA3
00FF9400FF9400FF9400FF9400FF9400FF9400FF9400FF9400FF9400FF8500FF8500FF85
00FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF85
00FF8500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF75
00FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF75
00FF7500FF7500FF7500FF7500FF7500FF7500FF8500FF8500FF8500FF8500FFA3FA00FF
00FFD100FFB300FFC200FFB300FF9400FF9400FF8500FF8500FF9400FF9400FF9400FFFF
00FFA300FFA300FF9400FF9400FF9400FF9400FF9400FF9400FF9400FF9400FFA300FFA3
00FFA300FFB300FFB300FFB300FFC200FFD100FFF000F0FF0075FF00C2FF0066FF0066FF
0094FF0094FF0075FF00C2FF00D1FF0085FF7000FF4200FF0094FF00FFF000FFD100FFC2
00FFD1000AFF00FFD100E1FF00FF9400FF7500FF7500FF7500FF7500FF8500D1FF00FFE1
00FFF000FFD100F0FF00FFF000FF5700FF4700FF2800FF2800FF2800FF2800FF1900FF19
00FF1900FF1900FF1900FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0014FF0014FF0014FF0014FF00
14FF0005FF0005FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0014FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
42FF0042FF0042FF0042FF00
00FF9400FF9400FFA300FFB300FFD100FFF000E1FF0094FF00C2FF0085FFFF00B80066FF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00FF8500FF9400FFA300FFB300FFC21400FFFF000000E1FF00F0FF00C2FF0075FF0085FF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00FF8500FF9400FF9400FFA300FFE10047FF0085FF00FFF000FFF000F0FF00A3FF0066FF
00C2FF00FFFF00FFE100FFE100FFE100FFE100FFD11400FF00FFA300FF9400FF8500FF85
00FF7500FF7500FF7500FF7500FF7500FF6600FF6600FF6600FF6600FF6600FF6600FF57
00FF5700FF5700FF5700FF5700FF5700FF5700FF4700FF4700FF4700FF4700FF4700FF47
00FF4700FF4700FF4700FF4700FF4700FF4700FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF2800FF3800FF2800FF28
00FF2800FF2800FF2800FF2800FF3800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF3800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF4700FF4700FF4700FF4700FF4700FF4700FF47
00FF4700FF4700FF4700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF57
00FF5700FF5700FF5700FF5700FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF75
00FF7500FF7500FF8500FF8500FF9400B3FF00FFA300FF9400FF9400FF9400FF9400FF94
00FF9400FF9400FF9400FF9400FF9400FF9400FF9400FF9400FF9400FF9400FF9400FFA3
00FFA300FFA300FFA300FFB300FFB300FFC20075FF0085FF00FFF000FFD100FFC200FFC2
00FFC200FFC200FFC200FFB300FFB300FFB300FFC200FFB300FFC200FFC200FFC200FFC2
00FFC200FFC200FFC200FFC200FFC200FFC200FFC200FFC200FFD100FFD100FFD100FFD1
00FFD100FFE100FFE100FFF000FFF000FFFF00FFFF00F0FF00F0FF00D1FF0500FF0085FF
0094FF0075FF0047FF8000FF4200FF0047FF0019FF1400FF0038FF0038FFFF00000500FF
0066FF0085FF00A3FF00B3FF00C2FF00D1FF00E1FF00E1FF00F0FF00F0FF00FFFF00FFFF
00FFFF00FFF000FFF000FFF000FFF000FFF000FFF000FFF000FFF000FFF000FFF000FFF0
00FFF000FFF000FFF000FFF000FFF000FFF000FFF000FFF000FFF000FFF000FFF000FFF0
00FFF000FFF000FFF000FFF000FFF000FFF000FFF000FFF000FFF000FFF000FFF000FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F0FF00F0FF00F0FF00F0FF
00F0FF00F0FF00F0FF00F0FF00E1FF00E1FF00E1FF00E1FF00E1FF00D1FF00D1FF00D1FF
00D1FF00D1FF00C2FF00C2FF00C2FF00C2FF00C2FF00B3FF00B3FF00B3FF00B3FF00B3FF
00A3FF00A3FF00A3FF00A3FF0094FF0094FF0094FF0085FF0085FF0057FF0057FF0057FF
0057FF0047FF0047FF0047FF0047FF0047FF0047FF0047FF0047FF0038FF0038FF0038FF
0028FF0019FF0019FF0019FF0019FF000AFF000AFF0500FF0500FF2300FF4200FF7000FF
FF00008F00FF6100FF6100FF6100FF7000FFFA00FFBD00FF8F00FF9E00FFFF004CFF00C7
FF00F5FF00E6FF008AFF00B8FF0000FF002EFF001EFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF000FFF000FFF0000FF0000FF0000FF006BFF0099FF00B8FF006B
FF00E6FF00F5FF00C7FF00A8DC00FF9E00FF8F00FFFA00FF8000FF6100FF5100FF5100FF
5100FFAE00FFFF00E6AE00FFBD00FFBD00FF8F00FFAE00FFFF00F53300FF0500FF3300FF
0047FF0057FF0066FF0066FF0066FF0075FF0075FF0075FF0085FF0085FF0085FF0085FF
0094FF0094FF0094FF00A3FF00A3FF00A3FF00B3FF00B3FF00B3FF00C2FF00C2FF00C2FF
00D1FF00D1FF00D1FF00D1FF00D1FF00D1FF00D1FF00E1FF00E1FF00E1FF00E1FF00E1FF
00E1FF00E1FF00E1FF00D1FF00D1FF00D1FF00C2FF00B3FF00B3FF00B3FF0066FF0094FF
00A3FF0094FF0057FF2300FF5100FF8000FF0038FF000AFF0038FF2300FF0066FF0085FF
00B3FF00D1FF00F0FF00F0FF00FFFF00FFFF00FFFF00E1FF0028FF00FFF000FFE100FFD1
00FFD100FFC200FFC200FFB300FFB300FFB300FFB300FFA300FFA300FFA300FFA300FFA3
00FF9400FF9400FF9400FF9400FF9400FF9400FF9400FF8500FF8500FF8500FF8500FF85
00FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF7500FF7500FF75
00FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF75
00FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF75
00FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF85
00FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF75
00FF7500FF7500FF7500FF7500FF7500FF8500FF8500FF8500FF8500FF8500FF8500FF94
00FF9400FF9400FFA300FFA300FFB300FFB300FFC200FFD100FFE100E1FF0028FF00C2FF
00FFF000FFE100FFD100FFC200FFC200FFD10500FF00FFE100FFD100FFC200FFE100E1FF
0057FF0500FF0057FF00A3FF00F0FF00FFFF00FFB300FFC200E1FF00E1FF00FFB300FF94
00FFFF00FF5700FF4700FF4700FF3800FF3800FF2800FF2800FF2800FF1900FF1900FF19
00FF1900FF1900FF1900FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A05FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
14FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0023FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
42FF0042FF0042FF0042FF00
00FF8500FF9400FF9400FFA300FFB300FFD100FFD100FFD100FFE100C2FF0038FF3300FF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00FF8500FF8500FF9400FF9400FFA300FFB300FFC200FFC200FFD100FFF000D1FF0038FF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00FF8500FF8500FF9400FF9400FFA300FFA300FFB300FFC200FFD100FFF000D1FF5100FF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00FF8500FF8500FF9400FF9400FF9400FFA300FFB300FFC200E1FF00B3FF00C2FF0500FF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00FF8500FF8500FF9400FF9400FFA300FFA300FFA300FFB300FFD100E1FF0038FF3300FF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00FF8500FF8500FF9400FF9400FF9400FFA300FFB300FFB300FFD100F0FF00E1FF0500FF
00E1FF00FFFF00FFE100FFC200FFB300FFA300FFA300FF9400FF9400FF8500FF8500FF85
00FF7500FF8500FF7500FF7500FF7500FF7500FF6600FF6600FF6600FF6600FF5700FF57
00FF5700FF5700FF5700FF5700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF47
00FF4700FF4700FF3800FF3800FF3800FF3800FF4700FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF2800FF2800FF2800FF3800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF3800FF2800FF2800FF2800FF2800FF2800FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF4700FF4700FF4700FF4700FF47
00FF4700FF5700FF4700FF4700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF57
00FF6600FF6600FF6600FF6600FF6600FF6600FF7500FF6600FF7500FF7500FF7500FF75
00FF8500FF8500FF9400FF9400FFB30094FF00C2FFFF003D00B3FF00F0FF00FFE100FFC2
00FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC2
00FFE100F0FF2300FF00C2FF00F0FF00F0FF00D1FF6100FF0094FF00E1FF00FFF000FFF0
00FFE100FFE100FFE100FFE100FFE100FFE100FFFF00FFFF00FFFF00F0FF0085FF00B3FF
00FFFF00FFF000FFE100FFE100FFE100FFE100FFE100FFE100FFE100FFF000FFF000FFF0
00FFFF00F0FF0500FF0038FF2300FF0057FF0075FF0057FFBD00FF9E00FF0028FF00A3FF
00B3FF1400FF00B3FF00D1FF00E1FF00E1FF00E1FF00E1FF00D1FF00C2FF00A3FF0028FF
7000FF00B3FF00C2FF00B3FF00B3FF00A3FF0057FFFF004C0075FF00A3FF00F0FF00FFFF
00FFF000FFE100FFE100FFE100FFE100FFE100FFD100FFE100FFD100FFE100FFD100FFE1
00FFD100FFE100FFD100FFD100FFD100FFD100FFE100FFE100FFE100FFE100FFE100FFE1
00FFE100FFE100FFE100FFF000FFE100FFE100FFF000FFF000FFF000FFF000FFF000FFF0
00FFF000FFF000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F0FF00F0FF00F0FF
00F0FF00F0FF00F0FF00E1FF00E1FF00E1FF00E1FF00E1FF00E1FF00E1FF00E1FF00D1FF
00D1FF00D1FF00D1FF00D1FF00C2FF00C2FF00C2FF00C2FF00B3FF00B3FF00B3FF00A3FF
00A3FF00A3FF00A3FF0094FF0094FF0094FF0085FF0085FF0075FF0066FF0057FF0047FF
0038FF000AFF4200FF8000FF0500FF000AFF0019FF0019FF0019FF000AFF0500FF2300FF
7000FFCC00FFFF00E67000FF6100FF6100FF8000FFFF008A9E00FFCC00FFFF0000FF00C7
DC00FFFF00E6FF004CFF00F59E00FF8F00FFAE00FFCC00FF8F00FF8000FF7000FF8000FF
8000FF8F00FF8F00FF9E00FFAE00FFCC00FFFA00FFFA00FFFF00F5FF00C7FF00A8FF003D
FF001EFF0000FF002EFF002EFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF002EFF004CFF006BFF0099FF00B8FF00A8FF0000FF00B8FA00FF
DC00FFBD00FFAE00FF9E00FF9E00FF9E00FFBD00FFFF00008F00FF5100FF3300FF3300FF
2300FF1400FF1400FF0500FF0500FF000AFF0019FF0019FF0028FF0028FF0038FF0038FF
0038FF0047FF0047FF0047FF0047FF0047FF0047FF0047FF0038FF0019FF5100FF1400FF
9E00FF7000FF6100FFFF00008F00FF7000FF7000FF0028FF0094FF00B3FF00C2FF00D1FF
00D1FF00D1FF00E1FF00E1FF00E1FF00E1FF00E1FF00F0FF00F0FF00F0FF00F0FF00F0FF
00F0FF00F0FF00F0FF00F0FF00E1FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00E1FF
00E1FF00D1FF0066FF0066FF0028FF0094FF0066FF0019FF00A3FF00C2FF00C2FF00A3FF
0075FF2300FF0066FFFF0000FA00FF8000FFBD00FFFF00D79E00FF00B3FF00D1FF00F0FF
00F0FF00FFF000FFF000FFE100FFF000FFFF00FFE100FFB300FFB300FFA300FFA300FFA3
00FF9400FF9400FF9400FF9400FF9400FF8500FF8500FF8500FF8500FF8500FF8500FF85
00FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF7500FF7500FF7500FF7500FF75
00FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF75
00FF7500FF6600FF6600FF6600FF6600FF7500FF6600FF6600FF6600FF6600FF6600FF66
00FF6600FF7500FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF66
00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF66
00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7500FF7500FF7500FF7500FF85
00FF8500FF9400FFA300FFB300FFC200FFFF0085FF7000FF00FFC200FFA300FFA300FFA3
00FFC200E1FF0066FF00F0FF00FF8500FF7500FF7500FF6600FF6600FF6600FF6600FF66
00FF6600FF6600FF6600FF6600FF6600FF7500FF8500FFA300FFD100B3FF00FFFF00FFA3
0066FF00FF7500FF5700FF4700FF3800FF3800FF2800FF2800FF2800FF1900FF1900FF19
00FF1900FF1900FF1900FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A05FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0014FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
42FF0042FF0042FF0042FF0042FF0042FF0033FF0042FF0042FF0042FF0042FF0042FF00
42FF0042FF0042FF0042FF00
00FF8500FF8500FF9400FF9400FF9400FFA300FFB300FFB300FFC200FFE100F0FF000AFF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00FF8500FF8500FF9400FF9400FFA300FFA300FFB300FFB300FFC200FFD100F0FF7000FF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00FF9400FF9400FF9400FFA300FFA300FFB300FFC200FFC200FFD100FFE100FFFF0047FF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00FF9400FF9400FFA300FFA300FFB300FFB300FFC200FFD100FFE100FFF000F0FF0094FF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00FF9400FF9400FFB300FFE100FFC200FFC200FFD100FFFF00E1FF00C2FF0500FF00E1FF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00FF9400FFA300FFC20085FF00FFF000FFE100FFF000C2FF5100FFDC00FF0057FF00FFF0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00FFA300FFB300FFD100F0FF00D1FF00FFFF0019FF0038FF00B3FF0047FF00FFE100FFD1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00FFA300FFC20075FF6100FF00B3FF6100FF4200FF0028FF00FFFF00FFF000FFC200FFC2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00FFB300FFC200FFE100F0FF2300FFFF00E60085FF00FFFF00FFD100FFC200FFB300FFB3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00FFC200FFE100FFF00085FF0075FF9E00FF0075FF00C2FF00FFD100FFB300FFA300FFA3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00FFE10085FF00D1FF2300FF00D1FF00FFFF0028FF00FFE100FFC200FFA300FFA300FF94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00FFFF00A3FF4200FF00D1FF00FFE100FFD100A3FF00FFC200FFA300FF9400FF9400FF94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00E1FF000AFF00B3FF00E1FF00FFD100FFC200FFB300FFA300FF9400FF9400FF9400FF85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0085FFAE00FF00F0FF00FFF000FFC200FFB300FFA300FF9400FF9400FF8500FF8500FF85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FA00FF0075FF00F0FF00FFD100FFC200FFA300FF9400FF9400FF8500FF8500FF8500FF85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0094FF2300FF00F0FF00FFFF00FFE100FFB300FF9400FF8500FF8500FF7500FF7500FF75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00F0FF00E1FF00C2FF0019FF0075FF00FFFF00FF9400FF8500FF7500FF7500FF7500FF75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00FFE100FFFF00C2FF00FFC200FFB300FFA300FF8500FF7500FF7500FF7500FF6600FF66
00FF6600FF6600FF7500FF7500FF7500FF7500FF8500FF8500FF9400FF9400FFA300FFB3
00FFD100F0FF00E1FF0085FF0019FF00C2FF0094FF00E1FF00F0FF00D1FF00F0FF00FFF0
00D1FF00FFD10500FF00FFC200FFC200FF8500FF6600FF5700FF5700FF4700FF4700FF47
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF38
00FF3800FF3800FF3800FF3800FF3800FF4700FF4700FF4700FF4700FF4700FF5700FF57
00FF6600FF7500FF7500FF8500FFA300FFB300FFF00019FF0075FF00D1FF00FFD100FFB3
00FFB300FFA300FFA300FFA300FFA300FFB300FFE100FFF000FFF000C2FF00C2FF00FFFF
00FFFF00C2FF00D1FF0057FF0028FF0019FF00A3FF00E1FF00F0FF00E1FF00E1FF00D1FF
00E1FF000AFF7000FF00B3FF00F0FF00FFF000FFE100FFD100FFC200FFC200FFB300FFB3
00FFB300FFB300FFB300FFB300FFB35100FF00FFD100FFC200FFB300FFB300FFB300FFB3
00FFB300FFA300FFA300FFA300FFA300FFB300FFB300FFB300FFB300FFB300FFB300FFB3
00FFC200FFC200FFC200FFD100FFD100FFE100D1FF0094FF00C2FF00C2FF00A3FF0047FF
0075FF00B3FF00C2FF0038FF00A3FF00FFF000FFE100FFE100FFD100FFD100FFC200FFC2
00FFC200FFC200FFC200FFC200FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB3
00FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB3
00FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB3
00FFB300FFB300FFC200FFC200FFC200FFC200FFC200FFC200FFD100FFD100FFD100FFD1
00FFE100FFE100FFE100FFF000FFF000FFF000FFF000FFFF00FFFF00F0FF00E1FF00D1FF
00C2FF00A3FF3300FF0019FF00A3FF00B3FF00B3FF00B3FF00A3FF00A3FF0094FF0075FF
0047FFFF00A80047FF0066FF0075FF0075FF0075FF0057FF0028FFAE00FF0066FF0085FF
0085FF0094FF0094FF0085FF0085FF0019FF0019FF000AFF000AFF2300FF7000FFCC00FF
000AFF0028FF0019FF000AFFFA00FF1400FF0028FF0047FF0057FF0066FF0075FF0075FF
0075FF0085FF0075FF0075FF0038FF0038FF0066FF0075FF0066FF0066FF1400FF0057FF
0057FF0066FF0066FF0066FF0066FF0066FF0066FF0057FF0057FF0038FF0500FF2300FF
FF00F58000FF7000FF3300FF7000FFCC00FF5100FF9E00FF8000FFFF0000DC00FF8F00FF
AE00FFBD00FFFF00B8FF006BFF0000FF008AFF0000FF001EFF0000FF001EFF001EFF001E
FF007AFF007AFF007AFF000FFF005CFF000FFF0000FF001EFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF005CFF00C7
FF00C7CC00FFAE00FF9E00FFFA00FF8000FF9E00FF7000FF2300FF000AFF0028FF0038FF
0047FF0057FF0066FF0066FF0075FF0075FF0085FF0085FF0085FF0085FF0094FF0094FF
0094FF00A3FF00A3FF00A3FF00A3FF00B3FF00C2FF00C2FF00C2FF00D1FF00D1FF00D1FF
00E1FF00E1FF00E1FF00F0FF00F0FF00F0FF00F0FF00F0FF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFF000FFF000FFF000FFF000FFF000FFE100FFE100FFE100FFE100FFE1
00FFE100FFE100FFD100FFD100FFD100FFD100FFD100FFD100FFD100FFD100FFC200FFC2
00FFC200FFC200FFC200FFC200FFC200FFB300FFB300FFB300FFB300FFB300FFB300FFB3
00FFA300FFA300FFA300FFA300FFA300FFA300FFA300FFA300FFA300FFA300FF9400FF94
00FF9400FF9400FF9400FF9400FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF85
00FF8500FF8500FF8500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF75
00FF7500FF7500FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF66
00FF6600FF6600FF6600FF6600FF6600FF6600FF5700FF5700FF5700FF5700FF5700FF57
00FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF47
00FF4700FF4700FF4700FF5700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF47
00FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF47
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
42FF0042FF0042FF0042FF00
00FFC200FFD10094FF00FFE100FF9400FF8500FF7500FF7500FF7500FF7500FF6600FF66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00FFB300FFB300E1FF00FFFF00FF9400FF7500FF7500FF6600FF6600FF6600FF6600FF66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00FFA300FFA300FFA300B3FF00FF8500FF7500FF7500FF6600FF6600FF6600FF6600FF57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00FF9400FF8500FF8500FF8500FF7500FF6600FF6600FF6600FF6600FF5700FF5700FF57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00FF8500FF8500FF7500FF7500FF6600FF6600FF6600FF5700FF5700FF5700FF5700FF57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00FF8500FF7500FF7500FF7500FF6600FF6600FF5700FF5700FF5700FF5700FF5700FF57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00FF8500FF7500FF7500FF6600FF6600FF5700FF5700FF5700FF5700FF5700FF4700FF57
00FF4700FF4700FF5700FF5700FF5700FF5700FF5700FF6600FF8500FFB30047FF00F0FF
00FFC200FFC200FFF00019FF00FFE100FFE100FFE100F0FF0094FF3300FF0038FF00D1FF
00FFA300FF9400FF8500FF8500FF7500FF6600FF6600FF6600FF5700FF5700FF5700FF57
00FF4700FF4700FF4700FF3800FF3800FF3800FF3800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF0A00FF0A00FF0A
00FF0A00FF1900FF1900FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF1900FF1900FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF4700FF4700FF4700FF4700FF5700FF66
00FF8500FFC200FFB30028FF00FFE100FFFF8F00FF00FFD100FFE100FFFF00A3FFFF00A8
FF00D700C2FF0094FF0019FF00A3FF00A3FF0028FF0075FF00D1FF00E1FF00FFFF00FFFF
0094FF00E1FF00FFD100FFC200FFB300FFA300FFA300FFA300FFA300FFA300FFC20094FF
00C2FFFF007A00F0FF00FFB300FFA300FFA300FFA300FFC200FFD100FFA300FF9400FF85
00FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF94
00FF8500FF9400FF9400FF9400FF9400FF9400FF9400FFA300FFA300FFA300FFA300FFB3
00FFB300FFC200FFD100FFD100FFE100FFE100FFF000FFFF00F0FF00B3FF0047FFAE00FF
0057FF0075FF00F0FF00FFFF00FFF000FFE100FFD100FFD100FFD100FFC200FFC200FFB3
00FFB300FFB300FFB300FFB300FFA300FFB300FFA300FFA300FFA300FFA300FFA300FFA3
00FFA300FFA300FFA300FFA300FFA300FFA300FFA300FFA300FFA300FFA300FFA300FFA3
00FFA300FFA300FFA300FFA300FFA300FFA300FFA300FFA300FFB300FFA300FFA300FFB3
00FFB300FFB300FFB300FFB300FFB300FFC200FFC200FFC200FFD100FFD100FFE100FFF0
00F0FF00D1FF5100FF0085FF00C2FF00D1FF00C2FF00A3FF0057FF0028FF0066FF0038FF
3300FF0038FF0066FF0057FF0028FF000AFF0075FF00A3FF00B3FF00C2FF00C2FF00C2FF
0085FF00A3FF00B3FF00A3FF00C2FF00C2FF00C2FF00C2FF00B3FF00B3FF00A3FF00A3FF
0094FF0075FF4200FF8F00FF0047FF0075FF0094FF0094FF00A3FF00A3FF00A3FF00A3FF
00A3FF00A3FF0094FF0066FF0094FF00A3FF00A3FF00B3FF00B3FF00B3FF00B3FF00B3FF
00B3FF00B3FF00B3FF00A3FF00A3FF00A3FF00A3FF0094FF0094FF0094FF0094FF0094FF
0085FF0085FF0085FF0085FF0075FF0075FF0075FF0066FF0066FF0066FF0066FF0057FF
0057FF0047FF0019FFFF005C7000FF8F00FF5100FF3300FF3300FF2300FF2300FF2300FF
2300FF3300FF4200FF5100FF6100FF7000FF8000FF8F00FF8F00FF9E00FFAE00FFBD00FF
DC00FFFA00FFFF00D7FF0099FF004CFF004CFF002EFF001EFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF001EFF003DFF004CFF005CFF006BFF005CFF003DFF0000FF002E
FF007AFF0099FF00A8FF0099FF00B8FF00B8FF00A8FF008AFF0000FF0000FF006BFF008A
FF0000FF003DFF006BFF0000FF0000FF0000FF0000FF0000FF0000FF004CFF0099FF00C7
FF00A8FF0000FF004CFF00E6FF00F5FF007AFF0000FF00F5FF0000FF00C7FF008AFF00C7
FF00C7EB00FFBD00FFFF0000BD00FF9E00FF7000FF3300FF0500FF0019FF0019FF0028FF
0038FF0047FF0047FF0047FF0028FF3300FF0047FF0075FF0085FF0085FF0094FF0094FF
00A3FF00A3FF00A3FF00B3FF00B3FF00B3FF00C2FF00C2FF00C2FF00C2FF00D1FF00D1FF
00D1FF00D1FF00D1FF00E1FF00E1FF00E1FF00E1FF00E1FF00E1FF00E1FF00E1FF00E1FF
00F0FF00F0FF00FFFF00FFFF00FFF000FFF000FFF000FFF000FFF000FFE100FFE100FFE1
00FFE100FFD100FFD100FFD100FFD100FFD100FFD100FFD100FFC200FFC200FFC200FFC2
00FFC200FFC200FFC200FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB3
00FFA300FFA300FFA300FFA300FFA300FFA300FFA300FFA300FF9400FF9400FF9400FF94
00FF9400FF9400FF9400FF9400FF9400FF9400FF8500FF8500FF8500FF8500FF8500FF85
00FF8500FF8500FF8500FF8500FF8500FF8500FF7500FF7500FF7500FF7500FF7500FF75
00FF7500FF7500FF7500FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF66
00FF6600FF6600FF6600FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF57
00FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF4700FF4700FF4700FF47
00FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF47
00FF4700FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF2800FF2800FF2800FF28
00FF2800FF3800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF1900FF2800FF2800FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A05FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
42FF0042FF0042FF0042FF00
00FF8500FF7500FF6600FF6600FF5700FF5700FF5700FF5700FF4700FF4700FF4700FF47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00FFA300FF8500FF7500FF6600FF5700FF5700FF5700FF4700FF4700FF4700FF4700FF47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2300FF00FFA300FF7500FF6600FF5700FF5700FF4700FF4700FF4700FF4700FF4700FF47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00D1FF00FFD100FF8500FF5700FF5700FF5700FF4700FF4700FF4700FF4700FF4700FF47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00FF8500FF8500FF7500FF5700FF5700FF4700FF4700FF4700FF3800FF4700FF3800FF38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00FF7500FF6600FF5700FF5700FF4700FF4700FF4700FF3800FF3800FF3800FF3800FF38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00FF6600FF5700FF5700FF4700FF4700FF4700FF3800FF3800FF3800FF3800FF3800FF38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00FF6600FF5700FF4700FF4700FF4700FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF4700FF47
00FF4700FF5700FF5700FF5700FF6600FF6600FF7500FF8500FFA300FFC200FFC200FFE1
6100FF6100FF00E1FF00F0FF00FFF00075FF00FFB300FFB300FFC200E1FF5100FF00FFC2
00FFA300FF8500FF6600FF5700FF4700FF3800FF3800FF2800FF2800FF2800FF2800FF28
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF38
00FF3800FF3800FF3800FF3800FF4700FF4700FF4700FF5700FF5700FF5700FF5700FF66
00FF7500FF8500FFE100FFD100FFB300FFB300FFD100D1FF0028FF7000FF00E1FF00FFE1
00FFD100FFC200FFC200FFD100FFE100FFFF00B3FF00B3FF0066FF00FFF000FFFF00FFC2
00FFA300FF9400FF8500FF8500FF7500FF7500FF7500FF6600FF6600FF6600FF6600FF66
00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF66
00FF6600FF6600FF7500FF6600FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF75
00FF8500FF8500FF8500FF8500FF8500FF9400FF9400FF9400FF9400FFA300FFA300FFA3
00FFB300FFB300FFD100FFF000FFFF00FFFF00F0FF00E1FF00B3FF0066FF0038FF0047FF
00C2FF00D1FF00C2FF0028FF0047FF00F0FF00FFF000FFD100FFC200FFC200FFB300FFB3
00FFA300FFA300FFA300FFA300FFA300FFA300FFA300FF9400FF9400FF9400FF9400FF94
00FF9400FF9400FF9400FF9400FF9400FF9400FF9400FF9400FF9400FF9400FF9400FF94
00FF9400FF9400FF9400FF9400FF9400FF9400FF9400FF9400FF9400FFA300FFA300FFA3
00FFA300FFB300FFB300FFB300FFB300FFC200FFD100FFD100FFE100FFE100FFF000F0FF
7000FF000AFF0066FF00A3FF00D1FF00D1FF00A3FF0047FF00A3FF0028FF0066FF00F0FF
00FFF000FFF000FFF000FFF000FFF000FFF000FFF000FFF000FFF000FFF000FFF000FFFF
00FFFF00FFFF00FFFF00F0FF00F0FF00E1FF00E1FF00D1FF00C2FF00B3FF0057FF6100FF
0019FFFF0000AE00FF1400FFFF005C0500FF0075FF00B3FF00C2FF00D1FF00D1FF00D1FF
00D1FF00D1FF00D1FF00D1FF00D1FF00D1FF00D1FF00D1FF00D1FF00D1FF00D1FF00D1FF
00C2FF00C2FF00C2FF00B3FF00B3FF00A3FF0094FF0094FF0085FF0085FF0075FF0075FF
0057FF3300FF0019FF0047FF0057FF0047FF0047FF0038FF0047FF0047FF0047FF0047FF
0038FF0038FF0028FF3300FF000AFF000AFF000AFF0500FF1400FF5100FFAE00FF5100FF
4200FF4200FF5100FF6100FF7000FF8000FF9E00FFAE00FFCC00FFEB00FFFF00F5FF00A8
FF006BFF0000FF002EFF006BFF005CFF004CFF001EFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF001EFF003DFF004CFF0000
FF002EFF0000FF0000FF0000FF008AFF0099FF00B8FF00E6FF00F5FA00FFFF00F5FF00B8
FF005CDC00FFBD00FFBD00FFBD00FFBD00FFBD00FFCC00FFFA00FFFF0000FF007AFF008A
CC00FF9E00FF8F00FF8F00FF8F00FF9E00FFEB00FFDC00FFFF007ABD00FF8F00FF7000FF
6100FF5100FF4200FF3300FF2300FF2300FF2300FF2300FF4200FFAE00FF7000FF3300FF
6100FF7000FFFF00D7000AFF0028FF0038FF0038FF0038FF0038FF0028FF0019FF000AFF
1400FF5100FFFF008AFF00C74200FFAE00FFFA00FF2300FF0019FF2300FF000AFF000AFF
0047FF0047FF0038FF0500FF2300FF0028FF7000FF3300FF4200FF0085FF0094FF00A3FF
00A3FF00A3FF00A3FF00A3FF00A3FF0094FF0085FF0028FFFF00993300FF0094FF00B3FF
00C2FF00C2FF00D1FF00D1FF00D1FF00D1FF00D1FF00C2FF00F0FF00FFFF00FFFF00FFF0
00FFF000FFE100FFE100FFE100FFE100FFE100FFD100FFD100FFD100FFD100FFD100FFD1
00FFC200FFC200FFC200FFC200FFC200FFC200FFC200FFC200FFB300FFB300FFB300FFB3
00FFB300FFB300FFB300FFB300FFA300FFA300FFA300FFA300FFA300FFA300FFA300FFA3
00FFA300FFA300FF9400FF9400FF9400FF9400FF9400FF9400FF9400FF9400FF9400FF94
00FF9400FF9400FF9400FF9400FF9400FF9400FF9400FF9400FF8500FF8500FF8500FF85
00FF8500FF7500FF7500FF7500FF7500FF7500FF7500FF6600FF6600FF6600FF6600FF66
00FF6600FF6600FF6600FF6600FF6600FF6600FF5700FF5700FF5700FF5700FF5700FF57
00FF5700FF5700FF5700FF5700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF47
00FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF3800FF3800FF47
00FF4700FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A05FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0014FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
42FF0042FF0042FF0042FF00
00FF6600FF5700FF4700FF4700FF4700FF3800FF3800FF3800FF3800FF3800FF3800FF38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00FF5700FF4700FF4700FF3800FF3800FF3800FF3800FF3800FF3800FF2800FF2800FF28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00FF5700FF4700FF3800FF3800FF3800FF3800FF3800FF2800FF2800FF2800FF2800FF28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00FF4700FF4700FF3800FF3800FF3800FF3800FF2800FF2800FF2800FF2800FF2800FF28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00FF4700FF3800FF3800FF3800FF3800FF2800FF2800FF2800FF2800FF2800FF2800FF28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00FF3800FF3800FF3800FF3800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28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00FF3800FF3800FF3800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28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00FF3800FF3800FF2800FF2800FF2800FF2800FF2800FF2800FF1900FF2800FF1900FF28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00FF3800FF2800FF2800FF2800FF2800FF2800FF1900FF2800FF1900FF1900FF1900FF19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00FF3800FF2800FF2800FF2800FF2800FF2800FF1900FF1900FF1900FF1900FF1900FF19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00FF3800FF2800FF2800FF2800FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19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00FF2800FF2800FF2800FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19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00FF2800FF2800FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19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00FF2800FF2800FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19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00FF2800FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF0A00FF0A00FF0A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00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF0A00FF0A00FF0A00FF0A00FF0A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00FF1900FF1900FF1900FF1900FF1900FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A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00FF1900FF1900FF1900FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A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00FF1900FF1900FF0A00FF1900FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A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00FF1900FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A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00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A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00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A05FF00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00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A05FF0005FF0000FF0A05FF00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00FF0A00FF0A00FF0A00FF0A00FF0A05FF0005FF0000FF0A05FF0005FF0000FF0A05FF00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00FF0A00FF0A00FF0A05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00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00FF0A05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00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05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00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05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00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05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00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05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00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05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00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05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0014FF0014FF0005FF0005FF00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05FF0005FF0005FF0005FF0014FF0014FF0014FF0005FF0014FF0014FF0014FF0005FF00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05FF0014FF0014FF0005FF0014FF0014FF0014FF0005FF0014FF0014FF0014FF0014FF00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05FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00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14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00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14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0014FF0014FF0005FF00
05FF0014FF0014FF0014FF0014FF0005FF0014FF0014FF0014FF0014FF0014FF0005FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0005FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0005FF0005FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0000FF0A05FF0005FF0005FF0005FF0005FF0005FF0000FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF0A00FF0A00FF0A00FF0A
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF3800FF3800FF3800FF3800FF3800FF3800FF4700FF4700FF47
00FF4700FF5700FF5700FF5700FF6600FF6600FF7500FF7500FF8500FF9400FFA300FFF0
00F0FF00FFFF0057FF0094FF00D1FFFF00000085FF00F0FF00E1FF0085FF0047FF00F0FF
00E1FF00FFFF00F0FF00FFE100FFD100FFC200FFA300FF9400FF8500FF8500FF7500FF75
00FF7500FF7500FF7500FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF66
00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF66
00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7500FF66
00FF6600FF6600FF6600FF6600FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF75
00FF7500FF7500FF7500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF85
00FF8500FF8500FF8500FF8500FF8500FF9400FF9400FF9400FF9400FF9400FF9400FF94
00FF9400FF9400FF9400FF9400FF9400FFA300FFA300FFA300FFA300FFA300FFA300FFA3
00FFA300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC200FFC200FFC2
00FFC200FFC200FFC200FFC200FFD100FFD100FFD100FFD100FFD100FFD100FFE100FFE1
00FFE100FFE100FFF000FFF000FFF000FFF000FFFF00F0FF00E1FF00D1FF6100FF8F00FF
0057FF3300FF6100FF0028FF0057FF0057FF00A3FF00A3FF00B3FF00B3FF00B3FF00A3FF
00A3FF00A3FF0094FF0085FF0066FF0047FF0038FF0019FF3300FFDC00FFBD00FFDC00FF
FF008A2300FF0019FF0019FF8000FF0057FF0066FF0075FF0075FF0057FF0066FF0085FF
0085FF0085FF0085FF0085FF0085FF0085FF0085FF0075FF0075FF0075FF0075FF0066FF
0066FF0057FF0057FF0047FF0047FF0038FF0028FF0019FF1400FF8F00FF9E00FF4200FF
FF00F51400FF000AFF0019FF0028FF0028FF0028FF0028FF0028FF0019FF0500FF2300FF
4200FFFF00D78000FF6100FF2300FF1400FF2300FF4200FF8000FFBD00FF6100FF3300FF
2300FF2300FF2300FF2300FF2300FF3300FF3300FF3300FF4200FF6100FFBD00FFFF0000
9E00FF8F00FF8F00FF9E00FFAE00FFCC00FFEB00FFFF00E6FF00B8FF000FFF0000FF000F
FF000FFF003DFF0000FF004CFF003DFF0000FF0000FF005CFF003DFF0000FF0000FF002E
FF004CFF004CFF002EFF000FFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF001EFF004C
FF005CFF007AFF007AFF007AFF007AFF0000FF007AFF006BFF0000FF0000DC00FFCC00FF
DC00FFDC00FFFA00FFFF002EEB00FFEB00FFFF00B8FF007AFF003D7000FF5100FF4200FF
4200FF5100FF5100FF6100FF7000FF8F00FFFF00C7BD00FF9E00FFBD00FFFF0000AE00FF
8F00FF8F00FF5100FF3300FF5100FFEB00FF3300FFFF007A9E00FF0500FF0028FF0038FF
0038FF0038FF0028FF0500FF1400FF0500FF0500FF0075FF0085FF0085FF0094FF0094FF
0094FF00A3FF00A3FF00A3FF00A3FF00B3FF00B3FF00B3FF00B3FF00C2FF00C2FF00C2FF
00C2FF00D1FF00D1FF00D1FF00D1FF00E1FF00E1FF00E1FF00F0FF00F0FF00F0FF00F0FF
00F0FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF000FFF000FFF000FFF000FFF0
00FFF000FFF000FFF000FFF000FFE100FFF000FFE100FFE100FFE100FFE100FFE100FFE1
00FFE100FFE100FFE100FFE100FFE100FFE100FFE100FFE100FFE100FFE100FFE100FFE1
00FFE100FFF000FFF000FFFF00F0FF00E1FF00D1FF00C2FF0094FF0500FF000AFF0094FF
00B3FF00C2FF00B3FF0085FFFF00D70085FF00B3FF00D1FF00E1FF00E1FF00E1FF00E1FF
00E1FF00D1FF00D1FF00D1FF00C2FF00C2FF00C2FF00C2FF0028FF0066FF8F00FF0057FF
0500FF9E00FF9E00FF000AFF8F00FF0500FF0500FF3300FF7000FF0500FF0028FF8F00FF
000AFFFF00F50038FF0047FF0019FF9E00FF0019FF0075FF0085FF00B3FF00C2FF00D1FF
00E1FF00F0FF00FFFF00FFF000FFE100FFE100FFD100FFD100FFD100FFC200FFC200FFC2
00FFB300FFB300FFB300FFB300FFA300FFA300FFA300FF9400FF9400FF9400FF9400FF85
00FF8500FF8500FF8500FF8500FF8500FF7500FF7500FF7500FF7500FF7500FF7500FF75
00FF7500FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF66
00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF66
00FF5700FF5700FF5700FF5700FF4700FF4700FF4700FF4700FF4700FF4700FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF19
00FF1900FF1900FF1900FF1900FF2800FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A05FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0014FF0014FF0014FF0014FF0005FF0005FF0014FF0014FF0014FF0014FF00
14FF0014FF0005FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0014FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0023FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
42FF0042FF0042FF0042FF00
14FF0005FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00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14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00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14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00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14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00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14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
05FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0000FF0A05FF0005FF0005FF0005FF00
05FF0005FF0005FF0000FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF2800FF2800FF28
00FF2800FF2800FF2800FF3800FF3800FF3800FF3800FF4700FF4700FF4700FF5700FF57
00FF6600FF6600FF6600FF6600FF7500FF7500FF8500FFF000C2FF0028FF0057FF0075FF
00F0FF00FFC200FFB300FFA300FFA300FFA300FFA300FFB300FFD10057FF0075FF00FFF0
00FFB300FFA300FF9400FF9400FF9400FF940075FF00FFA300FF8500FF7500FF6600FF66
00FF6600FF6600FF6600FF6600FF5700FF6600FF5700FF5700FF6600FF5700FF5700FF57
00FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF6600FF5700FF5700FF57
00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF66
00FF6600FF6600FF6600FF6600FF6600FF6600FF7500FF7500FF7500FF7500FF7500FF75
00FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF8500FF8500FF8500FF8500FF85
00FF8500FF8500FF8500FF8500FF8500FF8500FF9400FF9400FF9400FF9400FF9400FF94
00FF9400FF9400FF9400FF9400FF9400FFA300FFA300FFA300FFA300FFA300FFA300FFA3
00FFA300FFA300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC200FFC200FFC2
00FFC200FFC200FFC200FFD100FFD100FFD100FFD100FFD100FFE100FFE100FFE100FFE1
00FFE100FFE100FFF000FFF000FFF000FFFF00FFFF00F0FF00E1FF00E1FF00D1FF00C2FF
00B3FF00A3FF0094FF0075FF0028FF1400FF0057FF0075FF0075FF0075FF0057FF0057FF
0038FF2300FF0038FF0047FF0038FF000AFFAE00FFEB00FF0500FF0028FF0038FF0038FF
0019FFBD00FF0019FF9E00FFFF004C0038FF0085FF0094FF00A3FF00A3FF00A3FF00A3FF
00A3FF00A3FF00A3FF00A3FF00A3FF0094FF0094FF0085FF0085FF0057FF0047FF0047FF
0047FF0019FF4200FFFF007AFF00B84200FF1400FF000AFF2300FF8000FF0500FF0028FF
0038FF0047FF0047FF0047FF0057FF0057FF0057FF0057FF0057FF0047FF000AFF0028FF
0038FF0038FF0038FF0038FF0038FF0028FF0500FF8000FF8000FF8F00FF1400FF0500FF
000AFF000AFF000AFF0500FF0500FF1400FF2300FF2300FF3300FF4200FF4200FF5100FF
8F00FF9E00FF9E00FFAE00FFEB00FFFF004CFF00B8FF00D7CC00FFAE00FFAE00FFBD00FF
CC00FFDC00FFEB00FFFF00E6FF0000FF00A8FF007AFF00E6FF00F5FF00E6FF00C7FF00A8
FF008AFF0000FF003DFF001EFF008AFF006BFF005CFF003DFF001EFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF003DFF005C
FF008AFF00A8FF00C7FF00D7FF00E6FA00FFEB00FFDC00FFCC00FFBD00FFAE00FF9E00FF
8F00FF8F00FF8F00FF8F00FF9E00FFFF00F5FA00FFBD00FF4200FF3300FF2300FF2300FF
1400FF1400FF1400FF1400FF2300FF1400FF0500FF0500FF0500FF0500FF1400FF2300FF
3300FF5100FFCC00FF9E00FFAE00FFFF00B8FF00009E00FF5100FF5100FFAE00FFFF0099
3300FF8000FFFF00A8EB00FFFF003DFF0000EB00FF3300FF0047FF0066FF0085FF0094FF
0094FF0094FF00A3FF00A3FF00B3FF00B3FF00B3FF00C2FF00C2FF00C2FF00D1FF00D1FF
00D1FF00D1FF00D1FF00E1FF00E1FF00E1FF00E1FF00F0FF00F0FF00F0FF00F0FF00F0FF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF000FFF000FFF000FFF000FFF000FFF0
00FFE100FFE100FFE100FFE100FFE100FFE100FFE100FFD100FFD100FFD100FFD100FFD1
00FFD100FFD100FFD100FFD100FFD100FFD100FFD100FFD100FFD100FFD100FFD100FFD1
00FFD100FFE100FFE100FFF000FFFF00E1FF4200FF00C2FF00D1FF00F0FF00FFFF00FFF0
00FFF000FFF000FFFF00F0FF00B3FF8000FF00B3FF00E1FF00FFFF00FFF000FFF000FFF0
00FFF000FFF000FFFF00FFFF00F0FF00F0FF00E1FF00C2FF00B3FF0094FF0094FF0085FF
0075FFBD00FF3300FF5100FF2300FFCC00FF8F00FFFF00D7FF0000FF005CFF0099FF002E
FF0000FF001EDC00FFFF00C7FF0000EB00FF6100FF3300FFBD00FFFF00B80047FF0019FF
7000FF5100FF0047FF00A3FF00FFFF00FFF000FFE100FFE100FFD100FFD100FFC200FFC2
00FFC200FFB300FFB300FFB300FFB300FFA300FFA300FFA300FF9400FF9400FF9400FF94
00FF9400FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF7500FF7500FF7500FF75
00FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF75
00FF7500FF7500FF7500FF8500FF8500FF8500FF8500FF9400FFA300FFC200A3FF00D1FF
00FFE100FFF000FF8500FF7500FF6600FF5700FF5700FF5700FF4700FF4700FF4700FF47
00FF4700FF4700FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
14FF0014FF0014FF0014FF0014FF0005FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0042FF00
42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0051FF0051FF00
51FF0051FF0051FF0051FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00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14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00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23FF0014FF0014FF0014FF0023FF0023FF0023FF0014FF0014FF0023FF0023FF0023FF00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23FF0023FF0014FF0023FF0023FF0023FF0023FF0023FF0014FF0023FF0023FF0023FF00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23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0014FF0023FF0023FF0023FF00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23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00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23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00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23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00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23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00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23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00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23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00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23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00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23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00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23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00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23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00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23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00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23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00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23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0014FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0014FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0005FF0005FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0000FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF3800FF2800FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF4700FF47
00FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF47
00FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF5700FF4700FF4700FF4700FF57
00FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF66
00FF6600FF6600FF6600FF6600FF6600FF6600FF7500FF7500FF7500FF8500FF8500FF85
00FF8500FF8500FF9400FF9400FF9400FF9400FF9400FF9400FFA300FFA300FFA300FFB3
00FFB300FFB300FFB300FFB300FFA300FFA300FFA300FFA300FFA300FFA300FFB300FFA3
00FFB300FFA300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB3
00FFB300FFC200FFC200FFC200FFC200FFD100FFD100FFE100FFE100FFE100FFF000FFF0
00FFFF00F0FF00E1FF00C2FF0075FF000AFF0500FF00A3FF00B3FF00C2FF00D1FF00D1FF
00D1FF00D1FF00D1FF00C2FF00B3FF00A3FF0085FF0066FF0047FFFF004C1400FF6100FF
8000FF0038FF0500FF0085FF00A3FF00A3FF00A3FF00C2FF00C2FF00C2FF00C2FF00C2FF
00B3FF00A3FF0057FF7000FF6100FF0075FF00B3FF00C2FF00C2FF00B3FF0057FF0038FF
0057FF0038FF00C2FF00D1FF00E1FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF
00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00E1FF00E1FF
00E1FF00E1FF00E1FF00E1FF00D1FF00D1FF00D1FF00C2FF00C2FF00C2FF00C2FF00B3FF
00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A3FF00A3FF00A3FF0094FF0094FF0085FF
0085FF0075FF0066FF0047FF0028FF000AFF3300FF5100FF4200FF3300FF8000FFFF000F
8000FFDC00FFBD00FF5100FF2300FF2300FF3300FFDC00FF1400FF000AFF0019FF0028FF
0028FF0028FF0028FF0028FF0019FF0019FF000AFF0500FF1400FF8000FF4200FF4200FF
BD00FFFF00008000FFFF00C78F00FF8F00FFFF0000DC00FFBD00FFEB00FFFF00008000FF
8000FF8000FF8000FF8000FF8F00FF8F00FF9E00FFAE00FFBD00FFCC00FFEB00FFFA00FF
FF00F5FF00E6FF00C7FF00B8FF0000FF002EFF003DFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF002EFF003DFF005CFF0000FF004CFF005C
FF00B8FF00A8FF007AFF00F5FF00F5FF0099EB00FFFF003D9E00FF8000FF6100FF4200FF
3300FF2300FF2300FF2300FF2300FF1400FF1400FF2300FF5100FF2300FF2300FF3300FF
8000FF5100FFFF005C5100FF0038FF0047FF0057FF0066FF0066FF0066FF0075FF0075FF
0075FF0075FF0085FF0085FF0085FF0085FF0094FF0094FF0094FF0094FF00A3FF00A3FF
00A3FF00A3FF00A3FF0094FF0094FF0085FF0066FFAE00FF000AFF0085FF0075FF0066FF
0047FF0085FF0094FF0094FF0085FF0075FF0075FF0075FF0057FF0038FF7000FF9E00FF
DC00FF0066FF0038FF0066FF0085FF0085FF0066FF0057FF4200FF00A3FF00A3FF00A3FF
0094FF0066FF3300FF0075FF0094FF00A3FF0094FF8F00FF0057FF0038FFFF00D7FF002E
1400FF0085FF00C2FF00E1FF00FFFF00FFF000FFE100FFD100FFD100FFC200FFC200FFB3
00FFB300FFB300FFB300FFB300FFA300FFA300FFA300FFA300FFA300FFA300FFA300FFA3
00FFA300FFA300FFA300FFA300FFA300FFA300FFA300FFA300FFA300FFA300FFA300FFA3
00FFA300FFA300FFA300FFA300FFA300FFB300FFB300FFB300FFB300FFB300FFB300FFC2
00FFC200FFC200FFD100FFD100FFE100FFE100FFE100FFF000FFFF00E1FF1400FF00B3FF
00A3FF0047FFCC00FF0085FF00B3FF0066FF0057FF0085FF00E1FF00F0FF00FFFF00FFF0
00FFE100FFE100FFE100FFD100FFD100FFD100FFD100FFC200FFC200FFD100FFD100FFE1
0028FF0028FF00FFF000FFE100FFE100B3FF00FFFF00FFF000FFE100FFF000FFFF0028FF
00C2FF1400FF00B3FF000AFF0066FF2300FF0047FF0038FF8000FF0066FF0057FFFA00FF
0094FF00C2FF00E1FF00F0FF00FFFF00FFF000FFE100FFE100FFD100FFD100FFC200FFC2
00FFC200FFB300FFB300FFB300FFB300FFC200FFB300FFB300FFC200FFB300FFC200FFC2
00FFC200FFC200FFD100FFE100FFFF00E1FF0038FF00E1FF00FFF000FFD100FFD100FFC2
00FFC200FFC200FFC200FFE10057FF0047FF00FFFF00FFE100B3FF00B3FF00A3FFFF00E6
0038FF4200FF00FFD100FFB300FF9400FF8500FF7500FF7500FF6600FF6600FF5700FF57
00FF5700FF4700FF4700FF4700FF4700FF4700FF3800FF3800FF3800FF3800FF3800FF38
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF2800FF1900FF28
00FF2800FF2800FF2800FF3800FF3800FF9400FFFF00FF4700FF2800FF1900FF1900FF19
00FF1900FF1900FF0A00FF0A00FF0A00FF0A00FF1900FF0A00FF0A00FF0A00FF0A00FF19
00FF1900FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A05FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0014FF0014FF0005FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0033FF0033FF0033FF0033FF0023FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0042FF0042FF0042FF0042FF00
42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
42FF0042FF0042FF0051FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00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23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00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23FF0023FF0023FF0023FF0033FF0033FF0033FF0023FF0023FF0023FF0023FF0023FF00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23FF0023FF0023FF0033FF0033FF0033FF0033FF0033FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0014FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0014FF0014FF0014FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0000FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF38
00FF2800FF2800FF3800FF2800FF2800FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF4700FF3800FF3800FF3800FF3800FF4700FF4700FF4700FF4700FF47
00FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF5700FF57
00FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF57
00FF6600FF6600FF6600FF6600FF6600FF6600FF7500FF7500FF8500FFC200F0FF00A3FF
0066FF00FFD100FFC200FFB300FFB300FFB300FFC200FFD1FF009900FFFF00FFF000D1FF
00B3FF00B3FF00FFD100FFC200FFC200FFC200FFB300FFB300FFB300FFB300FFB300FFB3
00FFB300FFB300FFB300FFB300FFB300FFB300FFC200FFB300FFC200FFC200FFC200FFC2
00FFC200FFC200FFC200FFD100FFD100FFE100FFF000E1FF0094FF0094FF0085FF0075FF
00B3FF0047FF0066FF0094FF0085FF0075FFFF004C0075FF0094FF0094FF00A3FF0094FF
0038FF0085FF000AFF0057FF0085FF0075FF0038FF7000FF8F00FF0038FF0057FF0066FF
0047FF0028FF0075FF0047FF0057FF00D1FF00E1FF00E1FF00E1FF00E1FF00E1FF00E1FF
00E1FF00C2FF00A3FF0075FF0028FF0066FF00D1FF00E1FF00F0FF00F0FF00F0FF00F0FF
00F0FF00F0FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F0FF00F0FF00F0FF00F0FF00F0FF
00F0FF00F0FF00E1FF00E1FF00E1FF00E1FF00E1FF00D1FF00D1FF00D1FF00D1FF00D1FF
00C2FF00C2FF00C2FF00B3FF00B3FF00B3FF00A3FF00A3FF0094FF0094FF0094FF0085FF
0085FF0075FF0066FF0057FF0047FF0038FF0019FF0500FFAE00FFFF00F5FF0000FF0000
FF00E6FF008A3300FF1400FF000AFF0019FF0028FF0038FF0038FF0047FF0047FF0047FF
0047FF0047FF0047FF0038FF0038FF0028FF4200FFFA00FFFF005C8F00FF3300FF2300FF
1400FF2300FF2300FF4200FFFF0000FF00E68000FF5100FF4200FF4200FF4200FF4200FF
5100FF5100FF8F00FF9E00FFDC00FFFF00F5FA00FFFF00E6FA00FFEB00FFFF00C7FF007A
FF0000FF0000FF0000FF003DFF0000FF003DFF0000FF000FFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF001EFF003DFF0000FF00A8FF00D7FF00E6
FA00FFEB00FFCC00FFBD00FFBD00FFBD00FFBD00FFEB00FFBD00FFFF008A8000FFCC00FF
3300FF2300FF1400FF1400FF0500FF0500FF000AFF000AFF0019FF0019FF0019FF0028FF
0028FF0038FF0038FF0047FF0047FF0057FF0057FF0066FF0066FF0066FF0075FF0075FF
0075FF0085FF0085FF0085FF0094FF0094FF0094FF00A3FF00A3FF00A3FF00A3FF00B3FF
00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C2FF00C2FF00B3FF00C2FF
00C2FF00C2FF00B3FF00B3FF00B3FF00B3FF00A3FF0094FF0085FF0057FF8000FF0047FF
0075FF0094FF00B3FF00C2FF00C2FF00D1FF00D1FF00E1FF00E1FF00E1FF00E1FF00E1FF
00E1FF00E1FF00F0FF00F0FF00FFFF00FFFF00F0FF00F0FF00C2FF0028FF00B3FF00A3FF
00B3FF00F0FF00F0FF00F0FF00E1FF0085FF00E1FF00FFFF00FFE100FFD100FFC200FFB3
00FFB300FFA300FFA300FFA300FFA300FFA300FFA300FFA300FFA300FFA300FFA300FFA3
00FF9400FF9400FFA300FF9400FF9400FFA300FF9400FF9400FFA300FF9400FF9400FFA3
00FFA300FFA300FFA300FFA300FFA300FFA300FFA300FFB300FFB300FFB300FFB300FFB3
00FFC200FFC200FFD100FFF000C2FF000AFF00A3FF00D1FF0094FF8F00FF0094FF00C2FF
0038FF00FFFF00FFF000FFF000FFF000FFFF00F0FF00D1FF0057FF0047FF00C2FF0066FF
00FFFF00FFE100FFD100FFC200FFC200FFC200FFB300FFB300FFB300FFB300FFB300FFB3
00FFB300FFB300FFB300FFB300FFB300FFB300FFC200FFC200FFC200FFD100FFD100FFE1
00FFE100FFF000FFFF00F0FF00E1FF00B3FF0085FF3300FF0038FF0028FF1400FF0500FF
0500FF1400FF0094FF00B3FF00C2FF0057FF00D1FF00E1FF00F0FF00FFF000FFE100FFE1
00FFE100F0FF00D1FF00FFF000FFF000FFFF0094FF00B3FF00FFFF00FFE100FFE100FFE1
00FFE100FFF00075FF00E1FF00D1FF0047FF0094FF00D1FF00D1FF0075FF00C2FF00A3FF
0085FF00C2FF00F0FF00F0FF00F0FF00C2FF5100FF00C2FF00FFC200FFB300FFB300FFB3
00FFC200A3FF00B3FF00FF9400FF7500FF7500FF6600FF6600FF5700FF5700FF5700FF57
00FF4700FF4700FF4700FF4700FF4700FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF2800FF2800FF2800FF3800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF1900FF1900FF2800FF28
00FF1900FF1900FF2800FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF2800FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF2800FF1900FF2800FF2800FF2800FF3800FF38
00FF4700FF5700FF7500FFD100FF9400FF6600FF4700FF4700FF3800FF2800FF2800FF28
00FF2800FF1900FF1900FF1900FF1900FF2800FF1900FF2800FF2800FF2800FF2800FF28
00FF3800FF4700FFF000FF9400FF5700FF6600FF9400A3FF00FFF000FF9400FF1900FF0A
00FF0A00FF0A05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0014FF0014FF0014FF0005FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0005FF0014FF0005FF0005FF0005FF0005FF0005FF00
05FF0000FF0A00FF0A05FF0005FF0005FF0005FF0005FF0005FF0014FF0014FF0014FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0033FF0023FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0042FF00
42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
42FF0042FF0042FF0051FF00
23FF0023FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0023FF0023FF0023FF00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23FF0023FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0023FF0023FF0023FF00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23FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0023FF0023FF0033FF00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23FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0023FF0023FF0033FF00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23FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0023FF0033FF0033FF00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33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0023FF0033FF0033FF00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33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00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33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00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33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0023FF0033FF0033FF0033FF00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33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00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33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00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33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00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33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0023FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0000FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF4700FF3800FF38
00FF3800FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF47
00FF4700FF4700FF4700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF66
00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7500FF7500FF75
00FF7500FF8500FF8500FF8500FF9400FF9400FF9400FFA300FFA300FFB300FFC200FFC2
00FFC200FFD100FFFF00F0FF00FFFF00F0FF00C2FFFF00A80047FF0057FF00A3FF0094FF
00F0FF00FFFF00FFF000FFF000FFF000FFE100FFE100FFE100FFF000FFF000FFF000FFF0
00FFF000FFFF00E1FF0085FF00D1FF00F0FF00F0FF00F0FF00F0FF00F0FF00E1FF00D1FF
00B3FF0094FF0075FF0500FF0066FF0047FF7000FF9E00FF7000FF0075FF0085FF6100FF
0500FF0094FF0085FF00A3FF0094FF0094FF0075FF0038FFFA00FFFF00D7EB00FFAE00FF
9E00FF0075FF00A3FF0094FF00B3FF00D1FF00FFFF00FFFF00FFF000FFE100FFE100FFE1
00FFD100FFD100FFD100FFD100FFD100FFD100FFD100FFD100FFD100FFD100FFD100FFD1
00FFD100FFD100FFD100FFD100FFE100FFE100FFE100FFE100FFE100FFE100FFE100FFE1
00FFF000FFF000FFF000FFF000FFFF00FFFF00FFFF00FFFF00FFFF00F0FF00F0FF00F0FF
00F0FF00E1FF00E1FF00E1FF00D1FF00D1FF00D1FF00D1FF00C2FF00C2FF00C2FF00B3FF
00B3FF00B3FF00B3FF00A3FF00A3FF0094FF0085FF0075FF0057FF2300FFAE00FF8000FF
000AFF0019FF0019FF2300FF8000FF6100FF0019FF0019FF0075FF0085FF0094FF0094FF
0094FF00A3FF00A3FF00A3FF00A3FF0094FF0094FF0094FF0094FF0094FF0094FF0085FF
0085FF0085FF0075FF0075FF0075FF0075FF0066FF0066FF0066FF0057FF0057FF0057FF
0047FF0047FF0038FF0038FF0028FF0019FF0019FF000AFF000AFF0500FF2300FF5100FF
BD00FF8F00FF7000FF7000FF9E00FFFF008AEB00FFDC00FFFF00D7FF005CFF004CFF001E
FF00D7FF008AFF00F5FF00F5FF00E6FF00C7FF007AFF002EFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF003DFF006BFF001EFF007A
FF00A8FF00F5CC00FFAE00FF9E00FF8F00FF8000FF7000FF6100FF5100FF5100FF4200FF
4200FF5100FFFF002E8000FF4200FF5100FF1400FF1400FF1400FF3300FFCC00FF6100FF
4200FF0500FF000AFF000AFF0500FF7000FF3300FF0019FF0038FF0047FF0057FF0066FF
0066FF0075FF0085FF0085FF0094FF0094FF00A3FF00A3FF00B3FF00C2FF00C2FF00D1FF
00D1FF00D1FF00D1FF00E1FF00E1FF00E1FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF
00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00E1FF00E1FF00E1FF00D1FF00D1FF
00C2FF00B3FF00A3FF0085FF0028FFFF00006100FF3300FF0066FF0085FF00A3FF00D1FF
00F0FF00FFFF00FFF000FFF000FFE100FFE100FFD100FFC200FFC200FFC200FFB300FFB3
00FFB300FFB300FFA300FFA300FFA300FFA300FFA300FFA300FF9400FF9400FF9400FF94
00FF9400FF9400FF9400FF9400FF9400FF9400FF8500FF8500FF8500FF8500FF8500FF85
00FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF85
00FF8500FF8500FF8500FF8500FF9400FF8500FF9400FF9400FF9400FF9400FFA300FFA3
00FFB300FFD100FFD100FFE100D1FFFF003D00E1FF00FFF000E1FF2300FF00FFB300FFA3
00FF9400FF9400FF9400FF9400FF8500FF8500FF8500FF9400FF9400FF9400FFA300FFB3
2300FF00FFB300FFA300FF9400FF9400FF8500FF8500FF8500FF8500FF8500FF8500FF85
00FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF94
00FF9400FF9400FF9400FF9400FFA300FFA300FFA300FFA300FFA300FFA300FFB300FFB3
00FFB300FFC200FFD1FF00000047FF0066FF0047FF00C2FF0094FF0066FF0094FF0085FF
3300FF8F00FF0500FFFF00F5FF00F52300FFFF00998F00FFFF00C71400FF4200FFCC00FF
FF00B86100FF6100FF6100FF0047FF0094FF0094FF0028FF00A3FF00F0FF00FFE100FFC2
00FFB300FFB300FFB300FFA300FF9400FF9400FF9400FF8500FF8500FF8500FF8500FF75
00FF7500FF7500FF7500FF6600FF6600FF6600FF6600FF6600FF5700FF5700FF5700FF57
00FF5700FF5700FF4700FF4700FF5700FF4700FF4700FF4700FF4700FF4700FF4700FF47
00FF4700FF4700FF4700FF4700FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF4700FF4700FF47
00FF5700FF6600FF750038FF00FFA300FF6600FF5700FF5700FF5700FF5700FF5700FF57
00FF5700FF6600FF750038FF00FFC22300FF00FFB300FF8500FF7500FF5700FF5700FF47
00FF4700FF4700FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF4700FF3800FF4700FF4700FF4700FF4700FF5700FF57
00FF5700FF6600FF7500FF8500FFB300F0FF00FFE100D1FFFF00F500FFC200FFA300FF94
00FF8500FF8500FF8500FF9400FFA300FFB300FFF09E00FFFF00D700FFF0000AFF00FF85
00FF6600FF6600FF5700FF4700FF4700FF3800FF3800FF2800FF2800FF2800FF1900FF28
00FF1900FF1900FF1900FF1900FF1900FF1900FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF1900FF1900FF1900FF1900FF2800FF6600FF8500FF9400FF8500FF94
00E1FF0019FF00E1FF00FFC20028FF00FFA300E1FF00FF8500FF1900FF0A00FF0A00FF0A
05FF0005FF0005FF0005FF0005FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0023FF0023FF0023FF0023FF0023FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0042FF0042FF0042FF0042FF0033FF0042FF0042FF0042FF00
42FF0042FF0042FF0042FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00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33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00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33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0023FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0023FF0023FF0023FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0005FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0000FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF3800FF2800FF2800FF2800FF2800FF2800FF2800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF47
00FF4700FF4700FF4700FF4700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF57
00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7500FF7500FF7500FF75
00FF7500FF8500FF8500FF8500FF8500FF9400FF9400FFA300FFA300FFA300FFB300FFB3
00FFC200FFC200FFD100FFD100FFE100FFF000F0FF00D1FF00B3FF0500FF0094FF00D1FF
00E1FF00F0FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00E1FF00E1FF
00E1FF00E1FF00C2FF0085FF6100FF00A3FF00C2FF00D1FF00D1FF00D1FF00C2FF00B3FF
00B3FF0094FF0066FF0028FFFF00F54200FF3300FF0057FF0075FF00A3FF00B3FF00C2FF
00D1FF00D1FF00D1FF00D1FF00C2FF00B3FF0057FFFF003D0066FF00B3FF00D1FF00D1FF
00D1FF00D1FF8F00FF0500FF00A3FFFF00A80057FF00D1FF00FFE100FFE100FFD100FFD1
00FFD100FFD100FFD100FFD100FFD100FFD100FFD100FFD100FFD100FFD100FFD100FFD1
00FFD100FFD100FFD100FFD100FFD100FFD100FFD100FFE100FFE100FFE100FFE100FFE1
00FFE100FFF000FFF000FFF000FFFF00FFFF00F0FF00F0FF00F0FF00F0FF00E1FF00E1FF
00E1FF00D1FF00C2FF00C2FF0075FFAE00FF0094FF00A3FF00A3FF00A3FF00A3FFFF00B8
0085FF0094FF0094FF0094FF0085FF0075FF0047FF8000FFFF0000000AFF0057FF0066FF
0075FF0075FF0057FF6100FF0047FF0085FF0094FF0094FF0094FF00A3FF00A3FF00A3FF
00B3FF00B3FF00A3FF00B3FF00A3FF00A3FF00A3FF0094FF0094FF0094FF0094FF0094FF
0085FF0085FF0075FF0075FF0075FF0066FF0066FF0057FF0057FF0057FF0047FF0047FF
0047FF0038FF0028FF0028FF0500FFFF00003300FF2300FF2300FF3300FF4200FF8000FF
FF00C7FF004CFF0000FF008ACC00FFAE00FFFF00F5FF008A9E00FF8F00FF8F00FF8F00FF
9E00FFAE00FFBD00FFEB00FFFA00FFFF0099FF008AFF00A8FF006BFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF001EFF003DFF003DFF00B8FF00D7
FF00F5EB00FFDC00FFCC00FFBD00FFDC00FFEB00FFFF0000FF00005100FF3300FF2300FF
2300FF1400FF1400FF1400FF0500FF000AFF0019FF0019FF0019FF0019FF0028FF0028FF
0038FF0038FF0038FF0038FF0028FF0019FF1400FFFF00C74200FF3300FF1400FF0057FF
0066FF0075FF0085FF0094FF00A3FF00A3FF00B3FF00B3FF00C2FF00D1FF00D1FF00D1FF
00E1FF00E1FF00E1FF00E1FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF
00FFFF00F0FF00FFFF00F0FF00FFFF00FFFF00F0FF00F0FF00F0FF00F0FF00E1FF00E1FF
00B3FF0094FF000AFF0500FF0028FF0066FF0085FF0066FFFF00B80057FF0094FF0066FF
000AFF00D1FF00D1FF00B3FF0066FF00FFFF00FFE100FFD100FFD100FFC200FFB300FFB3
00FFB300FFB300FFA300FFA300FFA300FFA300FFA300FF9400FF9400FF9400FF9400FF94
00FF9400FF9400FF8500FF9400FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF85
00FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF85
00FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF9400FF9400FF94
00FFA300FFA300FFB300FFC200FFF01400FF00FFE100FFC200FFA300FF9400FF9400FF94
00FF8500FF8500FF8500FF7500FF8500FF7500FF7500FF7500FF7500FF7500FF7500FF85
00FF8500FF7500FF8500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF75
00FF7500FF8500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF8500FF8500FF85
00FF8500FF8500FF8500FF9400FF9400FF9400FF9400FF9400FF9400FFA300FFA300FFA3
00FFB300FFB300FFB300FFC200FFC200FFD100FFFF0028FFFF007A00E1FF00E1FF00D1FF
00C2FF00A3FF1400FF4200FF0066FF0085FF0500FF0075FFFF00000075FF0047FFFF00C7
0028FF0038FF0500FF0028FF0047FF00A3FFFF00B800F0FF00FFFF00FFF000FFE100FFD1
00FFD100FFD100FFD100FFE10075FF00FFB300FFA300FF9400FF9400FF8500FF8500FF85
00FF7500FF7500FF7500FF7500FF7500FF6600FF6600FF6600FF6600FF6600FF5700FF57
00FF5700FF5700FF5700FF5700FF5700FF5700FF4700FF4700FF4700FF4700FF4700FF47
00FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF3800FF4700FF4700FF3800FF38
00FF4700FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF4700FF38
00FF3800FF3800FF3800FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF5700FF57
00FF6600FF7500FF858000FF00FFF000FFC200FFB300FFB300FF7500FF7500FF6600FF66
00FF7500FF8500FF9400FFC200D1FF00FFFF00FFD100FFF000E1FF00FF8500FF6600FF57
00FF5700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF47
00FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF5700FF5700FF5700FF5700FF57
00FF6600FF6600FF6600FF7500FF7500FF8500FF9400FFB30094FF0075FF00D1FF00FFE1
00FFC200FFC200FFFFCC00FF0019FF00F0FF00FFC200FFA300FF9400FF940057FF00FF66
00FF5700FF5700FF4700FF4700FF3800FF3800FF3800FF2800FF2800FF2800FF2800FF28
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF0A00FF1900FF0A00FF1900FF0A00FF0A00FF0A00FF0A00FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF2800FF2800FF2800FF3800FF4700FF5700FF6600FF85
00FFFF4200FF00E1FF00FF7500FF5700FF4700FF3800FF2800FF2800FF1900FF1900FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A05FF0000FF0A05FF0000FF0A00FF0A05FF0005FF00
05FF0000FF0A00FF0A00FF4700FF2805FF0014FF0014FF0023FF0023FF0023FF0023FF00
33FF0033FF0033FF0033FF0033FF0033FF0042FF0042FF0042FF0042FF0042FF0042FF00
42FF0042FF0042FF0042FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00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33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00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33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00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33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00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33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00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33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00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33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00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33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00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33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00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33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00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33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0023FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0005FF0005FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
00FF0A00FF0A00FF0A05FF0000FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF4700FF47
00FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF47
00FF4700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF57
00FF5700FF6600FF6600FF6600FF6600FF6600FF6600FF7500FF7500FF7500FF7500FF85
00FF8500FF9400FFA300FFC200FFB300FFB300FFC20094FF0038FF00B3FF00F0FF00FFF0
00FFE100FFF000FFF000FFF000FFE100FFE100FFE100FFF000FFF000FFF000FFFF00FFFF
00F0FF00E1FF00D1FF00C2FF00A3FFFF00000047FF2300FF8000FF0019FF0028FF0019FF
2300FF7000FF2300FF5100FFFA00FFDC00FFFF0000FF00A8FF00A88000FFFF001E8F00FF
0038FF0066FF0075FF0057FF0047FF7000FF1400FF00C2FF00FFFF00FFFF00FFF000FFF0
00FFE100FFE100FFE100FFE100FFE100FFE100FFE100FFE100FFE100FFF01400FF00FFE1
00FFD100FFC200FFC200FFC200FFC200FFB300FFB300FFB300FFB300FFB300FFB300FFB3
00FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB3
00FFB300FFC200FFC200FFC200FFC200FFD100FFD100FFF000F0FF00FFFF00F0FF00E1FF
00F0FF00F0FF00E1FF00E1FF00A3FF00A3FF0085FF000AFF0500FF0066FF0066FF0038FF
1400FF0075FF00B3FF00D1FF00E1FF00E1FF00E1FF00E1FF00E1FF00E1FF00E1FF00E1FF
00D1FF00C2FF00B3FF0085FF0075FF0057FF9E00FF0047FF0075FF0075FF00A3FF00B3FF
00C2FF00D1FF00D1FF00D1FF00D1FF00E1FF00E1FF00E1FF00E1FF00E1FF00E1FF00E1FF
00E1FF00D1FF00D1FF00D1FF00C2FF00B3FF00A3FF0094FF5100FFFF00000028FF8000FF
1400FF0075FF0085FF0085FF0085FF0085FF0075FF0075FF0066FF0057FF0047FF1400FF
AE00FF4200FF000AFF0028FF0038FF0038FF0047FF0038FF0047FF0047FF0038FF0038FF
0028FF0019FF0019FF000AFF0500FF1400FF1400FF2300FF2300FF3300FF4200FF5100FF
6100FF7000FF8000FF8F00FF9E00FFAE00FFDC00FFFF00E6FF0099FF007AFF0000FF001E
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF003DFF006BFF007A
FF00C7FF00D7FF00E6FA00FFFF00C7FF00D7FF0000FF0000FF00B8FF00E6FF00E69E00FF
7000FF8F00FFFF008ACC00FF4200FF4200FF1400FF0500FF0028FF0038FF0047FF0057FF
0066FF0066FF0075FF0075FF0085FF0085FF0085FF0094FF0094FF0094FF0094FF00A3FF
00A3FF00A3FF00A3FF00B3FF00B3FF00C2FF00C2FF00C2FF00D1FF00D1FF00E1FF00E1FF
00E1FF00F0FF00F0FF00F0FF00F0FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF0
00FFF000FFF000FFF000FFF000FFF000FFE100FFE100FFE100FFE100FFE100FFE100FFE1
00FFE100FFE100FFE100FFE100FFE100FFE100FFE100FFE100FFF000E1FF00F0FF00FFF0
00FFE100FFD100FFD100FFD100FFD100FFD100FFD100FFD100FFFF0057FF5100FF00FFFF
00FFC200FFB300FFA300FF9400FF9400FF9400FF9400FF9400FF8500FF8500FF8500FF85
00FF8500FF8500FF8500FF8500FF8500FF8500FF7500FF7500FF7500FF7500FF7500FF75
00FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF75
00FF7500FF7500FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF66
00FF6600FF6600FF6600FF6600FF6600FF7500FF6600FF6600FF6600FF6600FF6600FF66
00FF6600FF6600FF6600FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF57
00FF5700FF6600FF5700FF5700FF6600FF5700FF5700FF6600FF5700FF5700FF6600FF66
00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7500FF6600FF7500FF75
00FF7500FF7500FF7500FF8500FF8500FF8500FF9400FF9400FFA300FFB300FFD100FFC2
00FFC200FFC200FFD100F0FF00E1FF00B3FF00E1FF00B3FF1400FF0019FF0085FFFF002E
00E1FF00FFFF00FFF000FFE100FFD100FFC200FFC200FFB300FFB300FFB300FFB300FFB3
00FFA300FFB300FFB300FFB300FFB300FFC200FFE100FFFFCC00FF00C2FF00E1FF0047FF
00F0FF00FFFF00FFFF0066FF0066FF00B3FFDC00FF00A3FF00B3FF8000FF00A3FF00FFFF
00FFE100FFD100FFD100FFE100FFF00066FF0094FF00FFF000FFE100D1FF00E1FF0028FF
00B3FF00FFD100FF9400FF8500FF7500FF7500FF6600FF6600FF6600FF6600FF6600FF66
00FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF57
00FF5700FF6600FF6600FF6600FF6600FF6600FF7500FF7500FF8500FFA300FFD100FFD1
00FF9400FF8500FF8500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF85
00FF8500FF8500FF8500FF9400FF9400FFA300FFA300FFB300FFC200FFD100F0FF0094FF
0066FF0066FF00FFE100FFD100FFC200FFB300FFA300FFA300FFA300FFA300FFB300FFA3
00FFA300FFB300FFE100FF9400FF8500FF8500FF9400FFA300FFB300FFD100E1FF0075FF
00F0FF0085FF00FFE100FFC200FFA300FFA300FF9400FF9400FF9400FF9400FFA300FFE1
00FFFF00FFE100FFE100E1FF00A3FF00FFFF00FFE100FFE100FFFF00E1FF00B3FF4200FF
00C2FF00F0FF00FFF000FFF00038FF00FFF000FFC200FFE10057FF00FF8500FF8500FF75
00FF7500FF7500FFD100FFC200FF7500FF6600FF6600FF6600FF5700FF5700FF5700FF47
00FF4700FF5700FF5700FF5700FF7500FFE100FFA300FF7500FF6600FF5700FF6600FF94
0038FF00E1FF00FF9400FF6600FF5700FF4700FF4700FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF4700FF4700FF4700FF5700FF5700FF6600FF6600FF75
00FF7500FF9400D1FF0038FF00FFFF00FF9400FF8500FF8500FF940094FF00FFE100FFD1
00D1FF8F00FF0019FF00FFFF00FFA300FF7500FF6600FF5700FF5700FF5700FF8500FFC2
00FF3800FF1900FF0A05FF0005FF0014FF0014FF0014FF0014FF0023FF0023FF0023FF00
23FF0023FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
42FF0042FF0042FF0042FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00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33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00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42FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0014FF0014FF0014FF0014FF0023FF0023FF0023FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0000FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF4700FF3800FF3800FF38
00FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF5700FF57
00FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF57
00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7500FF7500FF7500FF75
00FF8500FF8500FF8500FF9400FF9400FF9400FFA300FFA300FFA300FFB300FFB300FFB3
00FFC200FFC200FFC200FFC200FFD100FFD100FFD100FFE100FFE100FFE100FFF000F0FF
00D1FF4200FF00B3FF00B3FF00A3FF0094FF0066FFFF0000000AFF8000FFFF0000FF008A
BD00FFFF000FFF0000FF0099FF00F5FF0000FF00E67000FF7000FF8000FF8F00FF0066FF
0085FF0075FF6100FF0075FF00A3FF00D1FF00F0FF00FFFF00FFF000FFF000FFE100FFE1
00FFE100FFE100FFD100FFD100FFD100FFD100FFD100FFD100FFD100FFC200FFC200FFC2
00FFC200FFC200FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB3
00FFA300FFB300FFA300FFA300FFB300FFA300FFB300FFB300FFB300FFB300FFB300FFB3
00FFB300FFB300FFB300FFC200FFC200FFC200FFD100FFD100FFE100FFFF00E1FFAE00FF
0028FF00A3FF00A3FF0085FF0047FFFF007A0038FF000AFF00C2FF00D1FF00D1FF0075FF
00D1FF00F0FF00F0FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F0FF00F0FF00E1FF
00E1FF00D1FF00C2FF00A3FF0085FF0057FFFF004C0057FF0066FFFF00990019FF00C2FF
00D1FF00D1FF00E1FF00E1FF00E1FF00E1FF00E1FF00E1FF00E1FF00E1FF00E1FF00E1FF
00E1FF00E1FF00E1FF00D1FF00D1FF00C2FF00B3FF00B3FF0047FF00B3FF00B3FF00B3FF
00B3FF00B3FF00B3FF00A3FF00A3FF0094FF0085FF0075FF0066FF0019FF4200FFFA00FF
1400FF0028FF0047FF0057FF0057FF0057FF0057FF0057FF0057FF0057FF0047FF0038FF
0028FFEB00FF8000FFBD00FFFF00D7FF0000FA00FFAE00FF8000FF6100FF7000FFAE00FF
BD00FF9E00FFFF00E6FF0000EB00FFFA00FFFF00F5FF00F5FF00D7FF00C7FF008AFF000F
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF002E
FF002EFF0000FF001EFF004CFF00E6EB00FFCC00FFBD00FF8F00FF7000FF6100FF5100FF
3300FF2300FF2300FF2300FF2300FF0500FF0500FF2300FF0028FF0038FF0047FF0057FF
0066FF0066FF0075FF0075FF0075FF0085FF0085FF0094FF0094FF0094FF00A3FF00A3FF
00A3FF00A3FF00B3FF00B3FF00C2FF00C2FF00C2FF00D1FF00D1FF00D1FF00E1FF00E1FF
00E1FF00E1FF00E1FF00F0FF00F0FF00F0FF00FFFF00FFFF00FFFF00FFFF00FFF000FFF0
00FFF000FFF000FFF000FFE100FFE100FFE100FFE100FFE100FFE100FFE100FFE100FFD1
00FFD100FFD100FFD100FFD100FFD100FFD100FFD100FFD100FFD100FFC200FFC200FFC2
00FFC200FFC200FFC200FFC200FFC200FFC200FFB300FFB300FFB300FFB300FFB300FFB3
00FFB300FFA300FF9400FF9400FF9400FF9400FF9400FF9400FF8500FF8500FF8500FF85
00FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF7500FF7500FF7500FF7500FF75
00FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF6600FF6600FF6600FF6600FF66
00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF66
00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF5700FF5700FF6600FF5700FF57
00FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF57
00FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF57
00FF5700FF5700FF5700FF5700FF6600FF6600FF6600FF6600FF6600FF6600FF7500FF75
00FF7500FF7500FF8500FF8500FF8500FF9400FF9400FFA300FFA300FFC200FFE100D1FF
00D1FF00F0FF0094FF0019FF5100FF00C2FF00C2FF00FFFF00FFE100FFE100FFE100F0FF
00B3FF0019FF00B3FF00FFFF00FFD100FFC200FFB300FFB300FFA300FFA300FFA300FF94
00FF9400FF9400FF9400FFA300FFA300FFB30094FF00FFE100FFB300FFB300FFC200F0FF
00FFD100FFC200FFC200FFC200FFE10038FF00C2FF0500FF00D1FF0057FF3300FF0085FF
00B3FFFF00000085FF00C2FF00A3FF0047FF00F0FF00FFFF00FFE100FFE100FFD100FFB3
00FFA300FF9400FF9400FF8500FF8500FF7500FF7500FF7500FF6600FF6600FF6600FF66
00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF66
00FF7500FF7500FF9400FFC2000AFF00FFF000FFD100FFA300FFA300FFE100B3FF00FFF0
00FFB300FFA300FF9400FF8500FF8500FF8500FF8500FF8500FF9400FFA300FFB300B3FF
00FFE100FFB300FFB300FFA300FFB300FFC200FFE100D1FF0094FF00F0FF00F0FF00C2FF
0019FF1400FF00B3FF00B3FF0066FF00D1FF00FFF000FFE100FFD100FFE100FFF000E1FF
0094FF00FFFF00FFE100FFC200FFC200FFE10075FF00FFE100FFD100FFF00057FF00D1FF
0019FF00D1FF00C2FF00D1FF00FFE100FFFF00FFF02300FF00FFD100FFC200FFC200FFD1
00FFE100FFFF00D1FF0075FF0085FF00D1FF00E1FF00B3FF00C2FFDC00FF0075FF4200FF
8000FF6100FF0066FF0047FF00A3FF00F0FF00FFE100FFD100FFB300FFB300FFB300FFA3
00FFA300FFB300FFFF00D1FF00FFC200B3FF00D1FF00FFF000FF8500FF7500FF6600FF66
00FF6600FF6600FF6600FF7500FF8500FFF000A3FF00D1FF00FFA300FFA300FFC20094FF
00FFF000FFA300FF8500FF7500FF6600FF5700FF5700FF4700FF4700FF4700FF4700FF47
00FF4700FF4700FF5700FF5700FF5700FF5700FF5700FF5700FF6600FF6600FF6600FF75
00FF8500FF9400FFC200FFFF00FFE100FFC200FFB300FFD100FFA300FFB300FFD100FFD1
00FF6600FF6600FF750066FF00FF6600FF4700FF3800FF2800FF2800FF1900FF1900FF19
00FF1900FF0A05FF0005FF0014FF0014FF0014FF0014FF0014FF0023FF0023FF0023FF00
23FF0023FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0042FF00
42FF0042FF0042FF0042FF00
42FF0042FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0014FF0014FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0000FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF4700FF47
00FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF57
00FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF66
00FF6600FF6600FF6600FF6600FF6600FF6600FF7500FF7500FF7500FF7500FF7500FF75
00FF8500FF8500FF8500FF8500FF9400FF9400FF9400FFA300FFA300FFA300FFB300FFB3
00FFB300FFB300FFC200FFC200FFC200FFD100FFD100FFD100FFE100FFE100FFF000E1FF
1400FFFF00B80019FF0075FF0085FF0085FF000AFFFF003DFF00C78F00FFFF007AFF0000
EB00FFFA00FFFF0000EB00FF8000FFFF0000FF0000CC00FF000AFFFF00000057FF0085FF
0094FF0094FF0075FF9E00FF0075FF0019FF00E1FF00FFFF00FFF000FFF000FFE100FFE1
00FFE100FFD100FFD100FFD100FFD100FFD100FFC200FFC200FFC200FFC200FFC200FFC2
00FFC200FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA300FFA300FFA3
00FFA300FFB300FFA300FFA300FFA300FFA300FFA300FFB300FFA300FFB300FFB300FFB3
00FFB300FFB300FFB300FFB300FFC200FFC200FFD100FFD100FFE100FFF000E1FF00B3FF
0057FF0066FF0066FF000AFFFF00000066FF0094FF0094FF00E1FF00E1FF00F0FF00D1FF
00F0FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F0FF00F0FF00F0FF
00E1FF00D1FF00C2FF00B3FF0094FF0066FF8000FF0066FF0094FF00A3FF00B3FF00C2FF
00D1FF00D1FF00E1FF00E1FF00E1FF00E1FF00F0FF00F0FF00F0FF00F0FF00E1FF00F0FF
00E1FF00E1FF00E1FF00E1FF00E1FF00D1FF00C2FF00C2FF00C2FF00C2FF00C2FF00C2FF
00C2FF00C2FF00B3FF00B3FF00A3FF0094FF0085FF0075FF0057FF0028FFFF0000CC00FF
2300FF000AFF0047FF0057FF0066FF0066FF0066FF0066FF0066FF0057FF0047FF0019FF
1400FFFF008AFF00F53300FFFF00F55100FFFF00008000FFFF00A88F00FFCC00FFFA00FF
FF0000FF00B8FF00C7FF0000FF00A8FF006BFF00B8FF001EFF008AFF0099FF006BFF002E
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF008AFF00B8FF00E6FA00FFCC00FFAE00FF8F00FF8000FF7000FF5100FF
3300FF2300FF1400FF0500FF0500FF000AFF0019FF0028FF0038FF0047FF0047FF0057FF
0057FF0066FF0066FF0075FF0075FF0085FF0085FF0094FF0094FF0094FF00A3FF00A3FF
00A3FF00B3FF00B3FF00B3FF00C2FF00C2FF00C2FF00D1FF00D1FF00D1FF00E1FF00E1FF
00E1FF00E1FF00F0FF00F0FF00F0FF00F0FF00F0FF00FFFF00FFFF00FFFF00FFF000FFF0
00FFF000FFF000FFF000FFF000FFE100FFE100FFE100FFE100FFE100FFD100FFD100FFD1
00FFD100FFD100FFD100FFD100FFD100FFC200FFD100FFC200FFC200FFC200FFC200FFC2
00FFC200FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA3
00FFA300FFA300FF9400FF9400FF9400FF9400FF9400FF8500FF8500FF8500FF8500FF85
00FF8500FF8500FF8500FF8500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF75
00FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF6600FF6600FF6600FF6600FF75
00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF66
00FF6600FF6600FF6600FF6600FF6600FF5700FF5700FF5700FF5700FF5700FF5700FF57
00FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF57
00FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF57
00FF5700FF5700FF5700FF6600FF5700FF6600FF6600FF6600FF6600FF6600FF6600FF75
00FF7500FF7500FF8500FF8500FF8500FF9400FF9400FFA300FFB300B3FF000AFF0500FF
0500FFCC00FF0500FF0038FF00FFFF00FFFF00FFF000FFD100FFC200FFD100FFD100B3FF
0075FF0047FF00D1FF00FFF000FFD100FFC200FFB300FFA300FFA300FFA300FFA300FF94
00FF9400FF9400FF9400FF9400FF9400FFA300FFA300FFA300FFA300FFA300FFA300FFB3
00FFB300FFB300FFB300FFB300FFD100FFD100FFF00075FF00FFFF00E1FF00B3FF2300FF
0019FFFA00FF0075FF0085FFFF00E600B3FF00F0FF00FFF000FFD100FFD100FFB300FFB3
00FFA300FF9400FF9400FF8500FF8500FF7500FF7500FF7500FF7500FF6600FF6600FF66
00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF75
00FF7500FF7500FF8500FFB300E1FF0066FF00FFD100FFC200FFC200FFF00028FF0066FF
00FFC200FFA300FF9400FF9400FF9400FF9400FF9400FFA30085FF00FFC200FFC200C2FF
00FFF000FFC200FFB300FFC200FFC200D1FF00B3FF00E1FF0500FF00D1FF00D1FF00A3FF
0075FF0019FF1400FF0057FF0075FF00D1FF00F0FF00FFFF00E1FF00F0FF00F0FF00B3FF
0057FF00D1FF00FFFF00E1FF00FFF000C2FF2300FF00FFFF00FFF00028FFFA00FF00A3FF
0019FF1400FF0075FF00E1FF00FFFF00F0FF0019FF00D1FF00FFF000FFE100FFF000FFF0
00FFF000F0FF00D1FF0066FF0066FF00B3FF00C2FF2300FF0085FF0066FFFF00008F00FF
8000FF5100FFFF0099DC00FF0028FF0028FF00FFFF00FFE100FFD100FFD100FFC2DC00FF
00FFB300FFC200FFE100B3FF1400FF00F0FF00FFC200FF9400FF8500FF8500FF7500FF75
00FF7500FF7500FF7500FF8500FF8500FFA300FFD10038FF00FFE100FFC200D1FF4200FF
FF008A00FF9400FF7500FF7500FF6600FF5700FF5700FF5700FF4700FF4700FF4700FF47
00FF5700FF5700FF5700FF5700FF7500FF6600FF6600FF6600FF6600FF6600FF7500FF85
00FFB300FFB300FFE1DC00FF00FFD100FF9400FF9400FF8500FF8500FF8500FFC200FF66
00FF5700FF5700FF5700FF6600FF4700FF3800FF2800FF2800FF1900FF1900FF1900FF0A
00FF0A00FF0A05FF0005FF0014FF0014FF0014FF0014FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0042FF0042FF0042FF00
42FF0042FF0042FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00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42FF0042FF0042FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0000FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF4700FF3800FF3800FF4700FF47
00FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF5700FF5700FF5700FF57
00FF5700FF5700FF5700FF5700FF5700FF5700FF6600FF5700FF5700FF5700FF6600FF66
00FF6600FF6600FF6600FF6600FF7500FF6600FF6600FF7500FF7500FF7500FF7500FF75
00FF8500FF8500FF8500FF8500FF9400FF9400FF9400FF9400FFA300FFA300FFA300FFB3
00FFB300FFB300FFB300FFC200FFC200FFC200FFD100FFD100FFE100FFE100FFF000FFF0
00F0FF00D1FF00B3FF0057FF0019FFFF005C9E00FF3300FFFA00FFFF00F5FF0000FA00FF
FF00F52300FF7000FF4200FF000AFF0019FF9E00FF6100FF0038FF0066FF0085FF00A3FF
00B3FF00C2FF00C2FF00C2FF0028FF00B3FF00B3FF00E1FF00FFF000FFE100FFE100FFE1
00FFD100FFD100FFD100FFD100FFC200FFC200FFC200FFC200FFC200FFB300FFC200FFB3
00FFB300FFB300FFB300FFB300FFB300FFA300FFB300FFA300FFA300FFA300FFA300FFA3
00FFA300FFA300FFA300FFA300FFA300FFA300FFA300FFA300FFA300FFA300FFA300FFB3
00FFB300FFB300FFB300FFB300FFC200FFC200FFD100FFD100FFE100FFFF00E1FF00D1FF
00C2FF0057FFFA00FF7000FF8000FF0094FF00C2FF00E1FF00F0FF00FFFF00FFF000FFF0
00FFF000FFF000FFF000FFF000FFF000FFF000FFF000FFF000FFF000FFFF00F0FF00E1FF
00C2FF0075FF00A3FF0094FF0075FF0028FF000AFFFF000000A3FF00B3FF00C2FF00D1FF
00E1FF00E1FF00E1FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF
00F0FF00F0FF00F0FF00E1FF00E1FF00E1FF00E1FF00E1FF00E1FF00D1FF00D1FF00D1FF
00D1FF00C2FF00C2FF00B3FF00B3FF0094FF0066FFAE00FF2300FFAE00FFBD00FF0047FF
2300FF0066FF0066FF0075FF0066FF0075FF0075FF0075FF0066FF0066FF0057FF0057FF
0047FF0038FF0028FF0028FF000AFF0500FF2300FF6100FFFF00007000FF6100FFAE00FF
CC00FF8F00FFFF00F5FF006BEB00FFFA00FFFF00F5FF006BFF007AFF004CFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF006BFF0099FF004CFF002EEB00FFCC00FFFF006B9E00FF7000FF
4200FF2300FF1400FF0500FF000AFF000AFF0019FF0028FF0028FF0038FF0047FF0047FF
0047FF0057FF0057FF0038FF0028FF0066FF0075FF0085FF0085FF0094FF0094FF00A3FF
00A3FF00B3FF00B3FF00B3FF00C2FF00C2FF00C2FF00D1FF00C2FF00D1FF00D1FF00D1FF
00E1FF00E1FF00E1FF00E1FF00F0FF00F0FF00F0FF00F0FF00F0FF00FFFF00FFFF00FFFF
00FFF000FFF000FFF000FFE100FFE100FFE100FFE100FFE100FFD100FFD100FFD100FFD1
00FFD100FFD100FFD100FFD100FFC200FFC200FFC200FFC200FFC200FFC200FFC200FFB3
00FFB300FFB300FFB300FFB300FFB300FFB300FFA300FFA300FFA300FFA300FFA300FFA3
00FF9400FF9400FF9400FF9400FF9400FF9400FF8500FF8500FF8500FF8500FF8500FF85
00FF8500FF8500FF8500FF8500FF8500FF7500FF7500FF7500FF7500FF7500FF7500FF75
00FF7500FF7500FF7500FF7500FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF66
00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF57
00FF5700FF6600FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF57
00FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF57
00FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF57
00FF5700FF5700FF5700FF5700FF5700FF5700FF6600FF6600FF6600FF6600FF7500FF75
00FF7500FF8500FF8500FF9400FFA300FFA300FFA300FFB300FFB300FFD100FFF000C2FF
AE00FF0066FFFF005C00E1FF00FFE100FFC200FFB300FFB300FFB300FFB300FFC200FFD1
00FFF000D1FFBD00FF00D1FF0057FF00FFF000FFC200FFA300FFA300FF9400FF9400FF94
00FF9400FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF9400FF94
00FF9400FF9400FFA300FFA300FFA300FFB300FFC200FFD100FFE100FFFF00D1FF0075FF
000AFFFA00FF6100FF4200FF8000FF9E00FF2300FF00B3FF00FFE100FFD100FFC200FFB3
00FFA300FFA300FF9400FF9400FF8500FF8500FF8500FF7500FF7500FF7500FF7500FF75
00FF7500FF7500FF6600FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF85
00FF8500FF8500FF9400FFA300FFB300FFFF00C2FF4200FF00D1FF0066FF00F0FF00FFD1
00FFC200FFB300FFB300FFA300FFB300FFB300FFB300FFC200FFE10085FF000AFF00C2FF
00FFFF00FFE100FFE100FFFF00FFF000FFFF00E1FF00B3FF0028FF0075FF0057FF4200FF
3300FF0028FF1400FF0047FF0066FF00B3FF0066FF00C2FFBD00FF00B3FF0085FF0019FF
0085FF0075FF00D1FF00C2FF00E1FF0094FF0028FFFF005C0066FFEB00FF8000FF1400FF
0047FF2300FF00C2FF00D1FF0085FF1400FF0047FF0094FF0057FF0019FF7000FF0066FF
00A3FF4200FF0075FF0057FF1400FF0066FF0075FF0047FFFF00004200FF0085FF0094FF
0047FF0028FF0094FF0038FF00B3FF00C2FF8F00FF5100FF000AFF0075FF00A3FF00F0FF
00FFFF00D1FF00D1FF0038FF00E1FF00FFE100FFC200FFB300FFA300FF9400FFA300FFA3
00FFC200FFA300FF9400FF9400FF9400FFA300FFC200FFE10094FF00FFF000FFC200FFB3
00FF9400FF8500FF7500FF7500FF6600FF6600FF6600FF6600FF5700FF5700FF5700FF66
00FF6600FF6600FF7500FF940094FF00FF9400FF8500FF7500FF7500FF8500FF850085FF
0066FFBD00FF0019FF00FFF000FFC200FF8500FF7500FF6600FF6600FF5700FF5700FF47
00FF4700FF3800FF3800FF3800FF2800FF2800FF1900FF1900FF1900FF0A00FF0A00FF0A
00FF0A05FF0005FF0005FF0014FF0014FF0014FF0014FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0042FF0042FF0042FF00
42FF0042FF0042FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00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42FF0042FF0042FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00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42FF0042FF0042FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00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42FF0042FF0042FF0033FF0033FF0033FF0033FF0042FF0042FF0042FF0042FF0042FF00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42FF0042FF0033FF0033FF0033FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00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42FF0042FF0033FF0033FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00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42FF0042FF0033FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
42FF0042FF0042FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0000FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF4700FF4700FF4700FF4700FF5700FF5700FF57
00FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF6600FF5700FF66
00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF66
00FF6600FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF85
00FF8500FF8500FF9400FF8500FF9400FF9400FF9400FF9400FFA300FFA300FFA300FFA3
00FFB300FFB300FFC200FFC200FFE100F0FFFF000000A3FF00E1FF00F0FF00F0FF00F0FF
00D1FF00A3FF0038FF0075FF7000FF0066FF3300FF00A3FF00B3FF00B3FF0094FF0038FF
0075FF0085FF8000FF0094FF00C2FF00D1FF00D1FF00D1FF00C2FF0094FF0066FFFF00F5
0500FF0066FF0075FF00D1FF00F0FF00FFFF00FFFF00FFF000FFF000FFF000FFE100FFE1
00FFD100FFD100FFD100FFD100FFC200FFC200FFC200FFB300FFB300FFB300FFB300FFA3
00FFA300FFA300FFA300FFA300FFA300FFA300FFA300FFA300FF9400FF9400FF9400FF94
00FF9400FF9400FF9400FFA300FF9400FF9400FF9400FF9400FFA300FF9400FFA300FFA3
00FFA300FFA300FFB300FFB300FFC200FFC200FFE100E1FFEB00FF00D1FF00F0FF1400FF
00FFFF00FFE100FFD100FFD100FFC200FFC200FFC200FFC200FFC200FFC200FFC200FFC2
00FFC200FFC200FFC200FFD100FFD100FFD100FFE100FFF000FFFF00F0FF00E1FF00E1FF
00D1FF00B3FF0047FF5100FF0057FF00A3FF00C2FF00C2FF00D1FF0047FF00E1FF00F0FF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF000FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00F0FF00F0FF00F0FF00F0FF00F0FF00E1FF00E1FF
00E1FF00E1FF00D1FF00D1FF00D1FF00C2FF00C2FF00C2FF00B3FF00B3FF00B3FF00A3FF
00A3FF00A3FF00A3FF0094FF0094FF0085FF0085FF0075FF0075FF0066FF0066FF0057FF
0057FF0057FF0047FF0038FF0038FF0028FF0019FF000AFF0500FF2300FF2300FF3300FF
5100FF7000FF8F00FFCC00FFFF00B8FF002EFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF002EFF005CFF0000FF00B8FF00E6FF00D7FF00E6CC00FF8F00FF5100FF
4200FF5100FFFF007A7000FF4200FF2300FF3300FF5100FFFF00D77000FFFF00D7AE00FF
FF004CFF0000FF007AFF00F5BD00FF000AFF0019FF0038FF0047FF0047FF0057FF0057FF
0057FF0047FFCC00FF0038FF0047FF0028FF4200FF0075FF0094FF00A3FF00B3FF00B3FF
00B3FF00B3FF00A3FF0075FF0047FF0028FF0085FF00B3FF00D1FF00E1FF00F0FF00F0FF
00FFFF00FFFF00FFF000FFF000FFE100FFE100FFE100FFE100FFD100FFD100FFD100FFD1
00FFD100FFC200FFC200FFC200FFC200FFC200FFB300FFB300FFB300FFB300FFB300FFB3
00FFB300FFA300FFA300FFA300FFA300FFA300FFA300FFA300FFA300FF9400FFA300FF94
00FF9400FF9400FF9400FF9400FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF85
00FF8500FF8500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF75
00FF7500FF7500FF7500FF7500FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF66
00FF6600FF6600FF6600FF6600FF6600FF5700FF5700FF5700FF5700FF5700FF5700FF57
00FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF4700FF4700FF4700FF57
00FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF47
00FF4700FF4700FF4700FF4700FF4700FF4700FF5700FF4700FF4700FF4700FF4700FF47
00FF4700FF5700FF4700FF4700FF5700FF5700FF5700FF5700FF5700FF5700FF6600FF66
00FF6600FF7500FF8500FFA300FFB300FFC200FFE100D1FF5100FF00C2FF6100FF000AFF
4200FF00FFD100FF9400FF8500FF7500FF7500FF7500FF7500FF7500FF7500FF8500FFA3
00E1FF00D1FF0057FF0085FF9E00FF00B3FF0019FF00FFC200FF9400FF8500FF7500FF75
00FF7500FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7500FF75
00FF7500FF8500FF8500FFA300FFE10094FF0085FF00FFE100FFC200FFC200FFD100E1FF
0500FF00FFFF00FFC200FFB300FFB300FFB300FFC200FFC200FFD100FFE100E1FF00D1FF
3300FF000AFF0019FF00E1FF00FFF000FFD100FFC200FFB300FFA300FFA300FF9400FF94
00FF9400FF9400FF9400FFA300FFB300FFC200FFFF5100FF0075FF00F0FF00FFF000FFF0
00F0FF00FFFF00D1FFFF006B0085FFBD00FF000AFF0019FF4200FFDC00FF0075FF00A3FF
0038FF00FFF000FFE100FFD11400FF00FFC200FFB300FFB300FFC200FFE12300FF00FFD1
00E1FF00B3FF00FFB300FFA300FFA300FFB300FFB300FFC200FFD100FFD100F0FF0094FF
0047FF00F0FF00FFD100FFC200FFB300FFA300FF9400FF9400FF8500FF8500FF8500FF75
00FF7500FF7500FF7500FF7500FF7500FF7500FF8500FFD10094FF00FFE100FFA300FF94
1400FF00C2FF00FFF000FF9400FF8500FF8500FF8500FF8500FF9400FFD100FFB300FFB3
00FFFF0028FF00FFD100FFD100FFE1EB00FF0085FF00C2FF0066FF00FFD100FFC200FFC2
00FFE10085FF00FFD100FF9400FF8500FF8500FF8500FF8500FF8500FF8500FFA300FFD1
00C2FF00FFB300FFB300C2FF00FFD100FF8500FF8500FF8500FF9400FF9400FFA300FFA3
00FFB300FFE100FFFF00A3FF00C2FF1400FF00C2FF00D1FFDC00FF00C2FF00FFFF00F0FF
0094FF0047FF2300FF3300FF0094FF00FFF000FFD100FFFF00FFE100FFD100FFC200FFC2
00FFE100FFFF00D1FF0085FF00FFFF00FFF000FFE100FFE100FFE100FFFF00FFFF00F0FF
0094FF00C2FF00FFFF00FFD100FFC200FFD1000AFF00FFB300FF8500FF7500FF5700FF47
00FF4700FF3800FF3800FF2800FF2800FF2800FF1900FF1900FF1900FF0A00FF0A00FF0A
00FF0A05FF0005FF0005FF0005FF0005FF0014FF0014FF0014FF0014FF0014FF0014FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF00
42FF0033FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00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42FF0033FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00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33FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00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42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00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42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00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42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00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42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00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42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00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42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00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42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00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42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0033FF00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42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0033FF0042FF00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42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00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42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00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42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
42FF0042FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0000FF0A
05FF0005FF0005FF0005FF0005FF0005FF0000FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF3800FF3800FF3800FF38
00FF3800FF3800FF4700FF4700FF4700FF4700FF4700FF5700FF5700FF5700FF6600FF66
00FF8500FFD10047FF00D1FF00F0FF00F0FF00FFFF00F0FF00B3FF6100FF00D1FF00FFF0
00FFE100FFE100FFFF00FFC200FFB300FFB300FFA300FFA300FF9400FF9400FF9400FF94
00FF9400FF9400FF9400FF9400FF9400FF9400FF9400FFA300FFA300FFA300FFB300FFE1
00FFFF0085FFFF00000085FF0028FF0094FF0085FF0500FF00A3FF00C2FF00C2FF0019FF
0094FF0085FF00A3FF000AFF6100FF00A3FF00B3FFFF000000E1FF00FFFF00FFE100FFE1
00FFD100FFD100FFD100FFD100FFC200FFC200FFB300FFB300FFB300FFB300FFB300FFB3
00FFB300FFB300FFB300FFC200FFC200FFC200FFD100FFE100FFFF00B3FF0057FF8000FF
0047FFDC00FF00E1FF00FFE100FFD100FFC200FFB300FFB300FFB300FFB300FFB300FFB3
00FFD100FFD100FFC200FFFF00FFD100FFF00057FF0075FF00FFF000FFD100FFB300FFA3
00FFA300FF9400FF9400FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF85
00FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF85
00FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF85
00FF8500FF8500FF8500FF9400FF9400FF9400FF9400FF9400FF9400FF9400FF9400FF94
00FFA300FFA300FFA300FFA300FFA300FFA300FFA300FFB300FFB300FFB300FFB300FFC2
00FFB300FFB300FFC200FFC200FFC200FFC200FFC200FFC200FFC200FFC200FFC200FFC2
00FFC200FFD100FFD100FFD100FFD100FFD100FFD100FFD100FFE100FFE100FFE100FFE1
00FFF000FFF000FFFF00F0FF9E00FF00A3FF0066FFCC00FF2300FF0047FF0085FF0085FF
0094FF00A3FF00B3FF00B3FF00B3FF00A3FF00A3FF0094FF0085FF0066FF0047FF0038FF
0019FF8000FF8000FF9E00FF8000FF5100FF0500FFFF008A0028FF0057FF0057FF0057FF
9E00FF3300FF0047FF0047FF000AFF0047FF0066FF0066FF0066FF0066FF0057FF0047FF
0047FF0038FF0028FF0500FF4200FF8F00FF3300FF2300FF2300FF3300FF4200FF6100FF
8F00FFFF0000CC00FFCC00FFFF00F5FF00C7FF007AFF000FFF0000FF0000FF0000FF0000
FF0000FF00E6CC00FF9E00FF8000FF7000FF5100FF4200FF3300FF2300FF0500FF000AFF
0019FF0028FF0038FF0047FF0057FF0057FF0066FF0066FF0075FF0075FF0085FF0085FF
0094FF00A3FF00A3FF00B3FF00B3FF00B3FF00C2FF00C2FF00C2FF00C2FF00C2FF00C2FF
00C2FF00C2FF00C2FF00B3FF00B3FF00A3FF0094FF0085FF0075FF0057FFFF001E0047FF
0075FF0085FF0094FF0094FF0085FF000AFF0019FF0057FF0047FFFF00E60028FF0057FF
0047FF6100FF0047FF0094FF00B3FF00C2FF00D1FF00D1FF00D1FF00C2FF0094FF1400FF
00A3FF00D1FF00F0FF00F0FF00E1FF00B3FF00F0FF1400FF00FFF000FFD100FFC200FFC2
00FFC200FFB300FFB300FFB300FFB300FFA300FFB300FFA300FFA300FFA300FFA300FFA3
00FFA300FFA300FF9400FF9400FF9400FF9400FF9400FF9400FF9400FF9400FF9400FF85
00FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF7500FF7500FF85
00FF7500FF7500FF7500FF7500FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF66
00FF6600FF6600FF6600FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF4700FF47
00FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF47
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF4700FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF4700FF3800FF3800FF3800FF3800FF3800FF38
00FF4700FF3800FF3800FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF47
00FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF5700FF5700FF5700FF5700FF57
00FF5700FF5700FF5700FF5700FF6600FF6600FF6600FF6600FF7500FF7500FF7500FF75
00FF8500FF8500FF9400FF9400FFB300FFFF00E1FF00F0FF0066FF00B3FF00C2FF0085FF
00FFC200FF9400FF9400FF8500FF8500FF7500FF7500FF7500FF6600FF6600FF6600FF66
00FF6600FF6600FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF47
00FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF47
00FF4700FF4700FF4700FF4700FF4700FF5700FF5700FF6600FF8500FFFF00FF9400FF66
00FF5700FF4700FF3800FF3800FF3800FF3800FF3800FF3800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF3800FF3800FF3800FF4700FF4700FF4700FF5700FF6600FF7500FF94
00FFC20047FF00FFFF0094FF00FF9400FF6600FF5700FF5700FF5700FF5700FF5700FF66
00FF7500FFA300FFF00085FFBD00FF00FFB300FF9400FF4700FF3800FF2800FF2800FF28
00FF1900FF2800FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF3800FF28
00FF3800FF3800FF3800FF3800FF4700FF4700FF4700FF5700FF5700FF5700FF6600FF75
00FF8500FFD100C2FFFF00C70085FF00C2FF00FFD100FF9400FF7500FF7500FF6600FF66
00FF6600FF5700FF4700FF4700FF4700FF4700FF4700FF4700FF5700FF8500FFE100FFC2
00FF7500FF852300FF00FF7500FF5700FF5700FF6600E1FF00FFA300FFB300FFA300FFC2
0057FF0066FF00A3FF0085FF2300FF0094FF0047FF00FF8500FF7500FF5700FF4700FF38
00FF3800FF2800FF1900FF1900FF1900FF1900FF0A00FF0A00FF0A00FF1900FF1900FF47
00FF4700FF3800FF3800FF85
42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00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42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00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42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00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42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0033FF00
33FF0033FF0033FF0033FF0042FF0042FF0042FF0042FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0000FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF1900FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF2800FF2800FF1900FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF4700FF4700FF4700FF4700FF4700FF5700FF5700FF5700FF66
00FF6600FF6600FF7500FF8500FF8500FF9400FF9400FFA300FFC200FFFF00D1FF0094FF
FF005CCC00FF00E1FF00FFF000FFE100FFD100FFC200FFB300FFB300FFA300FFA300FFA3
00FFA300FFA300FFA300FFA300FFA300FFA300FFA300FFA300FFB300FFB300FFC200FFC2
00FFC200FFD100FFE100FFE100FFF000FFFF00E1FF0066FF0057FF0057FF4200FFBD00FF
FF001EFF00003300FF0066FF0075FF0085FF00F0FF00FFFF00FFF000FFF000FFD100FFD1
00FFC200FFB300FFB300FFB300FFA300FFB300FFA300FFA300FFA300FFA300FFA300FFA3
00FFA300FFA300FFA300FFA300FFB300FFB300FFC200FFC200FFD100FFF000D1FF0085FF
0085FF00E1FF00FFF000FFE100FFC200FFB300FFA300FFA300FF9400FF9400FF9400FF94
00FF9400FF9400FF9400FF9400FFA300FFA300FFC20047FF00FFC200FFA300FF9400FF94
00FF8500FF8500FF8500FF8500FF7500FF8500FF7500FF7500FF7500FF7500FF7500FF75
00FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF75
00FF7500FF7500FF7500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF85
00FF8500FF8500FF8500FF8500FF8500FF9400FF8500FF8500FF9400FF9400FF9400FF94
00FF9400FF9400FF9400FF9400FF9400FFA300FFA300FFA300FFA300FFA300FFA300FFA3
00FFA300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC200FFC200FFC2
00FFC200FFC200FFC200FFC200FFD100FFD100FFD100FFD100FFD100FFE100FFE100FFE1
00FFE100FFF000FFF000FFFF00FFFF00F0FF00E1FF00D1FF00C2FF00A3FF0094FF8000FF
3300FF0066FF0075FF0085FF0075FF0066FF0047FF2300FF0057FF0047FF0500FFEB00FF
7000FF000AFF0500FF0019FF1400FFEB00FF0500FF0038FF0066FF0085FF0094FF0094FF
0094FF0094FF0094FF0094FF0094FF0085FF0085FF0085FF0085FF0075FF0075FF0066FF
0066FF0057FF0047FF0047FF0038FF0028FF0019FF000AFF3300FFEB00FF5100FF5100FF
CC00FF8F00FFFF0099FF00E6FF002EFF003DFF007AFF0000FF0000FF0000FF0000FF0000
FF007AFF00F5DC00FFEB00FFDC00FF9E00FFEB00FF9E00FFEB00FFFF005CFF00E6FF0000
AE00FFFF00B83300FF0500FF0019FF0500FF8F00FFFA00FFFF007AFA00FF000AFF1400FF
FA00FF1400FF0066FF0028FF00C2FF00D1FF00D1FF00D1FF00E1FF00E1FF00E1FF00E1FF
00E1FF00D1FF00D1FF00C2FF00B3FF00A3FF0066FF3300FF0066FF00A3FF00B3FF0094FF
FF00000075FF00C2FF00D1FF00E1FF00E1FF00D1FF00C2FF0085FF0019FF0066FF0047FF
0075FF0019FF0019FF8000FF000AFF0028FF4200FF0047FF0047FF0500FF1400FF0094FF
00A3FF00B3FF00C2FF00D1FF00E1FF00F0FF00FFFF00FFF000FFE100FFD100FFD100FFC2
00FFC200FFC200FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA300FFA300FFA3
00FFA300FFA300FFA300FFA300FFA300FFA300FFA300FFA300FF9400FF9400FFA300FF94
00FF9400FF9400FF9400FF9400FF9400FF9400FF8500FF8500FF8500FF8500FF8500FF85
00FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF6600FF6600FF6600FF6600FF66
00FF6600FF6600FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF4700FF47
00FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF28
00FF2800FF3800FF3800FF3800FF2800FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF4700FF3800FF38
00FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF57
00FF5700FF5700FF5700FF5700FF5700FF6600FF6600FF6600FF6600FF7500FF7500FF94
00FF9400FFA300FFC200FFB300FFC200FFD100FFE100E1FFFF00D700D1FF00FFFF00FFC2
00FFB300FFA300FFA300FF8500FF7500FF7500FF7500FF6600FF6600FF6600FF5700FF57
00FF5700FF5700FF5700FF5700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF47
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF4700FF5700FF4700FF3800FF38
00FF3800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF1900FF2800FF1900FF28
00FF1900FF2800FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF2800FF28
00FF2800FF2800FF2800FF3800FF3800FF4700FFB300FFA300C2FF3300FF00FFB300FFE1
0028FF00F0FF00FFA300FF8500FF6600FF4700FF3800FF3800FF3800FF3800FF2800FF38
00FF2800FF3800FF3800FF4700FF6600FFE100FF750085FF00FF2800FF1900FF1900FF19
00FF1900FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF2800FF28
00FF2800FF2800FF2800FF3800FF3800FF4700FF4700FF4700FF5700FF6600FF6600FF75
00FF8500FF9400FFB300FFF000FFE100FFA300FF8500FF7500FF6600FF6600FF5700FF47
00FF4700FF3800FF3800FF3800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF1900FF2800FF2800FF2800FF2800FF2800FF3800FF4700FF5700FF6600FF94
00FFC20075FF00FFA300FF8500FF7500FF6600FF8500FF8500FF8500FFC200FFD1000AFF
0057FF00FFF000FF8500FF6600FF5700FF4700FF4700FF4700FF7500FF7500FFFF00C2FF
2300FF00FF9400FF5700FF47
42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00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42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00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42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00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42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00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42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0014FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0000FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF2800FF1900FF19
00FF1900FF1900FF1900FF1900FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF4700FF4700FF4700FF4700FF5700FF5700FF5700FF5700FF5700FF66
00FF6600FF6600FF7500FF7500FF7500FF8500FF8500FF9400FF9400FFA300FFB300FFC2
00FFD100E1FF0075FF7000FF00C2FF00F0FF00FFF000FFD100FFD100FFC200FFC200FFC2
00FFC200FFC200FFC200FFC200FFC200FFC200FFD100F0FF00E1FF00FFE100FFE100FFE1
00FFE100FFF000FFFF00E1FF00A3FF0047FF0085FF0057FF0038FF0094FF00C2FF00B3FF
00E1FF00E1FF00E1FF00D1FF00A3FF0094FF00E1FF00F0FF00FFFF00F0FF00FFF000FFE1
00E1FF00FFB300FFA300FFA300FF9400FF9400FF9400FF9400FF9400FF9400FF9400FF94
00FF9400FF9400FF9400FF9400FF9400FF9400FFA300FFA300FFB300D1FF00FFE100FFF0
00A3FF00F0FF00FFD100FFC200FFB300FF9400FF9400FF8500FF8500FF8500FF8500FF75
00FF7500FF7500FF7500FF7500FF7500FF8500FF7500FF7500FF7500FF7500FF7500FF75
00FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF75
00FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF75
00FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF8500FF85
00FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF9400FF94
00FF9400FF9400FF9400FF9400FF9400FF9400FF9400FFA300FF9400FFA300FFA300FFA3
00FFA300FFA300FFA300FFA300FFA300FFB300FFB300FFB300FFB300FFB300FFC200FFC2
00FFC200FFC200FFC200FFD100FFD100FFD100FFD100FFD100FFE100FFE100FFE100FFE1
00FFF000FFF000FFFF00FFFF00F0FF00E1FF00D1FF00C2FF00B3FF00B3FF00A3FF0094FF
0085FF0066FF0038FF0500FF6100FFFA00FFFF004CFF002E8000FFDC00FF7000FF2300FF
0075FF0085FF0094FF0094FF0094FF3300FF00A3FF00B3FF00B3FF00C2FF00C2FF00C2FF
00C2FF00B3FF00B3FF00B3FF00A3FF0094FF0094FF0085FF0038FF0028FF0047FF000AFF
4200FF0019FF0019FF0019FF0500FF8F00FFFF0000FF00B87000FF2300FFFF00005100FF
3300FF3300FF5100FFFF005CFA00FFFF0000FF0000FF0000FF008AFF0000FF0000FF0000
FF00B8FA00FFCC00FFBD00FFDC00FF9E00FF2300FF1400FF0500FF000AFF0028FF0038FF
0047FF0047FF0047FF0047FF0038FFFF00F55100FF4200FF000AFF0066FF0085FF00A3FF
00B3FF00C2FF00D1FF00D1FF00E1FF00E1FF00E1FF00F0FF00F0FF00F0FF00F0FF00F0FF
00F0FF00F0FF00F0FF00F0FF00F0FF00D1FF6100FF0094FF00F0FF00FFFF00FFFF00FFF0
00FFF000FFF000FFF000FFF000FFF000FFFF00FFFF00FFFF00FFFF00F0FF00F0FF00E1FF
00E1FF00D1FF00B3FF00A3FF0075FF000AFFBD00FF0038FF1400FF0028FF8000FF0028FF
0066FF0075FF00A3FF00C2FF00F0FF00FFFF00FFFF00FFF000FFE100FFE100FFE100FFD1
00FFD100FFD100FFD100FFC200FFC200FFC200FFC200FFC200FFC200FFC200FFC200FFC2
00FFC200FFD100FFD100FFC200FFC200FFD100FFE100FFFF00FFC200FFB300FFB300FFB3
00FFB300FFB300FFB300FFC200FFE100D1FF00FFF000FFC200FFB300FFA300FFA300FFA3
00FFA300FFB300FF9400FF9400FF8500FF8500FF7500FF7500FF7500FF7500FF7500FF75
00FF6600FF6600FF6600FF6600FF6600FF6600FF5700FF5700FF5700FF5700FF5700FF47
00FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF3800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF4700FF4700FF4700FF4700FF4700FF47
00FF4700FF4700FF5700FF5700FF5700FF5700FF5700FF6600FF6600FF7500FF7500FF75
00FF8500FF9400FFC200D1FF0038FF00FFF000FFFF00A3FF0019FFFF008A00A3FF00FFFF
00F0FF0047FF00B3FF00FFD100FFB300FF7500FF6600FF6600FF6600FF5700FF5700FF57
00FF5700FF4700FF4700FF4700FF4700FF4700FF4700FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF2800FF2800FF3800FF3800FF4700FF5700FFC2
0038FF00FFF000FF5700FF4700FF3800FF2800FF1900FF1900FF1900FF1900FF1900FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A05FF0000FF0A05FF0000FF0A05FF0005FF0005FF0005FF0000FF0A05FF0000FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF1900FF1900FF19
00FF1900FF2800FF2800FF3800FF5700FF5700FF6600FF6600FF7500FF9400FFF00066FF
0094FF00FFA300FF6600FF6600FF6600FF7500FFD100FFB37000FF00FFD100FFC200FFA3
00FF6600FF4700FF3800FF2800FF1900FF1900FF1900FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF1900FF470085FF00FF4700FF28
00FF1900FF1900FF3800FF8500FF2800FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF2800FF2800FF3800FF3800FF5700D1FF00F0FF00FF6600FF4700FF2800FF2800FF19
00FF0A00FF0A05FF0005FF00
42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00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42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00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42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00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42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00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42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF4700FF4700FF4700FF5700FF5700FF6600FF7500FF7500FF7500FF7500FF75
00FF8500FF9400C2FF00FFFF00FFB300FFB300FFB300FFC20047FF00FFE100FFD100FFE1
00F0FF00FFFF00D1FF00C2FFAE00FF00D1FF00E1FF00F0FF00FFFF00FFFF00FFFF00FFF0
00FFF000FFF000FFF000F0FF00A3FF0019FF00A3FF00B3FF8000FF00A3FF00C2FF00D1FF
00D1FF00B3FF0019FF0019FF0028FF00A3FF00D1FF00E1FF00D1FF00C2FF00FFF000FFE1
00FFE100FFD100FFE100FFE100FFF000F0FF0094FF5100FF00FFFF00FFC200FFB300FFA3
00FF9400FF9400FF9400FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF75
00FF8500FF7500FF7500FF8500FF7500FF8500FF8500FF8500FF8500FF9400FFA300FFF0
EB00FF00FFB300FFA300FF9400FF9400FF8500FF7500FF7500FF7500FF7500FF7500FF66
00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF66
00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF66
00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7500FF7500FF7500FF75
00FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF75
00FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF9400FF8500FF8500FF8500FF85
00FF8500FF8500FF9400FF9400FF9400FF9400FF9400FF9400FF9400FF9400FFA300FFA3
00FFA300FFA300FFA300FFA300FFA300FFA300FFB300FFB300FFB300FFB300FFB300FFC2
00FFC200FFD100FFE100FFE100FFE100FFE100FFF000FFF000FFF000FFF000FFFF00FFF0
00FFFF00FFFF00F0FF00F0FF00F0FF00E1FF00D1FF00D1FF00C2FF00B3FF0075FF0038FF
0019FF1400FF4200FF0057FF0038FF0057FF0047FF0066FF0038FFAE00FF0047FF0066FF
0075FF0094FF00A3FF00B3FF00C2FF00C2FF00D1FF00D1FF00E1FF00E1FF00E1FF00E1FF
00D1FF00D1FF00C2FF00B3FF0094FFFF00A80038FF0028FF0066FF0094FF0085FF0085FF
0075FF0057FF0028FF6100FF0019FF0047FF0057FF0057FF0047FF0038FF0019FF4200FF
AE00FFFF00D7AE00FF8000FFFF00B8FF0000FF00B8FF0000FF00F5FF0099FF0000FF0000
FF006BFF0000BD00FF9E00FF7000FF5100FF4200FF7000FFCC00FFFF004C2300FF0028FF
0057FF0066FF0075FF0085FF0085FF0085FF0094FF0094FF0094FF0085FF0094FF00B3FF
00B3FF00B3FF00D1FF00E1FF00E1FF00F0FF00F0FF00FFFF00FFFF00FFFF00FFFF00FFF0
00FFF000FFF000FFF000FFF000FFF000FFE100FFE100FFE100FFE100FFE100FFE100FFE1
00FFE100FFD100FFE100FFE100FFE100FFE100FFE100FFE100FFFF00D1FF0066FF00A3FF
2300FF0075FF00C2FF00D1FF00B3FF4200FF0038FF00D1FF00F0FF00F0FF00F0FF00F0FF
00E1FF00D1FF00C2FF0085FF6100FFFA00FF8000FF00B3FF00D1FF00F0FF00FFFF00FFF0
00FFF000FFF000FFF000FFF000FFFF0019FF00F0FF0047FF00E1FF00FFFF00FFFF00FFFF
00F0FF00E1FF00C2FF0066FF00A3FF00D1FF00F0FF00FFFF00FFF000FFF000FFF000FFF0
00E1FF00FFF000FFF000FFF000FFFF00F0FF00A3FF00A3FF000AFF00B3FF0028FF00FFF0
00FFD100FFC200FFB300FFA300FFA300FF9400FF9400FF8500FF8500FF8500FF8500FF85
00FF9400FF9400FFA30075FF00FFB300FF9400FF7500FF6600FF6600FF5700FF5700FF57
00FF5700FF4700FF4700FF4700FF4700FF4700FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF2800FF2800FF2800FF2800FF3800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF3800FF3800FF2800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF4700FF4700FF4700FF47
00FF4700FF4700FF4700FF5700FF5700FF5700FF5700FF6600FF6600FF6600FF7500FF75
00FF8500FF8500FF8500FF9400FFA300FFC200FFD100FFF00028FF0085FF00FFF000FFD1
00FFB300FFA300FF9400FF8500FF8500FF7500FF7500FF6600FF6600FF5700FF5700FF57
00FF5700FF4700FF4700FF4700FF4700FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF19
00FF2800FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF0A00FF0A00FF1900FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF1900FF1900FF2800FF3800FF6600FF85
00FF3800FF2800FF2800FF2800FF1900FF0A00FF0A00FF0A00FF0A00FF0A05FF0000FF0A
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0000FF0A00FF0A00FF0A00FF0A00FF1900FF1900FF19
00FF1900FF2800FF2800FF4700FF5700FF6600FF8500FFB30085FF00FFFF00FFFF00FFA3
00FF8500FF3800FF3800FF2800FF2800FF2800FF2800FF3800FF3800FF5700FF6600FFB3
0085FF00FFE100E1FF00FF7500FF4700FF1900FF0A00FF0A05FF0005FF0005FF0005FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
00FF0A00FF0A00FF1900FF2800FF3800FF5700D1FF00A3FF00FFE100FF5700FF5700FF47
00FF0A05FF0005FF0014FF00
42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00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42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0000FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF3800FF2800FF2800FF2800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF4700FF4700FF4700FF5700FF5700FF8500FFFF0057FF00FFA300FF9400FFA3
00FFB300FFF08000FF00FFFF00FFE100E1FF00FFF000D1FF0028FF00D1FF0057FF0066FF
FF00001400FF0066FF00E1FF00F0FF0085FF0085FF0038FF0066FF0057FF00C2FF00F0FF
00F0FF00F0FF00F0FF00E1FF00D1FF00C2FF00A3FF0075FF0028FF0085FF00A3FF0075FF
CC00FF0075FF0019FF4200FF0094FF3300FF00F0FF00FFFF00FFF000FFE100FFE100FFD1
00FFD100FFC200FFC200FFC200FFC200FFC200FFD100FFD100F0FF00FFD100FFA300FF94
00FF9400FF9400FF8500FF8500FF8500FF8500FF8500FF7500FF7500FF7500FF7500FF75
00FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF8500FF8500FF9400A3FF
00FFB300FF8500FF8500FF8500FF7500FF7500FF7500FF7500FF6600FF6600FF6600FF66
00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF66
00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF66
00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF66
00FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF75
00FF7500FF7500FF7500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF85
00FF9400FF9400FF9400FF9400FF9400FF9400FF9400FF9400FF9400FF9400FF9400FFA3
00FFA300FFA300FFA300FFA300FFA300FFA300FFB300FFB300FFB300FFB300FFB300FFC2
00FFC200FFD100FFF00057FF00E1FF00F0FF0094FF0085FF00D1FF00F0FF00F0FF00FFFF
00F0FF00F0FF00F0FF00E1FF00E1FF00C2FF000AFF0085FF00A3FF0094FF0066FF5100FF
000AFF000AFFFF005C0085FF00A3FF00A3FF00A3FF0094FF0057FF2300FF0066FF0066FF
0019FF1400FF0075FF0085FF00C2FF00D1FF00E1FF00E1FF00E1FF00E1FF00E1FF00E1FF
00E1FF00E1FF00D1FF00C2FF00C2FF0075FF00B3FF00C2FF00B3FF00B3FF00A3FF0094FF
0075FF0038FF8F00FF2300FF0047FF0066FF0066FF0066FF0066FF0057FF0047FF0038FF
0019FF1400FFAE00FF5100FF4200FF5100FF8000FF9E00FFDC00FFFF00D7FF0000FF0000
FF004CFF0099FF00B8FF00D78000FF3300FF1400FF0500FF000AFF0019FF0038FF0047FF
0057FF0066FF0075FF0085FF0085FF0094FF00A3FF00A3FF00B3FF00B3FF00C2FF00C2FF
00D1FF00D1FF00E1FF00E1FF00F0FF00F0FF00F0FF00FFFF00FFFF00FFFF00FFFF00FFF0
00FFF000FFF000FFF000FFE100FFE100FFE100FFE100FFE100FFD100FFD100FFD100FFD1
00FFD100FFD100FFD100FFD100FFD100FFD100FFE100FFE100FFF000FFFF00D1FF000AFF
0057FF00E1FF00FFFF00FFFF00E1FF0057FF0066FF00E1FF00FFFF00FFF000FFF000FFFF
00FFFF00E1FF0047FF0085FF4200FF00A3FF8000FF5100FF0085FF0094FF00C2FF00F0FF
00F0FF00F0FF00E1FF00E1FF00E1FF00C2FF0085FF0085FF00B3FF0075FF00A3FF000AFF
0094FF0085FF000AFF1400FF9E00FF0057FF00A3FF0028FF00B3FF00D1FF00B3FF2300FF
00B3FF00E1FF00E1FF00D1FF0057FF00B3FF0038FF0066FF00E1FF00FFFF00FFE100FFD1
00FFC200FFC200FFB300FFB300FFA300FFA300FFA300FF9400FF9400FF9400FF9400FFA3
00FFB300FFFF00E1FF00FFE100FFA300FF8500FF7500FF6600FF6600FF5700FF5700FF57
00FF5700FF4700FF4700FF4700FF4700FF4700FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF3800FF2800FF2800FF2800FF2800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF4700FF4700FF4700FF4700FF47
00FF4700FF4700FF5700FF5700FF5700FF5700FF6600FF6600FF6600FF6600FF7500FF75
00FF8500FF8500FF8500FF9400FFA300FFD100F0FF0085FF5100FF0047FF0085FF00F0FF
00FFE100FFB300FF9400FF9400FF8500FF8500FF7500FF7500FF6600FF6600FF6600FF57
00FF5700FF4700FF4700FF4700FF4700FF3800FF3800FF3800FF3800FF3800FF3800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF2800FF2800FF28
00FF1900FF0A00FF0A00FF0A00FF0A00FF0A05FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0014FF0014FF0005FF00
14FF0014FF0005FF0014FF0014FF0005FF0005FF0014FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0000FF0A00FF0A00FF0A00FF0A00FF1900FF19
00FF2800FF2800FF3800FF4700FF5700FF7500FFA300E1FF00FFC200FF7500FF7500FF85
00FF3800FF2800FF2800FF1900FF1900FF1900FF1900FF2800FF2800FF7500FFA300FFA3
00FF9400FFD100FFB300FF4700FF2800FF1900FF0A05FF0005FF0005FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0005FF0014FF0005FF0005FF0005FF00
05FF0000FF0A00FF1900FF4700FF8500FF8500FF943300FF00E1FF00F0FF00FFB300FF75
00FF4700FF1905FF0014FF00
42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00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42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00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42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00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42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00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42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00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42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00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42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00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42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00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42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00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42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00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42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00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42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00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42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00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42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00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42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00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42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
42FF0042FF0042FF0042FF0042FF0042FF0042FF0033FF0033FF0042FF0042FF0042FF00
42FF0042FF0042FF0042FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
05FF0014FF0014FF0014FF0014FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0000FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF1900FF0A00FF0A00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF4700FF4700FF4700FF47
00FF4700FF4700FF4700FF4700FF5700FF5700FF5700FF5700FF5700FF5700FF6600FF66
00FF6600FF6600FF7500FF7500FF7500FF7500FF8500FF8500FF8500FF9400FFD100FFC2
00FFC200FFD100FFD100FFD100FFD100FFE100FFF000F0FF00E1FF00C2FF0057FF0500FF
0066FF00D1FF00D1FF00C2FFCC00FF0085FF0085FF4200FF00C2FF00F0FF00FFFF00FFFF
00FFFF00E1FF00B3FF0066FF6100FF0085FF00D1FF00FFFF00FFF000FFE100FFE100FFD1
00FFD100FFD100FFD100FFD100FFC200FFC200FFB300FFA300FFA300FF9400FF9400FF94
00FF8500FF8500FF8500FF7500FF7500FF7500FF6600FF6600FF6600FF6600FF5700FF57
00FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF4700FF47
00FF5700FF4700FF4700FF4700FF5700FF4700FF4700FF4700FF5700FF4700FF4700FF47
00FF5700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF5700FF5700FF57
00FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF57
00FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF6600FF6600FF6600FF6600FF66
00FF6600FF6600FF6600FF6600FF6600FF7500FF7500FF7500FF7500FF7500FF7500FF75
00FF7500FF7500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF9400FF94
00FF9400FF9400FF9400FFA300FFA300FFA300FFA300FFA300FFA300FFA300FFA300FFB3
00FFB300FFB300FFB300FFB300FFB300FFB300FFC200FFC200FFC200FFC200FFC200FFD1
00FFD100FFD100FFE100FFE100FFFF00F0FF00F0FF00E1FF00D1FF0094FF7000FFFF00A8
0066FF00A3FF00C2FF00D1FF00C2FF00C2FF0057FF4200FF00C2FF00D1FF00D1FF0085FF
0094FF0066FF4200FF00FFF000FFE100FFD100FFD100FFD100FFD100FFD100FFD100FFD1
00FFD100FFD100FFD100FFD100FFD100FFD100FFD100FFE100FFE100FFE100FFE100FFF0
00FFF000FFFF00F0FF00F0FF00F0FF00E1FF00D1FF00D1FF0047FF00A3FF00B3FF00A3FF
0085FF0094FF0094FF0066FF9E00FF0038FF0075FF0057FF0066FF0094FF00A3FF00B3FF
00B3FF00A3FF00A3FF0094FF0075FF0057FF0028FF0019FF7000FFFF00D70019FF1400FF
7000FFFF00A8EB00FF7000FF1400FF0047FF0038FF6100FF0047FF0075FF0075FF0047FF
1400FF00C2FF00D1FF00E1FF00D1FF00E1FF00D1FF00D1FF00D1FF00C2FF00A3FFFF005C
1400FF0094FF00C2FF00E1FF00F0FF00FFFF00FFFF00FFFF00FFFF00FFF000FFF000FFFF
00C2FF00FFFF00FFF000FFF000FFFF0075FF00FFFF00FFD100FFC200FFB300FFB300FFA3
00FFA300FFA300FFA300FFA300FFA300FFA300FFA300FF9400FFA300FF9400FFA300FF94
00FF9400FFA300FFA300FFA300FFA300FFA300FFA300FFA300FFA300FFA300FFB300FFB3
00FFB300FFB300FFC200FFC200FFD100FFE100FFFF00F0FF00F0FF0066FF2300FF0075FF
00E1FF00FFFF00FFF000FFD100FFC200FFC200FFB300FFB300FFA300FFA300FFA300FF94
00FF9400FF9400FF9400FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF85
00FF8500FF8500FF8500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF85
00FF8500FF9400FF9400FFA300FFC200C2FFDC00FF00E1FF00FFE100E1FF00D1FF00FFC2
00FFB300FFA300FFA300FFA300FFC200FFE1FF00E60047FF00B3FF00FFD100FFA300FF94
00FF9400FF94000AFFFF00B800FF7500FF7500FF6600FF4700FF3800FF3800FF3800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF2800FF1900FF1900FF1900FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF3800FF3800FF3800FF3800FF38
00FF4700FF3800FF3800FF4700FF4700FF4700FF5700FF5700FF6600E1FF00FFD100FFC2
00FFB300FFB300FF9400FF9400FF9400FFA300FFA300FFB300FFE100FFFF00F0FF0057FF
0066FF00E1FF000AFF00FFC200FFA300FF9400FF8500FF8500FF7500FF7500FF6600FF66
00FF5700FF5700FF5700FF4700FF4700FF4700FF3800FF3800FF3800FF3800FF3800FF28
00FF2800FF2800FF2800FF2800FF2800FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0014FF0014FF0014FF0005FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0023FF0023FF0023FF0023FF0014FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0014FF0014FF0014FF00
05FF0005FF0000FF0A00FF1900FF7500FF6600FF1905FF0005FF0005FF0014FF0014FF00
23FF0023FF0023FF0023FF0023FF0033FF0023FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0042FF0033FF0033FF0042FF0042FF0033FF0033FF0042FF0042FF0033FF0033FF00
42FF0042FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0023FF0023FF0023FF0023FF0023FF0014FF0014FF0014FF0005FF0005FF00
05FF0000FF0A00FF2800FF57
42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00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42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00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51FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00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51FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00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51FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00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51FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0000FF0A05FF0005FF0005FF00
05FF0000FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF1900FF0A00FF0A00FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF2800FF2800FF2800FF2800FF2800FF3800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF47
00FF4700FF5700FF5700FF5700FF5700FF5700FF6600FF6600FF6600FF7500FF7500FF75
00FF7500FF8500FF8500FF8500FF8500FF9400FF9400FF9400FFA300FFB300FFF00066FF
00B3FF00B3FF00B3FF0500FF0047FF0028FFFF00E60028FF0057FF00F0FF00FFFF00FFF0
00FFD100FFD100FFD100FFC200FFC200FFC200FFB300FFB300FFB300FFB300FFB300FFB3
00FFC200FFC200FFD100FFE100FFF00094FFFF000000B3FF00FFF000FFE100FFD100FFD1
00FFD100FFE100F0FF00C2FF0094FF00FFF000D1FF0085FF0094FFFF00B80047FF00F0FF
00FFE100FFB300FFA300FF8500FF7500FF7500FF6600FF6600FF6600FF5700FF5700FF57
00FF5700FF5700FF4700FF4700FF5700FF4700FF4700FF4700FF4700FF4700FF4700FF47
00FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF47
00FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF47
00FF4700FF4700FF4700FF4700FF4700FF4700FF5700FF5700FF5700FF5700FF5700FF57
00FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF6600FF6600FF6600FF66
00FF6600FF6600FF6600FF6600FF7500FF7500FF7500FF7500FF7500FF8500FF8500FF85
00FF8500FF8500FF8500FF9400FF8500FF9400FF9400FF9400FF9400FF9400FFA300FFA3
00FFA300FFB300FFC200FFF00500FF00FFFF00FFE100FFD100FFD100FFD100FFC200FFD1
00FFD100FFD100FFD100FFE100F0FF00E1FF00FFF000FFF000FFE100FFE100FFF000FFF0
00FFF000FFF000FFFF00F0FF00D1FF00B3FFCC00FF0075FF0094FFFA00FF00C2FF00E1FF
00FFFF00FFF000FFE100FFE100FFE100FFE100FFF000FFFF00B3FF00B3FF00FFE100FFD1
00FFC200FFC200FFC200FFC200FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC2
00FFB300FFC200FFC200FFC200FFC200FFD100FFD100FFE100FFE100FFF000FFF000FFFF
00F0FF00E1FF00B3FF0085FFFF00004200FF0085FF00B3FF00D1FF00D1FF00E1FF00E1FF
00E1FF00D1FF0085FF0057FFAE00FF2300FF00B3FF00D1FF00E1FF00E1FF00E1FF00F0FF
00E1FF00F0FF00E1FF00E1FF00E1FF00E1FF00D1FF00C2FF00C2FF00B3FF00B3FF00A3FF
0085FF0057FF8000FF0047FF0085FF00A3FF00B3FF00C2FF00D1FF00D1FF00E1FF00F0FF
00F0FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F0FF00E1FF0085FF
0057FF3300FF7000FF0019FF00B3FF00E1FF00FFFF00FFF000FFE100FFD100FFC200FFC2
00FFB300FFB300FFB300FFA300FFA300FFA300FFA300FFA300FFA300FF9400FFA300FF94
00FF9400FF9400FF9400FF9400FF9400FF9400FF9400FF9400FF9400FF9400FF9400FF94
00FF9400FF9400FF9400FF9400FF9400FF9400FF9400FF9400FF9400FFA300FFA300FFA3
00FFB300FFC200FFC200FFD10085FF00FFFF00FFFF00F0FF00F0FF00D1FF0057FF8000FF
2300FF0085FF00B3FF0066FF00D1FF00FFF000FFD100FFC200FFB300FFA300FF9400FF94
00FF8500FF8500FF8500FF8500FF7500FF7500FF7500FF7500FF7500FF7500FF6600FF66
00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF66
00FF6600FF6600FF7500FFD100FF8500FF8500FF6600FF6600FF6600FF6600FF5700FF57
00FF5700FF5700FF5700FF5700FF5700FF6600FF6600FF7500FF7500FF9400FFD100FFF0
00FF9400FF7500FF5700FF5700FF4700FF4700FF3800FF3800FF3800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF1900FF1900FF1900FF1900FF2800FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF19
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF1900FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF1900FF1900FF1900FF0A00FF0A00FF0A00FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF2800FF1900FF1900FF1900FF1900FF1900FF1900FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF4700FF4700FF4700FF4700FF5700FF5700FF57
00FF5700FF6600FF6600FF6600FF7500FF8500FF9400FF9400FFA300FFB300FFD100F0FF
00C2FF0085FF00FFFF00FFE100FFD100FFF0AE00FF00FFB300FF8500FF7500FF7500FF66
00FF6600FF5700FF5700FF5700FF5700FF5700FF4700FF4700FF4700FF4700FF4700FF38
00FF3800FF3800FF3800FF2800FF2800FF2800FF2800FF1900FF1900FF1900FF1900FF19
00FF1900FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0033FF0033FF0033FF0023FF0023FF00
33FF0033FF0023FF0023FF0033FF0033FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0042FF0042FF00
42FF0033FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
42FF0042FF0033FF0042FF0033FF0042FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0023FF0023FF0005FF00
51FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00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42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00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42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00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42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
42FF0042FF0042FF0042FF0042FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0005FF0014FF00
14FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0000FF0A05FF0005FF0005FF0000FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF28
00FF2800FF2800FF2800FF3800FF4700FF571400FF00FF8500FF5700FF4700FF3800FF38
00FF3800FF3800FF3800FF3800FF2800FF2800FF3800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF3800FF2800FF2800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF4700FF3800FF3800FF4700FF47
00FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF5700FF57
00FF5700FF5700FF5700FF5700FF5700FF6600FF6600FF7500FF8500FFE100FFF000FFFF
0057FF0057FF00FFC200FFA300FFA300FFA300FFA300FFB300FFB300FFC200FFD100FFE1
00FFF000B3FF0075FF0057FF00C2FF00D1FF00E1FF00D1FF1400FF00D1FF00B3FF0028FF
00F0FF00FFC200FFB300FFA300FFA300FFA300FFA300FF9400FFA300FFA300FFA300FFA3
00FFB300FFB300FFC200FFE100FFFF00C2FF0038FF00F0FF00FFF000FFC200FFB300FFA3
00FFA300FF9400FF9400FF9400FF9400FF9400FFA300FFFF00FFD100FFC200FFC200FFA3
00FFB300FFC200FFF000FFFF00FFF000FFA300FF8500FF6600FF5700FF5700FF5700FF47
00FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF47
00FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF47
00FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF47
00FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF5700FF5700FF5700FF57
00FF5700FF5700FF5700FF5700FF5700FF5700FF6600FF6600FF6600FF6600FF6600FF66
00FF6600FF6600FF6600FF7500FF7500FF8500FF8500FF9400FF9400FF9400FF9400FF94
00FF9400FF9400FF9400FF9400FF9400FF9400FFA300FFA300FFA300FFA300FFB300FFC2
00B3FF00FFF000FFF000FFFF00E1FFDC00FF00D1FF00F0FF00FFFF00FFF000FFFF00FFFF
00FFFF00F0FF00D1FF00A3FF8F00FF0057FF00A3FF0047FF00A3FF0075FF5100FF0066FF
0066FF0047FF0038FF0075FF0085FF00D1FF00E1FF00F0FF00FFFF00FFF000FFF000FFE1
00FFE100FFD100FFD100FFD100FFC200FFC200FFC200FFC200FFC200FFC200FFB300FFB3
00FFB300FFB300FFB300FFB300FFB300FFB300FFA300FFB300FFA300FFB300FFB300FFB3
00FFB300FFB300FFB300FFB300FFB300FFC200FFC200FFD100FFE100FFFF00B3FF7000FF
0038FFDC00FF00A3FF00D1FF00F0FF00FFFF00FFF000FFF000FFF000FFF000FFF000FFF0
00FFFF00D1FF0075FF000AFFFF00C70047FF0057FF00C2FF00F0FF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00F0FF00F0FF00E1FF00E1FF00D1FF00C2FF00B3FF
0094FF0075FF1400FF6100FF0066FF0094FF00A3FF00C2FF00C2FF00D1FF00E1FF00F0FF
00FFFF00FFFF00FFF000FFF000FFF000FFF000FFE100FFE100FFE100FFE100FFF000FFF0
00FFF000FFFF00F0FF00D1FF0094FFDC00FF0019FF00B3FF00E1FF00FFF000FFC200FFC2
00FFB300FFA300FFA300FFA300FFA300FF9400FF9400FF9400FF9400FF9400FF9400FF85
00FF9400FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF85
00FF8500FF8500FF8500FF8500FF9400FF8500FF9400FF9400FF9400FF9400FF9400FF94
00FFA300FFA300FFB300FFB300FFC200FFD100FFE100E1FF2300FF00E1FF00E1FF00C2FF
0094FF0047FF00D1FF00F0FF00FFF000FFE100FFD100FFC200FFB300FFA300FF9400FF94
00FF9400FF8500FF8500FF8500FF7500FF7500FF7500FF7500FF6600FF6600FF6600FF66
00FF6600FF6600FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF57
00FF5700FF4700FF4700FF4700FF4700FF5700FF4700FF4700FF4700FF4700FF4700FF47
00FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF5700FF5700FF6600FF7500FF94
0075FF00FF8500FF6600FF4700FF3800FF3800FF2800FF2800FF2800FF2800FF2800FF28
00FF1900FF1900FF1900FF2800FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF0A00FF1900FF1900FF1900FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF1900FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF1900FF0A
00FF0A00FF0A00FF0A00FF0A00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF4700FF4700FF4700FF4700FF5700FF5700FF57
00FF5700FF5700FF6600FF6600FF7500FF8500FF9400FFA300FFC200FFF00085FF00B3FF
00B3FF0075FFFF00000085FF00F0FF00FFF000FFFF00FFE10028FF00FFA300FF9400FF85
00FF7500FF7500FF6600FF6600FF6600FF6600FF6600FF6600FF7500FF8500FF9400FF75
00FF850066FF00FF7500FF5700FF4700FF3800FF2800FF2800FF2800FF1900FF1900FF19
00FF1900FF1900FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0023FF0023FF0023FF0023FF0023FF0023FF00
14FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0033FF0033FF0033FF0033FF00
23FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0023FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0042FF0042FF0033FF0042FF0042FF0042FF0033FF0042FF0042FF0042FF0042FF00
42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0033FF0042FF00
33FF0033FF0033FF0033FF00
42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00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42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00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42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00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51FF0051FF0051FF0051FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
42FF0042FF0042FF0042FF0042FF0042FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0023FF0033FF0033FF0033FF0033FF0033FF0033FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0000FF0A05FF0005FF00
05FF0005FF0005FF0000FF0A05FF0005FF0005FF0000FF0A00FF0A05FF0005FF0000FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF2800FF2800FF2800FF2800FF28
00FF3800FF3800FF5700FFE100FFB300FFF000FFB300FF8500FF6600FF5700FF5700FF47
00FF4700FF4700FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF4700FF3800FF4700FF3800FF4700FF4700FF4700FF4700FF47
00FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF47
00FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF5700FF5700FF5700FF5700FF57
00FF5700FF5700FF6600FF6600FF6600FF6600FF7500FF8500FF8500FF9400FFA300FFB3
00FFE100C2FF00C2FF00FFF000FFD100FFD100FFD100FFE100FFF000F0FF00B3FFFA00FF
8000FF00B3FF00F0FF00FFE100FFD100FFC200FFC200FFD100C2FF0075FF00FFC200FFA3
00FF9400FF9400FF9400FF8500FF8500FF8500FF8500FF8500FF8500FF9400FF9400FF94
00FFA300FFC200FFF000F0FF0085FF8F00FFFF000000A3FF3300FF00D1FF00FFC200FF94
00FF8500FF8500FF8500FF8500FF7500FF7500FF7500FF6600FF6600FF6600FF6600FF66
00FF6600FF7500FF8500D1FF00FF8500FF6600FF5700FF5700FF4700FF4700FF4700FF47
00FF4700FF4700FF4700FF4700FF4700FF3800FF4700FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF4700FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF4700FF4700FF4700FF4700FF4700FF47
00FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF5700FF57
00FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF6600FF6600FF66
00FF6600FF6600FF7500FF7500FF7500FF8500FFB300D1FF0028FF0500FF00FFF000FFF0
0094FF00FFC200FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC200FFC200FFD1
00FFE100FFF000FFFF00E1FF00B3FF0075FF0500FF000AFF9E00FFFF00003300FF0085FF
0019FF00D1FF00E1FF00E1FF00A3FF00A3FF0500FF00E1FF00FFF000FFF000FFF000FFF0
00FFF000FFFF00F0FF1400FF0047FF0028FF0038FF00F0FF00FFF000FFF000FFE100FFD1
00FFD100FFD100FFC200FFC200FFC200FFB300FFB300FFB300FFB300FFB300FFA300FFA3
00FFA300FFA300FFA300FFA300FFA300FFA300FFA300FFA300FFA300FFA300FFA300FFA3
00FFA300FFA300FFA300FFA300FFB300FFB300FFC200FFC200FFD100FFF000E1FF0057FF
00F0FF00FFF000F0FF00FFE100FFD100FFC200FFC200FFC200FFD100FFD100FFD100FFF0
00C2FF0094FF00B3FF0047FF0085FF00D1FF00F0FF00FFFF00FFF000FFF000FFE100FFE1
00FFE100FFF000FFF000FFF000FFF000FFFF00D1FF0066FFFF00B80057FF0028FFFF008A
0047FF4200FFAE00FFFF00E66100FF000AFF0500FFFF00B80085FF00C2FF00E1FF00F0FF
00FFFF00FFF000FFE100FFE100FFE100FFE100FFD100FFD100FFD100FFD100FFD100FFD1
00FFD100FFD100FFE100FFE100FFD100FFE100FFE100FFE100FFFF00C2FF00FFE100FFC2
00FFA300FFA300FF9400FF9400FF9400FF9400FF9400FF9400FF8500FF8500FF8500FF85
00FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF85
00FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF94
00FF9400FF9400FF9400FFA300FFA300FFA300FFB300FFC200FFC200FFD100FFE100FFF0
00FFFF00C2FF2300FF00B3FF0066FF00F0FF00FFF000FFD100FFC200FFB300FFB300FFB3
00FFB300FFA300FFA300FF8500FF8500FF7500FF7500FF7500FF6600FF6600FF6600FF57
00FF5700FF5700FF5700FF5700FF5700FF5700FF4700FF4700FF4700FF4700FF4700FF47
00FF4700FF4700FF4700FF4700FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF4700FF57
00FF5700FF4700FF3800FF3800FF2800FF2800FF2800FF2800FF2800FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF0A
00FF0A00FF0A00FF1900FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF1900FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF3800FF38
00FF3800FF3800FF3800FF3800FF4700FF4700FF4700FF4700FF4700FF5700FF5700FF57
00FF5700FF5700FF6600FF6600FF7500FF7500FF8500FF8500FF9400FFA300FFB300FFC2
00FFE100E1FF0066FFFF005C00B3FF00D1FF00FFC200FFB300FFA300FFA300FF9400FF94
00FF8500FF8500FF8500FF8500FF8500FF9400FFB300FFC200FFE12300FF00FFF05100FF
00FF9400FF6600FF5700FF4700FF3800FF3800FF2800FF2800FF2800FF1900FF1900FF19
00FF1900FF1900FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0023FF0023FF0023FF0023FF0023FF0014FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0033FF0033FF0033FF0033FF0033FF0023FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0042FF0042FF0042FF0033FF0042FF0042FF00
42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0051FF00
51FF0051FF0042FF0042FF0051FF0051FF0051FF0051FF0042FF0051FF0051FF0051FF00
51FF0051FF0051FF0051FF0051FF0051FF0042FF0051FF0051FF0051FF0051FF0051FF00
51FF0051FF0042FF0051FF0051FF0042FF0051FF0051FF0042FF0051FF0042FF0042FF00
42FF0042FF0042FF0042FF00
51FF0051FF0051FF0051FF0051FF0051FF0042FF0042FF0042FF0042FF0042FF0042FF00
42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
42FF0042FF0042FF0042FF0042FF0042FF0042FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0005FF0005FF0005FF0005FF0005FF0005FF0000FF0A
00FF0A00FF0A05FF0005FF0005FF0005FF0005FF0005FF0005FF0000FF0A05FF0005FF00
00FF0A05FF0005FF0000FF0A00FF0A05FF0000FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF0A00FF0A00FF1900FF1900FF19
00FF1900FF1900FF1900FF2800FF1900FF1900FF1900FF2800FF2800FF2800FF2800FF28
00FF3800FF3800FF4700FF6600FF7500FFA300E1FF00FFFF00FF7500FF6600FF5700FF57
00FF4700FF4700FF4700FF4700FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF47
00FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF47
00FF4700FF4700FF4700FF4700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF57
00FF5700FF5700FF6600FF6600FF6600FF7500FF7500FF8500FF9400FFA300FFA300FFC2
00FFD1000AFF0019FF00E1FF00FFE100FFE100FFE100FFF000FFFF00E1FF00A3FF0047FF
0085FF0047FF00A3FF00FFF000FFC200FFC200FFB300FFB300FFB30085FF00FFB300FF94
00FF9400FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF94
00FF9400FFA300FFB300FFD13300FF00E1FF0085FF00D1FF00FFF000FFE100FFC200FF94
00FF8500FF8500FF7500FF7500FF7500FF6600FF6600FF6600FF6600FF6600FF6600FF66
00FF6600FF6600FF7500FF7500FF6600FF5700FF5700FF4700FF4700FF4700FF4700FF47
00FF4700FF4700FF4700FF4700FF3800FF3800FF3800FF4700FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF4700FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF4700FF3800FF3800FF4700FF4700FF47
00FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF5700FF4700FF4700FF57
00FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF6600FF6600FF6600FF66
00FF6600FF7500FF7500FF7500FF8500FF8500FF9400FFB300FFD10066FF0066FF0094FF
00FFFF00FFD100FFC200FFB300FFB300FFB300FFB300FFC200FFC200FFC200FFD100FFE1
00FFE100FFFF00F0FF00E1FF0075FF0028FFFF00F5FF006B8000FF0066FF00C2FF00C2FF
00C2FF00FFFF00FFFF00F0FF0085FF00E1FF00F0FF00E1FF00FFE100FFE100FFE100FFE1
00FFF000FFF000FFFF00E1FF00A3FF9E00FF00C2FF00E1FF00FFFF00FFF000FFE100FFD1
00FFD100FFC200FFC200FFC200FFC200FFB300FFB300FFB300FFB300FFB300FFA300FFA3
00FFA300FFA300FFA300FFA300FFA300FFA300FFA300FFA300FFA300FFA300FFA300FFA3
00FFA300FFA300FFA300FFA300FFA300FFB300FFC200FFC200FFF000F0FF00C2FF00E1FF
00FFF000FFD100FFD100FFC200FFC200FFC200FFC200FFC200FFC200FFD100FFD100FFE1
00FFF000D1FF0047FFFF000F0057FF0028FF0094FF00FFFF00FFF000FFE100FFE100FFE1
00FFE100FFE100FFE100FFE100FFF000FFFF00F0FF00C2FF00B3FF00C2FF00A3FF0075FF
0047FF0057FF0028FFDC00FFAE00FFFF00990085FF0075FF2300FF0085FF00B3FF00F0FF
00FFFF00FFF000FFE100FFE100FFD100FFD100FFE100FFD100FFD100FFD100FFD100FFC2
00FFC200FFD100FFC200FFC200FFC200FFC200FFD100FFD100FFFF0028FF00FFD100FFB3
00FFA300FFA300FF9400FF9400FF9400FF9400FF8500FF8500FF8500FF8500FF8500FF85
00FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF85
00FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF9400FF85
00FF9400FF9400FF9400FF9400FFA300FFA300FFB300FFB300FFB300FFC200FFE100FFFF
00D1FF00B3FF000AFF000AFF0066FFFF000F00C2FF00FFE100FFC200FFC200FFC200FFC2
00C2FF00FFF000FFF000FF9400FF8500FF7500FF7500FF7500FF6600FF6600FF6600FF57
00FF5700FF5700FF5700FF5700FF5700FF5700FF4700FF4700FF4700FF4700FF4700FF47
00FF4700FF4700FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF2800FF2800FF2800FF2800FF2800FF2800FF1900FF2800FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF0A00FF0A
00FF0A00FF0A00FF0A00FF1900FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF1900FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF4700FF4700FF4700FF4700FF4700FF5700FF5700FF57
00FF5700FF6600FF6600FF6600FF7500FF7500FF8500FF8500FF9400FFA300FFA300FFB3
00FFC200FFFF00E1FFFF000000E1FF00FFF000FFD100FFC200FFC200FFA300FFA300FF94
00FF9400FF9400FF8500FF9400FF9400FFA300FFFF00D1FF0057FF00FFE100FFB300FFC2
1400FF00FF6600FF4700FF4700FF3800FF3800FF2800FF2800FF2800FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A05FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0023FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0042FF0042FF0042FF0033FF0042FF0042FF0042FF0042FF0042FF0042FF00
42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0051FF0051FF00
51FF0051FF0051FF0042FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF00
51FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF00
51FF0051FF0051FF0051FF0051FF0042FF0051FF0051FF0042FF0051FF0051FF0051FF00
51FF0042FF0042FF0042FF00
51FF0051FF0051FF0051FF0051FF0051FF0051FF0042FF0042FF0042FF0042FF0042FF00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51FF0051FF0051FF0051FF0051FF0051FF0051FF0042FF0042FF0042FF0042FF0042FF00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51FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0042FF0042FF0042FF0042FF00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51FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0042FF0042FF0042FF0042FF00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51FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0042FF0042FF0042FF0042FF00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51FF0051FF0051FF0051FF0051FF0051FF0051FF0042FF0042FF0042FF0042FF0042FF00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51FF0051FF0051FF0051FF0051FF0051FF0051FF0042FF0042FF0042FF0042FF0042FF00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51FF0051FF0051FF0051FF0051FF0051FF0042FF0042FF0042FF0042FF0042FF0042FF00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51FF0051FF0051FF0051FF0051FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00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51FF0051FF0051FF0051FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00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51FF0051FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00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42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00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51FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0042FF0042FF0042FF0042FF00
42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
42FF0042FF0042FF0042FF0042FF0042FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0014FF0014FF0014FF0014FF0014FF0014FF0005FF0014FF0014FF00
05FF0005FF0005FF0005FF0000FF0A00FF0A00FF2800FF8500A3FF6100FF00FFC200FF94
00FFC20094FF00FF8500FF8500FF6600FF4700FF4700FF4700FF4700FF4700FF3800FF38
00FF3800FF3800FF2800FF2800FF2800FF2800FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF2800FF1900FF2800FF2800FF2800FF2800FF2800FF2800FF38
00FF3800FF4700FFC200C2FF00FFF000A3FF00FFA300FFFF00FFB35100FF00FF8500FF75
00FF7500FF7500FF7500FF8500FF9400FFA300FFD10094FF0094FF00FFD100FFC200FFB3
00FF9400FF8500FF7500FF7500FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF66
00FF5700FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7500FF7500FF8500FFC2
00F0FF4200FF00FFFF00FFE100FFC200FFC200FFE10047FF00F0FF0019FF00FFB300FF94
00FF9400FF8500FF8500FF8500FF7500FF7500FF8500FF7500FF8500FF8500FF8500FF85
00FF8500FF9400FFB300FFC200FF9400FF8500FF8500FF8500FF8500FF8500FF8500FF85
00FF8500FF8500FF8500FF8500FF9400FFA300FFC200FFE18F00FF00FFFF00FFFF00B3FF
FF00D700D1FF00FFF000FFFF00FFE100FFC200FFB300FFB300FFB300FFC200FFE100E1FF
00C2FF00FFD100FFA300FF9400FF8500FF7500FF7500FF7500FF6600FF6600FF6600FF66
00FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF57
00FF5700FF5700FF5700FF5700FF6600FF6600FF6600FF7500FF8500FFC2FF000F00FF94
00FF8500FF8500FF6600FF5700FF4700FF4700FF4700FF4700FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF2800FF28
00FF3800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF3800FF2800FF2800FF28
00FF2800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF4700FF4700FF4700FF4700FF4700FF4700FF5700FF57
00FF5700FF5700FF5700FF6600FF6600FF6600FF6600FF6600FF6600FF7500FF7500FF75
00FF7500FF8500FF8500FF8500FF9400FF9400FFA300FFA300FFB300FFC200FFD100E1FF
00F0FF00D1FF0085FF0057FF0075FF0057FF00B3FF0094FF0057FF00E1FF00F0FF00FFF0
00FFE100FFD100FFB300FFB300FFA300FF9400FF9400FF9400FF9400FF8500FF8500FF85
00FF8500FF8500FF8500FF9400FF8500FF9400FF9400FF9400FF9400FF9400FFA300FFA3
00FFB300FFB300FFD100FFF00047FF00D1FF00E1FF00A3FF000AFF00B3FF00E1FF00F0FF
00FFFF0038FF00FFF000FFFF00FFC200FFB300FFA300FFA300FF9400FF9400FF9400FF94
00FF9400FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF85
00FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF85
00FF8500FF8500FF8500FF8500FF8500FF9400FF8500FF8500FF9400FF9400FF9400FF94
00FF9400FF9400FF9400FF9400FF9400FFA300FFA300FFA300FFA300FFA300FFB300FFB3
00FFB300FFB300FFC200FFC200FFE100E1FF0094FF0085FF0066FF0028FF6100FF0057FF
0094FF00A3FF0085FF0057FF6100FFFF008A5100FF0019FF0038FF000AFF0047FF0085FF
00C2FF00E1FF00FFFF00FFF000FFE100FFD100FFC200FFC200FFC200FFB300FFB300FFA3
00FFA300FFA300FFA300FFA300FF9400FF9400FF9400FF9400FF9400FF9400FF8500FF85
00FF8500FF8500FF8500FF8500FF8500FF7500FF7500FF7500FF7500FF7500FF7500FF75
00FF7500FF7500FF7500FF7500FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF66
00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7500FF7500FF75
00FF7500FF7500FF8500FF9400FF9400FFB300FFB300FFA300FFA300FFA300FFA300FFB3
00FFF00094FF00F0FF00FFD100FFD100FFD100FFE10047FF0094FF00B3FF0038FF00F0FF
00FFE100FFD100FFE100FFC200FFA300FF9400FF9400FF8500FF8500FF8500FF8500FF75
00FF7500FF8500FF7500FF6600FF5700FF4700FF4700FF4700FF4700FF3800FF3800FF38
00FF3800FF3800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A05FF0005FF0000FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A05FF0005FF0005FF0005FF0000FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF2800FF2800FF3800FF4700FF940028FFFF007A00B3FF
00FFC200FFB300D1FF00F0FF00A3FF00FFD100E1FF00FFF000FFB300FFA300FFA300F0FF
00FFD1FF00F500FFB300FFC200FFD100FFD100FFE100FFFF0057FF00E1FF00FFFF0094FF
00FFFF00FFE100FFE100FFF000FFFF00E1FF00C2FF0047FFAE00FFFF003D3300FF1400FF
0500FF00D1FF00FFE100FFB300FFA300FF9400FF8500FF8500FF8500FF7500FF7500FF75
00FF6600FF6600FF6600FF7500FF9400FF5700FF4700FF4700FF4700FF3800FF3800FF28
00FF2800FF2800FF1900FF1900FF1900FF1900FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
42FF0033FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0051FF00
51FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF00
51FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF00
51FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF00
51FF0051FF0051FF0061FF0061FF0061FF0061FF0061FF0051FF0051FF0061FF0061FF00
61FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF00
61FF0061FF0061FF0061FF00
51FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0042FF0042FF0042FF00
42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
42FF0042FF0042FF0042FF0042FF0042FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0014FF0023FF00
23FF0023FF0023FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
05FF0005FF0005FF0005FF0000FF0A00FF0A00FF1900FF5700FF4700FF6600FF5700FF57
00FF750066FF00E1FFFA00FF00FF9400FF5700FF5700FF5700FF9400FF6600FF4700FF47
00FF4700FF4700FF3800FF3800FF2800FF2800FF2800FF2800FF1900FF1900FF1900FF19
00FF1900FF1900FF2800FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF3800FF38
00FF3800FF4700FF6600FF7500FF9400FFF00094FF00F0FF00FFFF00FFB300FF9400FF85
00FF8500FF8500FF8500FF8500FF9400FFB300FFE100A3FF00FFFF00FFC200FFB300FF94
00FF9400FF8500FF7500FF7500FF7500FF6600FF6600FF6600FF6600FF6600FF6600FF66
00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7500FF7500FF8500FF8500FFA3
00FFC200FFF0FF003D00F0FF00FFE100FFE10028FF00A3FF00FFE100FFC200FFB300FFA3
00FF9400FF9400FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF9400FF9400FF94
00FF9400FFB30066FF00FFB300FF9400FF8500FF8500FF8500FF8500FF8500FF8500FF85
00FF8500FF8500FF8500FF9400FFA300FFC200E1FF00A3FF0085FF00C2FF0094FF0057FF
00C2FF00E1FF00FFE100FFC200FFB300FFB300FFA300FFA300FFA300FFB300FFC200FFF0
FA00FF00C2FF00FFB300FF8500FF8500FF7500FF7500FF6600FF6600FF6600FF6600FF57
00FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF57
00FF5700FF5700FF5700FF5700FF5700FF6600FF6600FF7500FFA300F0FF00FFF000FF85
00FF6600FF6600FF5700FF4700FF4700FF4700FF4700FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF4700FF4700FF4700FF4700FF4700FF5700FF57
00FF5700FF5700FF6600FF6600FF6600FF6600FF6600FF7500FF7500FF7500FF7500FF75
00FF8500FF8500FF8500FF8500FF9400FF9400FFA300FFB300FFB300FFC200FFE100D1FF
00B3FF0094FFCC00FF00C2FFEB00FF00E1FF00F0FF00E1FF00A3FF0057FF0047FF0085FF
00F0FF00A3FF00FFC200FFA300FF9400FF9400FF9400FF8500FF8500FF8500FF8500FF85
00FF8500FF8500FF8500FF8500FF8500FF8500FF9400FF9400FF9400FF9400FFA300FFA3
00FFA300FFB300FFC200F0FF00F0FF00FFFF00F0FF00A3FF0500FF0075FF00E1FF00FFFF
00FFF000FFE100FFD100FFC200FFB300FFA300FFA300FFA300FF9400FF9400FF9400FF94
00FF9400FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF85
00FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF85
00FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF9400FF94
00FF9400FF9400FF9400FF9400FF9400FFA300FFA300FFA300FFA300FFA300FFA300FFB3
00FFB300FFB300FFC200FFC200FFD100FFF000FFF000E1FF00D1FF00C2FF00B3FFAE00FF
1400FF0066FF0019FF7000FFFA00FFFF00B88F00FF1400FF0038FF0047FF0085FFCC00FF
0075FF00A3FF00D1FF00D1FF00FFFF00FFE100FFD100FFC200FFC200FFB300FFB300FFB3
00FFA300FFA300FFA300FFA300FF9400FF9400FF9400FF9400FF9400FF8500FF8500FF85
00FF8500FF8500FF8500FF7500FF7500FF7500FF8500FF7500FF7500FF7500FF7500FF75
00FF7500FF6600FF6600FF7500FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF66
00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF75
00FF7500FF7500FF7500FF8500FF8500FF8500FF9400FF9400FF9400FF9400FFA300FFA3
00FFF0FF0000FF00D700FFC200FFC200FFC200FFC200FFD10075FF00F0FF0094FF0038FF
00F0FF00FFFF0066FF00FFD100FFC200FFA300FF9400FF9400FF9400FF9400FF9400FF94
00FFA300FFC200FF9400FF7500FF6600FF5700FF4700FF4700FF4700FF3800FF3800FF38
00FF3800FF3800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF0A00FF0A00FF1900FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A05FF0005FF0005FF0005FF0005FF0000FF0A
00FF0A00FF0A00FF0A05FF0005FF0005FF0005FF0005FF0005FF0000FF0A00FF0A00FF0A
00FF0A00FF0A05FF0005FF0005FF0000FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF2800FF2800FF2800FF3800FF6600FF6600FF7500FF85
00FFB300FFD100FFA300FFA300FF9400FFA30047FF00C2FF00FFB300FF8500FF8500FFA3
00FF9400FF9400FF9400FF9400FFA300FFB300FFC200FFF0000AFF00FFF000FFD100FFD1
00FFC200FFC200FFD100FFE100F0FF00A3FF2300FF0085FF00A3FF1400FFBD00FF0028FF
00E1FF0047FF0500FF00FFC200FFA300FF9400FF8500FF8500FF7500FF7500FF6600FF66
00FF6600FF6600FF5700FF6600FF5700FF4700FF4700FF4700FF3800FF3800FF2800FF28
00FF2800FF2800FF1900FF1900FF1900FF1900FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A05FF0005FF0005FF0005FF0000FF0A05FF0005FF0005FF0005FF0005FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0042FF0042FF0042FF0042FF0042FF0042FF00
42FF0042FF0033FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0051FF00
51FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF00
51FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF00
51FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF00
51FF0051FF0051FF0061FF0061FF0061FF0061FF0061FF0061FF0051FF0061FF0061FF00
61FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF00
61FF0061FF0061FF0061FF00
51FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0042FF0042FF00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51FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0042FF00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51FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0042FF00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51FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0042FF00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51FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0042FF00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51FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0042FF0042FF00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51FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0042FF0042FF0042FF00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51FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0042FF0042FF0042FF0042FF00
42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
42FF0042FF0042FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0023FF00
23FF0033FF0033FF0033FF0033FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0014FF0023FF0023FF0023FF0023FF0023FF0023FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0005FF0005FF00
05FF0005FF0005FF0005FF0000FF0A00FF0A00FF0A00FF0A00FF1900FF1900FF2800FF38
00FF4700FF6600FF8500D1FF00FFB300FFFF00F0FF3300FF00FFFF00FFE100FF9400FF75
00FF6600FF5700FF5700FF4700FF4700FF4700FF3800FF3800FF3800FF3800FF3800FF28
00FF3800FF2800FF3800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF3800FF2800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF4700FF4700FF47
00FF4700FF4700FF5700FF5700FF5700FF6600FF6600FF6600FF7500FF7500FF8500FF94
00FF9400FFA300FFB300FFC200FFFF00D1FFAE00FF0066FF0094FF00FFD100FFC200FFC2
00FFC200FFB300FFB300FFB300FFB300FFA300FFA300FFA300FFB300FFC200FFE100D1FF
00A3FF0057FF00FFFF00FFE100FFD100FFC200FFC200FFD100FFFF0075FF00D1FF00F0FF
00D1FF00D1FF0094FFFF00F5FF00F54200FF9E00FF0019FF0500FF0047FF0085FF0057FF
FF002E0019FF0057FFCC00FF0047FF0085FF00C2FF00B3FF0094FF00C2FF0094FF0047FF
1400FFFA00FF0038FF0075FF000AFF0047FF0057FF0075FF5100FF0019FF2300FF00A3FF
0066FF00D1FF00E1FF00FFFF00B3FF0085FF00FFF000FFE100FFD100FFB300FFA300FFA3
00FFA300FF9400FF8500FF8500FF8500FF7500FF7500FF7500FF7500FF6600FF6600FF66
00FF6600FF6600FF6600FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF4700FF47
00FF5700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF47
00FF3800FF4700FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF2800FF2800FF3800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF3800FF2800FF2800FF2800FF28
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF4700FF4700FF4700FF57
00FF6600FF7500FF7500FF940085FF00D1FF00FFD100FFFF7000FF00D1FF00FFE100FFC2
00FFC200FFC200FFC200FFD100FFF000FFF000F0FFFF00F50057FF00D1FF00F0FF0057FF
00FFF000FFC200FFB300FF9400FF9400FF9400FF9400FF9400FF9400FFB300FF9400FF85
00FF7500FF7500FF7500FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF66
00FF6600FF6600FF6600FF7500FF7500FF7500FF7500FF8500FF8500FF9400FFFF00FFE1
00E1FF00C2FF00E1FF0094FF00FFFF00FFFF00E1FF0075FF0028FFFF00D70500FF0019FF
00F0FF00FFFF00E1FF00D1FFEB00FF0019FF00F0FF00FFD100FFA300FF9400FF8500FF85
00FF8500FF8500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF75
00FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF75
00FF7500FF7500FF7500FF7500FF7500FF7500FF8500FF8500FF8500FF8500FF8500FF85
00FF8500FF8500FF9400FF9400FF9400FF9400FF9400FF9400FFA300FFA300FFA300FFB3
00FFB300FFB300FFB300FFB300FFC200FFC200FFD100FFD100FFD100FFE100FFE100FFF0
00FFF000FFFF00F0FF00E1FF0028FF0085FF0047FF0047FF0094FF00B3FF00D1FF00F0FF
00FFFF00FFF000FFF000FFE100FFE100FFD100FFD100FFD100FFC200FFC200FFC200FFC2
00FFB300FFB300FFB300FFB300FFB300FFB300FFA300FFA300FFA300FF9400FF9400FF94
00FF8500FF8500FF8500FF7500FF7500FF7500FF7500FF7500FF6600FF6600FF6600FF66
00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF5700FF5700FF6600FF57
00FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF57
00FF5700FF5700FF5700FF5700FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF66
00FF6600FF7500FF7500FF7500FF8500FF8500FF8500FF9400FF9400FFA300FFB300FFB3
00FFD10066FFDC00FFFF0000DC00FF7000FF0057FF0019FF3300FF00E1FF00FFE100FFD1
00FFD100FFFF00FFC200C2FF00FFD100FF8500FF8500FF5700FF4700FF4700FF3800FF38
00FF3800FF2800FF2800FF2800FF2800FF2800FF2800FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
05FF0005FF0005FF0005FF0005FF0005FF0005FF0000FF0A05FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0000FF0A05FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0000FF0A00FF0A05FF0005FF0005FF0005FF0005FF0000FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF1900FF0A00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF2800FF2800FF2800FF2800FF2800FF2800FF3800FF3800FF3800FF3800FF4700FF47
00FF5700FF6600FF8500FFE100FFFF6100FF00FFF000FFA300FF9400FF8500FF7500FF75
00FF7500FF7500FF7500FF7500FF8500FF8500FFA300FFD100FFD100FFF000FFFF00C2FF
5100FFAE00FFDC00FF00C2FF0075FF0019FF0057FF0057FF00FF8500FF7500FF6600FF57
00FF5700FF5700FF4700FF4700FF4700FF4700FF3800FF3800FF3800FF3800FF2800FF28
00FF2800FF2800FF2800FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A05FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
42FF0051FF0051FF0051FF0051FF0051FF0042FF0051FF0051FF0051FF0051FF0051FF00
51FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF00
51FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF00
61FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF0051FF0061FF0061FF0061FF00
61FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF00
61FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF00
61FF0061FF0061FF0061FF00
51FF0051FF0051FF0051FF0051FF0051FF0042FF0042FF0042FF0042FF0042FF0042FF00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51FF0051FF0051FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00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51FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0042FF0042FF0042FF0042FF00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51FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0042FF0042FF00
42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
42FF0042FF0042FF0042FF0042FF0042FF0042FF0033FF0042FF0042FF0042FF0042FF00
42FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0000FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF1900FF1900FF28
00FF3800FF3800FF4700FF4700FF5700FF6600FF7500FF940047FF4200FF00FFFF00FFB3
00FFC20085FF00FF8500FF6600FF5700FF5700FF4700FF4700FF4700FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF5700FF57
00FF5700FF5700FF5700FF6600FF6600FF6600FF7500FF7500FF7500FF8500FF8500FF94
00FFA300D1FF0094FF00FFF000FFF000F0FF0094FF4200FF00B3FF00D1FF00F0FF00E1FF
00C2FFFF007A2300FF00D1FF00FFFF00FFF000FFF000FFFF0066FF00B3FF0085FFFF00B8
0500FF0019FF4200FFFF003D00C2FF00F0FF00D1FF00FFF000FFE100FFFF00D1FF0094FF
00FFE100FFD100FFD100FFE100B3FF00FFFF00F0FF0047FF00C2FF00FFFF00FFFF00FFD1
00FFC200FFB300FFC20075FF00FFA300FFA300FFA300FFA300FFB300FFC20019FF00D1FF
00FFF00094FF00FFF000FFB300FFA300FFA300FFA300FFB300FFB300FFA300FFA300FFA3
00FFB300FFB300FFC200FFF000A3FF00E1FF00FFE100FFC200FFB300FFA300FF9400FF94
00FF8500FF8500FF7500FF7500FF7500FF7500FF6600FF6600FF6600FF6600FF6600FF57
00FF5700FF5700FF5700FF5700FF5700FF5700FF4700FF4700FF4700FF4700FF4700FF47
00FF4700FF4700FF4700FF4700FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF2800FF28
00FF3800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF1900FF1900FF1900FF2800FF2800FF2800FF1900FF1900FF1900FF19
00FF2800FF2800FF2800FF2800FF1900FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF4700FF4700FF47
00FF4700FF5700FF6600FF6600FF7500FF8500FF9400FFA300FFE100FFFF0057FF00C2FF
2300FF0085FF0094FF00B3FFFF00B85100FF4200FF3300FF00B3FF00FFE100FFC200FFB3
00FFA300FF9400FF9400FF8500FF8500FF7500FF7500FF7500FF7500FF7500FF6600FF66
00FF6600FF6600FF5700FF6600FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF66
00FF6600FF6600FF6600FF6600FF6600FF6600FF7500FF7500FF7500FF8500FF8500FF94
00FFA300FFB3EB00FF0094FFDC00FF00FFFF00E1FF0085FF0019FF8F00FF0075FF00E1FF
00F0FF00D1FF0028FF0094FF00FFE100FFC200FFA300FF9400FF9400FF8500FF8500FF85
00FF7500FF7500FF7500FF7500FF7500FF7500FF6600FF6600FF6600FF6600FF6600FF66
00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7500FF6600FF66
00FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF8500FF8500FF85
00FF8500FF8500FF9400FF9400FF9400FF9400FFA300FFA300FFA300FFA300FFB300FFB3
00FFB300FFC200FFB300FFC200FFC200FFC200FFD100FFD100FFD100FFE100FFE100FFF0
0094FF0075FF00A3FF00B3FF00B3FF0094FF0066FFFF007A0057FF0085FF00A3FF0057FF
2300FF00C2FF00E1FF00F0FF00FFFF00FFF000FFE100FFE100FFE100FFE100FFD100FFD1
00FFE100FFE100FFF000FFF000FFFF00D1FF0057FF00E1FF00FFF000E1FF00FFF000E1FF
00FFB300FF9400FF8500FF8500FF7500FF7500FF7500FF6600FF6600FF6600FF6600FF66
00FF6600FF6600FF6600FF6600FF6600FF5700FF5700FF5700FF5700FF5700FF5700FF57
00FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF57
00FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF6600FF6600FF66
00FF6600FF6600FF6600FF7500FF7500FF8500FF8500FFA300FFA300FFC200FFC200FFD1
00FFF000FFF000D1FF3300FF00F0FF00E1FF00A3FF00D1FF0085FFFF00F500FFF05100FF
00FFA300FF9400FF8500FF7500FF6600FF6600FF5700FF4700FF4700FF4700FF3800FF38
00FF3800FF3800FF2800FF2800FF2800FF2800FF2800FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A05FF0005FF0005FF0005FF0005FF0005FF0005FF00
00FF0A05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0000FF0A05FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0000FF0A05FF0005FF00
05FF0005FF0005FF0000FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF2800FF2800FF2800FF2800FF2800FF3800FF3800FF57
00FF7500FFC20075FF00FFC200FF8500FF7500FF9400FF6600FF5700FF5700FF5700FF57
00FF5700FF5700FF6600FF6600FF6600FF6600FF7500FF8500FF9400FFE100FFE100FFC2
00FFC200FFFF00B3FF00D1FF00FFE100FFC200FFA300FF9400FF8500FF8500FF7500FF75
00FF7500FF7500FF6600FF5700FF5700FF4700FF4700FF4700FF3800FF3800FF3800FF38
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF1900FF2800FF1900FF1900FF19
00FF2800FF2800FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF0A00FF0A00FF0A
05FF0005FF0005FF0005FF0005FF0005FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0042FF0042FF00
42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
51FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF00
51FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF00
51FF0051FF0051FF0051FF0051FF0051FF0061FF0061FF0061FF0061FF0061FF0051FF00
51FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF00
61FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF00
61FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF00
61FF0061FF0061FF0061FF00
51FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0042FF00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51FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0042FF00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51FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF00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51FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0042FF00
42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
23FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0005FF0005FF0005FF0005FF0000FF0A05FF00
00FF0A00FF0A00FF0A00FF0A00FF1900FF1900FF1900FF1900FF1900FF2800FF2800FF28
00FF3800FF3800FF3800FF4700FF4700FF6600FF8500FFE100FFE10019FF000AFF00FFFF
00FFC200FFA300FF9400FF8500FF7500FF6600FF5700FF5700FF5700FF4700FF4700FF47
00FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF47
00FF5700FF5700FF5700FF7500FF940028FF00FFA300FF8500FF7500FF6600FF6600FF66
00FF6600FF6600FF7500FF7500FF8500FF9400D1FF00F0FF00FFC200FFB300FFB300FFB3
00FFD100FFE100FFFF0085FF8000FF9E00FF8F00FF8000FF0038FF000AFFFF0000000AFF
0038FFFF0000AE00FFDC00FF8000FF0085FF00F0FF00FFF000FFE100FFD100FFC200FFC2
00FFD100FFF00500FF00FFE100FFF02300FF00FFB300FF9400FF9400FF8500FF8500FF85
00FF9400FF9400FFA300FFB300FFC200B3FF9E00FF00FFF000FFFF00B3FF00B3FF0038FF
00FFB300FF9400FF8500FF8500FF7500FF7500FF7500FF7500FF7500FF8500FF8500FF75
00FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF8500FF8500FF8500FF85
00FF9400FFA300FFB300FFE100FFFF2300FF0085FF00FFF000FFD100FFB300FFA300FFA3
00FF9400FF8500FF8500FF7500FF7500FF6600FF6600FF6600FF6600FF5700FF5700FF57
00FF5700FF5700FF5700FF5700FF5700FF4700FF4700FF4700FF4700FF4700FF4700FF47
00FF4700FF3800FF3800FF3800FF3800FF4700FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF1900FF1900FF1900FF2800FF2800FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF3800FF2800FF2800FF2800FF3800FF3800FF3800FF3800FF3800FF3800FF47
00FF4700FF4700FF5700FF6600FF7500FF8500FF9400FF9400FF9400FF9400FFA300FFB3
00FFD17000FF00A3FF8000FF8F00FF00B3FF00E1FF00B3FF2300FF00F0FF00E1FF00FFFF
00A3FF00FFD10038FF00FFB300FF8500FF7500FF6600FF6600FF6600FF5700FF5700FF57
00FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF57
00FF5700FF5700FF5700FF6600FF6600FF6600FF6600FF7500FF7500FF7500FF7500FF85
00FF8500FF9400FFA300FFA300FFB300FFC200FFE100E1FF0085FF00B3FFDC00FF00FFE1
00FFC200FFC200FFB300FFB300FFB300FFB300FFB300FF9400FF8500FF8500FF7500FF75
00FF7500FF7500FF7500FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF66
00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF66
00FF6600FF6600FF6600FF6600FF7500FF7500FF7500FF7500FF7500FF8500FF8500FF85
00FF8500FF9400FF9400FFA300FFB37000FF00FFD100FFC200FFC200FFC200FFC200FFD1
00FFD100FFF000FFE100FFE100FFE100FFE100FFE100FFE100FFE100FFF000FFF000F0FF
00B3FF0038FF0057FF0085FF0066FF0038FF1400FFFF0000FA00FF3300FF0028FF0057FF
0094FF00B3FF00C2FF00D1FF00E1FF00F0FF00F0FF00FFFF00FFFF00F0FF00E1FF00A3FF
0066FF0057FF0019FF00B3FF00FFFF00FFF000F0FF00E1FF00FFC200FFB300FFA300FF94
00FF9400FF8500FF8500FF7500FF7500FF7500FF6600FF6600FF6600FF6600FF6600FF66
00FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF57
00FF5700FF5700FF5700FF5700FF5700FF5700FF4700FF4700FF5700FF4700FF4700FF47
00FF5700FF4700FF4700FF5700FF4700FF4700FF5700FF5700FF5700FF5700FF5700FF57
00FF5700FF6600FF6600FF7500FF7500FF9400E1FF6100FF7000FF00F0FF00FFC200FFA3
00FFA300FFB300B3FF00B3FF00FFC200FFA300FF9400FF9400FFA300FFB300FFC200D1FF
9E00FF0075FF3300FF2300FF00FFA300FF7500FF6600FF5700FF5700FF5700FF4700FF47
00FF3800FF3800FF3800FF2800FF2800FF2800FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A05FF0005FF00
05FF0005FF0005FF0005FF0005FF0000FF0A05FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0000FF0A05FF0005FF0005FF0005FF0005FF0000FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF0A00FF0A00FF0A00FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF2800FF2800FF2800FF2800FF28
00FF2800FF3800FF3800FF3800FF3800FF3800FF4700FF4700FF4700FF4700FF4700FF47
00FF4700FF4700FF4700FF5700FF5700FF5700FF6600FF6600FF7500FF7500FF8500FF94
00FFA300FFC20047FF00F0FF0075FF0019FF00FFE100FFD100FFC200FFB300FFC200C2FF
0057FF00FFC200FF9400FF8500FF7500FF7500FF6600FF6600FF5700FF4700FF4700FF38
00FF3800FF3800FF3800FF3800FF3800FF2800FF3800FF2800FF2800FF3800FF3800FF38
00FF3800FF4700FFA300FF5700FF4700FF5700FF6600FFE100FF8500FF9400FF8500FF57
00FF1900FF0A05FF0005FF0005FF0005FF0005FF0005FF0014FF0014FF0014FF0014FF00
14FF0014FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0042FF00
42FF0042FF0033FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0051FF0051FF0051FF0051FF00
51FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF00
51FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF00
51FF0051FF0051FF0051FF0051FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF00
61FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF00
61FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF00
61FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF0070FF0070FF00
70FF0070FF0070FF0070FF00
51FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0042FF00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51FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0042FF0042FF00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51FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0042FF0042FF0042FF00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51FF0051FF0051FF0051FF0051FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00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42FF0042FF0051FF0051FF0051FF0051FF0042FF0042FF0042FF0042FF0042FF0042FF00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51FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0042FF0042FF0042FF00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51FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0042FF0042FF00
42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
42FF0042FF0042FF0042FF0042FF0042FF0042FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
23FF0033FF0033FF0033FF0033FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0000FF0A00FF0A00FF1900FF2800FF66
0075FF00FF7500FF5700FF4700FF5700FF8500FFA300F0FF00FFA300FF7500FF6600FF57
00FF6600FF6600FF7500FF6600FF6600FF7500FF7500FF8500FF9400FFB300FFE100A3FF
00FFD100FFB300FF9400FF8500FF7500FF7500FF7500FF6600FF6600FF6600FF6600FF66
00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7500FF7500FF8500FF94
00FFB300F0FF00D1FF6100FF0085FF00A3FF00FFF000FFD100FFC200FFC200FFC200FFD1
3300FF0066FF00FFFF00E1FF0066FF2300FF00D1FF00A3FF00D1FF0057FF00E1FF00FFF0
00FFD100FFB300FFB300FFB300FFB300FFE100FFB300FFC200FFE100FFC200FFD100FFE1
00E1FF0066FF0057FF00FFFF00FFC200FFB300FFA300FF9400FF9400FF8500FF8500FF75
00FF7500FF7500FF6600FF6600FF6600FF5700FF5700FF5700FF5700FF5700FF5700FF57
00FF6600FF6600FF7500FFA300F0FF00FF9400FF6600FF6600FF5700FF5700FF5700FF57
00FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF4700FF5700FF5700FF5700FF57
00FF5700FF5700FF5700FF5700FF5700FF5700FF6600FF6600FF6600FF6600FF7500FF75
00FF8500FF8500FFA300FFD10075FF00FFF000FFF000D1FF0075FF0075FF00FFD100FFC2
00FFB300FFA300FF9400FF8500FF7500FF7500FF7500FF6600FF6600FF6600FF5700FF57
00FF5700FF5700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF3800FF3800FF38
00FF4700FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF2800FF3800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF3800FF3800FF3800FF3800FF47
00FF4700FF4700FF4700FF5700FF5700FF5700FF6600FF7500FF9400FFD100D1FF0094FF
00B3FF00FFD100FFB300FF9400FF8500FF7500FF7500FF8500D1FF00FFE100B3FF00FFA3
00FF7500FF6600FF5700FF5700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF47
00FF3800FF4700FF3800FF3800FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF47
00FF4700FF4700FF5700FF5700FF5700FF6600FF7500FF8500FF9400FFD100FFFF00FFC2
00FFC200FFC200FFC200FFC200FFD100E1FF00F0FF0085FF00B3FF00FFFF00FFE100FFD1
00FFB300FFA300FFA300FF9400FF9400FF8500FF8500FF7500FF7500FF7500FF6600FF66
00FF6600FF6600FF6600FF6600FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF57
00FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF57
00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7500FF8500FFD10094FF8000FF
EB00FF00E1FF2300FF00A3FF00FFFF00FFFF00D1FF0085FF00FFFF00FFE100FFE100D1FF
00FFFF00E1FF00FFF000FFFF00F0FF00E1FF00D1FF0094FF0047FF0500FF0085FF0075FF
0057FF00A3FF0085FF0066FF0085FF0066FF7000FF3300FFEB00FFFF0000AE00FF000AFF
0075FF00A3FF00C2FF00D1FF00E1FF00F0FF00F0FF00FFFF00F0FF00E1FF00C2FF8000FF
0075FF00E1FF00FFFF8000FF00FFE100FFC200FFB300FFB300FFA300FFA300FF9400FF85
00FF8500FF7500FF7500FF7500FF6600FF6600FF6600FF6600FF6600FF5700FF5700FF57
00FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF4700FF4700FF4700FF4700FF47
00FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF47
00FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF47
00FF4700FF4700FF4700FF5700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF47
00FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF5700FF5700FF5700FF57
00FF6600FF6600FF7500FFA300FFE100FFF000FF9400FF7500FF5700FF5700FF4700FF38
00FF3800FF3800FF2800FF2800FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A05FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0000FF0A05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
00FF0A00FF0A05FF0000FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF3800FF38
00FF3800FF3800FF3800FF4700FF5700FF6600FF9400FFA300FFD100E1FF00FFB300FFE1
00FFD100FFF06100FF00F0FF00FFFF00F0FF00B3FF6100FF0038FF0500FF0094FF0047FF
00FFC200FFB300FFA300FF9400FF8500FF7500FF7500FF6600FF6600FF6600FF5700FF57
00FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF6600FF6600FFD100FFE1
00FFA300FFE100B3FF00FFE100FF8500FF9400E1FF00FFC200FF3800FF2800FF1900FF19
00FF1900FF0A00FF0A00FF0A05FF0005FF0005FF0005FF0005FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0023FF0023FF0014FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0033FF0023FF0023FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0042FF00
42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
42FF0042FF0042FF0042FF0042FF0042FF0051FF0051FF0051FF0051FF0051FF0051FF00
42FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF00
51FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0061FF0061FF00
61FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF0051FF0061FF00
61FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF00
61FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF00
61FF0061FF0070FF0070FF0070FF0070FF0070FF0070FF0070FF0070FF0070FF0070FF00
70FF0070FF0070FF0070FF00
51FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0042FF00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51FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0042FF00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51FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0042FF00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51FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0042FF0042FF00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51FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0042FF0042FF0042FF00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51FF0051FF0051FF0051FF0051FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00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51FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0042FF0042FF0042FF0042FF00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51FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0042FF0042FF00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51FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0042FF0042FF00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51FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0042FF00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51FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0042FF0042FF00
42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
33FF0033FF0033FF0033FF0033FF0033FF0023FF0033FF0033FF0033FF0033FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0014FF0014FF00
23FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0005FF0014FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0000FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF19
00FF1900FF1900FF1900FF2800FF2800FF2800FF3800FF3800FF3800FF4700FF4700FF47
00FF5700FF5700FF5700FF6600FF6600FF7500FF7500FF7500FF8500FF9400FFA300FFB3
00FFD100FFF000C2FF0085FF00A3FF00D1FF00E1FF00FFE100FFD100FFE100FFF000FFFF
00D1FF0094FF00B3FF00E1FF00FFFF00FFF000FFF000FFFF0094FF0085FF6100FF00D1FF
00FFFF00FFFF0019FF00FFF000FFD100FFB300FFB300FFB300FFC200FFE10019FF00FFD1
00FFB300FFB300C2FF00FFF000FFC200FF7500FF6600FF5700FF5700FF5700FF4700FF47
00FF5700FF5700FF5700FF5700FF5700FF6600FF6600FF7500FF8500FFA300FFE10057FF
00FFC200FFC200FF7500FF6600FF6600FF6600FF6600FF7500FF7500FFA300FF9400F0FF
00FFA300FF7500FF5700FF4700FF3800FF3800FF3800FF3800FF3800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF3800FF2800FF2800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF4700FF4700FF4700FF4700FF5700FF5700FF5700FF7500FFA300FFB3
00FFE100F0FF00FFE10094FF00B3FF00A3FF00F0FF0094FF0028FF0075FF000AFF0500FF
00A3FF00E1FF00FFFF00FFF000C2FF00D1FFFF00E600D1FF00F0FF00F0FF00FFB3FF00D7
00FF7500FF6600FF5700FF5700FF5700FF4700FF4700FF4700FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF2800FF2800FF3800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF1900FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF19
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF0A00FF0A00FF0A00FF0A00FF0A
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF2800FF2800FF2800FF3800FF4700FF5700FF66
00FF7500FFB300E1FF00FF9400C2FF00FF7500FF5700FF5700FF5700FF5700FF6600FF94
00FFB30094FF00FF6600FF5700FF4700FF3800FF3800FF3800FF2800FF2800FF2800FF28
00FF2800FF2800FF3800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF4700FF4700FF4700FF4700FF5700FF5700FF6600FF66
00FF7500FF8500FFB300FFC200C2FF1400FF00FFD100FFB300FF9400FF9400FF9400FF94
00FFC200FFD10085FF00FF9400FF7500FF6600FF5700FF5700FF5700FF5700FF5700FF47
00FF5700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF47
00FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF47
00FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF6600FF5700FF5700FF66
00FF6600FF6600FF6600FF6600FF6600FF7500FF7500FF7500FF7500FF8500FFA300FFB3
00FFE100F0FF00B3FF00FFF00094FF00FFE100FFC200FFB300FFB300FFB300FFB300FFB3
00FFC200FFC200FFD100FFE100FFF000F0FF00F0FF00E1FF00C2FF1400FF1400FF8F00FF
0094FF00C2FF0057FFFF00A800D1FF00FFE100FFC200FFC200FFB300FFB300FFA300FFA3
00FFA300FFA300FFA300FFA300FF9400FF9400FF9400FF8500FF8500FF8500FF8500FF85
00FF7500FF7500FF7500FF6600FF6600FF6600FF6600FF5700FF5700FF5700FF5700FF57
00FF5700FF5700FF5700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF47
00FF4700FF3800FF3800FF3800FF3800FF3800FF4700FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF2800FF28
00FF2800FF3800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF3800FF380094FF00FF4700FF3800FF2800FF2800FF19
00FF1900FF1900FF1900FF1900FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A05FF0005FF0005FF0000FF0A05FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0005FF0005FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0005FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0005FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0005FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0000FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF3800FF3800FF3800FF3800FF3800FF4700FF4700FF5700FF4700FF57
00FF5700FF5700FF6600FF6600FF7500FF8500FFA300FFC200FFC200FFD100FFD100FFF0
AE00FF0066FF6100FF1400FF00A3FF00D1FF5100FF0066FF00D1FF00D1FF00FFF000FFD1
00FFC200FFB300FFB300FFB300FFC200FFD100B3FF00FFE100F0FF00D1FF00C2FF2300FF
00FFFF00F0FF00FFC200FFF08000FF00FFA300FFA300FFB38F00FF00FFD100FF9400FFA3
00B3FF00FFB300FFFF00C2FF00FFE10094FF0038FF00FFB300FF7500FFC200FFF000FF94
00FF5700FF1900FF0A05FF0014FF0014FF0014FF0014FF0014FF0014FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0042FF0042FF00
42FF0042FF0042FF0033FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
42FF0042FF0042FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF00
51FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF00
51FF0051FF0051FF0051FF0051FF0051FF0061FF0061FF0061FF0061FF0061FF0061FF00
61FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF00
61FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF00
61FF0061FF0061FF0061FF0061FF0061FF0070FF0070FF0070FF0070FF0070FF0070FF00
70FF0070FF0070FF0070FF0070FF0070FF0070FF0070FF0070FF0070FF0070FF0070FF00
70FF0070FF0070FF0070FF00
51FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0042FF0042FF00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51FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0042FF0042FF0042FF0042FF00
42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0023FF0033FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0014FF0023FF0023FF0014FF0023FF0023FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0000FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF19
00FF1900FF1900FF1900FF2800FF2800FF2800FF2800FF3800FF3800FF3800FF4700FF47
00FF4700FF5700FF5700FF5700FF6600FF6600FF7500FF7500FF8500FF9400FFA300FFB3
00FFC200FFF00038FF8000FF0075FF00D1FF00F0FF00FFFF00FFF000FFFF00F0FF00F0FF
00E1FF0019FF000AFF00B3FF00C2FF0019FF0047FF00A3FF0038FF00D1FF0075FF00FFE1
00FFC200FFB300FFC200FFA300FF9400FF9400FF9400FF9400FFA300FFE10094FF00FFD1
00FF9400FF8500FF7500FF6600FF6600FF5700FF5700FF4700FF4700FF4700FF4700FF47
00FF4700FF4700FF4700FF4700FF5700FF5700FF6600FF8500FFA300FFB300FFFF00FFFF
00FFB300FF9400FF6600FF5700FF5700FF4700FF4700FF4700FF4700FF5700FF5700C2FF
00F0FF00FF6600FF4700FF3800FF3800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF3800FF2800FF2800FF2800FF2800FF2800FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF4700FF4700FF4700FF4700FF4700FF5700FF5700FF5700FF6600FF66
00FF7500FF9400FF9400FFB300FFE10500FF00F0FF00FFFF00F0FF00A3FF7000FF0019FF
0094FF00A3FF00FFD100FFC200FFC200FFC200FFB300FFB300D1FF00FFD100FF9400FF94
00FFA300FF6600FF5700FF5700FF4700FF4700FF4700FF4700FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF1900FF1900FF2800FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF1900FF0A00FF0A00FF0A00FF0A00FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF2800FF2800FF2800FF3800B3FF4200FF0057FF
00FF7500FFD100FF7500FF5700FF4700FF4700FF3800FF3800FF3800FF3800FF4700FF47
00FF7500FFB300FF6600FF4700FF3800FF3800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF3800FF28
00FF3800FF3800FF3800FF3800FF3800FF4700FF4700FF4700FF5700FF5700FF5700FF66
00FF7500FF850028FF00FFFF0500FF0047FF0066FF00FFD100FF8500FF7500FF7500FF75
00FF7500FF7500FFD100FF7500FF6600FF5700FF5700FF4700FF4700FF4700FF4700FF47
00FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF47
00FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF47
00FF4700FF4700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF57
00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7500FF7500FF8500FF8500FF94
00FFB30038FF00FFB300FFA300FFA300FFA300FFA300FFA300FFA300FFA300FFA300FFB3
00FFB300FFB300FFC200FFF000D1FF00A3FF0047FF0038FF0057FF6100FF8F00FF2300FF
0057FF0075FF0075FF00E1FF00FFF000FFD100FFC200FFB300FFB300FFA300FFA300FFA3
00FF9400FF9400FF9400FF9400FF9400FF8500FF8500FF8500FF8500FF7500FF7500FF75
00FF7500FF7500FF6600FF6600FF6600FF6600FF6600FF5700FF5700FF5700FF5700FF57
00FF5700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF47
00FF4700FF4700FF4700FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF1900FF1900FF19
00FF1900FF1900FF0A00FF0A00FF1900FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0014FF00
14FF0014FF0005FF0005FF0005FF0005FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0005FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0005FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0005FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0005FF0005FF0005FF0014FF00
14FF0014FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0000FF0A05FF0005FF00
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF2800FF2800FF2800FF28
00FF2800FF2800FF3800FF3800FF3800FF3800FF3800FF4700FF4700FF4700FF4700FF57
00FF5700FF5700FF6600FF6600FF7500FF8500FFB300F0FF00E1FF00A3FF00B3FF00D1FF
00A3FF0500FF0019FFFF00D70047FFFF00000075FF00D1FF00F0FF00FFFF00FFF000FFE1
00FFD100FFD100FFE100FFF000FFE100F0FF0047FFFF00F500FFFF00FFD100FFB300FFB3
00FFD100FFC200FFE100C2FF00FFFF00FFF000D1FF00A3FF0085FF00C2FF00E1FF00FFD1
00F0FF00FFC200FFFF6100FF00FFA300FF7500FF5700FF3800FF3800FF3800FF3800FF28
00FF2800FF2800FF0A05FF0005FF0014FF0014FF0014FF0014FF0014FF0014FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0033FF0033FF0033FF0023FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0042FF00
42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
42FF0042FF0042FF0042FF0042FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF00
51FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF00
51FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0061FF0061FF0061FF0061FF00
61FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF00
61FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF00
61FF0061FF0061FF0061FF0061FF0061FF0061FF0070FF0070FF0070FF0070FF0070FF00
70FF0070FF0070FF0070FF0070FF0070FF0070FF0070FF0070FF0070FF0070FF0061FF00
70FF0070FF0070FF0070FF00
51FF0051FF0051FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00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51FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0042FF0042FF0042FF00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51FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0042FF0042FF00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51FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0042FF0042FF00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51FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0042FF0042FF00
42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0033FF0033FF0033FF0033FF00
33FF0023FF0023FF0014FF0000FF5700FF0A05FF0005FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
05FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0005FF0005FF0014FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0000FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF0A00FF1900FF1900FF19
00FF1900FF1900FF2800FF2800FF2800FF2800FF2800FF3800FF3800FF3800FF4700FF47
00FF4700FF5700FF5700FF5700FF6600FF7500FF7500FF9400FFB300FFE100F0FF0019FF
0038FF00B3FF0094FF0047FF7000FF5100FF0028FF0085FF0075FF3300FFAE00FF0038FF
FF00C71400FF0500FFFF007A0047FF1400FF0038FF00E1FF00E1FF2300FF00FFFF00FFE1
00FFC200FFB300FF8500FF7500FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF75
00FF6600FF5700FF4700FF4700FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF4700FF4700FF5700FF6600FF9400FFB3
00FF7500FF4700FF4700FF3800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF1900FF2800FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF28
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF2800FF1900FF1900FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF3800FF2800FF38
00FF3800FF3800FF3800FF3800FF3800FF4700FF4700FF4700FF4700FF5700FF5700FF57
00FF6600FF6600FF7500FF8500FF8500FF8500FF9400FFA300FFB300FFD10085FF00C2FF
0075FF00F0FF00FFF000FFC200FFA300FF9400FF8500FF8500FF7500FF7500FF6600FF66
00FF6600FF5700FF5700FF5700FF4700FF4700FF4700FF4700FF4700FF4700FF3800FF38
00FF3800FF3800FF3800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF1900FF1900FF1900FF1900FF2800FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF2800FF1900FF1900FF2800FF1900FF1900FF28
00FF1900FF1900FF1900FF2800FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF28
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF3800FF3800FF3800FF3800FF4700FF4700FF5700FF6600FF9400F0FF00FFE1
0047FF00E1FF00FFB300FFC20085FF00FFD100FF8500FF7500FF6600FF5700FF5700FF47
00FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF47
00FF3800FF3800FF3800FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF47
00FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF5700FF5700FF5700FF5700FF57
00FF5700FF5700FF5700FF5700FF6600FF6600FF6600FF6600FF6600FF6600FF7500FF75
00FF7500FF7500FF7500FF8500FF8500FF8500FF8500FF9400FF9400FF9400FF9400FFA3
00FFA300FFA300FFB300FFB300FFC200FFC200FFD100FFE100FFFF00F0FF00C2FF7000FF
00B3FF00E1FF00FFFF00FFE100FFD100FFD100FFC200FFB300FFB300FFA300FFA300FFA3
00FF9400FF9400FF9400FF8500FF8500FF8500FF8500FF7500FF7500FF7500FF7500FF75
00FF6600FF6600FF6600FF6600FF6600FF6600FF5700FF5700FF5700FF5700FF5700FF57
00FF5700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF1900FF1900FF1900FF2800FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0005FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0005FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0005FF0005FF0014FF0014FF0014FF0014FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0000FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF1900FF1900FF1900FF1900FF1900FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF3800FF3800FF3800FF3800FF4700FF4700FF4700FF4700FF5700FF5700FF5700FF57
00FF5700FF6600FF6600FF6600FF7500FF7500FF8500FF9400FFA300FFB300FFC200FFD1
00FFF000F0FF00D1FF0047FF000AFF00A3FF0094FF0028FFFF00D77000FF0038FF00A3FF
00A3FF0047FF0094FF00E1FF00FFFF00FFF000FFC200FFB300FF9400FF8500FF8500FF75
00FF7500FF6600FF6600FF6600FF5700FF5700FF5700FF5700FF5700FF4700FF4700FF47
00FF3800FF3800FF4700FF5700FF3800FF2800FF1900FF1900FF0A00FF0A00FF0A00FF0A
05FF0005FF0005FF0005FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
42FF0042FF0042FF0042FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF00
51FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF00
51FF0051FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF00
61FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF00
61FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF0070FF0070FF00
70FF0070FF0070FF0070FF0070FF0070FF0070FF0070FF0070FF0070FF0070FF0061FF00
70FF0070FF0070FF0070FF0070FF0070FF0070FF0070FF0070FF0070FF0070FF0070FF00
70FF0070FF0070FF0070FF00
51FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0042FF0042FF0042FF00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51FF0051FF0051FF0051FF0051FF0051FF0051FF0042FF0042FF0042FF0042FF0042FF00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51FF0051FF0042FF0051FF0051FF0051FF0051FF0051FF0042FF0042FF0042FF0042FF00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51FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0042FF0042FF00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51FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0042FF00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51FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0042FF00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51FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0042FF0042FF00
42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0033FF0033FF0033FF0033FF00
33FF0023FF0023FF0023FF0014FF0005FF0000FF0A00FF2800FF570038FF0019FF00FF38
00FF2800FF2800FF1900FF1900FF1900FF1900FF1900FF2800FF4700FF7500FF3800FF28
00FF2800FF5700FF8500FFA300FF4700FF2800FF1900FF0A00FF0A00FF0A00FF0A05FF00
00FF0A05FF0000FF0A05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0000FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF1900FF1900FF1900FF1900FF2800FF3800FF3800FF3800FF2800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF4700FF4700FF5700FF6600FF7500FF85
00FFB30047FF00FFE100FFB300FFA300FFB300FFC21400FF0075FF00A3FF0028FF00F0FF
00FFF000FFD100FFC200FFD100FFF000D1FF00C2FF00FFFF0094FF00A3FF00FFD100FFC2
00FFC200FFC200FFD100FFE10047FF0038FF00FFFF00FFFF00FFC200FF9400FF8500FF85
00FF7500FF7500FF6600FF6600FF5700FF5700FF5700FF4700FF4700FF4700FF3800FF38
00FF3800FF3800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF0A00FF0A00FF1900FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF1900FF1900FF0A00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF3800FF3800FF3800FF3800FF4700FF4700FF4700FF4700FF5700FF5700FF57
00FF5700FF6600FF6600FF6600FF7500FF7500FF8500FF9400FFC200F0FF00B3FF00E1FF
0038FF3300FFFF008A00FFFF00FFE100FFD100D1FF00FFB300FF9400FF8500FF7500FF75
00FF7500FF7500FF7500FF6600FF6600FF6600FF6600FF5700FF5700FF5700FF5700FF47
00FF4700FF3800FF3800FF3800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF0A00FF0A00FF0A00FF1900FF0A00FF0A
00FF0A00FF1900FF0A00FF0A00FF0A00FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF2800FF2800FF2800FF2800FF2800FF2800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF4700FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF2800FF3800FF3800FF2800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF4700FF4700FF47
00FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF5700FF57
00FF5700FF5700FF5700FF5700FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF66
00FF6600FF7500FF7500FF7500FF7500FF7500FF8500FF8500FF8500FF9400FF9400FFB3
1400FF00E1FF0094FF0047FF6100FF0085FF00D1FF00E1FF00E1FF00C2FF0066FF0019FF
FF00001400FF0085FF00B3FF00B3FF00A3FF0066FF00E1FF00FFF000FFE100FFD100FFB3
00FFB300FFA300FF9400FF9400FF8500FF8500FF8500FF7500FF7500FF7500FF7500FF75
00FF7500FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF5700FF5700FF5700FF57
00FF5700FF5700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF1900FF1900FF1900FF1900FF1900FF1900FF2800FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF0A00FF0A
00FF0A00FF0A00FF1900FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A05FF0005FF0005FF0005FF0000FF0A05FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0005FF0014FF0014FF0014FF0014FF00
14FF0014FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0000FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF19
00FF1900FF1900FF2800FF2800FF3800FF5700FFC200FF6600FF5700FF5700FF5700FF57
00FF5700FF5700FF6600FF8500FF8500FFA300C2FF00FFB300FF9400FF9400FF940085FF
00FFC200FFFF00FFB300FFA300FFA300FFA300FFB300FFC200FFE100B3FF9E00FF0085FF
00FFFF00FFD100FFC200FFB300FFC200FFC200FFD100FFE100FFFF00D1FF0075FFFF0099
00D1FF0066FF0038FF2300FF00C2FF00FFF000FFD100FFC200FFB300FF9400FF8500FF75
00FF6600FF6600FF5700FF5700FF4700FF4700FF3800FF3800FF3800FF2800FF2800FF28
00FF2800FF2800FF1900FF1900FF1900FF1900FF0A00FF0A00FF0A00FF0A00FF0A05FF00
05FF0005FF0005FF0005FF0005FF0005FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
42FF0042FF0042FF0042FF0042FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF00
51FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF00
51FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF00
61FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF00
61FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF00
61FF0070FF0070FF0070FF0070FF0070FF0070FF0070FF0070FF0070FF0070FF0070FF00
70FF0070FF0070FF0070FF0070FF0070FF0070FF0070FF0070FF0070FF0070FF0070FF00
70FF0070FF0070FF0070FF00
51FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0042FF0042FF0042FF0042FF00
42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0033FF0033FF0033FF00
33FF0023FF0023FF0023FF0014FF0005FF0005FF0000FF1900FF3800FF7500FFB300FF47
00FF3800FF2800FF3800FF3800FF2800FF2800FF2800FF3800FF754200FF00FF6600FF47
00FF4700FF85FF007A00FFE100FF4700FF2800FF1900FF1900FF0A00FF0A00FF0A00FF0A
00FF0A05FF0000FF0A05FF0000FF0A05FF0005FF0005FF0005FF0000FF0A05FF0005FF00
00FF0A05FF0000FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF1900FF1900FF1900FF1900FF2800FF3800A3FF00FF4700FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF4700FF4700FF5700FF6600FF8500FF8500FF94
00FFB300E1FF8F00FF00FFC200FFC200FFC200FFD100FFFFBD00FF7000FF0094FF00FFF0
00FFC200FFB300FFB300FFC200FFE10019FF00FFF000FFD100FFF00019FF00FFE100FFB3
00FFB300FFB300FFC200FFE100F0FF0085FF0094FF00E1FF00FFC200FFA300FF9400FF85
00FF7500FF7500FF6600FF6600FF5700FF5700FF5700FF4700FF4700FF4700FF3800FF38
00FF3800FF3800FF2800FF2800FF2800FF2800FF2800FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF1900FF0A00FF0A00FF0A00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF3800FF3800FF3800FF3800FF4700FF4700FF4700FF4700FF5700FF5700FF57
00FF6600FF6600FF6600FF7500FF7500FF7500FF8500FF940047FF0094FF00FFE100FFF0
00E1FF0057FF00D1FF00FFF000FFD100FFC200FFB300FFA300FF9400FF8500FF8500FF75
00FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF6600FF6600FF7500FF6600FF47
00FF4700FF3800FF3800FF3800FF3800FF2800FF2800FF2800FF2800FF2800FF2800FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF0A00FF0A
00FF0A00FF1900FF0A00FF0A00FF0A00FF1900FF1900FF0A00FF0A00FF0A00FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF3800FF38
00FF2800FF2800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF28
00FF3800FF2800FF2800FF2800FF2800FF3800FF2800FF2800FF3800FF2800FF2800FF28
00FF3800FF2800FF2800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF4700FF3800FF3800FF38
00FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF5700FF5700FF5700FF57
00FF5700FF5700FF5700FF5700FF5700FF5700FF6600FF6600FF6600FF6600FF6600FF66
00FF7500FF7500FF7500FF7500FF7500FF7500FF8500FF8500FF9400FF9400FF9400FFA3
00FFB300FFC200FFF000FFFF6100FF00A3FFFF006B00B3FF00C2FF00A3FF0057FF0019FF
EB00FF1400FF0028FF0047FF5100FF1400FF00A3FF00E1FF00F0FF00FFF000FFE100FFD1
00FFC200FFB300FFA300FF9400FF9400FF8500FF8500FF8500FF7500FF7500FF7500FF75
00FF7500FF7500FF7500FF6600FF6600FF6600FF6600FF6600FF6600FF5700FF5700FF57
00FF5700FF5700FF5700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF1900FF1900FF1900FF1900FF2800FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A05FF0005FF0005FF0005FF0005FF0005FF0000FF0A
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0014FF0005FF0005FF0005FF00
05FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0000FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF19
00FF1900FF1900FF2800FF2800FF3800FFA300FFB300FFA300FF9400FF7500FF5700FF57
00FF5700FF6600FF6600FF940066FF00FFF00038FF00FFC200FFB300FFB300FFB300FFD1
8000FF00FFF000FFD100FFF0FF00C700FFC200FFC200FFE100B3FF00C2FF00FFFF0066FF
00B3FF00FFD100FFB300FFB300FFB300FFB300FFD100A3FF00B3FF00A3FF0066FF00E1FF
00FFFF00FFFF00F0FF0047FF0057FF0066FF00FFD100FFB300FFA300FF9400FF8500FF75
00FF6600FF6600FF5700FF5700FF4700FF4700FF3800FF3800FF3800FF3800FF3800FF38
00FF2800FF1900FF1900FF1900FF1900FF1900FF0A00FF0A00FF0A00FF0A00FF0A05FF00
05FF0000FF0A05FF0005FF0005FF0005FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0033FF0023FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
42FF0042FF0042FF0042FF0042FF0042FF0051FF0051FF0051FF0051FF0051FF0051FF00
51FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF00
61FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF00
61FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF00
61FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF00
61FF0061FF0070FF0070FF0070FF0070FF0070FF0070FF0070FF0070FF0070FF0070FF00
70FF0070FF0070FF0070FF0070FF0070FF0070FF0070FF0070FF0070FF0070FF0070FF00
70FF0070FF0070FF0070FF00
51FF0051FF0051FF0051FF0042FF0051FF0051FF0051FF0051FF0042FF0042FF0042FF00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51FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0042FF00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51FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0042FF00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51FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0042FF00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51FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0042FF0042FF00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51FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0042FF0042FF0042FF00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51FF0051FF0051FF0051FF0042FF0051FF0051FF0051FF0051FF0051FF0042FF0042FF00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51FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF00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51FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF00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51FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF00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51FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0042FF00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51FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0042FF0042FF0042FF00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51FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF00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51FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF00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51FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF00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51FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF00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51FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0042FF00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51FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0042FF0042FF0042FF0042FF00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51FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF00
51FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0023FF0023FF0023FF0023FF00
23FF0014FF0014FF0014FF0005FF0005FF0005FF0005FF0000FF0A00FF0A00FF1900FF19
00FF2800FF2800FF4700FF5700FF5700FF6600FF7500FFA300C2FF00FFFF00FFC200FFFF
00FF7500FF6600FF5700FF4700FF4700FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF4700FF4700FF4700FF4700FF4700FF57
00FF5700FF5700FF6600FF7500FF8500FF8500FF9400FFA300FFC200FFF000C2FF0028FF
0094FFDC00FF00D1FF00F0FF00D1FF00A3FF00B3FF00FFE100FFB300FFA300FF9400FF85
00FF7500FF6600FF5700FF4700FF4700FF3800FF3800FF3800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF3800FF3800FF47
00FF4700FF5700FF6600FF8500FFFF00D1FF00FFC200FF7500FF6600FF4700FF4700FF28
00FF2800FF2800FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF28
00FF4700FF1900FF0A00FF0A00FF0A05FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0014FF0014FF0014FF0005FF0014FF00
14FF0014FF0014FF0005FF0005FF0014FF0014FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0000FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF1900FF1900FF1900FF19
00FF1900FF2800FF2800FF2800FF2800FF3800FF3800FF3800FF5700FF7500FFC200FF94
00FF9400FFB300FF9400FF8500FF7500FF7500FF8500FF8500FF9400FF9400FFA300FFC2
00FFD100E1FF0038FF00A3FF00E1FF00FFD100FFB300FFA300FF9400FF8500FF8500FF75
00FF7500FF7500FF7500FF7500FF7500FF7500FF9400FF9400FF6600FF6600FF6600FF66
00FF6600FF7500B3FF00FF4700FF3800FF2800FF2800FF2800FF2800FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0000FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF1900FF0A00FF0A00FF0A00FF0A00FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF3800FF3800FF3800FF38
00FF3800FF4700FF4700FF4700FF6600C2FF00FF9400FF8500FFA300FF9400FF8500FF85
00FF9400FF9400FFB300FFD100F0FF0085FF00FFFF00FFE100FFD100FFD100FFC200FFD1
000AFF00FFFF00FFFF00B3FF00FFE100FFC200FFC200FFB300FFB300FFB300FFB300FFB3
00FFB300FFC200FFC200FFD100FFD100F0FF00B3FF0085FF0028FF00A3FF00A3FF0075FF
0047FF0019FF4200FFFA00FF4200FF0038FF0066FF0094FF00C2FF00D1FF00E1FF00F0FF
00FFFF00FFF000FFF000FFE100FFE100FFE100FFE100FFE100FFE100FFFF00B3FFFF00D7
00A3FF00FFFF00FFE100FFE100B3FF00FFB300FFA300FF9400FF8500FF8500FF8500FF75
00FF6600FF6600FF6600FF5700FF5700FF5700FF5700FF4700FF4700FF4700FF4700FF47
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A05FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0014FF0014FF0014FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0014FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0014FF0023FF0023FF0023FF0023FF0023FF0023FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0005FF0005FF0005FF0005FF0005FF0005FF0000FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF1900FF1900FF19
00FF2800FF2800FF4700FF6600FF7500FFC27000FF00FFB300D1FF00FF8500FF5700FF47
00FF3800FF3800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF3800FF3800FF3800FF3800FF4700FF4700FF4700FF4700FF5700FF5700FF6600FF75
00FF9400B3FF00FFC200FFC200F0FF0075FF00E1FF00FFF02300FF00FFF000F0FF00FFC2
00FFC200FFD100E1FF0094FF00F0FF00C2FF0038FF00D1FF00FFB300FFA31400FF00FF66
00FF4700FF3800FF3800FF2800FF2800FF2800FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF2800FF2800FF3800FF5700FF5700FF6600FF85
00FFE100C2FF00FFB300FF6600FF6600FF855100FF00FF4700FF0A05FF0005FF0014FF00
14FF0014FF0023FF0023FF0023FF0023FF0023FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0051FF00
51FF0042FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF00
51FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF00
61FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF00
61FF0061FF0070FF0070FF0070FF0070FF0070FF0070FF0070FF0070FF0070FF0070FF00
70FF0070FF0070FF0070FF0070FF0070FF0070FF0070FF0070FF0070FF0070FF0070FF00
70FF0070FF0070FF0070FF0070FF0070FF0070FF0070FF0070FF0070FF0070FF0070FF00
70FF0070FF0070FF0070FF00
51FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF00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51FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF00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51FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF00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51FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0042FF00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51FF0051FF0051FF0051FF0051FF0042FF0051FF0051FF0051FF0051FF0051FF0051FF00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51FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF00
51FF0051FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0023FF0023FF0023FF0023FF0023FF00
14FF0014FF0014FF0005FF0005FF0005FF0000FF0A00FF0A00FF0A00FF1900FF1900FF19
00FF2800FF2800FF3800FF3800FF3800FF4700FF5700FF6600FF7500FFB300D1FF00FFF0
00FFB300FF8500FF7500FF6600FF6600FF5700FF5700FF5700FF5700FF5700FF5700FF66
00FF6600FFC200FF7500FF7500FF7500FF8500FFC20085FF00FFC200FFA300FF8500FF85
00FF8500FF9400FF9400FFB300FFC200F0FF0075FFFF000000E1FF0019FFFF00F500F0FF
00FF9400FF8500FF7500FF7500FF8500FF8500FFA300FFF00094FF00FFA300FF7500FF57
00FF4700FF4700FF3800FF3800FF2800FF2800FF1900FF1900FF1900FF1900FF1900FF19
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF1900FF1900FF1900FF19
00FF2800FF2800FF3800FF4700FF5700FF9400C2FF00FF7500FF3800FF2800FF1900FF19
00FF0A00FF0A00FF0A05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0014FF0005FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
05FF0014FF0014FF0014FF0014FF0014FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0000FF0A05FF0005FF0005FF0005FF0000FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF1900FF1900FF19
00FF1900FF1900FF2800FF2800FF2800FF2800FF2800FF2800FF3800FF3800FF3800FF38
00FF4700FF4700FF4700FF5700FF5700FF6600FF6600FF7500FF7500FF8500FF9400FFB3
00FFC200FFE10047FF0066FF00FFF000FFC200FFB300FFA300FF9400FF8500FF7500FF66
00FF6600FF5700FF5700FF5700FF5700FF4700FF4700FF4700FF4700FF3800FF3800FF38
00FF3800FF3800FF2800FF2800FF2800FF2800FF2800FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A05FF0000FF0A00FF0A05FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0000FF0A05FF0005FF0005FF0005FF0005FF0000FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF3800FF38
00FF3800FF3800FF3800FF4700FF4700FF4700FF5700FF5700FFE100FFC200FF8500FF75
00FF7500FF8500FF9400E1FF00FFD100FFD100B3FF00FFB300FFA300FFB300FFC2FF00A8
00FFF0FF00F500FFE100FFE100FFFF0094FF0094FF0075FF0085FF3300FF00C2FF00FFFF
00FFF000FFFF00B3FF00C2FF5100FF00D1FF00D1FF0085FF0028FF0066FF0057FFEB00FF
0038FF8000FF4200FFEB00FFFF0000CC00FFFF00008000FF1400FF1400FF0028FF1400FF
0066FF00A3FF00A3FF00A3FF4200FF00A3FF00E1FF00F0FF00F0FF00E1FF0038FF5100FF
00E1FF00FFFF00F0FF00FFD100FFC200FFC200FFB300FFB300FFA300FF9400FF9400FF85
00FF8500FF8500FF7500FF7500FF7500FF6600FF6600FF5700FF5700FF5700FF5700FF47
00FF4700FF4700FF3800FF3800FF3800FF3800FF3800FF3800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A05FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0023FF0023FF0023FF0023FF0023FF0023FF0014FF0014FF0014FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0014FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0014FF0023FF0023FF0023FF0023FF0023FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0000FF0A00FF0A00FF0A
00FF2800FFC200FF8500FF5700FF3800FF4700FF9400FF3800FF2800FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF2800FF2800FF2800FF3800FF3800FF4700FF5700FF6600FF7500FF7500FF85
00FFA300FF9400FFA300FFB300FFC22300FF0047FF0075FF00E1FF00E1FF00B3FFDC00FF
5100FF00B3FF0066FF00FFF000FFA300FF8500FF8500FF7500FF6600FF5700FF5700FF57
00FF4700FF4700FF4700FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF4700FF4700FF5700FF7500FF9400C2FF0038FF
00FF8500FF8500FF7500FF4700FF2800FF1900FF1900FF0A00FF0A00FF0A05FF0005FF00
05FF0005FF0005FF0014FF0014FF0014FF0014FF0014FF0023FF0023FF0023FF0023FF00
23FF0023FF0033FF0033FF0033FF0033FF0042FF0042FF0042FF0042FF0042FF0042FF00
51FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF00
51FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF00
61FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF00
61FF0070FF0070FF0070FF0070FF0070FF0070FF0070FF0070FF0070FF0070FF0070FF00
70FF0070FF0070FF0070FF0061FF0070FF0070FF0070FF0070FF0070FF0070FF0070FF00
70FF0070FF0070FF0070FF0070FF0070FF0070FF0070FF0070FF0070FF0070FF0070FF00
70FF0070FF0070FF0070FF00
51FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF00
51FF0051FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
42FF0033FF0033FF0033FF0033FF0033FF0023FF0023FF0023FF0023FF0023FF0014FF00
14FF0014FF0014FF0005FF0005FF0000FF0A00FF0A00FF0A00FF1900FF1900FF1900FF28
00FF2800FF3800FF3800FF4700FF4700FF4700FF5700FF6600FF7500FF9400FFE100FFFF
00FFA300FF8500FF7500FF6600FF6600FF6600FF6600FF5700FF5700FF5700FF6600FF66
00FF850038FF00FF9400FF8500FF8500FF9400FFC200D1FF5100FF00FFB300FF9400FF94
00FF9400FF9400FFC200FFD100FFE100A3FF0094FF00FFE100FFE1FF00D700FFC200FFA3
00FF8500FF7500FF7500FF7500FF7500FF8500FFD10094FF00C2FF00FFB300FF7500FF57
00FF4700FF3800FF3800FF2800FF2800FF1900FF1900FF1900FF1900FF1900FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF0A00FF1900FF19
00FF1900FF2800FF2800FF3800FF4700FF942300FF00FF7500FF4700FF2800FF1900FF0A
00FF0A00FF0A05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0014FF00
14FF0014FF0005FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0000FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF2800FF2800FF2800FF2800FF2800FF3800FF3800FF3800FF38
00FF4700FF4700FF4700FF5700FF5700FF6600FF6600FF7500FF7500FF8500FF9400FFA3
00FFB300FFD100E1FF00B3FF00FFF000FFC200FFA300FF9400FF8500FF7500FF7500FF66
00FF6600FF5700FF5700FF5700FF5700FF4700FF4700FF4700FF4700FF3800FF3800FF38
00FF3800FF2800FF2800FF2800FF2800FF2800FF2800FF1900FF2800FF1900FF1900FF19
00FF1900FF1900FF1900FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0000FF0A05FF0005FF0005FF0005FF0005FF0005FF0005FF0000FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF2800FF28
00FF2800FF2800FF3800FF2800FF2800FF2800FF2800FF2800FF2800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF4700FF4700FF4700FF5700FF5700FF6600FF6600FF75
00FF6600FF7500FF94000AFF00FF9400FFA300B3FF00FFA300FF9400FF9400FFA300FFB3
00FFB300FFFF00FFC200FFD100F0FF00FFFF00C2FF00F0FF0094FF2300FF00C2FF00F0FF
00F0FF00E1FF00D1FF0075FF0075FF0094FF0019FF000AFF1400FF6100FFAE00FFFF0000
6100FFAE00FFFA00FF9E00FFFF0000DC00FF1400FF0028FF0057FF0066FF0085FF0019FF
0066FF00C2FF00D1FF00C2FF0094FF00D1FF00FFFF00FFF000FFF000F0FF0094FF0085FF
0057FF00C2FF00A3FF00C2FF00FFE100FFD100FFFF00FFD100FFC200FFB300FFA300FF94
00FF9400FFE100FF9400FF8500FF8500FF7500FF6600FF6600FF6600FF5700FF5700FF47
00FF4700FF4700FF4700FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A05FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0014FF0014FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0014FF0023FF0023FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0005FF0014FF0014FF0014FF0014FF0014FF0014FF0005FF0014FF0014FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0000FF0A00FF0A
00FF1900FF1900FF3800FF2800FF2800FF2800FF3800FF2800FF1900FF1900FF1900FF19
00FF0A00FF0A00FF1900FF0A00FF1900FF0A00FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF2800FF2800FF3800FF3800FF3800FF4700FF6600FFD100FF8500FF9400FFE1
00FFD100FFD100F0FF00FFD100FFE10085FF00B3FF00FFF000FFF000E1FF0085FF00B3FF
0047FF00B3FF00FFF000FFC200FFA300FF9400FF8500FF7500FF7500FF6600FF5700FF57
00FF5700FF4700FF4700FF4700FF4700FF4700FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF4700FF4700FF5700FF6600FF9400FFA30066FF00FFA3
00FF7500FF5700FF4700FF3800FF2800FF2800FF1900FF1900FF1900FF0A00FF0A00FF0A
05FF0005FF0005FF0005FF0005FF0005FF0005FF0014FF0014FF0014FF0014FF0014FF00
23FF0023FF0023FF0033FF0033FF0033FF0042FF0042FF0042FF0042FF0042FF0042FF00
42FF0042FF0042FF0042FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF00
51FF0051FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF00
61FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF00
70FF0070FF0070FF0070FF0070FF0070FF0070FF0070FF0070FF0070FF0070FF0070FF00
70FF0070FF0070FF0070FF0070FF0070FF0070FF0070FF0070FF0070FF0070FF0070FF00
70FF0070FF0070FF0070FF0070FF0070FF0070FF0070FF0070FF0070FF0070FF0070FF00
70FF0070FF0070FF0070FF00
51FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF00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51FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF00
51FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0023FF0023FF0023FF0023FF0014FF0014FF00
14FF0005FF0005FF0000FF0A00FF1900FFD100FF5700FF3800FF2800FF2800FF3800FF38
00FF5700FF9400FF6600FF5700FF6600FF8500FF9400FF8500FFFF00FFC200FFF000F0FF
00FFC200FFB300FF9400FF9400FFB300FF8500FF8500FF7500FF7500FF7500FF7500FF75
00FF8500FFE100E1FF00FFFF00FFF000FFC200FFD10075FF00F0FF00FFC200FFB300FFB3
00FFC200FFC200D1FF1400FFFF00A800F0FF00FFD100FFB300FFA300FFA300E1FF00FF75
00FF6600FF6600FF6600FF5700FF6600FF6600FF7500FF8500FFC20038FF00FFF000E1FF
00FF4700FF3800FF2800FF2800FF1900FF1900FF1900FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF1900FF1900FF2800FF3800FF6600D1FF00FF9400E1FF00FF5700FF1900FF0A
00FF0A05FF0005FF0005FF0005FF0005FF0005FF0014FF0005FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0005FF0014FF0014FF0014FF0014FF0014FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0000FF0A05FF0005FF0000FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF1900FF1900FF19
00FF1900FF1900FF2800FF2800FF2800FF2800FF3800FF3800FF3800FF3800FF3800FF47
00FF4700FF4700FF5700FF5700FF6600FF6600FF7500FF8500FF8500FF9400FF9400FFA3
00FFC200F0FF0019FF0038FF0047FF00B3FF00FFB300FFA300FF9400FF8500FF8500FF75
00FF6600FF5700FF5700FF5700FF4700FF4700FF4700FF3800FF3800FF3800FF3800FF38
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
00FF0A05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0014FF0014FF0014FF0005FF0005FF0005FF0005FF0005FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0005FF0005FF0005FF0014FF0014FF0014FF00
14FF0014FF0014FF0005FF0005FF0005FF0005FF0005FF0005FF0014FF0014FF0014FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0000FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF38
00FF3800FF3800FF3800FF3800FF3800FF4700FF4700FF4700FF4700FF5700FF5700FF57
00FF5700FF6600FF6600FF6600FF7500FF7500FF7500FF8500FF8500FF8500FF8500FF94
00FF9400FFA300FFA300FFB300FFB300FFC200FFD100FFE100FFF000F0FF00C2FF0066FF
0085FF0057FF0019FF0085FFFF00B800A3FF00B3FF00B3FF6100FF0028FF0094FF0094FF
0085FF0066FF0038FF9E00FFFF00A8AE00FF0019FF0047FFBD00FF00A3FF00C2FF00D1FF
00E1FF00F0FF00FFFF00FFF000FFF000FFE100FFE100FFD100FFD100FFE100FFE100FFFF
0094FF0085FF0094FF0038FF0057FF00D1FF00B3FF00B3FF00FFFF00FFD100FFC200FFC2
00FFD10094FF00FFF000A3FF00B3FF00FF9400FF8500FF7500FF7500FF8500FF8500FF66
00FF5700FF4700FF4700FF3800FF3800FF3800FF3800FF3800FF3800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A05FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0014FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0014FF0014FF0023FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0005FF0014FF0014FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF0A00FF1900FF1900FF19
00FF1900FF1900FF2800FF2800FF3800FF4700FF5700FF8500FFE15100FF00A3FF00FFD1
0500FF00FFA300FFB300FFC2000AFF00FFD100FFB300FFB300FFB300FFD100FFC200FFD1
00FFE100D1FF4200FF00F0FF00FFE100E1FF00FFD100FFA300FFB300FF7500FF6600FF66
00FF5700FF5700FF5700FF5700FF5700FF4700FF4700FF4700FF4700FF4700FF4700FF47
00FF4700FF4700FF4700FF4700FF4700FF5700FF6600FF7500F0FF00FFD1000AFF0500FF
00FF8500FF5700FF4700FF3800FF3800FF2800FF2800FF2800FF1900FF1900FF1900FF19
00FF1900FF1900FF2800FFD100FF2800FF280019FF00FF1900FF0A05FF0005FF0000FF0A
00FF3800FFC214FF0023FF0033FF0033FF0033FF0042FF0042FF0042FF0042FF0042FF00
42FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF00
51FF0051FF0051FF0051FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF00
61FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF00
70FF0070FF0070FF0070FF0070FF0070FF0070FF0070FF0070FF0070FF0070FF0070FF00
70FF0070FF0070FF0070FF0070FF0070FF0070FF0070FF0070FF0070FF0070FF0070FF00
70FF0070FF0070FF0070FF0070FF0070FF0070FF0070FF0070FF0070FF0070FF0070FF00
70FF0070FF0070FF0080FF00
51FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0042FF0042FF0042FF00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51FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF00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51FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF00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51FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF00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51FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF00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51FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF00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51FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF00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51FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF00
51FF0051FF0051FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
33FF0033FF0033FF0033FF0033FF0033FF0023FF0023FF0014FF0014FF0000FF0A00FF66
00F0FF00FF2800FF1900FF2800FF3800FF6600FFD100FFA300FF9400FF4700FF3800FF38
00FF4700FF4700FF3800FF3800FF3800FF3800FF3800FF3800FF4700FF4700FF4700FF57
00FF6600FF6600FF7500FF8500FFA300FFD10057FF00B3FF000AFF00B3FF00FFFF00FFF0
00FFFF00FFE100FFF00038FF00C2FF6100FF00E1FF00D1FF00C2FF0066FF4200FFDC00FF
FF000000A3FF00E1FF00FFFF00FFF00094FF00FFF000FFB300FF9400FF7500FF6600FF57
00FF4700FF4700FF3800FF3800FF3800FF2800FF2800FF2800FF2800FF1900FF1900FF19
00FF1900FF0A00FF0A00FF0A00FF0A00FF0A05FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0014FF0014FF0005FF0014FF0005FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0023FF0023FF0014FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0014FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0014FF0023FF0023FF0023FF0023FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0000FF0A
00FF0A00FF0A00FF0A00FF0A00FF1900FF1900FF1900FF1900FF1900FF1900FF2800FF28
00FF2800FF2800FF2800FF2800FF3800FF3800FF3800FF3800FF3800FF4700FF4700FF47
00FF4700FF4700FF5700FF5700FF6600FF7500FFFF00FFFF00FFFF00FFE100FFC200FFD1
00A3FF0075FF8F00FF00A3FF1400FF00FFE100FFD100FFC200FFD100FFE100FFD1FF0000
00FFC200FFC200FFD100FF5700FF5700FF4700FF4700FF4700FF3800FF3800FF3800FF38
00FF3800FF2800FF3800FF2800FF2800FF2800FF2800FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
05FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0005FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0005FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
05FF0005FF0014FF0014FF0014FF0014FF0014FF0014FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0000FF0A00FF0A05FF0005FF0005FF0000FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF4700FF4700FF47
00FF4700FF4700FF5700FF5700FF5700FF5700FF6600FF6600FF7500FF8500FF941400FF
0066FF00FFC200FFC200FFE100F0FF0075FF0066FF00A3FF00E1FF00FFE100FFC200FFC2
00FFB300FFB300FFB300FFB300FFC200FFC200FFE100E1FF00F0FF00F0FF00FFFF00D1FF
FF006B00B3FF00C2FF00B3FF0085FF0038FF0075FF00B3FF00D1FF00E1FF00D1FF00C2FF
0500FF00D1FF00FFE100FFC200FFB300FFB300FFB300FFA300FFA300FFA300FFA300FFA3
00FF9400FF9400FF9400FF9400FF9400FF9400FF9400FF9400FF9400FF9400FFA300FFB3
00D1FF3300FF00FF9400FF8500FF8500FF7500FF7500FF6600FF6600FF6600FF6600FF66
00FF6600FF5700FF5700FF4700FF4700FF3800FF3800FF3800FF3800FF3800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A05FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0014FF0023FF0023FF0023FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0005FF0014FF0014FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0000FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF1900FF1900FF1900FF2800FF2800FF28
00FF3800FF5700FF6600FF6600FF4700FF4700FF4700FF4700FF4700FF5700FF5700FF57
00FF6600FF6600FF7500FF8500FF9400FFB300B3FF00FFF00085FF00C2FF00E1FF00F0FF
00C2FF00FFF000F0FF0094FF00E1FF00FFF000FFE100FFC200FFB300FFA300FF9400FF94
00FF9400FF9400FFA300FFB300FFE10094FF0066FF00FFE100FFB300FF9400FF7500FF75
00FF7500FF7500FF85000AFF00FFA300FF7500FF7500FF7500FF9400FFF0000AFF00FF75
00FF4700FF4700FF4700FF4700FF9400FFB300FF5700FF4700FF2805FF0005FF0014FF00
14FF0014FF0014FF0023FF0023FF0023FF0033FF0033FF0033FF0042FF0042FF0042FF00
42FF0042FF0042FF0042FF0042FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF00
51FF0051FF0051FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF00
61FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF00
70FF0070FF0070FF0070FF0070FF0070FF0070FF0070FF0070FF0070FF0070FF0070FF00
70FF0070FF0070FF0070FF0070FF0070FF0070FF0070FF0070FF0070FF0070FF0070FF00
70FF0070FF0070FF0070FF0070FF0070FF0070FF0070FF0070FF0070FF0070FF0080FF00
80FF0080FF0080FF0080FF00
51FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF00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51FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF00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51FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF00
51FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0023FF0023FF0023FF0014FF0014FF00
14FF0005FF0005FF0005FF0000FF0A00FF0A00FF0A00FF0A00FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF2800FF2800FF2800FF2800FF2800FF3800FF3800FF4700FF57
00FF7500FF9400FFA300FFA300FFA300FFB300FFD14200FF00C2FF2300FF8F00FFFF00F5
0057FF0028FF0047FF0057FFFF00000057FF00D1FF00F0FF0075FF00C2FF0094FFCC00FF
00E1FF00FFF000FFD100FFB300FFA300FFA300FFA300FFB30066FF0075FF00FF8500FF57
00FF4700FF3800FF3800FF2800FF2800FF2800FF1900FF1900FF1900FF1900FF1900FF0A
00FF0A00FF0A00FF0A00FF0A05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0023FF0014FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0014FF0014FF0023FF0023FF0023FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0000FF0A00FF0A
00FF0A00FF0A00FF1900FF1900FF1900FF1900FF1900FF2800FF2800FF2800FF3800FF38
00FF4700FF4700FF3800FF3800FF3800FF4700FF4700FF4700FF4700FF4700FF4700FF57
00FF5700FF5700FF5700FF6600FF6600FF6600FF7500FF8500FF8500FF9400FFA300FFC2
FF00F500C2FF0075FF0028FF00B3FF00F0FF00FFB300FFA300FF9400FF9400FF8500FF75
00FF7500FF7500FF6600FF6600FF5700FF5700FF4700FF4700FF4700FF4700FF3800FF38
00FF3800FF3800FF3800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF1900FF19
00FF1900FF1900FF1900FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0005FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0005FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0005FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0000FF0A
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0000FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF2800FF19
00FF1900FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF4700FF47
00FF4700FF4700FF5700FF5700FF5700FF6600FF6600FF7500FF8500FF9400FFA300FFD1
00E1FF2300FFFF000000E1FF0094FF00FFD100FFC200FFE100FFB300FFB300FFA300FFA3
00FFA300FFA300FFA300FFA300FFA300FFB300FFB300FFB300FFC200FFC200FFD100FFF0
00FFF000FFF000FFFF00F0FF00B3FF0094FF3300FF00B3FF00E1FF00FFFF00FFF000FFE1
00FFD100FFD100FFC200FFB300FFB300FFB300FFA300FFA300FF9400FF9400FF9400FF94
00FF9400FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF85
00FF8500FF7500FF7500FF6600FF6600FF6600FF6600FF5700FF5700FF5700FF5700FF57
00FF4700FF4700FF4700FF4700FF4700FF3800FF3800FF3800FF3800FF3800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A05FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0014FF0014FF0023FF0023FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0005FF00
14FF0014FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0000FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF1900FF1900FF1900FF19
00FF1900FF2800FF2800FF2800FF2800FF3800FF3800FF3800FF3800FF4700FF4700FF57
00FF6600FF7500FF9400FF9400FFA300FFB300FFC200FFE100E1FF0094FF4200FF0028FF
0075FF0066FF0057FF00C2FF00FFFF00FFF000FFE100FFD100FFC200FFC200FFC200FFC2
00E1FF6100FF00A3FF0028FF00FFFF00FFC200FFB300FFB300FFA300FF6600FF5700FF57
00FF5700FF4700FF4700FF3800FF3800FF3800FF3800FF3800FF4700FF4700FF2800FF28
00FF1900FF1900FF1900FF1900FF1900FF4700FF2805FF0005FF0014FF0014FF0023FF00
23FF0023FF0023FF0033FF0033FF0033FF0033FF0033FF0042FF0042FF0042FF0042FF00
42FF0042FF0042FF0042FF0051FF0051FF0042FF0051FF0051FF0051FF0051FF0051FF00
51FF0051FF0051FF0051FF0051FF0051FF0061FF0051FF0051FF0061FF0061FF0061FF00
61FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF00
70FF0070FF0070FF0070FF0070FF0070FF0070FF0070FF0070FF0070FF0070FF0070FF00
70FF0070FF0070FF0070FF0070FF0070FF0070FF0070FF0070FF0070FF0070FF0070FF00
70FF0070FF0070FF0070FF0070FF0070FF0070FF0070FF0070FF0070FF0070FF0070FF00
70FF0080FF0080FF0080FF00
51FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF00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51FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF00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51FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF00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51FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF00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51FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF00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51FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0042FF0042FF0042FF00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51FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF00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51FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF00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51FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF00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51FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF00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51FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF00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51FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF00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51FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF00
51FF0051FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
42FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0023FF0023FF00
23FF0023FF0023FF0014FF0014FF0014FF0014FF0005FF0005FF0005FF0005FF0005FF00
00FF0A00FF0A00FF0A00FF1900FF2800FF3800FF4700FF6600C2FF0057FF00FFA300FF94
00FF9400FFC200FFD1FF00E600F0FF00FFD100FFFF00FF8500FF7500FF6600FF6600FF57
00FF6600FF8500FF5700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF5700FF57
00FF5700FF6600FF7500FF8500FFA300FFE100FFD100FFC200D1FF00FFD100FFF00075FF
1400FF00B3FF00FFF000FFF0000AFF00FFC200FF8500FF6600FF4700FF4700FF4700FF47
00FF8500FF5700FF1900FF0A00FF0A00FF0A05FF0005FF0014FF0014FF0014FF0014FF00
14FF0023FF0014FF0023FF0023FF0023FF0014FF0023FF0023FF0023FF0023FF0023FF00
33FF0033FF0023FF0033FF0033FF0033FF0033FF0023FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0014FF0023FF0023FF0023FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0005FF0005FF0005FF0005FF0005FF0005FF00
00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF2800FF1900FF2800FF2800FF3800FF38
00FF4700FF4700FF4700FF5700FF6600FF7500FF7500FF9400FFB300FFD10085FF00F0FF
00FFD100FFC200FFD100FFF000B3FF00FFE100FFE100FFFF00FFFF00FFFF00F0FF00C2FF
0094FF0019FF0057FF0066FF0500FF2300FF0057FF00A3FF0047FF00FFF000FFE100FFFF
00FFD100FFB300FFA300FFA300FFB32300FF00E1FF00C2FF0047FF00A3FF3300FF00FFE1
00FFA300FF9400FF9400C2FF00FFC200FF9400FF6600FF4700FF4700FF4700FF4700FF47
00FF5700FF3800FF1900FF1900FF1900FF0A00FF0A00FF0A00FF0A05FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0000FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF4700FF4700FF4700FF4700FF4700FF4700FF5700FF5700FF5700FF57
00FF5700FF5700FF5700FF6600FF6600FF6600FF6600FF6600FF7500FF7500FF7500FF75
00FF7500FF7500FF8500FF8500FF8500FF8500FF9400FF9400FFA300FFB300FFC200FFE1
00FFFF0066FF00A3FF00E1FF00E1FF0047FF0075FF0019FF2300FFBD00FF00C2FF00F0FF
00FFFF00FFFF00FFFF00FFFF0085FF00B3FF00FFE100FFFF00FFB300FF9400FF8500FF85
00FF8500FF7500FF7500FF7500FF7500FF7500FF7500FF6600FF6600FF6600FF6600FF66
00FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF4700FF4700FF4700FF4700FF47
00FF4700FF4700FF4700FF4700FF3800FF3800FF4700FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A05FF0005FF0000FF0A05FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0023FF0023FF0023FF00
23FF0023FF0023FF0014FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0023FF0023FF0023FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0023FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0023FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
23FF0033FF0033FF0033FF0033FF0033FF0033FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0000FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF1900FF1900FF1900FF1900FF2800FF2800FF2800FF2800FF3800FF3800FF3800FF38
00FF4700FF4700FF4700FF5700FF5700FF6600FF7500FF9400E1FF00FFFF0047FF9E00FF
00D1FF00FFB300FFA300FF9400FF9400FF9400FF9400FFA300FFC200FFE1FF00C700FFFF
6100FF00FFE100FFC200FFB300FFC200A3FFFF005C0047FF00FFC200FFB300FFA300FF75
00FF6600FF6600FF6600FF7500FFB300FF7500FF3800FF2800FF1900FF1900FF1900FF0A
00FF0A05FF0005FF0005FF0014FF0014FF0014FF0014FF0014FF0023FF0023FF0023FF00
23FF0023FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0042FF0042FF0042FF00
42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0051FF0051FF0051FF0051FF00
51FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0061FF0061FF0061FF0061FF00
61FF0061FF0061FF0061FF0051FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF00
61FF0061FF0070FF0070FF0070FF0070FF0070FF0070FF0070FF0070FF0070FF0070FF00
70FF0070FF0070FF0070FF0070FF0070FF0070FF0070FF0070FF0070FF0070FF0070FF00
70FF0070FF0070FF0070FF0070FF0070FF0080FF0080FF0080FF0080FF0080FF0080FF00
80FF0080FF0080FF0080FF00
51FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF00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51FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF00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51FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0042FF0051FF0051FF0051FF00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51FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0042FF00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51FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF00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51FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF00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51FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF00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51FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0042FF0051FF0051FF0042FF00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51FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0042FF0042FF00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51FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0042FF00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51FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0042FF00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51FF0051FF0051FF0051FF0051FF0051FF0042FF0051FF0051FF0051FF0042FF0042FF00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51FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0042FF0042FF0042FF0042FF00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51FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0042FF0042FF0042FF00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51FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0051FF0042FF0042FF0042FF00
42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0023FF0023FF0023FF0023FF0023FF0023FF0014FF0014FF00
14FF0014FF0005FF0000FF0A00FF7500FF5700FFC200FFB30085FFEB00FF00F0FF00A3FF
00B3FF00FFC200FFD100FFFF000AFF0075FF00D1FF00C2FF00FF7500FF6600FF4700FF38
00FF2800FF2800FF1900FF1900FF0A00FF0A00FF0A00FF0A05FF0000FF0A05FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0000FF0A00FF0A00FF0A00FF1900FF1900FF28
00FF2800FF3800FF6600FFA300E1FF00FFF000FF6600FF3800FF2800FF1900FF0A00FF0A
05FF0005FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0000FF0A00FF0A14FF0014FF0023FF0023FF0023FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
42FF0042FF0042FF0042FF0033FF0042FF0042FF0042FF0042FF0042FF0033FF0042FF00
42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
33FF0042FF0042FF0042FF0042FF0042FF0042FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
05FF0005FF0005FF0005FF0005FF0000FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF19
00FF1900FF2800FF2800FF2800FF2800FF3800FF3800FF3800FF3800FF4700FF4700FF47
00FF5700FF5700FF6600FF7500FF8500FF9400FF9400FFA300FFC22300FF00C2FFFF0000
0094FF00C2FF00FFA300FF9400FF8500FF7500FF7500FF6600FF6600FF6600FF5700FF57
00FF5700FF5700FF5700FF5700FF6600FF6600FF7500FF9400FF8500FF9400FFE100FFFF
1400FF00D1FF7000FF00FFD100FFA300FF6600FF4700FF2800FF2800FF1900FF1900FF0A
00FF0A00FF0A00FF0A05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0014FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0014FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0014FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0014FF0014FF0014FF0023FF0023FF0023FF0023FF0023FF00
23FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0000FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF38
00FF3800FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF5700FF5700FF5700FF57
00FF5700FF5700FF5700FF6600FF6600FF6600FF6600FF7500FF8500FFE100FFFF00FFC2
00FFB300FFC200FFE10028FF00FFF000FFC200FFB300FFB300FFB300FFB300FFB300FFC2
00FFC200FFC200FFD100FFD100FFE100FFF000FFFF00F0FF00A3FF0066FF0019FF0094FF
00D1FF00F0FF00FFFF00FFF000FFE100FFE100FFD100FFD100FFD100FFD100FFD100FFE1
4200FF00D1FF0047FF00F0FF00FFF000FFE100FFB300FFA300FF9400FF9400FF8500FF85
00FF8500FF7500FF7500FF7500FF7500FF6600FF6600FF6600FF6600FF5700FF5700FF57
00FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF4700FF4700FF4700FF4700FF47
00FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF47
00FF4700FF4700FF4700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF66
00FF6600FF7500FF9400FFB300C2FF00D1FF00FFC200FFB3000AFF00F0FF00F0FF00FF85
00FF7500FF6600FF5700FF5700FF5700FF4700FF4700FF4700FF4700FF4700FF5700FF66
00FF94DC00FF00FFFF00FF5700FF3800FF2800FF1900FF1900FF0A00FF0A05FF0005FF00
05FF0005FF0005FF0005FF0005FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0023FF0023FF0023FF0023FF0023FF0014FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0023FF00
33FF0033FF0033FF0033FF0033FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0014FF0014FF0014FF0014FF0014FF0005FF0005FF00
00FF0A00FF1900FF8500FFD100FF9400D1FF00FF6600FF4700FF4700FF4700FF4700FF57
00FF8500FFB300FFA30094FF00B3FF00FFA300FFA300E1FF00FFA300FFD100FF9400FF47
00FF3800FF3800FF2800FF2800FF3800FF3800FF4700FF5700FF6600FF8500FFC200C2FF
00FFB300FFB34200FF00FF5700FF3800FF2800FF2800FF1900FF1900FF1900FF1900FF19
00FF1900FF0A00FF0A00FF0A00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF19
00FF2800FF2800FF2800FF3800FF3800FF4700FF6600FF6600FF7500FFB300FFFF0500FF
00A3FF00FFFF00FFFF9E00FF00FFC200FF8500FF6600FF5700FF4700FF3800FF2800FF19
00FF0A00FF0A05FF0005FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0023FF00
23FF0023FF0023FF0014FF0014FF0014FF0014FF0014FF0014FF0000FF1900FF5714FF00
23FF0023FF0023FF0023FF0023FF0023FF0005FF0023FF0033FF0042FF0042FF0051FF00
51FF0051FF0051FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF00
61FF0070FF0070FF0070FF0070FF0070FF0070FF0070FF0070FF0070FF0070FF0070FF00
70FF0070FF0070FF0070FF0070FF0070FF0070FF0070FF0070FF0070FF0070FF0070FF00
70FF0070FF0070FF0070FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF00
80FF0080FF0080FF0080FF00
51FF0051FF0051FF0051FF0051FF0051FF0042FF0042FF0042FF0042FF0042FF0042FF00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51FF0051FF0051FF0051FF0051FF0051FF0051FF0042FF0042FF0042FF0042FF0042FF00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51FF0051FF0051FF0051FF0051FF0051FF0051FF0042FF0042FF0042FF0042FF0042FF00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51FF0051FF0051FF0051FF0042FF0051FF0051FF0042FF0042FF0042FF0042FF0042FF00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51FF0051FF0051FF0051FF0051FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00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51FF0051FF0051FF0051FF0051FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00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51FF0051FF0051FF0051FF0051FF0042FF0042FF0042FF0042FF0042FF0042FF0033FF00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51FF0051FF0051FF0051FF0042FF0042FF0042FF0042FF0042FF0042FF0033FF0033FF00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51FF0051FF0051FF0051FF0042FF0042FF0042FF0042FF0042FF0042FF0033FF0033FF00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51FF0051FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0033FF0033FF00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51FF0051FF0051FF0042FF0042FF0042FF0042FF0042FF0042FF0033FF0033FF0033FF00
23FF0005FF0000FF0A14FF0014FF0014FF0014FF0014FF0014FF0023FF0014FF0014FF00
14FF0014FF0014FF0014FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF00
00FF0A00FF0A00FF1900FF1900FF2800FFFF00B3FF00FFE100F0FFAE00FF00FFFF00FF75
00FF5700FF3800FF2800FF2800FF1900FF1900FF2800FF3800FFA30500FF00FF4700FF19
05FF0014FF0014FF0014FF0014FF0014FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0014FF00
14FF0014FF0005FF0000FF0A00FF1900FF3800FF8500FFB300FF5700FF2805FF0014FF00
23FF0023FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0042FF0033FF00
42FF0042FF0033FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
42FF0042FF0042FF0042FF0042FF0042FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0000FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A
00FF1900FF1900FF1900FF1900FF2800FF2800FF3800FF4700FF4700FF4700FF5700FF57
00FF5700FF6600FF6600FF6600FF7500FF9400D1FF00D1FF00F0FF2300FF00FFF000FFE1
00FFA300FF8500FF7500FF6600FF5700FF5700FF4700FF4700FF4700FF3800FF3800FF38
00FF2800FF2800FF2800FF2800FF2800FF2800FF1900FF1900FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF1900FF0A00FF0A00FF0A
05FF0005FF0005FF0005FF0005FF0005FF0005FF0014FF0014FF0014FF0014FF0014FF00
05FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0005FF0014FF0014FF0014FF0014FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0000FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF1900FF1900FF19
00FF1900FF1900FF1900FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF28
00FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF2800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF47
00FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF47
00FF4700FF4700FF4700FF4700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF57
00FF5700FF6600FF6600FF6600FF6600FF7500FF7500FF7500FF8500FF8500FF9400FFA3
00FFB300FFC200FFD100FFD100FFE100FFFF00FFFF00E1FF00D1FF0066FF0066FF0085FF
FA00FFFF00A87000FF0038FF0057FF0019FF1400FF0019FF1400FF0500FFCC00FFFF000F
FF007AFF00B87000FF5100FF0028FF0028FFBD00FF00A3FF00B3FF00B3FF00E1FF00F0FF
00FFFF00FFFF00FFFF00FFF000FFF000FFF000FFF000FFFF00FFE100FFC200FFC200FFB3
00FFB300FFA300FFA300FF9400FF8500FF8500FF8500FF8500FF7500FF7500FF7500FF75
00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF66
00FF6600FF6600FF6600FF7500FF7500FF7500FF7500FF8500FF8500FF9400FFA300FFC2
00FFD100FFF000B3FF0500FF00F0FF00E1FF00FFFF00D1FF0028FF0094FF00F0FF00FFFF
00FFFF00A3FFBD00FF00FFC200FFA300FFA300FFA300FFB300FFD100F0FF0066FF00F0FF
00FFF000FF9400FF7500FF5700FF4700FF4700FF3800FF3800FF3800FF2800FF2800FF28
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FFD100FF9400FF2800FF0A00FF0A
05FF0005FF0005FF0005FF0005FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0033FF0033FF0033FF0033FF0023FF0023FF0023FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0033FF0033FF00
33FF0033FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
33FF0033FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0033FF00
33FF0033FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0023FF0033FF0033FF0033FF00
23FF0023FF0023FF0023FF0023FF0014FF0023FF0014FF0014FF0014FF0014FF0014FF00
05FF0005FF0000FF0A00FF0A00FF2800FF5700FF6600FF7500E1FF00FFA300FF6600FF47
00FF4700FF7500FFF000FF3800FF1900FF0A00FF0A05FF0005FF0005FF0014FF0005FF00
14FF0014FF0014FF0014FF0005FF0005FF0000FF0A05FF0000FF0A00FF1900FFB300FF47
00FF4700E1FF00FFB300FF4700FF3800FF2800FF1900FF0A05FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
05FF0005FF0000FF0A00FF1900FF2800FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FFE1
00FF4700FF1900FF0A00FF0A00FF0A00FF1900FF1900FF4700FF3800FF4700FF9400FF47
00FF5700FFD100FFC200A3FF00FFB300FF6600FFA300FFA30019FF00FFD100FF7500FF66
00FF7500FFA37000FF00FF3800FF1900FF1900FF1900FF3800FFA300FF3800FF0A00FF0A
14FF0023FF0023FF0023FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0042FF00
42FF0051FF0051FF0051FF0051FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF00
70FF0070FF0070FF0070FF0070FF0070FF0070FF0070FF0070FF0070FF0070FF0070FF00
70FF0070FF0070FF0070FF0070FF0070FF0070FF0070FF0070FF0070FF0070FF0080FF00
80FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF00
80FF0080FF0080FF0080FF00
51FF0051FF0042FF0042FF0042FF0042FF0042FF0042FF0033FF0033FF0033FF0023FF00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51FF0042FF0042FF0042FF0042FF0042FF0042FF0033FF0033FF0033FF0033FF0023FF00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51FF0042FF0042FF0042FF0042FF0042FF0033FF0033FF0033FF0033FF0023FF0023FF00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42FF0042FF0042FF0042FF0042FF0033FF0042FF0033FF0033FF0033FF0023FF0023FF00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42FF0042FF0042FF0042FF0042FF0042FF0033FF0033FF0033FF0023FF0023FF0014FF00
05FF0000FF1900FF9400A3FF00FF4700FF2800FF1900FF0A00FF0A00FF0A00FF0A00FF0A
00FF1900FF3800FFD100FF5700FFA300FFF000FF4700FF3800FF3800FF3800FF5700FFFF
00FF5700FF4700FF4700FF4700FF5700FF9400FFD100D1FF00FF4700FF3800FF3800FF28
00FF1900FF0A00FF0A05FF0005FF0005FF0014FF0014FF0014FF0014FF0014FF0014FF00
23FF0023FF0023FF0023FF0023FF0033FF0033FF0033FF0023FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
23FF0023FF0023FF0005FF0000B3FF00FF2814FF0023FF0023FF0023FF0033FF0033FF00
33FF0033FF0042FF0033FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0051FF0051FF0051FF00
42FF0042FF0042FF0042FF0051FF0051FF0051FF0051FF0042FF0042FF0042FF0042FF00
42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0014FF0014FF00
14FF0005FF0014FF0014FF0014FF0014FF0014FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0000FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF19
00FF1900FF1900FF1900FF2800FF2800FF2800FF3800FF4700FF5700FF7500FF948000FF
8000FF00FFD100FFB300FFA300FFB300FFC200A3FF00E1FF6100FF00E1FF00A3FF00FFB3
00FF9400FF9400FF8500FF8500FF7500FF7500FF6600FF5700FF4700FF3800FF3800FF28
00FF2800FF2800FF1900FF1900FF1900FF1900FF1900FF1900FF0A00FF1900FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A05FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0014FF0005FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0014FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0000FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF1900FF1900FF1900FF1900FF2800FF28
00FF3800FF570047FF0094FF00FF5700FF4700FF4700FF3800FF3800FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF4700FF3800FF3800FF47
00FF4700FF4700FF4700FF4700FF4700FF5700FF5700FF6600FF5700FF5700FF5700FF57
00FF5700FF4700FF5700FF4700FF5700FF4700FF5700FF5700FF5700FF5700FF5700FF57
00FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF6600FF66
00FF6600FF6600FF6600FF6600FF7500FF7500FF7500FF8500FF8500FFA300FFB300FFC2
0075FF00F0FF00D1FF00FFE100FFF000FFFF00FFF000FFE100FFE100FFE100FFF000FFF0
00FFFF00FFFF00E1FF00D1FF00C2FF00B3FF00A3FF0094FF0066FF0019FF5100FFFF006B
FF006B8000FF1400FF1400FF0047FF0085FF0094FF0075FF0057FF3300FF00B3FF00FFFF
00FFF000FFE100FFE100FFE100FFD100FFD100FFC200FFC200FFC200FFB300FFB300FFA3
00FFA300FFA300FF9400FF9400FF9400FF9400FF8500FF8500FF8500FF8500FF8500FF85
00FF8500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF7500FF85
00FF8500FF8500FF9400FFA30066FF00B3FF00FFC200FFC200FFC200FFE100C2FF0085FF
5100FFFF000000D1FF00A3FF00F0FF0057FF00F0FF00FFF000FFD100FFB300FF9400FF75
00FF7500FF6600FF6600FF6600FF6600FF6600FF6600FF8500FFA300F0FF00FFE100FF75
00FF5700FF4700FF3800FF3800FF2800FF2800FF2800FF1900FF1900FF1900FF1900FF19
00FF1900FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A05FF0005FF0005FF00
05FF0005FF0014FF0005FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0033FF0033FF0033FF0033FF00
42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
33FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0033FF0042FF0042FF00
42FF0042FF0042FF0042FF0042FF0033FF0033FF0033FF0033FF0042FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0023FF0023FF0023FF0023FF0023FF0023FF0014FF0014FF0014FF0005FF0005FF00
00FF1900FF1900FF2800FF3800FF4700FF6600FFD100FF6600FF3800FF2800FF0A00FF0A
05FF0005FF0014FF0014FF0014FF0014FF0014FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0014FF0014FF0014FF0005FF0000FF0A
00FFB300FFFF00FF2800FF2800FF2800FF2805FF0014FF0014FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0005FF0005FF0005FF0005FF0005FF0000FF0A00FF0A
00FF1900FF2800FF3800FF5700FFF000E1FF00FF5700FF3800FF2800FF1900FF0A00FF0A
05FF0005FF0014FF0014FF0014FF0023FF0023FF0023FF0023FF0023FF0033FF0033FF00
33FF0042FF0042FF0042FF0042FF0042FF0042FF0051FF0051FF0051FF0051FF0051FF00
51FF0051FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF0070FF00
70FF0070FF0070FF0070FF0070FF0070FF0070FF0070FF0070FF0070FF0070FF0070FF00
70FF0070FF0070FF0070FF0070FF0070FF0070FF0070FF0080FF0080FF0080FF0080FF00
80FF0080FF0080FF0080FF0080FF0080FF0070FF0080FF0080FF0080FF0080FF0080FF00
80FF0080FF0080FF0080FF00
42FF0042FF0042FF0042FF0042FF0033FF0033FF0033FF0023FF0023FF0014FF0014FF00
05FF0000FF1900FF384200FF00FF8500FF3800FF1900FF1900FF0A00FF0A00FF0A00FF19
00FF1900FF3800FF7500A3FF00E1FF00FF8500FF5700FF4700FF5700FF570047FFFF0000
00FF7500FF6600FFF000FF6600FF750075FF00FF7500FF5700FF3800FF2800FF1900FF19
00FF0A00FF0A05FF0005FF0005FF0005FF0014FF0014FF0014FF0014FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0023FF0014FF0014FF0023FF0023FF0023FF0033FF0033FF0033FF0033FF00
33FF0033FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
42FF0042FF0051FF0051FF0051FF0051FF0042FF0042FF0051FF0051FF0051FF0051FF00
51FF0042FF0042FF0051FF0051FF0051FF0051FF0051FF0042FF0042FF0042FF0042FF00
51FF0051FF0051FF0051FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0033FF0033FF0042FF00
42FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0023FF0023FF0023FF0023FF0014FF0023FF0023FF0023FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0005FF0005FF0000FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF19
00FF1900FF1900FF1900FF2800FF2800FF2800FF3800FF4700FF5700FF6600FF7500FFA3
00FFFF0094FF00FFD100FFC200FFC20085FF000AFF3300FF7000FFFF00000085FF0066FF
00FFA300FF9400FF9400FF9400FFC20085FF00FF9400FFF000FF5700FF3800FF3800FF28
00FF2800FF2800FF1900FF1900FF1900FF1900FF1900FF1900FF0A00FF0A00FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A05FF0005FF0005FF0005FF0005FF0005FF0005FF00
05FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0023FF0023FF0023FF0023FF0014FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0014FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0005FF0005FF0005FF00
05FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0005FF0000FF0A00FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF1900FF1900FF1900FF1900FF2800FF38
00FF4700FF6600F0FF00FF7500FF5700FF5700FF4700FF4700FF4700FF3800FF3800FF38
00FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF3800FF4700FF4700FF47
00FF4700FF4700FF4700FF5700FF5700FF6600FF750066FF00FF7500FF6600FF5700FF57
00FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF57
00FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF5700FF6600FF6600FF66
00FF6600FF6600FF6600FF6600FF7500FF7500FF7500FF8500FF8500FF9400FFA300FFA3
00FFC200FFC200FFF000FFD100FFD100FFD100FFD100FFD100FFE100FFE100FFE100FFF0
00FFF000FFFF00E1FF00D1FF00C2FF00B3FF00A3FF0094FF0066FF0019FF000AFFEB00FF
FF005CBD00FF1400FF0028FF0057FF0066FF0066FF2300FF0047FF00A3FF00E1FF00FFFF
00FFF000FFF000FFE100FFD100FFD100FFD100FFC200FFC200FFC200FFB300FFB300FFA3
00FFA300FFA300FFA300FF9400FF9400FF9400FF9400FF8500FF8500FF8500FF8500FF85
00FF8500FF8500FF8500FF7500FF8500FF7500FF7500FF7500FF7500FF8500FF8500FF85
00FF8500FF9400FFA300FFB300FFD18F00FF00FFE100FFD100FFE100FFFF00B3FF5100FF
00B3FF00FFF000FFE100FFE100FFE100F0FF00D1FF00D1FFFF00E60057FF00FFA300FF75
00FF6600FF6600FF5700FF5700FF5700FF5700FF6600FF850075FF00E1FF00FFF000FF85
00FF5700FF3800FF3800FF2800FF2800FF2800FF1900FF1900FF1900FF1900FF1900FF0A
00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A00FF0A05FF0005FF0005FF0005FF00
05FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF0014FF00
14FF0014FF0014FF0014FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0042FF00
42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0033FF0033FF0033FF00
42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
42FF0033FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF00
42FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0042FF0033FF0042FF0042FF00
42FF0042FF0042FF0042FF0042FF0033FF0033FF0042FF0042FF0042FF0042FF0042FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0023FF0023FF0023FF0023FF0014FF0014FF0014FF0005FF0000FF0A
00FF6600C2FF00FF4700FFB300FFC200FFFF00FF9400FF7500FF3800FF1900FF0A05FF00
05FF0014FF0014FF0014FF0014FF0014FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0014FF0014FF0005FF0000FF0A
00FF4700FF7500FF0A05FF0005FF0005FF0014FF0014FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF00
23FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0023FF0014FF00
14FF0014FF0014FF0014FF0014FF0014FF0014FF0005FF0005FF0005FF0000FF0A00FF0A
00FF1900FF2800E1FF00E1FF00FFD100FFE100F0FF00FF4700FF1900FF1900FF0A05FF00
05FF0014FF0014FF0014FF0023FF0023FF0023FF0023FF0033FF0033FF0033FF0033FF00
42FF0042FF0042FF0042FF0042FF0042FF0051FF0051FF0051FF0051FF0051FF0051FF00
51FF0061FF0051FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF0061FF00
70FF0070FF0070FF0070FF0070FF0070FF0070FF0070FF0070FF0070FF0070FF0070FF00
70FF0070FF0070FF0070FF0070FF0070FF0070FF0080FF0080FF0080FF0080FF0080FF00
80FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0070FF0080FF0080FF00
80FF0080FF0080FF0080FF00
42FF0042FF0042FF0042FF0033FF0033FF0033FF0033FF0023FF0014FF0005FF0005FF00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42FF0042FF0042FF0033FF0033FF0033FF0033FF0033FF0014FF0000FF0A00FF2800FF28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pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQ
ooooo`007_ooool2o`0000Cooooo00?o0000ooooooooool00_ooool3o`0000?ooooo0ol0000Ioooo
o`;o00001?ooool00ol0003oooooooooo`02ooooo`?o00001?ooool2o`0000?ooooo0ol0000Eoooo
o`;o00001?ooool00ol0003oooooooooo`02ooooo`?o00001?ooool2o`0000?ooooo0ol0000Foooo
o`;o00001?ooool00ol0003oooooooooo`02ooooo`?o00001?ooool2o`0000Cooooo0ol0000Doooo
o`;o00001?ooool00ol0003oooooooooo`02ooooo`?o00001?ooool2o`0000;ooooo1Ol0000Koooo
o`;o00001?ooool00ol0003oooooooooo`02ooooo`?o00000oooool001gooooo00Co0000oooooooo
oooo00002Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01Oooooo00Co0000oooo
oooooooo00002Oooool00ol0003oooooooooo`02ooooo`06o`000?ooooooooooo`000?oooooo0000
0oooool00ol0003oooooooooo`0Aooooo`04o`000?ooooooooooo`0000Wooooo00?o0000oooooooo
ool00_ooool01_l0003oooooooooool0003oooooo`0000?ooooo00?o0000ooooooooool04_ooool0
1?l0003oooooooooool00009ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo0000
1?ooool00ol0003oooooooooo`0Booooo`04o`000?ooooooooooo`0000Wooooo00?o0000oooooooo
ool00_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0001[ooooo00Co0000
oooooooooooo00002Oooool00ol0003oooooooooo`02ooooo`005_ooool5o`0000;ooooo00Co0000
oooooooooooo00002Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo013ooooo1Ol0
0002ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool00_ooool01_l0003ooooo
ooooool0003oooooo`0000?ooooo00?o0000ooooooooool02_ooool5o`0000;ooooo00Co0000oooo
oooooooo00002Oooool00ol0003oooooooooo`02ooooo`06o`000?ooooooooooo`000?oooooo0000
0oooool00ol0003oooooooooo`0;ooooo`Go00000_ooool01?l0003oooooooooool00009ooooo`03
o`000?oooooooooo00;ooooo00Go0000oooooooooooo0000ooooo`05o`0000cooooo1Ol00002oooo
o`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0
0003ooooo`03o`000?oooooooooo01?ooooo1Ol00002ooooo`04o`000?ooooooooooo`0000Wooooo
00?o0000ooooooooool00_ooool001gooooo00Co0000oooooooooooo00002Oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo01Oooooo00Co0000oooooooooooo00002Oooool00ol0003o
ooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo0ol0000Dooooo`04o`000?oooooooooo
o`0000Wooooo00?o0000ooooooooool00_ooool01Ol0003oooooooooool0003ooooo00Co00005Ooo
ool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo00;ooooo00Ko0000oooooooooooo
0000ooooool00002ooooo`03o`000?oooooooooo01;ooooo00Co0000oooooooooooo00002Oooool0
0ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool06Ooo
ool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo00;ooooo000Mooooo`04o`000?oo
ooooooooo`0000Wooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Gooooo`04o`00
0?ooooooooooo`0000Wooooo00?o0000ooooooooool00_ooool01_l0003oooooooooool0003ooooo
o`0000?ooooo00?o0000ooooooooool04Oooool01?l0003oooooooooool00009ooooo`03o`000?oo
oooooooo00;ooooo00Ko0000oooooooooooo0000ooooool0000Hooooo`04o`000?ooooooooooo`00
00Wooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooo
000001Cooooo00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`02ooooo`06o`000?oo
ooooooooo`000?oooooo00000oooool00ol0003oooooooooo`0Hooooo`04o`000?ooooooooooo`00
00Wooooo00?o0000ooooooooool00_ooool001gooooo00Co0000oooooooooooo00002?ooool2o`00
00Cooooo0_l0000Iooooo`04o`000?ooooooooooo`0000Sooooo0_l00004ooooo`06o`000?oooooo
ooooo`000?oooooo00000oooool00ol0003oooooooooo`0Aooooo`04o`000?ooooooooooo`0000So
oooo0_l00004ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool05Oooool01?l0
003oooooooooool00008ooooo`;o00001?ooool01?l0003oooooooooool00003ooooo`;o00005?oo
ool01?l0003oooooooooool00008ooooo`;o00001?ooool01_l0003oooooooooool0003oooooo`00
00?ooooo00?o0000ooooooooool06?ooool01?l0003oooooooooool00008ooooo`;o00001?ooool0
01kooooo0_l0000:ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool06?ooool2o`00
00[ooooo00?o0000ooooooooool00oooool2o`0000?ooooo0ol0000Eooooo`;o00002_ooool00ol0
003oooooooooo`03ooooo`;o00001?ooool2o`0001Kooooo0_l0000:ooooo`03o`000?oooooooooo
00?ooooo0_l00005ooooo`03o`000?oooooooooo01?ooooo0_l0000:ooooo`03o`000?oooooooooo
00?ooooo0_l00003ooooo`?o00007?ooool2o`0000[ooooo00?o0000ooooooooool00_ooool00?oo
oooo8Oooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool0027ooooomol00008oooo
o`008Oooool01Ol0003ooooooooooooooooo000000_ooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool01Ol0
003ooooooooooooooooo000000Sooooo0008ooooo`;o00001?ooool00ol0003oooooooooo`02oooo
o`;o00000oooool5o`0000Cooooo00?o0000ooooooooool0loooool00ol0003oooooooooo`06oooo
o`001oooool01?l0003oooooooooool0000:ooooo`05o`000?ooooooooooooooool000000_ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo0??ooooo00?o0000ooooooooool01_ooool0
00Oooooo00Co0000oooooooooooo00002oooool01Ol0003ooooooooooooooooo000000Kooooo0_l0
003cooooo`;o00002?ooool000Oooooo00Co0000oooooooooooo00002?ooool4o`0000Cooooo00?o
0000ooooooooool00oooool03Ol0003oooooooooooooool0<ol003Wo000mo`00?ol0047o0012o`00
@?l004;o0010o`001@12o`001P0oo`00@Ol004;o0012o`00??l003oo0080@_l000<0?_l003?o000c
o`003`0co`000`0Wo`008ol002?o000402?o0003027o000No`005_l000805?l001L03Ol000Go0001
o`T00?lL003oH00=eI`01lNj00KCgP0@[N@04;O_003Hj00kEnl02=kI003hZ@00ogl00?ma013L[`00
ohd00?mR003oF@00oeD00?mD003oE@02003oE`0V003oF000of400?mZ003oN@00ogl00?n8003oWP0A
/>405Ikl003o`000ok400?ne003na@00nN@03l;k00^Mo`02Qol0EcKR002go`05^Ol06;7[003o`@00
ojd00?nR003oV000oi<00?n=003oQ`0@kg/00?m]003oG`00oeL00?mB003oB@00odL00?m5003o>`00
ocT2003o>003003o=@00obT00?lX00800?lX00<00?lV003o8000oaT00`00oaT01P00o`l00?l;003o
2P00o`X00Ol800Co10@01Ol000<01_l000oo000Do`001`0Do`0302?o0004023o000So`008ol002;o
00808ol000@08_l002?o000So`008Ol01@0So`000`0Ro`008ol0023o000202;o00<05?l00P0Co`00
8@07o`001?l3003o3@00o`l00?lC003o5`00oaT00?lM003o9`00ocP00?mT003oP@00n:P02Z_j03Di
jP08anH00Mc8003Z^`00od000?lW003o7`00oa`00?lM003o9000m6l00^e<003o4`01mC<00?=:023o
000co`00=Ol003oo000304;o000304Oo001Ao`00DOl000D0DOl000H0Dol005Co001Ho`00HOl0063o
001Oo`03067o0003063o001Qo`00HOl000H0HOl01?ooool00ol0003oooooooooo`06ooooo`001ooo
ool01?l0003oooooooooool00007ooooo`07o`000?ooooooooooooooool0003oooooo`000003oooo
o`03o`000?oooooooooo00;ooooo00Co0000oooooooooooooooo0P0co`000`0eo`00=?l0043o0002
03ko000504;o000mo`00@_l004;o000mo`000`12o`00200mo`00@_l004;o000mo`00=_l0043o0012
o`00>Ol0300co`000`0bo`00<Ol003?o000203?o000302ko000So`008ol000D08ol001d07_l001Co
000Do`005?l000ko0005o`000ol5003o4000obP02Nj8013_V000ohH00?2S003oNP00oiH02lWa00C_
`000oh800?mU003oF`00of400?mG003oC`00odT00?m8003oB@00odP00?m:003oDP02003oE`07003o
H@00ofL00?m/003oN000nJ005;_S003e``02003oXP0J003oYP00ok<00?o1003ZjP00nO/03ZSo02P`
o`0B/?l00?kb003oe000okd00?nY003oW000oi<00?n7003oPP00ogL00?ma003oIP00oe/00?mG003o
CP00odP00?m7003o@P00ocX2003o>003003o=P00obT00?lY00<00?lX00<00?lO003o6P00oaT00P00
oaT00`00o`l00?l<003o2P02003o2P0300Co0`05o`001Ol000<01Ol000@03ol001Co000Do`004ol0
1P0Do`00100Ro`008ol001ko000Oo`0202?o000302;o000So`008ol000H08ol000H08_l002?o000S
o`008Ol002?o000Ro`0201Ko00@05?l002802ol000Go0001o`X00>IC003o?@00ob400?lR003o8`00
obP00?l]003o?000oe400?ma003faP00[OT01=3W013Sd00<j;X00?mO003o<@00oah00?lG003o4000
o``00?l@003o5P03o`H02?l200oo000Bo`009Ol003?o000eo`00?ol00`12o`000`18o`00Col004ko
0007057o000:05?o001Mo`00E_l0063o001Qo`00G_l0067o001Po`00HOl0063o00<0HOl000<0H?l0
067o001Qo`001?ooool00ol0003oooooooooo`06ooooo`001oooool01?l0003oooooooooool00007
ooooo`07o`000?ooooooooooooooool0003oooooo`000003ooooo`03o`000?oooooooooo00;ooooo
00Go0000oooooooooooooooo037o000503?o000=03So000mo`00=Ol0047o0012o`00>?l0043o0012
o`00?Ol003Go0010o`00@Ol003Oo000=03?o000603;o000co`00<ol003?o000bo`00;Ol00P0`o`00
0`0Wo`008ol002?o000202?o00808_l000<08Ol001go000Do`000P0Do`004P0@o`001Ol000Co0P00
o`d00?i100GWZ@00oe400?lo003o@`00oeH00mc500?U]00=/m@00>RV003oE`00odT00?m7003oAP80
0?m502<00?m6003oA`00odL00?m7003oB000odd00?mG003oF000oe/00?mU003oK000ogX00?n=003o
S000oi000?nE003oW`00ojT00?ni003oc@00n>d00jco03hnl00DP?l00>gb003od000okh00?nZ003o
V`00ohh00?n5003oM`00og@00?mZ003oI002003oE`05003oC@00odL00?m7003o?P00ocT00P00ocP0
0`00oc000?lZ003o:002003o:003003o8000oaX00?lJ00800?lI00<00?lF003o3`00o`/00`00o`X0
0`02o`H01Ol100Go000300Go000400Wo000>o`004Ol001?o00H05?l000L05Ol001Ko000Do`008_l0
02?o000Ro`007Ol000808ol000X08?l002?o000So`008ol002;o000So`008?l002;o000So`007Ol0
0P0Ko`0401Co000901?o000>o`001Ol000Co0`00oa@01nR500W7V`00oeP00?mM00800?lg01H00?li
003oB000lH000?n:00OBe00MQ>`00^jb003oP`00fL@00?Ei003o9`00oaP00?l<003o2P03o`D01?l2
00Ko000?o`005?l001[o000Ro`00:Ol00P0co`000`10o`00@Ol004;o000204;o000404Co001Ao`00
D?l0053o00P0DOl000P0F?l005Ko001Lo`00H?l005_o001Qo`00H?l0067o0080H?l000<0HOl0063o
001Qo`001?ooool00ol0003oooooooooo`06ooooo`002?ooool2o`0000Wooooo0ol00003ooooo`?o
00001Oooool01Ol0003oooooooooooooool0:_l000P0<ol000H0=Ol003Ko000co`00=Ol003[o000d
o`0F03?o0003033o000So`008ol000L08ol000<08_l001Wo000Do`000P0Do`00500Ao`001Ol000Go
0001o`T00?lK003o<`00obD00?lW003o;P00odl03>2f003hHP00oeh00?VG003oAP00oc`00?lk003o
>@00ocP00?li0P00ocX08@00od800?m7003oA`00odL00?m;003oEP00oeL00?mM003oIP00of/00?me
003oN`00ohD00?n>003oV000ojP00?ni003oc`00ond05Z;o03l`o@0EN?X00MOm003oi000m><00=oH
003oX000ohd00?n3003oMP00og@00?mV003oI002003oE`04003oB`00odL00?m7003o?@<00?lh00H0
0?l^003o:000obP00?lX003o9P00oal4003o6@03003o5@00o`/00?l:00<00?l:1`05o`001@0=o`00
5?l001Co000Do`004ol000L05?l000@07Ol0027o000Ho`007?l00P0So`002P0Mo`008ol002?o000Q
o`007ol002?o000Ro`005ol0027o000Io`0601Co000N013o0007o`001Ol000;o1`00oa<00?le003d
W`0>_^X00?n3003oD000odH00?m9003oG`02i[800>3S02b?m000lLh00?mh003oEP00odT00?ln003o
7`00oa800?l:00Co0`05o`001ol001;o000Do`006_l00P0So`00100^o`00<ol003?o000lo`0404;o
000304?o001:o`00Bol000/0DOl00P1Bo`002@1Do`00Eol005So001Jo`00G?l005_o001Po`00Fol0
05oo0004ooooo`03o`000?oooooooooo00Kooooo000Qooooo`06o`000?ooooooooooooooo`0To`00
:ol06`0co`001P0bo`00<ol003?o000co`00<Ol003;o00<0<ol000<09_l002?o000So`00100So`00
100Qo`008ol002?o000Ko`0301Co000601?o0006o`001Ol000?o1@00o`/00?lB0P00oaT02P00ob40
0?l`003o?000ocL00?li003o?000ocH00?lg003o=P00ocL4003o>006003o>@00och00?m7003oA`00
odP00?m?0P00oeL07000of<00?mV003oK`00ogD00?mm003oQ`00oiT00?ni003cg@00onT00?kh003D
o`0iG_h07VC_00nklP00j?l06GOo003Uf@00ojD00?n=003oQ000ogL00?md003oI`00ofD00?mH003o
E`00oe02003oA`05003o?000ocP00?lh003o=@00obT00`00obP00`00obH00?lJ003o6@03003o6@03
003o3P00o`d00?l;00<00?l:00<00_l800Co1005o`401005o`00100?o`005?l001;o000Bo`0;01Co
000:01Wo000So`008?l001Co000Ro`008ol001ko000Io`008_l001co00L05?l000<04ol0013o000;
o`000P05o`007P01o`P00?lC003o:@06diH05lg<01S4``00kiT00?mN003oF`00og004lC5002hlP16
?_400m7S003fS`00odd00?lh003o:000oaT00?l?007o2004o`801Ol000oo000Do`005_l0023o000R
o`009?l0037o0080<ol000<0=ol003go0011o`001012o`000`1:o`00DOl004go000A057o000305?o
001Ao`00Dol000Cooooo00?o0000ooooooooool01_ooool0027ooooo00Oo0000oooooooooooooooo
02?o000Uo`00;Ol001X0<ol000<0<_l003?o000co`000P0co`001@0]o`00<?l003?o000bo`009?l0
00L08ol000<07ol001[o000Do`000`0Do`00300Bo`001ol000Go0005o`400ol5003o2P00o``00?lC
003o6P00oad00?lS003o9`@00?lX00@00?lZ003o:`00oc000?ld0`00ocP09P00ocT00?m0003oA`00
odL00?m:003oEP00oeL00?mO003oIP00ofL00?md003oN@00ohD00?nG013Df00WS?L09hO[003Fo`0=
Nol0@B7O07L?gP1]?]d066S_00G5o@00oN000?Nl003oUP00ohD00?mi003oM@00of`00?mV003oH@00
oeL00?mD003oB000odL00?lm0P00ocP00`00oc<00?lZ003o:002003o:004003o8000oa/00?lI003o
6P800?lI00<00?l>003o2P00o`X00`00o`X00`05o`401Ol000Go000500Go000300Wo000=o`005?l0
00`05?l000H05_l001Co000Do`005ol001_o000Eo`0:01Co000L01?o000=o`001Ol000Go0003o`@0
0?l:003o5P00ob<00?m000c^P`09ZO000?:h003oM000ofl00?n4003mZ@0;VoT01;;f00KEg@0=hJh0
0?m9003o=@00obL00?lJ003o3`02o`H01Ol000Wo00805?l000D06ol0027o000So`009Ol0037o0002
03?o000303Go0012o`00@Ol000@0@_l000L0@ol004Go001<o`00DOl004ko001Ao`00D?l00100DOl0
1?ooool00ol0003oooooooooo`06ooooo`008Oooool01?l0003oooooooooooooool202?o000402Oo
000]o`00<ol003;o01P0<ol000P0<?l003?o000co`00<ol003;o000So`009ol002Go00D08ol000D0
8_l002?o000So`008ol002;o000501Co000>00ko0005o`001Ol000Go0@01o`P00?l:003o2`00oa00
0?lH003o6@00oaX00?lQ003o9000obH3003o:003003o:@00ob/00?lb00<00?lh00L00?lj003oA@00
odL00?m8003oD`00oeL00?mL00800?mV01`00?mc003oM`00ohD00?n@003oZ000old01=?h025Nk`0O
@?<0V0;B08/5f`0dC>H00<[o0124m00WL_D02;Ke003m[@00ohX00?n2003oMP00og@00?m]003oIP00
oel00?mG003oD000odL00?lo0P00ocP00`00ocD00?l[003o:002003o:003003o8@00oaX00?lI0080
0?lI00<00?lH003o4000o`h01000o`X01003o`D01?l300Go0@05o`4500Go000401?o000Do`005?l0
01?o01P05?l00P0Co`007`0>o`001Ol000Go0005o`000_l7003o3@00oaX00?lY003o?`00oe/02^6Z
01Z_i000oiH00?nE01W=e00@iL/0:HC_00;Ih`00oiP00?me003oC@00oc`00?l^003o8@00oa000_l7
00Go000<o`004ol001Co000Oo`000P0So`000`0To`00<?l003?o000203?o000303Oo0010o`00@_l0
00D0@_l000X0AOl004Wo0019o`00D?l004ko001Ao`00C_l0053o001Ao`00C_l01`1Ao`02053o0080
DOl01?ooool00ol0003oooooooooo`06ooooo`008Oooool01Ol0003oooooooooooooool08?l00080
8ol000<09ol002[o000bo`000`0bo`0403?o000503;o000co`00<ol003?o000bo`001@0co`001@0b
o`00<ol003?o000co`00<_l00080<ol000<0<_l002ko000co`000P0co`000`0Wo`008ol002?o0006
02?o000402;o000Qo`007ol001go00@05?l000H04_l000co0005o`001Ol000Go0@03o`@3003o2P03
003o3`00oaD00?lI00800?lI00<00?lM003o8P00obL00`00obP01P00obX00?l`003o>000ocP00?li
003o@P800?m700<00?mA003oE`00oeh00P00ofL08000og@00?mg003oQ@00ohd00?nM003de@0NOOP0
1mSm00c2o`0CMol0BbO]016Ym@00no/00?k/003bh000ol400?nP003oT000ohH00?n2003oOP00ogT0
0?mf003oKP00og<00?mJ003oB`00od800?li003o>000oc<00?lY0`00obP00`00oa`00?lI003o6@02
003o6@03003o5`00o`/00?l:00@00?l:00<00Ol900Co0P05o`001P05o`000`0=o`003_l000go0002
01Co000301?o000Do`005?l001005?l000L04ol001Co000Do`004ol001Co000?o`002?l000801Ol0
01`00ol5003o2`00oal00?lZ003o?`00of/00OF2017JYP07a>d03[_H01?4hP0ORo/05g7b02JPi@00
om000nRW003oK`00oe/00?mE003oL@00oeT00?lO00;o1P05o`003Ol001?o000Eo`008Ol00P0So`00
0`0Vo`00<Ol003?o000203?o000303Go000no`00@?l000L0@_l000`0@ol004Co0016o`00Aol004So
0017o`00Bol004Wo0018o`00BOl004Oo0016o`0404Oo0080BOl000<0B?l0ooooooooool00_ooool0
0ol0003oooooooooo`06ooooo`008Oooool01Ol0003oooooooooooooool07Ol000@08ol000H0:ol0
02[o000co`00<Ol003?o000bo`0903?o000403;o000co`00<ol0037o00<0<ol000P0<Ol003?o000c
o`00<ol002[o000/o`00<ol002oo00/08ol000<07_l001Co000Do`00100Do`001P0Co`001Ol000Go
0005o`001Ol100?o10800?l:00<00?l;003o3P00oa@00P00oaT01000oaX00?lI003o8000ob@3003o
:005003o:`00oc800?lh003o>@00ocl00P00odL06000oe@00?mH003oHP00ofL00?m/003oM@00og/0
0?n6003oS`00oid00?[0003jfP00onH00>cl002Zo`0i8nh0383o003dn000om/00?o7003o]000oj<0
0?nF003oTP800?n>00X00?jW013H_P00oj000^3;003oN000oe800?m5003o>@00ocP00?ld1000obP0
0`00ob800?lL003o6@03003o6@03003o4P00o`/00?l:00<00?l:00D00Ol800Go0005o`001Ol200Go
0@0600Go000401?o000Do`005?l001;o00805?l000<04ol001Co000Do`003P0Do`00900Co`005?l0
01?o000>o`002ol000Go0005o`401Ol0007o2000o`h00?YB003nS`00l:L00=?R032]i@08e>800?f]
003haP0U^N<0C3;Z00iCo`0@SOH03kGn003EkP00oi<00?mm01?M_`00`>T00mRL003h@@01o`T01Ol1
00oo000Do`005Ol0023o00<08ol000<0<Ol003?o000co`000P0co`00100do`00@_l0047o0011o`0A
04;o0003043o000no`00@?l000@0@_l01?ooool00ol0003oooooooooo`06ooooo`008Oooool01_l0
003oooooooooooooool05ol0023o00@08ol000L09Ol002go000[o`00<ol002oo000co`00<Ol00080
<ol000<0<_l003?o000bo`000P0co`001@0_o`00<ol003?o000co`00<Ol00080<ol000D0;_l003;o
000co`00<ol002_o000:02?o0003027o000So`008ol000808ol000<05ol001Co000Do`000P0Do`00
0`0Bo`003Ol000Go000300Go000300Co1002o`P00?l:00800?l:00<00?l@003o5@00oaT00P00oaT0
0`00oaX00?lN003o:003003o:00X003o;`00ocP00?lh003o?P00odL00?m:003oE`00oe`00?mW003o
K000ogD00?mf003oP`00ohD00?nB003oW@00oj`00?o0003oeP00h_L03FKo07LD/00JJ_l03<3k003o
g000olT00?nh003oZ@00oj400?nK003oW@00oj@00?3A032Ch`00[?@01N3100cY/@00oeX00?m7003o
>`800?lh00D00?l/003o:000obP00?lX003o6`05003o6@03003o2`00o`X00?l:00D00?l:00<00_l7
00Go0005o`001P05o`001@0?o`004ol000_o000Co`005?l000804ol03P0Do`001P0Co`005?l001?o
000Bo`005?l000Wo00<01Ol001d01Ol2003o2P00o`l00?Le003oS@00j:d0;LOB003cXP01khP00?mk
003cW00@cNX00:Go02U8k`0l<Ml0@2gf00o2l`00m/D01l?B00_9g`00ogd00?9;003o6`01o`P01Ol0
00go000Do`005Ol001oo000302?o000302_o000ao`00<ol000<0<ol00P0ho`001@12o`00@?l004;o
0011o`00@_l00080@Ol02012o`002P11o`00??l003Go000^o`008ol402Km400fo`00?Ol0043o000o
o`04ooooo`03o`000?oooooooooo00Kooooo000Qooooo`07o`000?ooooooooooooooo`0Do`006ol0
02;o000502?o000502Ko000[o`009ol003?o000/o`000P0co`000`0^o`00<ol0033o000203?o0005
02oo000ao`00<ol003?o000]o`000P0co`001@0]o`00:Ol003?o000co`00:?l000/08ol000@08Ol0
01ko000Oo`007_l01`0Do`001P09o`001Ol000Go0005o`001Ol100;o1`@00?l:00<00?lA003o6000
oaT00P00oaT00`00oaX00?lM003o:002003o:00X003o;000ocL00?lj003oA000odL00?mB003oF@00
ofD00?mg003oOP00ogl00?n4003oQ`00oi400?nE003oX@00ojd00?o0003of000o_800=Ko035Cl008
U?l00?Gn003ol@00l^P00?o9003o^000oj`00?nZ003o]003gNP04[cb031gm@00dNL00?n5003oJ@00
oeD00?m7003o?@800?lh00H00?l]003o:000obT00?lX003o9000oa/2003o6P800?lI00<00?lG003o
3P00o`/01@00o`X200Go000300Go0@05o`001Ol000H01Ol000@02Ol001Co000Do`004Ol00P0Do`00
0`0Co`005?l001Co000:01Co000501?o000Bo`005?l000_o0009o`001005o`006P03o`D00?l:003o
3`00oah00?la003oD000nFL00?mJ003oGP00ofP00?mn003d^`0Jd=d00>;n02iKmP10=nl06[Od00Zl
j@0O`>H00?n8003oE000oc@00?lK003o2`05o`002_l00P0Do`001`0Qo`008ol002?o000So`00:Ol0
03?o000bo`00100co`001@0eo`00?Ol003_o0012o`00@?l00080@_l00100@Ol004;o0012o`00@Ol0
043o000ko`00>_l003So000eo`00<ol003;o000To`004^ln00_YE`0Do`80;Ol00`0co`04ooooo`03
o`000?oooooooooo00Kooooo000Qooooo`;o00000_ooool201Co000301go000Ro`008ol000H08ol0
00T09_l002Co000]o`00;?l002Wo000co`00;Ol0033o000co`000P0]o`001`0co`00<Ol002Go000b
o`00<ol002[o000So`000P0Uo`0=02?o000302;o000Fo`005?l000D05?l000<04_l000co0005o`00
1@05o`000`01o`P00?l:003o2P02003o2`07003o3P00oaT00?lI003o6@00oaX00?lN003o9003003o
:00K003o=@00ocP00?m3003oC`00oe/00?mS003oM@0@dj/00?N/003oT000ohl00?nF003oV@00oil0
0?nU003o/`00fm`00>_f003jo@0K/^l09S3m03<hn`0>`Ol00>Go015no`00iO800>[N00800?nm00X0
0?oA022Fm@0aQ^d00?[9003Ra000ogT00?mR003oE@00odL00?m10P00ocP01@00oc000?lY003o:000
obP00?lR00D00?lI00<00?lD003o2P00o`X01@00o`X200?o1P0300Co0`05o`001Ol000L01Ol000<0
3ol000go000=o`000P0Do`00100Ao`005?l001Co000Bo`0401Co000401;o000Do`005?l0017o0080
5?l000<03?l001;o0009o`001005o`007P05o`800Ol8003o2P00o`d00?lJ003o9@00obh00?lj003o
A@00odl00?mN003oK`00ohh00?nm02:Eo00;V?/03Kcj007ScP00oi801>SA012@g`0;iI/00>i/003o
?000oa800ol500Oo000Co`005?l001Wo00<08ol000<09?l002Wo000co`001P0co`002@0eo`00>Ol0
03co000lo`00@?l003_o000lo`00>ol003Ko000203?o000=037o000_o`00;ol002_o000Uo`005Ol1
017_?P08j5d03ol0027o000Yo`00<?l003;o0003ooooo`;o00002?ooool0027ooooo00Co0000oooo
oooooooooooo0P0Do`00100Eo`007?l002;o000Qo`0:02?o000402Ko000To`009Ol002Wo00809?l0
00D0;?l002Go000So`009Ol002Oo000>02?o00808_l00P0So`000`0Lo`005?l001Co000501Co0003
01?o0007o`001Ol000<01Ol000@01?l3007o2@00o`X00?l:0P00o`/00`00o`l00?lF003o6@02003o
6@0d003o6P00ob<00?lX003o:000obT00?lb003o>000odD03O9f003ZX000oh@00?^]01Roj000olh0
0?ne003[b@00iLH00?nZ003oZ`00ok800?nn003fj@0SNOH00=3o00N]o`0?C_l0?cSh00RHo`00V_l0
4ESo00fKo`00mnl00?oF003oe`0>]_804hkb00[ThP00oj<00?n8003oL@00ofD00?mF003oBP00odL0
0?lj003o>000oc<00?lZ003o:@00obP00?lW003o80@00?lI00<00?lG003o4P00o`d01P00o`X01001
o`P01Ol000Go0@04o`8900Go000B00Wo000Co`003ol000ko000Do`004ol0013o000Do`004_l001?o
000Do`004?l001?o000Do`003Ol0013o000Co`001ol01P05o`007`03o`D00?l:003o2P00o`/00?lI
003o7000obP00?la003o>`00odP00?mR003oQP00oiL00>KH01aPo@00kmd00_:c003oQ`00ofh00?mh
003=b004e//04;?W003^U@00oTL00_l900Go000Co`005?l001Ko000Qo`000`0So`001@0Wo`00;?l0
03;o000co`00<_l000`0<ol000l0<?l002Oo000Eo`l05_l101ko000Oo`006Ol000oe:000kJD03MZJ
00;o8`0Co`008Ol002;o000So`001?ooool00ol0003oooooooooo`06ooooo`008Oooool01Ol0003o
ooooooooooooool04_l000<05?l000@05ol001oo000Po`008_l08P0So`00100Mo`007_l001ko000G
o`0501Co000401?o000Ao`003ol000Ko00D01Ol000<01?l3003o2P00o`X00`00o`X01P00oa800?lI
003o6@00oaX00?lI003o6P<00?lX00d00?l`003o>000od800?mP003[/@08`>H07;Oi04<omP0GIol0
:ZCj035loP00mnL00?o900800?o101`00?oA00f_l@08I_l00f;o00]3o`0K?_d0J0oM01L^o`2Z2MX0
=S_c002ko`00eOl02Ygo00GBn`0<S?l00>oa003o_@00oih00?n9003oN@00ofd00?mP003oE@00odP0
0?m4003o>@00ocH00?l/0`00obP00`00oad00?lK003o6@03003o6@04003o5P00o`X00?l:003o2`D0
0?l:00<00ol600?o1@05o`003005o`003009o`004?l000Wo000<o`005?l000ko000?o`005?l000oo
000:o`005?l000Wo00P01Ol000D01?l200;o1`00o`X00?l:003o3P02003o6@0J003o9`00obT00?lh
003oA@0@kfh04]?:016gj001ao4029km003eaP00oi000?mZ003oF000oe400?mD003kN@04hJ000?mD
003VR000oa801Ol000ko000Co`005?l001co000Qo`0402?o0003033o000/o`00<ol000H0<ol001<0
<_l003?o000co`00<ol003;o000_o`008ol0017o3P01nUH00olB00_o0@0=o`001ol0007o6@04jXl0
2lFQ003cG@06o`<04ol000805_l01?ooool00ol0003oooooooooo`06ooooo`008Oooool01Ol0003o
ooooooooooooool02ol000804ol00`0Do`000`0Io`007Ol0027o000202;o01808ol000<08_l002?o
000So`001P0So`0202;o00808ol000<08_l001Co000Do`001`0Do`000`0Bo`002?l000Go000400Go
000300Co0`02o`L00?l:00<00?l:00<00?l>003o5000oaT00`00oaT0;`00oah00?lW003o:000obP0
0?l/003o>000od000?m>003`V@00oi@00>^f0071n007iMl00<kd02MPh@0CQ_l04Ico003og`00omP0
0?oY003^oP0AT_X0R@Za08d3e`0^2?@0`03305X2kP3T0:L0N`gI010fo`18>>L08d;c012Do`05T?l0
4=[V003je000okP00?nN003oS000nXh00?me003oH000oeL00?m9003o?@00ocP00?l`00<00?lX00<0
0?lW003o6P00oaT01000oaT00`00oa<00?lA003o2P06003o2P0600;o1P05o`001?l300Go0@05o`00
1Ol13005o`001@09o`001_l000Ko000=o`001_l000/01Ol001d01?l3003o2P00o`X00?l:003o4@00
oaT00?lK003o:000ob/00?li003oA`00oeX00>BW01g=k@0RLOT0=co_0174h003d]T00?mV003oC000
od<00?lm007_C000ocD00?lR003o6@02o`P01Ol000co000201Co000301[o000Po`008ol000@08ol0
00@0:?l002ko000bo`00<Ol00P0co`005`0bo`00<ol003?o000co`00<_l0037o000Xo`008ol001ko
000:o`D01NUb00O_M001k7<00?lI003o3P00oST04<k5007URP00oaX00_l700So000<o`002_l000Co
oooo00?o0000ooooooooool01_ooool0027ooooo00Ko0000oooooooooooooooo00Go0009o`0201;o
000:01?o000Do`005?l001Co000Fo`007_l001oo000Po`008_l002?o00808_l03@0So`000`0Ro`00
8ol002?o000302?o0005027o000So`008ol002?o000Po`000`0So`000`0Ho`005?l001Co000401Co
000401?o000Do`005?l0013o00H01Ol000<00ol5003o2P00o`X00`00o`X00`00o``00?lI003o6@03
003o6@0_003o9@00obP00?lX003o:P00ocP00?lj003oAP00oeH00?mQ003jQ@06kjT00?nK003b``0@
e=`03L_V012;o`0P`O800>_j022Fk@0XM_l0Ad[M09H3gP3W0:<0]P3G0?/0DP2Q0;h0f02V07H9d@00
ROl00;co00^io000oNl00>Gd01Iko`0WQ_D00jgi00ODk@00ok`00>7X003Y_000oh403NnW003oE`00
odL00?li003o=@00obX00P00obP00`00obL00?lM003o7@05003o6@03003o4000o`X00?l<00800?l:
00P00?l;003o2P00o`X00?l:007o2@02o`H01Ol000Co0P801Ol000<01Ol200Go0005o`005@05o`00
1005o`401Ol000Co1001o`P3003o2P0J003o4P00oaX00?lM003o:000obl00?lk003oB000oeX00?V8
003oY`0K]]T05Zgb003Kh@08jk/00?mM003o@P00ocL00?l^003o:000ob000?lF003o2`03o`D01Ol0
00[o000Bo`0201Co000301co000Ro`008ol000D08ol000<0:_l002So000_o`000P0^o`005P0_o`00
<Ol002go000Yo`009?l002?o000Ro`005_l000_o0@00lE404;_S00gE^@00od400?l]003oA@0KdL@0
0?R5003o:@00o`d00_l700?o1@02o`P4ooooo`03o`000?oooooooooo00Kooooo000Qooooo`04o`00
0?ooooooooooooooo`801Ol000@01ol000go000Ao`004ol01@0Do`001P0Eo`006?l001ko000No`00
7ol002?o00808_l03@0So`000`0Ro`008ol002?o000202;o00808ol000@08_l001So000No`007Ol0
1`0Do`00100Co`003ol000go0008o`0600Go000400Co0`00o`X00?l:003o2P800?l>00<00?lE003o
6@00oaT00P00oaT00`00oa/00?lU003o:002003o:00/003o=P00ocP00?m1003oB000oeD00?mO003o
L@00oh000?n@003oXP00ol400?G`0227k@0SLO40?DKV02mQj@0HJ?l0DPkZ0<l0[0102O00TP3[01LD
o`1/3N40@27_002Po`00j_/00?oM003oc@00om400<[`00g3m@18?MP06WWj02mlk@0bE>H01:o`01?5
h006dLl00?ij003oC`00ocd00?lh003o;P00obT2003o:003003o9@00oaT00?lI00@00?lI00@00?lH
003o5`00o``00?l;1P00o`X01@01o`T00ol500?o1@05o`001Ol200801Ol000<01Ol100Go0005o`00
4`05o`000`05o`401?l200Co0`02003o2P800?l;02000?lF003o6@00ob800?l[003o>000od<00?mB
003oGP00og<00?nP00^bk`00h=T00?nE00CYV@00oeH00?ln003o<000obP00?lN003o6@00o`l00?l:
00Co0P05o`002Ol001;o000Co`005?l001Go000Ko`008ol002;o00l08ol001006ol001Co0008o`40
0?la003dOP0@gkP00=;J003ZS@00og804<3G003oDP00obT00?lI003o5000oa/01>lg1?ooool00ol0
003oooooooooo`06ooooo`008Oooool01_l0003oooooooooooooool00ol400Co0P<01Ol000D01_l0
00[o000<o`004_l001?o000501Co000401Ko000Ho`007ol001oo00808_l000@08ol002;o000So`00
8_l0100So`00100Ro`008ol002?o000Qo`0302?o000501oo000Ro`008ol002?o000Ho`002`0Do`00
0`0<o`001Ol000Go000300Go000300Go0@03o`@00?l:00800?l:00@00?l;003o2P00o`X00?l;1000
oaT00`00oa/00?lT003o:002003o:00/003o<`00ocP00?lk003oA`00od`00?mI003oIP00og@00?n9
003oX000nm40:9Gg00Bfo000o^`00=o_003hnP06_ol06DWh02Lko@08Gol0G1WC01MFlP0CPOl00:;o
01IRo`01d?@00?o8003o^@00okP00?ni003_fP00ao800?oJ00gPdP0PUo`01nWD00GWX000mZH00>f]
003oH`00ocl00?lh003o<P00obX3003o:004003o9000oa`00?lI003o6P@00?lI00@00?lD003o4P00
o`X00?l<1P00o`X02@01o`P00ol500;o1P05o`001?l200Go0005o`401Ol000Go0@0>00Go000600Go
0@05o`001Ol000Go0@05o`000Ol81000o`X06000o`l00?lI003o6P00obL00?m:00[bI@00of`00?mU
003oJ`00oh801<?/02U]l@01g]l00?n5003oI000odl00?lm003o;P00ob@00?lJ003o6000o`/00?l:
00Co0P801Ol000l04?l001Co000Do`005?l001Go000Io`008ol0027o000Ro`008ol002;o000So`00
8_l002?o000Ro`001@0So`004P0Oo`006Ol001Co000Ao`001_l0007o3P00ob@00?mU003LX@02gLD0
0Mk9003gS`00odh00?lh003o<@00oT<01Nn1003dX@Cooooo00?o0000ooooooooool01_ooool0027o
oooo00Co0000oooooooooooooooo0P00o`X02@01o`P00Ol9007o2@01o`P00ol600Go0@06o`002_l0
00_o000200oo000301Co000Co`005?l000805?l000@06?l001Oo000So`007ol00P0So`000`0Qo`00
8ol002?o000202?o0005027o000So`008ol002?o000Po`000P0So`001@0Po`006ol002?o000Ro`00
5_l000L05?l000D04ol001;o000Co`005?l000go000700Go000700;o1`00o`X00?l:003o2P00o`/0
0?l=003o5P05003o6@0_003o8`00obP00?lX003o:000oc800?lh003o>@00odD00?m7003oF000ofH0
0?mn003kY@00o[d088ki00FNoP00k>@00?o:003oc008hNh06g_o021al`00bOl00;;o02h`k@0VAoT0
0<3o003Uo`01T?l01^OR003o^@00oj`00?nS003oXP00nZX00?nS003oW000ok40=I[P003lW000og80
0?mW003oG000od`00?m0003o>@00ocP00P00obT3003o:0800?lP00/00?lI003o6P00oaT00?lI003o
6P00oaT00?lH003o5`00o`/00?l<003o2`07003o2P0800;o1`01o`P01Ol100?o1@05o`001Ol100Go
0005o`4200Go000300Go0@05o`001Ol100D01Ol000L01Ol100Go0005o`001Ol200Go0002o`H00_l7
00@00?l:01H00?l=003o5000oaT00?lL003o:000n5800?2k00>mhP00m:D00?n:003oU@00olP0:8Oi
00KHh@00oiT00?m/003oGP00odD00?l^003o8P00oaT00?lD0P00o`X01@05o`401Ol000Go000=o`00
4ol000D05?l000X07?l001_o000Po`008Ol002;o000Qo`007ol001co000Mo`006Ol00P0Go`004`0E
o`005?l001Co000Do`002Ol000Go0001o`T00?lH003o:P00och00?mE00ONZ@02bml00?mh003oP`00
oWH00?mM003oY@0K]NH01?ooool00ol0003oooooooooo`06ooooo`008Oooool03Ol0003ooooooooo
ooooool00?lB003o2`00o``00?lB003o>@00nU<00?1Q007o2P04o`<00`05o`0200Go0@0300Wo000=
o`004ol000<05?l000<05ol001Go000Ro`000P0Oo`001P0So`007ol002?o000So`007ol002;o0080
8ol000D06_l002?o000So`008_l001Co000201Go00X05?l000<03ol000Wo0005o`001@05o`000`04
o`@00Ol9003o2P02003o2P04003o2`00o`X00?l:003o4@@00?lI00<00?lO003o9@00obP00P00obP0
:@00obh00?lh003o>@00od<00?m7003oFP00ofd00?j@01Jak00?dO004Hco01F/mP00ol000?ne003o
^000mll00?oU02NEn`00m_`03LSo03=BkP07I?l00=_o003om`00onL00???003o[P00oj@00?nJ003o
U000oi000?n;003oRP00ohh00?J[003oLP00of<00?mH003oD@00odP00?m100800?lh00<00?la003o
:000obP00`00obP00`00ob@00?lO003o6P07003o6@03003o5@00o`l00?l:00800?l;2000o`X03P03
o`H00Ol800Co1003o`@01?l300Go0005o`801Ol000Go0@05o`001?l300Go0004o`801Ol00P05o`40
1005o`000_l600Co0`01o`P4003o2P0G003o2`00o``00?lI003o6@00ob000?lY003o?@00of806]NU
016Fn00=hL<00?c300:^n`0JSOh00no>003oVP00oi<00M_1003jQ000oc400?lT003o6@00oa@00P00
o`X01P04o`<01Ol000Go0005o`003ol001?o00`05?l000@04_l000oo000=o`003ol00P0Co`004@0A
o`002_l000Go0004o`<00?l;003o6000ob@00?le003oC@00nh@09:CX007/d`0Cbmd00?fU00o:]P0R
`=@06HGj00Cooooo00?o0000ooooooooool01_ooool0027ooooo00Co0000oooooooooooooooo0`00
oaT04000ob<00?m700WA/P00oc<00?lB003o2P01o`T00Ol8007o2@00oaP00Ol<007o2@04o`@01ol0
01;o000Co`0301Co000701Oo000Eo`007_l002?o000Io`008_l002?o000201ko00808ol000@05?l0
01go000So`006ol02P0Do`001@0Bo`005?l001Co000Do`001ol000@01Ol000@01Ol100Go0005o`00
0Ol81000o`X00`00o`/00?lA003o5`05003o6@05003o9P00obP00?lX003o:000oc400P00ocP09P00
od<00?m:00WbL@00oi000?ja01nAl`0hLO002^GI00c_a@00ojL00?nS003oY`00ok800?o3003ofP00
onP00>oo00:Co`0YB_`00;Co003ok`00om<00?nl003oZP00oil00?nD003oSP00ohH00?n1003oN`00
ogH00?m`003oIP00oeX00?mG003oBP00odL00?m00P00ocP00`00ocL00?l`003o:005003o:004003o
8P00ob400?lM003o6PD00?lI00D00?lH003o5@00o`X00?l<003o2`05003o2P03003o2`00o`X00?l:
00@00?l:00P00_l6007o2005o`400ol500Go0003o`@01Ol000Co0`801Ol100<00_l700Go0P01o`P0
1@00o`X00`00o`/00?l:003o5@02003o6@0F003o8@00obP00?lh003oC@00og400?Ri022dl00HVn/0
BS;]00YMo`0:U_l00?GE00BliP00hl<00?mH003o<`00obD00?lI003o5@00o`/00?l:00;o1`801Ol1
00@01Ol000Ko000=o`004_l01@0Do`000`0Co`005?l001Co000201?o000700oo0006o`800_l@003o
>003o`@01Ol000Oo000200Go000?00Co0`01o`T00?lA003o6`00obL00?li003fN006j;401=;O03a;
h`0RBOl0;8[b00fbl002_nD00>[000Cooooo00?o0000ooooooooool01_ooool0027ooooo01Oo0000
oooooooooooooooo003o9000ob400?lW003o?`0@jZ`00lgE003kF`00ob000?lF003o4`00oaH00?lM
00K[MP00ocl01NQV00?XGP03o`@02Ol001?o000501Co000501Go000Go`005?l001_o000Oo`000P0F
o`000`0No`006ol001Co000:01Co000701?o000Do`005?l001Co000?o`004?l000oo000300Go0005
00Go0@05o`001Ol000?o1003o`H01000o`X00`00o`/00?l:003o3`03003o6@800?lJ00H00?lQ003o
:000obP00?lX003o:P00oc82003o>00[003o@@00odP00?i^00WCb00L^>@00>;F00Zgm@03k[X00?nI
003oU@00oiL00?nN003oY`00okL00?o8003og@00b_`06dKf07PEl004MOl02mgi003of000ol800?nZ
003oW@00oi400?n5003oPP00ogH00?me003oKP00ofH00?mQ003oE`00oe@00?m8003oA`00ocl00?lh
003o>@00ocP00?lb003o;@08003o:005003o9P00ob@00?lQ003o7000oa/00`00oaT01000oaL00?lA
003o3`00o`/2003o2P03003o2`00o`X00?l:00X00?l:00<00Ol8003o2P03o`H00P01o`P00`02o`L0
0?l:003o2P06003o2P03003o2`00oa<00?lH00800?lI01@00?lS003o:P00oc/00?mF003`Z00DYNd0
2>??003ej00<Pol0?SoU03a;n`0?_?D01m?^003oY@00ofP00?m0003o:`00oa`00?lI003o30800?l:
00<01?l300Go0005o`000P05o`008`07o`003_l0017o000@o`004_l001?o000@o`003Ol000Oo0007
o`401Ol000Go0P01o`l00?Ek003`FP00oa400_l700?o1004o`@00_l6003o2`00oa400?lR003o9`00
oc<00?m0003oJ003dMT06Z?^00aOo`0I[_h00>SW003i[@00mhL00?m[00Cooooo00?o0000oooooooo
ool01_ooool0027ooooo01So0000oooooooooooooooo003o<P00oc000?lf003oE@00l[000=3D00g`
L@00oc800?lW003o<P00l6D00?mE00_DZ@00hYD00m]e003o7P02o`L01Ol000co000Bo`0B01Co0003
01?o000Do`005?l000@05?l000D04ol001Co000Do`004ol000Ko000500Go000300Go0@04o`801Ol0
00H00?l:00<00?lC003o5`00oaT00P00oaT00`00oa/00?lI003o8003003o:00<003o:P00oc400?lh
003o>000od000?m7003oEP00n8@00?b9003oRP0;lYH00?n90P00ohL06@00ohd00?nD003oXP00okL0
0?o:003og@00l_T00:So03l]l`00__l00?Kn003kk`00a>d00?7?003oW000ohl00?n5003oN@00ogD0
0?m^003oIP00ofD00?mH003oE`00oe000P00odL00`00od<00?li003o>002003o>006003o<`00obh0
0?lX003o:@00obP00?lY1000obP01P00obT00?lX003o:@00obL00?lS003o7@<00?lI00L00?lH003o
5@00oa000?l>003o4@00o`l00?l<00800?l?0P00o``00`00o`X00?l;003o2`0A003o2P0N003o3`00
oaD00?lI003o6@00oa/00?lV003o:`00ocd01n6<00O:``0=lIP00?n@003oY`00ln40497o0039l000
o[800>>j01;0e@0B`=@00?6@003o<P00oah00?lI003o4@00o`/00?l:007o2004o`<01Ol11@05o`02
00Oo00801Ol001`00ol4007g7001oa400Ol;003o3`00mSD06Kbn003dO@00obL00?lA003o2`00o`X0
0?l=003o5@00obD00?ej003fE`00od400?m>003dT`00hl`00?oN02]Wk`0@[_P00?o0003oW`00oeP0
0?m01?ooool00ol0003oooooooooo`06ooooo`008Oooool2o`0000;ooooo01D00?mD003o@@00odD0
0?mH00;Yd`01/^l00?Id003oA@00od<00?mJ016ocP0F`]D02Mji003o?000ob<00?l@007o2005o`40
1Ol000oo000Co`006@0Do`00100?o`004ol001?o0006o`0400Go000300Go0@05o`001?l200<00?l:
0P00o`/00`00o`h00?l?003o5@03003o6@04003o6P00oaT00?lS003o9`@00?lX02000?ld003o>000
ocP00?lo003oA`00odl00?mI003oH`00of/00?m`003oM000ogH00?n1003oQ@00oi000?nW003`d`00
goD04=g^003aoP0DL_l0@`oW030ko`0>Xol009co012_j`00okd00?nM003oSP00ohD00?mg003oM@80
0?mW00@00?mR003oF@00oeL00?mA0`00odL00`00och00?lh003o>002003o>00A003o=`00oc400?l_
003o;P00obX00?l/003o;P00oc800?le003o?`00oc/00?lh003o>@00ocH00?lY003o8@00oa/03000
oaT2003o5`03003o4@00o``00?l:00d00?l:00<00?l=003o3000oa@00P00oaT05`00oa/00?lM003o
:000obX00?lh003oBP00oe/00?mX003oM`0?jZ`00>OU01emo`00oM800?nA003oN@00og<00?Yc003o
C000oc400?lR003o6@00oaH00?l;00<00?l:00<00ol500Co0P05o`400P05o`4300Go000N00Go0P01
o`P00?lN013RQ@00och00?lS003o8P00nT/00=K4003d[@00n5X00?lQ003o6000oaL00?lK003o;000
ocl03M^k003oO`00oed00?mU003oNP00oj@00?kA002Wo@0@/Oh08[[a013Ba`00oeL00?la0oooool2
o`0000Sooooo000Qooooo`0Jo`000?ooooooooooooooo`00ogh00?mF003oE@00of@00?nU012ieP00
ogP00?mU003d]000oid0<ICP03J?h00:jZ`00?lg003o7@00o`l00Ol800Go0@05o`001ol001?o000A
o`0301Co000301?o000Do`005?l000l05?l000@04ol001Co000Do`004_l02005o`0200Co10@00?l:
00<00?l>003o2`00oaT00P00oaT01@00oaX00?lI003o6P00oah00?lR00@00?lX02P00?l]003o=`00
ocP00?li003o?P00odL00?m8003oE@00oeP00?mS003oIP00of/00?me003oMP00oh800?n8003j[001
cO008i?P01mem00RO^l0GbcH0>00]P310il00FKo001no`0=bnh00>o>003oXP00ohh00?n5003oM@00
og@00?mX003oIP00of800?mH003oE`00oe<00?m80P00odL01000od800?lk003o>000ocT8003o>00;
003o>@00od<00?6<003oH@00oe/00^6K00?WT`00ocD00?lY003o9000oa/01`00oaT02@00oad00?lP
003o8000ob000?lR003o7P00oaX00?lH003o4P02003o30X00?l:00<00?l=003o2P00oaT00`00oaT0
5`00oaX00?lP003o:000obT00?lh003o?`00odd00?mM003oK@00oi803[Kb03QPn@00fO400?n<003o
J@00oeP00?m:003o>@00ob/00?lV003o6`00oaT00?lB00@00?l:02D00Ol900;o1`03o`D00ol500Co
1003o`@00_l7003o2P00o`/00?lN003dN@00d/400?me003o@000oeh00;gY003]T000od400?l[003o
8`00ob@00?lZ003oLP0?^K<00?K6003jWP00og/00/o2003o]00;cn@00>;c0126o`1Q=Mh01/C^00gD
c`00n6h00?lb00Cooooo00?o0000ooooooooool01_ooool0027ooooo01Ko0000oooooooooooooooo
003oN`00of`00?m`003oMP00oiL04LgS003h[002j<L0;HK`002cl000l;L00?n:00OWX`00obl00?lI
003o3@00o`/01Ol10`05o`0301?o01<05?l00P0Ao`000`0Do`004ol000Go000500Go000300Go0@05
o`000ol400@00?l:00<00?l>003o4P00oaT01000oaT00`00oaX00?lI003o9003003o:003003o:P00
obT00?l[00<00?lh02@00?lo003oA`00odP00?mA003oE`00oeX00?mU003oI`00ofl00?me003oO000
ohD00?nC003o[P00om400;ol016Hn`0HLol0ERCc00EAo`08]ol00>km00bRo@0OXo@00???003oS`00
ohD00?mg003oM000ofL00?mV003oH`00oeP00?mG003oE@00odX3003oA`03003o?`00oc`00?lh00H0
0?lh00/00?li003o>P00od<00?m=00CXU000h<h07]jk00;<dP00oeL00?lj003o:@02003o:00B003o
9000oad00?lK003o6`00oad00?lR003o9P00obl00?Y7003o<000oc400?YA003kE000obP00?lJ003o
6@00oaD00?l?0P00o`/2003o2P08003o3P00o`X00?l<003o2P00o`d00?l:003o5000oaH2003o6@03
003o6P00oaT00?lJ00800?lX01T00?lY003o>000ocX00?m9003oFP00of/00?n5003T_00CZ>d00?ne
003oPP00of@00?mB003o@P00ocP00?lZ003o:000oa`00?lI003o6000oa800?l=003o2`00o`X00?l;
00H00?l:00`00?l;003o4`00ob<00?>100W:f`00f<D00>j5003lP007c=d00?:;003oB@00ocP2003o
<@0@003o>`00oe400?^M00[0fP00h]X00^c4012Ul`0hOOX098_k00^Go00j@mL02gSo00BXlP00lXl0
0?mH003o@0Cooooo00?o0000ooooooooool01_ooool0027ooooo01?o0000oooooooooooooooo003o
X000n:/00>W:003oX000fMH02/7[003DgP00_N@00?:l00[Nf000of`00?mF00oUMP00ob/00?lH0080
0?l:00P01?l300Go0005o`001Ol000So000=o`005?l001;o00805?l000<04ol001Co000Co`002P0D
o`001`0Co`004_l001Co000Do`002?l000_o0007o`001`05o`001`02o`L00Ol9003o2P00o`X00?l;
003o3`00oaD01@00oaT00`00oa/00?lM003o9@03003o:003003o:P00obP00?l[00<00?lh00D00?li
003o?`00odL00?m7003oC@02003oE`03003oG`00ofH00?mX00800?me01<00?n4003oS@00oj400>cP
01>=kP00moD00>Wn025Wk`0<M_l00>Gn003oj@00o]/00?o1003oZ000oi800?n5003oN`00ogD00?m/
00800?mV00D00?mI003oE`00oeL00?m<003oB@03003oA`04003o@P00ocl00?lh003o>P800?lh00d0
0?li003o?000od<00?m7003oC000oeP00?me02;>d000mkH00?me003oD000ocd00?lc00P00?lX00T0
0?l^003oDP00hjP00?mI013_K00=l;@04>]]003o<@00ob800P00oaT2003o5`07003o2`00oa800?l:
003o4000o`X00?lB003o2P02003o50D00?lI01H00?lJ003o8P00obP00?lX003o;@00ocP00?lj003o
B@00ofD00?f;003oV`0@k/D08W;_003fa@00oid00?mj003oD@00od400?lh003o;000obP00?lT0`00
oaT00`00oaP00?lB003o4@02003o3P03003o4000o`h00?l>00800?lA01h00?lF003o6@00ob@00?m5
003oL005g=P00<WT003/a`00il/00?m[003oDP00odL00?m6003lHP00oe@00?mP003oQP0=fMD0=33g
01ZSn`0CSoL03lWd003oZP00okT04Joh003fa`0>ZnD04;7R003oLP00ofL4ooooo`03o`000?oooooo
oooo00Kooooo000Qooooo`0Ho`000?ooooooooooooooo`01cND00>SV01VLm00?a^d02J7f00cR_P00
ohX00?mk003oKP00mgT00?m8003o?@00oc000?lP003o5`00o``00?l:00;o1@05o`001Ol10P05o`00
1008o`003Ol000ko000Do`0201?o000301Co000Co`005?l000@05?l000@04ol001Co000Co`004ol0
0P0Do`00100=o`004_l001Co0007o`0700Go000300Co0@03o`D00Ol900800?l:00/00?l<003o4`00
oaT00?lI003o6P00oa/00?lJ003o6`00ob400?lT003o9`03003o:004003o:@00obP00?l^003o<`80
0?lh0P00ocT08P00od400?m7003oA`00od/00?mG003oF000oeX00?mV003oJ000ogD00?mg003oP`00
oh`00?nI003n]`00olP00?oD00C=m`0GH_80=cge00bdo`00omh00?o4003o[P00oj000?nD003oQ`00
oh800?mf003oM000ofP00?mV003oG`00oeP2003oE`03003oBP00odP00?m700<00?m700<00?m3003o
@@00od<00P00od<07P00odL00?m9003oEP00ogD00?m/00_ZVP0TX?800?VY003oI@00oe000?m1003o
>@00ocD00?l/003o:@00obP00?lZ003o:@00obd00?lc003o?000oe400=ff007Q^000e]002=6c003o
A000oc000?lW003o7@D00?lI00<00?lD003o6000oa<00P00oaP7003o6@0D003o8@00obL00?lX003o
:@00oc800?lh003o>P00odX00?mW003G`00=bMl00LK`02mEo@0G_Nh06LGV003oQ@00oeP00?m3003o
>@00oc@2003o:003003o9000oa`00?lI00@00?lI02@00?lK003o7000ob<00?lT003o7@00oa`00?lM
003o8`00ob/00?ll003oCP00of/02?:F00?<h@0<i[<00?ml003oJP00of@00]VP00OPc`00ohP00^nQ
00g=f00=]N`074gX00g5k@00oj800>fL003oJ`0:k[000^FY003oQ`00oXD03mZh003Ub00;^=84oooo
o`03o`000?oooooooooo00Kooooo000Qooooo`0Do`000?ooooooooooooooo`0XJ_h075ol05@RlP0k
Fol02N_J003oVP00og@00?mQ003oD`00odL00?lk003o<000obL00?lJ003o5`00o``2003o2P0300Co
0P05o`401Ol000<01Ol000<02ol001;o000<o`000P0Do`00100Ao`005?l001Co000Co`0201Co0004
013o000Do`005?l000ko00805?l000<03Ol000Ko0007o`001`05o`000`04o`<01Ol1007o2003003o
2P06003o5000oa/00?lT003o:P00obP00?lW2@00obP01`00oc400?lb003o>000ocP00?li003o>000
oc/00`00odL07`00od/00?mG003oE`00oe`00?mV003oJ@00ogD00?mh003oQ@00ohd00?nF003oY@00
okP00?o:003nj`0=]Ol084;o003To`00on/00?o7003o/000oj<00?nF003oTP00ohP00?n3003oN000
og800?mX003oI@00oe/00P00oeL00`00oeH00?m:003oA`08003oA`0<003oB@00oeD00?mX00o>d`00
o:l06Mnb02>Cl000oj000?md003oG@00odT00?lm0P00ocP04@00ocH00?lb003o=P00ocH00?li003o
A000odd00?mN003nV@0?gMT00?n4003oFP00ocl00?l`003o:@00obD00?lK00d00?lI0P00oaX05`00
ob<00?lW003o:000obP00?l[003o=P00ocP00?lo003oB@00oe`00?n4006dj000kn800h[n01;6l002
dmX02/CA003cN000odX00?lk003o>000oc000?lY00800?lX00@00?lU003o8`00obD00?lW0P00ob`0
1000oc802nmb007^K@00ob`2003o:00M003o:P00ocH00?m2003oC`00of800?n0003[cP0O^^T00>[L
00?De000ohh00?n`00nHn@02`>P01[[e01Z<o000k]X04j7/003[d`00ohD00?mP003oB`00odl00?m7
003oB000odl00?mj003@c000oeh01?ooool00ol0003oooooooooo`06ooooo`008Oooool04Ol0003o
ooooooooooooool00?K`002io`0IB?l0=5;_01N^n`00l[X00?m`003oG000odX00?m1003o>000obT0
0?lU00800?lI00D00?l<003o2P00o`X00_l700Go0@0600Go000700Ko000Co`003_l000oo000Do`00
4ol000oo000201Co000700co000Do`005?l000So000>o`003ol000Oo000:00Go000;007o2@00o`X0
0?l:003o2P00oa800?lI003o9@00o5/00?9P003o<`00ob`00`00obP2003o:@05003o:000obX00?lY
003o<P00ocL01000ocP09000oc`00?m1003oA`00odL00?m8003oCP00oeL00?mH003oH@00ofH00?m`
003oMP00ogd00?n5003oT000oiL00?nU003o]`0@g=/02<[k002do`0[??L00;;o01V;k`0=l]H00?nh
003oZ@00oj400?nJ003oV@00oj800?nA003oN000ofl00?mV003oH`<00?mG01L00?mE003oC@00odL0
0?m8003oA`00odP00?m7003oB000odL00?m:003oE@00oel00?md003l[P04^_<01moX00JFo000olH0
1/?A003oK`00oe400?m7003o?`03003o>@0?003o>000ocl00?m700;_R000og@00?mk00S>i`0S]N00
0?ma003oD000ocd00?lf003o:@00obP00?lS00800?lJ2P00oaT00`00oa/00?lI003o9@03003o:00A
003o:@00oc400?lh003o>000od800?m9003oF000n7h00?bM003o[00aR>l02m7T003oV000ogX00?mR
003oC000od@00P00ocP0;000ocD00?l^003o:`00obP00?lY003o;P00oU000>=e003oA000oe008K3B
003WP000och00?le003o=P00ocX00?m8003oD@00oeT00?m]003B`P0AfNL0:Fgb02eAo`00h^h00>OO
01VJn@0P?nl08;KL00GZ^@00lk800?n6003n/000i=l00<cB003oO000ocT00?la003o;`00oc<00?m1
003aR`0Q^mh00?mR1?ooool00ol0003oooooooooo`06ooooo`008Oooool04Ol0003ooooooooooooo
ool01NKi03aBm018?o000>Ck012liP0C_mP00?mn003oF`00odX00?lo003o>000obT00?lV00800?lI
00H00?lA003o2`00o`X00Ol900Co1005o`4800Go000900[o000Bo`002ol000_o000Do`004?l000Go
000?o`003_l000`01Ol001@01?l400?o1@00o`X00?l:003o2`00o`d00?lG003o7@00oc801mBX003o
M`00od<00?li003o=000oc800?l`003o;P00oc800?ld003o=@H00?lh0P00ocX0E@00odH00?m7003o
A`00odP00?mB003oE`00oeP00?mS003oJP00ogL00?mo003oQ@00ohd00?nF003oX000ojL00?ng003m
f00<SOl08Tc_0;/4Y00`>ol05WGe01:em@00ol`00?ne003o[@00oj`00?O;00KEiP00jMT00?n>003o
M000ofX00?mV003oHP00oeT00?mH003oE`00oeH00?m@003oB`00odX00?m9003oBP00odP00?m@003o
E`00oeT00?m[00CXa`0@/n/03lWj05E8gP1G6>805:Kk00;5iP0L`jT02Nf2003oCP00odL00?m4003o
@P00od000?m5003oB`00oed00?nG00GBb000nk007:_T003h_`00ogD00?mA003o?`00ocP00?l/003o
:000obL00?lS003o6P00oa/00?lJ003o6@00oaX00`00oaT01@00oaX00?lI003o7@00ob800?lV00@0
0?lX01@00?l^003o>000ocP00?li003oAP00odT00?mG003oH`00ogP00?nN01jfj000mMd00?nQ003o
L@00of000?mB003oA`00od@00?ll003o>@@00?lh01T00?ll003gI@0<[md00?n1003oNP00an@00?RA
003oC000od<00?m2003oC000nY804>io003oKP00oh400=7H002Io`12<nP09e?g01ido`0AY>T03L;[
00BljP00d^D00nn<00800?mP00D00MBb003/V@00oFX00?a`003o:P02003o8P05003o9`00oc@00?mN
00Jhg@00nh`01?ooool00ol0003oooooooooo`06ooooo`008Oooool05Ol0003oooooooooooooool0
8Uko02=0n@05WOl00?g`003oa000oj400?mj003oI000oe000?m3003o>000ob`00?lX003o7000oaT0
0?lG003o2`02003o2P03007o2004o`801?l200/01Ol000<02Ol000Go0005o`003005o`000`05o`80
1Ol100Co0`04003o2P09003o5@00oaT00?lS003o=`00oI008:_H003fJ`00od<00?li00T00?lh00@0
0?li003o>000oc/00?lj1000odL02@00odX00?mE003oE`00oeX00?mU003oM`00mYP00?n@003oU`02
003oX@0H003oY@00ok400?nl003egP0LVO800:3o04TTlP00R?l00>3o003ilP00om000?o2003o_P00
ol/0>8gK00jFn`00oj`00?n;003oN`00og<00?m[003oIP00of@00?mJ1000oeL00`00oeH00?mD003o
DP02003oE`0>003oF000oel00?m^003oU000o[L00?o200>gmP0=Iol03^KL003gb@00j;h00?me003o
E`00od/3003oA`0>003oC000oe`00=Rc0238/P00bNd00]7^002Nn@00l;000?mn003oHP00od@00?li
003o=000obX2003o:00;003o9`00oah00?lP003o6P00oad00?lJ003o6@00oal00?lM003o8P00obL0
0`00obP2003o:@0E003o<@00ocL00?lh003o>@00od400?m7003oC000oeL00?mT003oM@00l;l029?m
01>5o`00g/l00?mg003oI@00oeP00?mB003oBP00odP00?m<00800?m802T00?m5003o@`00odP00?mS
003Ib`0N^]d00>^e01>hg@00ogl00?mK003oDP00oeP04>ND003I^P00n[H00?n9003oUP00olP02]_h
054og@0_N?l00?c]003o_000oih00?Nh003M]`00oVd00?m5003oAP00m9000>:N003o<000ob@00?lK
003o5`00oaT00?lJ003o:`00l9801[kM007:g`04ooooo`03o`000?oooooooooo00Kooooo000Qoooo
o`0Eo`000?ooooooooooooooo`0SHNl0=1gX01IVm@0BM_l00?cK003^/000ohX00NjE003iP`00odX0
0?lm003o<P00obT00?lQ003o6`00oaT00?lB00800?l;0P00o`X200Co0QL01Ol00P05o`400`05o`00
0Ol8003o2P03003o2P0<003o3`00oaP00?lL003o;P00odH00?me00fkg@00ofT00?m?003oB@00odD0
0?m30`00od401`00ocl00?ln003o>`00ocX00?li003o?P00od001000odL05`00odT00?m>003oE`00
oeL00?mO003oIP00oH803MoK003db`0=g=003McT003o^P00okT00?nl003oa000omL00?gg00fko01;
;mD07e3c003Oo`00o_<00?oL00800?oC00`00=7b00mjm@00i^/00?na003oT`00ohL00?mn003oM`00
og800?mY003oI@00oed7003oE`800?mI00d00?mU003oKP00ogh00?n@003m]P0<YOX0<FGb007Ne@00
oi`00?n1003oK@00oe`00?mG00800?mC00l00?mE003oF@00ofD00?j>003k]@02_nX0HAWA03=RkP0=
j=H02[WN003oP000od/00?lm003o>000oc001000obP01P00obL00?lT003o9000obD00?lS003o9`<0
0?lX00D00?lY003o:000obh00?lc003o=`02003o>00n003o>P00od400?m7003oB@00oe@00?mH003o
IP00og<00?VH00WWfP0K[>h00?nV003oO`00og400?mV003oGP00oed00?mQ00OURP00oWL0:L6d003o
G`00oeH00?mK003oJ000oh`00?75003;n000o[@00?n1003oM000oWh00?mf00O]YP03_o401nGI00gV
d00?dm/00l_/00[3n@0P@?l06ggb00W4n00;iL400?mf003oKP00og/00?m0003o<`00obd00?lh003a
C`00oaX00?lB003o2`00o``00?l;003o4000oa/00?ll00ObNP04^]H4ooooo`03o`000?oooooooooo
00Kooooo000Qooooo`0Go`000?ooooooooooooooo`00m=h059kc003]j@04^o<07fG_00SCmP00okD0
0>7M003oS`00ofl00?m8003o>@00obh00?lX003o8P00oaX00?lI003o4`00o`/00`00o`X00`04o`<0
1?l400Go000C00Go00801Ol100<01Ol000?o1@03o`H01000o`X04@00o`/00?lH003o6P00ob<02^]X
003K^P00fLl04/_?003`S`00ofT00?mL003oIP00oed00?mE003oF000oe@00?m;00800?m700<00?m5
003oA`00odL01000odL0:000odT00?m;003oE@00oeL00?mH003oHP00ofL00?n000KD``0L]N`0ESg7
02b`k003g^d00?KM003oc@00om400?oQ003[o@00e?l0>5KX01QEo`00aOl03KCb003MnP00onh00?o`
00:ToP0=XoD00?oA003o/`00oj@00?nP003oV`00lk<00?n?003oN`00ofd00?mV003oH@00oeX5003o
E`0Q003oG000ofH00?mX003oLP00ogl00?nA003o[00>e^406iWl003]dP00oid00?n2003oK`00ofD0
0?mM003oF000oeL00?mK003oI@00og400?n3003b[@00jnP04F__01BMn000c?@00>?I003oTP00oel0
0?m7003o>@00ocP00?l^00`00?lX00<00?l/003o=000ocP00P00oc`0@000och00?m0003oA@00odL0
0?m8003oD@00oeT00?mT003oJP00ogL00?n<003e`@0YQnL00?nd003oTP00ohH00?^<003oSP00ogH0
0?mn00g@h@0=gll00>;?003oMP00ofh00?mi003oS000oi804>fo01nLn002c>`01?2m00KTd00>f^D0
0?Jd003Wf@0<YOT08eSc009_o`0PQ_P098SM041<k@0j8_005HOn00O@k`07g<400?mU003oC`00od00
0?lb003o9P00oad00?lH003o4P00o``00?l:007o2002o`H00ol6007o2@00o`/00?lK003o=P00oh04
ooooo`03o`000?oooooooooo00Kooooo000Qooooo`0Go`000?ooooooooooooooo`04kj`00^S2003f
/00Gf]<0:h[e00mZoP0VR_X00<Kg0037j00?elP00?mY003o@@00ocH00?l^003o:000ob<00?lK003o
6000oa000P00o`/2003o2P0300;o1P05o`801Ol201001Ol000H01Ol100Go0005o`001?l300Go0@02
o`L4003o2P0C003o2`00oa<00?lI003o6@00obD00?lm003eM@00ogL00>Zh00ZHl@00nJP00?mk003a
a@00ohd00?f500g_``0<ghd00?mF003oBP06003oA`04003oB000odX00?m8003oE0800?mG02T00?mI
003oIP00ofL00?mh003oSP00jLd01KOd00FKo00TF_D00?Og003oi000onD00?_e00b:o`00Z_l0;dcd
04PSj@00Pol094go01^>o@00kol00>_o01>8k`00g_/00?oL003oc000o/P04/kM003Wi`0P`=@02[oW
003n/@00ogP00?mX003oIP00of@00?mP003oG@00oeX00?mK003oHP02003oIP0=003oJ`00ogD00?n?
003^_000nlL01]S^03AMf`00nn<01LkI003oT@00ogL00?m[003oIP02003oI@0B003oJ000ogP04>^?
003oUP05i/L09gCb00RjnP0@kkd00?nb00K2fP0Q]>@00>nZ003oC`00od000?lh003o=P00obd00?lY
2000obP0A`00obX00?lb003o>000ocT00?m6003oGP00od/00?m8003oA`00odP00?m<003oD`00oeX0
0?mW003oL000ogD00?n8003oX000o<P04Iol003Vh@02fM`00?bn003Ph@06bmh00?nI00[_Y@00olD0
0=7e003o[`00oi<00?nH003;eP00l<L00?g000FVo018;Ml0AcKT00NomP00YOX0@FcY00>io00KMo80
<f3g01RGn@00nmT00?K:003o^P01^?P00=Kh02Eik`00okh00?n7003oHP00od`00?lk003o;000oad0
0?lF003o2`00o`X00ol600Go0@05o`001Ol100Go0005o`400_l6003o4@00oe804>>Y00Cooooo00?o
0000ooooooooool01_ooool0027ooooo0_l00002ooooo`0D003oJ@00ofd00?mj003oU`00nlh00hSo
01lao000hMX00?nO003oNP00oe/00?m8003o@@00oc`00?li003o;`00obH00?lJ003o6@00oa<5003o
2P0400Go0004o`801Ol100Go0@/01Ol000H01Ol100Go0005o`001?l300Go0003o`D6003o2P0E003o
3P00oaP00?lI003o7000obP00?lb003oAP00oe/00>bL00b`k@0GaN@00?n_0139f005klH04ZkK00nj
bP00og000?mJ003oE@00odd00?m800<00?m700<00?m8003oB`00odP00`00oeL08`00oeP00?mP003o
IP00ofX00?mf003oQ`00oi/00?ni013Ei@0ZVo40:FWo003do@00oOX00=Go01=An00a>OT0:1cf06`8
j@1P2mH0C23Q00j<o`0=Ool0?TCd00i]o`0@V?800<Cm00JMoP05a_/057;n03=Zc009j=H00?n/003o
S@00ogT00?m_00T00?mV01d00?ma003oNP00oi003;KN01bMm@06/Od0G3C/01f@nP0?Z?@00<W?00Kb
T000og@00?m_003oKP00ofl00?mf003oTP0Pb=D00?no003^g@0AS_809YSS003iZ`00ohl00?n<00_b
QP00ofd00?mA003o@`02003o>003003o=P00oc400?lY00800?lZ0P00obP0@000obT00?l/003o<@00
ocL00?lh003o>@00odH00?mY003][P00oed00?mD003oD@00oe@00?mG003oF`00ofL00?VY003oS@00
oh/00?Nm007Dj@0HU?802^oL0137h@0]L?405I;m029^o@09[?D00mGZ022kfP0@a>H0@EWh003Rj`01
[o400>?H02>>n@03aO800=ca0030oP0i7nl0587o00Jan@0?^_@02KOj003m_P00h[l00?WG01o1l000
oJD00?n6007[X00@dK`00?fd013<k@05_ND00?n=003oL000oeL00?m1003o;@00oa`00?l?007o2@04
o`@300Go00802?l000D01_l000Go0002o`/00Me]003o?003ooooo`;o00002?ooool0027ooooo01[o
0000oooooooooooooooo003oE000oeH00?m]003T]@0FbmT09WOf01i^o`01e>/00?nN003oM`00of@0
0?mD003oC`00oeL00?V=003mKP00oc000?lS003o6P00oaT00?lD003o30<00?l:00@00Ol9007o2005
o`001?l30P05o`000`05o`401Ol000Go0@0400Go000700Go0@05o`001Ol100Co0`05o`000Ol800;o
1`05003o2P800?l;01X00?lF003o6@00oaX00?lO003o:000oc000?m0003oE@00og<00?Jk01F@k@0`
Y]P06[7j003Cl`0=dm@00?RU003oKP00of800?mH003oEP00oe800?m?003oB`00odX00?m@003oDP@0
0?mG02H00?mI003oIP00ofH00?m^003oN@00ohL00?nI003oZ`00olH02O7^00Z8o`00/?l049oh002/
o`0?G?l0f0250:d0b`3@09L0f02c0;T2XP138Nl0<D_f00:0o`00h_l03i3o01I/o`0_EoT05YCm012[
o@0MW_`00?^m003oU@00ohL00?mi003oL`00ofL00?mV003oI`@00?mV00h00?mW003oJ`00ogD00?mn
003oS@00okP00;Gh01R>nP17<^l06ZG^003aj`00jM000?nC003oO`800?me01000?mh003jU`0@cMh0
79WW00gEm00ZPO401k7b003a_@00oi800?mo003oL`00ofL00?mH003oB`00odL00?ll0`00ocP0A000
ocD00?lc003o<P00obh00?lb003o=P00ocL00?lh003o>@00oc/00?m5003oC`00nYX00>;4003oN@00
of<00?mM003oF`00of000?mX003oO@00f/T02^K>003o[`00kml0=Tgo003Mi000oj@00?nX003[^P00
mll09ho[00GMj00URNT02j7m02]Bo`11AnT02jGk03Abj@0<VoT0>UWX01j0n`0TP^`0=4W`05LJn00J
RoH03Nc<013][001`lT00?n=003oOP00g=000?Bk00OF``00ofT00?mV003oK`00ogl00?nS002oj`0K
^]403l[;003YYP00oh<00?m8003o8000o`/01?l30P05o`001`0;o`004?l001Co000Bo`005?l000oo
000:o`400P04o`@4ooooo`03o`000?oooooooooo00Kooooo000Qooooo`0Mo`000?oooooooooooooo
o`00od000?m400[_M00?bKl01lWC003nb000lmT0:7kc00?Zc008kKX00?R@003oJP00ofH00>F^00Ro
hP00ofD00?lm003o;P00obL00?lN003o6P00oaL00?l<003o2P00o`/00P00o`X01001o`P00_l700Go
0003o`@200Go000600Co0`05o`001Ol000Co0P05o`001?l30P05o`000`00o`X00_l6003o2P05003o
2P03003o2`00o``00?lD00800?lI01800?lJ003o8`00obP00?lb003o@P00oH006]NZ003c``0VU>L0
K@cX0229o`00olP00?nL003oP`00og400?mV003oG`00oeP9003oE`0V003oF@00of<00?mV003oJ000
ogD00?n2003oTP00ojL00?O:003jf`00fOT067_e002Fo`0^D>l0>TW^04<RjP3/05h0hP2e0=`0Q`37
0>80^`2Z00]Po`00_Ol00?3n003om`00oO400?c_0038n`00jND00?oB00g@i000ojH00?n@003oQ@00
og/00?me003oM000ofd2003oI`0T003oIP00ofL00?mY003oK`00og@00?me003oP`00oi000>g800_M
g@00n^T07f_j01ZEm`00om800?n]003oU`00ohT00?n5003oQ000ohX00?nJ00gbb@00hoP0HRGJ02m0
l`00lnT00?nl003oS`00ogP00?mY003oGP00oeL00?m;003oA`00od<00?lj2000ocP0:`00ocT00?ll
003o@P00odP00?m>003oF`00k:804igg003Og@00nhh00?m]003oJ000of`00?mh00_RaP00enl02L_c
01_0l@0TNOH01=_V003Pb@00ohP00?n0003oQ000kKX03N73003oV`00oJ/00?Nl00_5kP0=aN<00?jl
003j/@00o[L01kc^003cb008i/`01KKd01m`m@00j>H00?jR003oP@00og800P00oel04`03jil00?mQ
003oG`00odl00?m@003oF`00of`00?Ne0039i000oY@00>ff00KM_`03^nL00>FI00[`B@01o`/01Ol1
00Oo000@o`002@0Do`04ooooo`03o`000?oooooooooo00Kooooo000Qooooo`0?o`000?oooooooooo
ooooo`00oc400?ld003o@000oe@00?nF003oOP00oi402mcH01m/nP0=]_P04>VZ00800?n400/01<cR
003Q`P00ofP00?m?003oA000od<00?Q0003o9000oaT00?lE003o2`05003o2P09007o2@00o`X01?l4
00Co0`02o`H01Ol000Co0`02o`L01Ol000<00Ol81P00o`X2003o2`06003o3`00oaH00?lI003o6@00
oaX00?lN0P00obP03`00oc@00?m1003oI@00njT07KGY01:Sm@0WGO@08YWY00KYhP00oj800?n5003o
MP00of`00?mV003oH@06003oE`800?mH02D00?mJ003oH000ofH00?mV003oK`00ogT00?B/003l`000
k]d01;Gl00j6oP0fE?l00k;o003ho@00k_l00=3o00f2lP1J3M40I0OL0883k00A5ol09bok02<elP0I
POl00?Cj003oi@00omL00?oA003oc@00okl00?ne003oZP00oiT00?n>003oQ@00ogh00?mf00800?me
00D00?mc003oK`00og400?mc003oM002003oM@0L003oNP00ohD00?n>003oW@00ojh00?o=003Fo00X
O?@00>Ka003ma`00oj<00?nE003oTP00oi@00?nR003g]`01k=H00<Gl03AHo`0jD_/079gc003Ij@0@
kj000?md003oIP00oe`00?mG003oB`800?m700<00?m0003o>000ocP01000ocP0@@00ocT00?lk003o
@000odP00?mC003oF@00oe`00?mW003oU00hY]404Mc5003oTP00ogh00?mg003oO@00ohT00?nS003i
f`18@=h025?o003Vk@00ojT00?n9003oM@00ofd00?m/003oL@00ofh00?mb003oOP00ojP01kSb003H
j000oYl00?mh003oP@00ohH00?n7003oS000ojH04;GW00KKhP00oiP00?ma003oG000od/00?m8003o
AP00od000?lm003o?P00od<00?m=003oK000klP01lOA003oI000od/00?eT00OXKP07jWP00?m<00;o
1P06o`004?l000805?l000D05Ol001Ko000Mo`008Ol001ko0002023o000302;o0?oooooooooo00;o
oooo00?o0000ooooooooool01_ooool0027ooooo01co0000oooooooooooooooo003o9`00obT00?lc
003o?P00odh00?mP003oRP03`^h0<7SO01:]lP00olD00?Ni003oYP0@aN`00?nX003oOP00n8000NFS
003nY`00l9L00?aA003o8P00oaX00?lB2P00o`X00`01o`P00?l:003o2P0:003o2P04003o3000oa<0
0?lG003o6@800?lJ01D00?lL003o:000obP00?lY003o=`00od400?mE003^X@00c]l00?ng003di`15
E^X02j3o003`bP00oi000?n3003oM@00ofd00?mV003oI000oeh00`00oeT0:000oeL00?mH003oG`00
of400?mV003oI`00ofH00?mc003oNP00nj@04<Sd02J3lP1?BN004J[g00fel000ond00?oZ003nm`0:
VOl06d[o001`o`06J_l0@B;^00Xjo`00Vol09WS^00j8o`00oo400?oM003oc`00ol<00?nn003o/`00
ojP00?nR003oU000ohh00?n5003oQ000ogT9003oM@0Q003oP000ohD00?n>003oV000ojP00>ON003H
o@1F<^l05g7o002in000o[X00?nR003oX@00ojP00?_C00S?l`00i_L0G3Gm012dk`00mnX01Jcl003m
b@00oh/00?ma003oIP00oeX00?mG003oCP00odT00?m7003oAP00od@00?li00800?lk0P00ocX0<@00
ocl00?m5003oA`00oe800?JG003oR000ogL00?mk003oTP0UXm/069[g003m[@00ohh00?n9003oUP00
oKX00?jl01NVk@0UFOT0C53^00OKkP00kl<00?mn003oI`00of800?mO003oGP00oed00?mR003oL006
i/h00>G:00gbU@0@hZ@00?mT003oH000of800?mX003oN`00ojD08;GV003BfP0PZ=T00?jF003oE`00
od<00?li003o=@00oc000P00oc<03@00ocT00?m4013WRP0G`MX0:XgV00?_LP00ocH00?lV003o8000
oal00?lJ00Go0@0?o`000P0Do`001`0Eo`007?l002;o000So`008_l002?o000Ro`000P0So`04oooo
o`03o`000?oooooooooo00Kooooo000Qooooo`0Oo`000?ooooooooooooooo`00oaX00?lT003o:P00
ocP00?m5003oE`00ofd00?Ff003[f@0HS?`03jCl00>Oo`0E`^h02L;i016JkP0JS>T00ZoZ01RCm@00
kj400?Uk003gEP00obL00?lJ003o6000oa400?l:003o2`0A003o2P04003o2`00o`X00?l?003o5@@0
0?lI01@00?lM003o:000obP00?lX003o<000ocP00?m2003oD@06kh<00?n<003oU000`mT00:Ol00jE
o@00o/d00?n/00?L``00oh`00?mi003oK`800?mV00H00?mU003oHP00of400?mO003oI000ofD2003o
IP0T003oI`00of`00?me003oN`00m9T00?na003cf`0U]M/00?oK003oe000omD00?oH003oi@00m_P0
59_o00:_o`05VOl0Ab?T05DKh`00Z_l00=So003ToP00on`00?oH003obP00ol400?nd003o/000oj<0
0?nN003oU000oi000?n6003oQ@00oh<00?mg1@00ogD2003oMP0<003oO`00ohD00?n5003oT000oiL0
0?nW003hd`0ATol086Wo02aWo`00o^/00?o30P00ok<04000ol@04<Sj0320l@0eEN/01L_k00;Ti@00
ol000^cJ012Tg`03jJL00?mc003oIP00oe`00?mG003oD`00odX4003oA`04003oA000odD00?m3003o
A@800?m702d00?m<003oGP00fk`06lKN013?eP00ojT00?nZ00O:j00@d>h00?n_003oWP00oj000=OJ
00jgn@04h>l0:FgZ003KlP00nNX00kc]01GM^P00ogD00?mR003oF000oeL00?mF003oE@00oeH00?mP
00[O[`00ohH00?mP003oG000oe000?mA003oD`00oe`00?me007;g`0AaM400?n600[C_00=`><00?mM
003o>`00obd00`00obP03@00obT00?l/003o?000oe/00>nZ00bne000of800?l_003o6000o`d00Ol8
00Co0P0<o`000P0Do`00100Fo`007ol002?o000Ro`0302?o000302Co000Xo`00;_l000Cooooo00?o
0000ooooooooool01_ooool0027ooooo023o0000oooooooooooooooo003o6000oa/00?lY003o=`00
odP00?mI003oK@00oh/00>WC003SnP0NCnl0CASO00bbn000oKd00?Fk003_e000l;@00>O3003lKP00
od@00?lc003o:000oa/00?lI003o5`00oa800?l:003o2`l00?l:01l00?l<003o2`00oa400?lG003o
6P00oaT00?lJ003o7`00ob@00?lW003o:000obT00?l/003o=P00ocT00?m4003oCP00oeh00?m_003o
P`00oj800?OF0419l000c_@00?[R03BSi@00ojH00?6H003oP000og400?mX00L00?mV02800?mW003o
J000ogD00?me003oO000ohT00?nH003oY`00ok<00?nj003o_`00ol<00?o>003of000onL00?[k003U
o`00aOl04Fgo04Dcg006YOl00>Wo003mnP00onX00?oG003ob@00okd00?nc003oZP00oj<00?nL003o
U000oi<00?n90P00ohD08`00oh@00?mo003oM`00ogT00?mg003oN@00ogh00?n3003oQ@00ohH00?n9
003oU000oiL00?nT003o`@03hNX00>Gk01i^o`0?X_/00?cI003oa`00om@04>SL003;n`1K9OP049?_
003kjP00ok`00?nY003oY000oj800?:Q003oLP00ofH00?mM00800?mG00<00?m?003oB@00odP01`00
odL06@00odT00?mE003oG`00ogl02<OP022FmP0DSn`03k3^00RZn000lN`00?o1003o^P00ol000?;/
03IYn@0dJN/00=_/003o_@00okP02KKe003oS@00ofD00?mI003oD`00odX00P00odP01@00odT00?m=
003oFP00odl00?m800800?m501l00?m4003oA`00oe@00?mg00o?c@00kKh00?mT003oF`00kXT02^AY
003o;P00obL00?lS003o7P00ob400?lS003o:000oc800?mD003hTP09Wo800>2g003o>000oa800Ol8
00Go0009o`004_l001?o000Eo`007ol000D08ol000@09_l002ko000co`00<Ol01?ooool00ol0003o
ooooooooo`06ooooo`008Oooool06ol0003oooooooooooooool00?l?003o6@00obP00?m0003gN`00
og/00?:@003oV004e>H05VOo05<Rg00@J_l06:7[003oX000ohL00?ml003oK000ofH00?m<003o>P00
obl00?lX003o7@02003o6@04003o5`00oa<00?l;003o30/00?l:0`00o`/01`00o`l00?lC003o6@00
oaT00?lJ003o8@00obP00P00obX06@00obT00?l[003o<P00ocL00?lh003o?000odL00?m>003oF000
of`00?RD003``P00nmT03:?n03e0kP0FTO8059ce03^DeP0A]N`00o2X003oN@00og800?mY003oIP00
ofL00`00ofH00`00ofL00?mZ003oL`02003oM@0O003oP000ohH00?nC003oV@00oj800?nY003o/`00
ok`00?o4003od@00on800?oe003ao`00WOl0>3?V07`8ZP0NE_D02/go003joP00oo@00?oV003oc@00
okl00?nc003o[000oj<00?nO003oUP00oi@00?n@003oR@0:003oQ@0K003oR@00oi400?nD003oV`00
oj<00?nb003oaP03k^T0?8;Z03IRf@04kOD00?S/0037o@0jFMT0:G7/00:lo@07U_l00=?Z003o/000
oiT00?n>003oQP00ogP00?m^003oIP00of800?mH00800?mG02000?mB003oBP00odT00?m7003oBP00
odL00?m8003oBP00odh00?mF003oF000of<00?md00oVW000ojh02MGN01c7h00:aoP04G_n003`lP0]
W?400N?f02>Pl`0HGo8097ko007XgP00oiL00?n<003oT000oXD00?mK003oD@800?m700H00?m5003o
@P00od000?m0003o?@00oc`2003o>@0>003o>P00ocP00?ll003oB00:lHh079oS003caP00odh00?lj
003o=000ob`00?lP003o6`00oaX3003o6@0>003o7@00ob`00>b3003n]001^</00?>`00Ce?@00o`h0
1?l200Oo000Co`005?l001Ko000Qo`0402?o000302Go000_o`00<?l000<0<ol01?ooool00ol0003o
ooooooooo`06ooooo`008Oooool06ol0003oooooooooooooool00?l;003o6000oT000?2F01Z]h@0<
[nH03:k]00?Qg`0OR?/0>DO[020mo`02/?l00o3I003oU`00ogX00?mY003oF`00odd00?m0003o>000
obX00?lX003o8@04003o6@800?lA00@00?l:003o2`00o`X00?l;0`00o`X02000o``00?l:003o2`00
o`X00?l>003o2P00oa@00?lG0`00oaT01@00ob800?l[003kC@00odD00?li00800?lh0P00ocT06P00
oc`00?m7003oB000oe800?mI003oJ`0@kiH01[[L02^Zg@0mFn/0IAkM012ik000o^800?kC003e^@00
ohl00?mm003oM@00og<00?m_003oJ@00ofP00?mY003oI`00ofh00?mc0P00ogD07@00ogH00?n2003o
Q@00oi000?nD003oX000oj<00?n^003o]`00olD00?oE003ojP00oO/00>co00Jbo`0@Ood0@Q7_0027
o`00col00>3o01bInP0@Uo800?[L003o`P00okD00?n_003oY000oj<00?nI00800?nD00<00?nB003o
RP00ohL01@00ohD07`00ohH00?n9003oSP00oi800?nD003oUP00oj400?nT003o/P00ol000?oA003n
k`0:WOl07H[f01]TnP0FL>l08Fgj007Nn@00omh04<?^00CZd`00oih00?nA003oQP00ogl00?mf003o
K@00ofH00?mU003oF`00oeP00`00oeL01P00oe800?mA003oD000oe400?mC003oEP800?mG01P00?mK
003oIP00og400?n0003oT@00oj000?ng003oh00@[^l09eGg06L/j`0PD?803gCo02Fjg@0@j>X01<g?
003oRP00ogD00?mY003oG`00oeD00?m8003oAP00od02003o>@<00?lh02400?le003o<000obl00?l`
003o;`00ocD00?lj003oB`0@iXH00?:J003o?@00obT00?lQ003o6`00oaT00?lH003o4`00oa000?lA
003o5000oaD00?lK003o9@00ocd00?]J007H`000oeL00Ol<00Go000?o`005?l001Ko000Oo`00100S
o`000`0Wo`00<ol0037o000403?o00Cooooo00?o0000ooooooooool01_ooool000;ooooo0_l00004
ooooo`03o`000?oooooooooo00;ooooo0_l00003ooooo`Go000000?oooooo`000?l000000ol00004
ooooo`0Lo`000?ooooooooooooooo`00o`X00?lB003o8`01kf004>5d003oNP00oYT00m?V003mbP00
^?@00>Gf041leP0=e^400?Jk003oP`00ofD00?mG003oB000och00?lh003o:`00obP00?lW003o6P@0
0?lI00l00?lE003o3`00oa400?l:003o3000o`X00?l;003o2P00o`l00?l:003o4000o`/00?lB003o
5P00oaP00`00oaT02P00ob800?lZ003o>`0@iI800?mX003oB@00od400?m2003o@`00odD2003oA`0@
003oD000oeL00?mM003oJP00oh00?kb^002lm00;dO@0;F;e003Mo000oll00?nb003oWP00oh/00?n3
003oMP800?me00<00?mc003oM000og<01@00ogD07`00ogd00?n5003oQP00oi000?nD003oVP00oj<0
0?n[003o]@00olL00>cb00bco@00c_l00=Oo0031o`0BIOl0BQWc01Y7n`04T?l04:Cn01YHo`00go`0
0?oP003ob@00okd00?nc003oZ`00oj<00?nQ003oV@00oiD00P00oi@01000oi800?n@003oS`00ohl2
003oT@@00?nD01L00?nE003oWP00oj<00?nY003o]000ol400?o@003oj`00e_l04Y?o007<o@00m_H0
3>3g003od`00okh00?nl003o/P00oiL00?n=003oQ@00ogT00?me003oL002003oIP03003oH@00oeX0
0?mG00L00?mG01X00?mH003oFP00of000?mV003oJ@00ogD00?mn003oS@00oid00?n`00nnm008X_l0
HacY08d0fP02GOl00=Wo003ng`00ok/00?nR003oP000og000?mU003oE`00odd00?m7003o@0<00?lh
01<00?le003o;`00ob`00?lZ003o:000obT00?lX003o:@00obP00?l]003o?000iY`00?mH003o:P00
oah00?lI003o6000oa400?l<00D00?l:00P00?l>003o5P00oa`00?l`003IYP00oTT00_l800[o0080
5?l000<07?l002?o000So`000P0So`000`0Yo`00;_l0037o000503?o00Cooooo00?o0000oooooooo
ool01_ooool00005ooooool0003oooooooooool000002_ooool01Ol0003ooooooooooooooooo0000
00;ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`02ooooo`0Io`000?oooooo
ooooooooo`00o`X00?l=003o6`00obL00?li003oE000nj<03L7P003oT@00oiT00?nm01VMn00HS_80
0<gd003kY000of/00?mH003oB@00och00?lh003o<002003o:003003o8@00oaT00?lI00@00?lI00/0
0?lF003o4`00oa@00?l;003o5@00o`X00?lC003o3`00oaD00?lG003o6004003o6@0:003o7P00obP0
0?l`003oA@00hZD01]Nm003oG000odd00?m<003oC`800?mA01800?mE003oF000oeT00?mS003oJ`00
og`00?nT003o]P00n=/0>f_P002Fo`00oMT00?n^003oW@00ohl00?n5003oOP00ogL8003oM@0M003o
O000oh@00?n5003oQP00oi<00?nD003oW000oj<00?nZ003o/`00olL04mS]03MclP0LC?l05h7_002F
o`107>l0ZP320:@1^P0m<=h07c[o00F:o`00dOl00>Ke003jh@00ol@00?nd003o/@00ojD00P00oj<0
0`00oj400?nJ003oUP03003oU00O003oUP00oiT00?nM003oWP00oi`00?nJ003oW000oj400?nS003o
Y000ok400?nk003obP00omX04=;Y02V5nP0:/?l00?o]003of000ol/00?nm003o/@00ojH00?nL003o
U@00ohL00?n4003oN000ogD00?mb003oJ002003oIP03003oH`00oed00?mI00800?mH01h00?mG003o
F@00oeT00?mP003oI@00ofH00?mW003oJ@00og400?mg003oQ@00oi800?nP003o]@0@g^T0383o024g
o`2P0K/09RKo011mn000fnT00?nc003oV@00oh800?ma003oH`00oeL00?m8003oA@00ocT2003o>003
003o<@00obX00?lX00@00?lX00/00?lW003o9P00obH00?lW003o;000och00?lW003o7`00oaP00?lB
003o3009003o2P09003o3@00oad00>b<007o6@05o`004Ol001Co000Fo`008_l000<08ol000<09?l0
02_o000co`001@0co`000`0lo`3oooooooooo`02ooooo`03o`000?oooooooooo00Kooooo00001Ooo
oooo0000oooooooooooo000000_ooooo00Go0000ooooooooooooooooo`000005ooooo`03o`000?oo
oooooooo00Cooooo01go0000oooooooooooooooo007o2@00o`X00?lE003o8@00obh00?mG01G4h@00
mIh00?ma003oPP05emH06KKf031Kn@00o=h01nfc003oL000oel00?m=003o@P00ocT00?ld003o:@00
obP00?lU003o7P0:003o6@03003o5P00oaT00?lI00800?lI02D00?lJ003o6@00oaT00?lI003o7@00
obL00?lZ003o@`0;j7@00?BO01?2_P00og<00?mV003oL000of`00?RJ003oI@00oed00?mN003oI@00
ofH00?m`003oO000ohh00?nT003oa@0B_n`07Ygh003og`00olH00?nR003oT`00ohH00?n5003oO`00
ogP00?mf00800?me0P00ogH0;000ogL00?mo003oQ000ohD00?n6003oSP00oi@00?nE003oWP00oj<0
0?n[003o]000ol800?oF003nl`00dol005Oo01lio`2=3mD0i01]0;40Y`0K@ol00:;o01ULk`15D>40
<6CU003<nP00om000?nn003o]000ok000?nY003oY000ojD00?nT003oX`00oj000?nO003oX000oj80
0?jb013/b@00oLh00?nX0`00oj<05`00ojD00?n`003o^006jmD00?oP003oj`07coh0DcC>00mho`00
on@00?o<003o_`00ok@00?nY003oXP00oiD00?nA003oQ`00ohD00?mh003oM@00og@00?m]00<00?mV
0P00ofD2003oH@0M003oHP00of@00?mV003oJP00ogX00?mi003oM000ogD00?mf003oP@00ohd00?>h
003o_000ol<00?kX003Oo`0BPOT0>a?k0:/7a`00X?l05[o^003o^P00oj000?nC003oQP00ofd00?mH
003oA`00ocl00P00ocP00`00oc400?lZ003o:002003o:004003o9`00ob<00?lP003o6P800?lK00L0
0?lI003o7@00oa/00?lI003o5P00o`l00?l;00<00?l:00l00Ol900;o1`04o`<01?l300Co0P03o`@0
0ol500;o1`00o`/00?l^00?o100>o`005?l001Go000No`00100So`000`0_o`00<_l0037o000503?o
000303co0?oooooooooo00;ooooo00?o0000ooooooooool01_ooool00005ooooool0003ooooooooo
ool000002?ooool4o`0000Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03oooo
o`;o00000_ooool05P01o`P00?l:003o3`00oaT00?lW003YH@00og000?mF003oF`00ofP00?n<003]
d00F[^`00];W003oX@00ogl00?mk003oJP00odT00?lk003o>000ob/2003o:004003o9000oal00?lI
003o6Ph00?lI01l00?lJ003o7@00obP00?lX003o;`00odX00?2]003Q]000dMd04kOM003oV@03bmT0
0<cA00;Va@00ogP00?m[003oJP00of/00?m_003oMP00oh800?n>003m/`00a?802Z[n03E5n00XYO/0
1MW/003o/000oiP00?n>00800?n500L00?n4003oOP00ogT00?ml003oN`00ogh00?n300800?n500D0
0?n7003oS`00oiD00?nE003oW002003oX`0S003o/000ok@00?o2003oe003g_L05VKo01ajoP00/?l0
:U3k00h`o`0e;?400h3o003=o`00dol00>Ko00?KnP00on<00?o?003o`P00okX00?nd003o/`00ok@0
0?nj003oa@03i/T00?n_003oZ@00oj`00?nb003_fP0=^?000?kC003o^000ok800P00ojh04@00ok<0
0?ng003o`@00k>X0;8_c003[o`0>Wol0<3o_003To@00on800?o:003o^`00ok800?nT003oW@00oi@0
0?nA00800?n500H00?ml003oM@00ogD00?md003oJ`00ofP5003oIP0P003oJ000of/00?m`003jR@00
i=D00?nI003oQ000oh400?n3003oR`00oi`00>oK00R^n@00o^D01kkk00F2o`0e>OD0@3O]03E;kP0P
Ho809;ce003mgP0:bn<03lKT01:TlP0;fK<00?]Z003oA`00ocX00?lh003o<`00obT3003o:005003o
9000oah00?lJ003o6@00oaX00`00oaT00`00oaP00?lE003o4004003o2P0500;o1`03o`D01?l100Go
0005o`401P05o`001`07o`003Ol001Co000Eo`007Ol002?o000Ro`000P0So`000`0Xo`00;_l003;o
000403?o000303Go000oo`00?ol000?ooooo0_l00008ooooo`0000Goooooo`000?ooooooooooo`00
0007ooooo`07o`000?ooooooooooooooool0003oooooo`000003ooooo`03o`000?oooooo000000?o
oooo00?o0000ooooooooool00_ooool06_l0003oooooooooooooool00_l6003o2`00o`d00?lI003o
7`00obX00?le003o?P00odT00?mK003oKP00oh`03l3M02=Pk`0;km400?^_012nj000og`00?mA003o
@`00ocP00?lf0P00obT01@00obP00?lU003o8`00oaT00?lK00800?lJ00<00?lI003o6P00oaT01000
oaT01@00oaX00?lI003o6P00oaX00?lN00800?lX01d00?lY003o=@00och00?mC003oJ000j:/03;_/
01:_mP0BSN/00N3U003oY000ohT00?mn003oN`00ogd00?mn003oPP00ohL00?nC003o[P00c?L07H7c
04a1o`00`ol01YSo013Ri000oj800?nD003oS008003oQ@0m003oQ`00oh/00?nB003oUP00oi/00?nQ
003oX`00oj@00?n[003o]000okL00?o3003oe@00g_H00<[o003Vo`00e_l00;Ko00AJo`0h:N<009Wo
003Ao`00lOl00?ol003ok000om`00?oA003oa@00ol<00?o0003o_P00ol400?oC0038o@0BgNh00?o1
003o^`00ok`00?o8007ImP0TN_d04>[M003ob@00ok`00?nf003o/`00okT00?o200g_d`00jOD0:gW_
006<o`0NB>l04V3o003Lo`00boP00?;D003o_@00ok400?nU003oW@02003oU004003oR000ohD00?n3
003oN0<00?me00d00?ma003oK@00of`00?m^003oL000og800?me003oNP00ogl03O:K002Pm000f]L0
1^nV00800?n@01H00?nI007VbP0?]O@088SW0036o`0/F_d0@DWP00KJo@0@[Nl01kom003Yl@0CX?`0
3hol00flhP00jld05MW>003gV@01j7L00?m4003o>000ocL00?l[0`00obP00`00ob000?lL003o6@05
003o6@03003o4@00o`/00?l<00@00?l:00<01?l300Co0P05o`401@05o`001@06o`002Ol000go000A
o`004ol000805?l000L06ol002;o000So`008ol002;o000So`00<_l000H0<ol000<0=Ol0047o0012
o`001?ooool00ol0003oooooooooo`06ooooo`0000Goooooo`000?ooooooooooo`000007ooooo`07
o`000?ooooooooooooooool0003oooooo`000003ooooo`03o`000?oooooo000000?ooooo00?o0000
ooooooooool00_ooool06ol0003oooooooooooooool00_l7003o2P00o``00?lH003o6P00obD00?lZ
003o=`00odH00?mK003oM`00oi<00?g;00mjo`0PW?H00<Wa00COf001lYD00?m/003oC@00och00?lh
003o;`04003o:005003o9000oa/00?lL003o6@00oa/00`00oaT01@00oa/00?lI003o6@00oaX00?lI
00800?lN0`00obP08@00ob`00?lg003o?P00od`00?mO003oP`0@kjL0=7WR05h`c`00knX00?G6003o
X`00ojP00?nU003Z^`00ohh00?n=003oT`00oi/00?n/003od@00a_T09U3a003kl@00o]P00?nn003o
Y000oiD00?nC003oRP00ohH00?n5003oQP03003oQ@0U003oQ`00ohh00?nD003oV@00ojX00?fe003o
ZP00oj`00?n_003o/`00okD00?no003oa000om800?oR003olP00nol00>3o01Y[lP0S>?d0T`Vn048^
k000_ol00?Co003on@00onX00?oN003odP00oll00?o6003oa000olL00?o>007Lk00TTNh00<Wi003o
f@02003oc006003hh@0KSO80HRS[00F7oP0AcNT00?o90`00ol803P00olX00?gS00BOoP0;Qol09DC^
0=L0Y01c5l`05W;m00jko@00omX00?nm003o/`00oj@00?nO0P00oi@01P00ohd00?n6003oQ@00oh00
0?mh003oMPD00?me02000?mg003oQ@00lj@00?n>003oS`00mjl09hSi0039l`00okP00?nO003oWP00
ojL00?o1003dlP0@XoL0O13800Ueo`0>a?h00?oS003Xi000olX00?o5003YjP0PP_D00?nb003oS@00
ogD00?mP003oD@00ocl00?lh003o<P<00?lX00@00?lP003o7@00oaT00?lJ0P00oaT01000oaL00?lD
003o2`00o`/4003o2P04007o2004o`@01Ol100Go0@@01Ol000D01_l000co000@o`004?l001?o0003
01Co000301Wo000Ro`008ol000808ol000<09?l002_o000]o`001P0co`000`0jo`00?Ol0043o0004
ooooo`03o`000?oooooooooo00Kooooo0002ooooo`;o00002Oooool3o`0000?ooooo0ol00003oooo
o`?o00001Oooool01?l0003oooooooooooooool2003o2P0F003o2`00oaL00?lI003o8@00obT00?lb
003o@P00khT00<cK003<g`00g^D0;CK_02Xmn000in`07[KU00bXl@00g/400?mU003oA000ocT00?lf
003o:`@00?lX0P00obH01000oah00?lO003o7@00oaT2003o7@05003o6P00oah00?lL003o9000obD0
1000obP07000oc400?lh003o?P00od/00?Mo01jibP00e>X07io[02Udo`0WINl00:cn003od@04c^h0
1Z[d003gd`00oj800?nL003oWP00ojD00?na003heP0JZo407HKo003ejP00olL00?nd003oY000oiL2
003oU00S003oT@00ohX00?n8003oQ`00oh/00?n?003oTP00oi@00?nI003oZ@00k]H00?3J003o^@00
okL00?ne003o]`00okh00?o2003ob000om800?oM003ojP00oo`00>co01:Sk`0IFnl0=A_c0024o`00
]?l00>ko003oo@00onl00?oR003of`00om800`00om408P00omh00KCm03/ok`15GnT02]Sj003ogP00
om/00?__002no`0RH?@00>_o003ok000om<00?o;003ob@00ol/00?oB003oh@00o?/00=oo00:Bo`1O
8=40>4G_00ejo`0DQol00/cd003ob@00ok@00?nX003oX`00oiT00?nD003oTP00ohX2003oQ@03003o
P`00og/00?mg00<00?me02400?mj003oQ@00ik804JoY003o^@00lZl00?ni012Yl`0=T?/04>ng003o
/P00ojl00?o1003od`0@f^<01iko07DDi00:POl00?We003oc000ok800?nX003o[000n]006:Oj00KE
d@00ohD00?mZ003oEP00odP00?ll003o=`00ob/00P00obP01000obH00?lM003o6@00oaX3003o6@05
003o3P00o``00?l;003o2P00o`/00P00o`X00`02o`L01?l400Go000500Go000400_o000=o`005?l0
01;o00805?l000<04ol001Co000Ho`001@0So`000`0Vo`00<ol003?o000503?o000403Oo0012o`00
@_l004;o00Cooooo00?o0000ooooooooool01_ooool0027ooooo00Co0000oooooooooooooooo0P00
o`X05`00o`/00?lI003o6@00ob000?lX003o<@00och00?mE003nRP00n<d02kCg035WnP0L[_H00?g4
003oX000miH00?m]003oEP00odL00?li003o>000oc@00?l/00P00?lX00D00?lU003o9`00obH00?lV
003o9`06003o:00N003o;000ocH00?lh003o@000od`00?iZ003oS@00ol800=;S003neP0UTo/0893]
00eeo`0YP>h00=Wj003od@00ok/00?jo003m_@00okH00?nn003ig@0cK?4096Kk0134i000olH00?nd
003oY@00oj000?nF1`00oi@09@00oiD00?nL003oY@0@kk<04;Wi00WKkP00oll00?o8003o``00ol80
0?o3003oa000oll00?oC003oh000ond00?kn003/o`00d?l009co048/o00@ROl00<_o003Oo`00i?l0
0?ch003oj`00on800?oM003oeP00omL00?oM003oi`0;h_h00:Go01mdl000k?h00P00oo@07@0<eOd0
AD;Y00e_o`00ioh00?o[003og@00om800?oA003oe000om`00?o[003ln`03a_l09U3_038YjP00/?l0
0=So00k8o`06d_H00?[C003o^@00ojh00?nS003oX@00oiP00?nD003oT`00ohT00?n600800?n502D0
0?n3003oP000ogl00?n2003oQ@00ohd00?nV0135kP0QPNl00?SW003le`07/O`00<cl003oe000olH0
0?G>00O8l@00hOT03Jkn02LekP0:]_l08HG_01>Mn@00k]P00?nP003oV@00oiX00N[101NYkP0H^><0
0?Bg003oM000oeL00?m7003o>P00oc@00?lY00800?lX00<00?lP003o6@00oaX00P00oaT00`00oaP0
0?l<003o3@05003o2P0300?o1P03o`D01Ol000@01Ol000D01_l000So000Ao`005?l001?o000401Co
000301Go000So`008ol000<08ol000@09?l002[o000]o`00<_l01@0co`00100do`00@?l004;o0012
o`04ooooo`03o`000?oooooooooo00Kooooo000Qooooo`04o`000?ooooooooooooooo`800?l:01@0
0?l?003o6@00oaX00?lO003o:000obh00?li003oB000ofl00>3=003mZ@00f^T07W3o00gLf000ohl0
0?mc003oG`00oeD00?m7003o@`800?lh00H00?lf003o;`00ob/00?lY003o:000obT2003o:003003o
:@00obP00?lX00L00?lX03d00?lY003o;000ocD00?lh003o>@00od800?m7003oF000ofh00>?800[Z
Y000oih00?Zd003idP00a?X0KacJ02]_o00=X_000>kb00nGo@0=lNH00?kF003nfP00o^X06G?l003J
oP00m>P00?o7003o]P00oj/00?nS003oX@00oi`00?nF003oU000oiH00?nE003oV@00oi`00?nQ003o
Y000ojh00?o4003RlP0RP?405j3l00g8lP00omP00?o=003oc000om000?oA003ofP00on@00>ci003B
o`03`_l00<Oo00Umo`1H4Mh01dgo00800:_o04L0@5ce003Wo`00noX00?kb003oi`00on<00?oQ003o
i000oo000?Go00fDo`1@9L`06ggc003/o`00l_l00<ko04I3k`0ZJ_h02;?o003om@00onD00?oQ003o
gP00on800?o]003Mo@00i_l03L?l02E@iP16?n404IWo003go@00onl00?oK003ob`00okl00?nc003o
[`00ojX00?nT003oW000oiH00?nD003oT000oh/00?n9003oQP00ohD00?n6003oQ`00ohX00?nC003o
YP0=bMT03LWa01Mcm`0JRnh068Sn003So@00onT00?oP003jl00DT_`0=4o_02YNl@0=dNl00?WU01Ja
n@00iMT00?nR003oS`02003oR009003oS`00ojP05;_X01^HkP05j:H00?mV003oAP00ocT00?la0080
0?lX00<00?lV003o6P00oaT00P00oaT00`00oaP00?lB003o3005003o2P03007o2@05o`401Ol000D0
1Ol000<02ol001Co000Bo`001@0Do`000`0Io`008?l0027o000402?o000402So000co`00<ol003;o
00D0<ol000@0>Ol003go0011o`00@Ol01?ooool00ol0003oooooooooo`06ooooo`008Oooool01ol0
003oooooooooooooool00?l:003o3000oaD00P00oaT04`00ob@00?lX003o;P00ocT00?m5003oEP00
ofT00?n3003k^00aSM@00>KE003oW000og400?mN003oEP00odP00?m6003o?@00ocT00P00ocP00`00
ocH00?lb003o;P02003o:`03003o:P00obP00?lX00@00?lY00H00?lX003o:@00obP00?l[003o;`00
ocH2003o>00N003o>@00od@00?m7003oD`00oel00?mb003oN`00ohH00?nN00;:h@06[Oh04ZKk0032
oP0JTOl0>f7o05XahP0:UOl05FOl0136mP00e?h02hWo013Zj000omT00?o7003o_@00ok800?nX003o
Y000oj<00?nR0P00oj403@00oj<00?nU003o[@00ojl00?nb003o^@00oll02ICm05Dbi`00]Ol00?Gl
003oiP00omP00P00om<08@00om/00?oQ003ojP05i?`04E__02iCm000XOl007oo03DNlP0I9Ol05VCi
01i>k`0:OOl00;?o0066o`00d?l00?of003ok`00onh00?o`003omP00mol03Z[o01UUo`06D_l01kGo
003?o`00M?l0C3CO003:o`00k?l00?ok003ol002003ojP0I003ol000no`01I[o01>1o`0@W^l0@1K^
00Ifo`00eOl00?Wl003ojP00omX00?o>003o``00ol000?nk003o_P00nl@00?jg003oXP00oi`00?nI
003oV000oiD00?nC003oS`02003oT00P003oU000oiP00?nU003o^@00oM<00?S`01;Go@0PP?P0;8Ga
00C2o`0LS?l00=Oo025No`1R=N8077ko013UfP00okl00?nl013D``00ohd00?n3003oN`00ogL00?ml
003mV@00h=800?j]003Mf`0@kXP00?m5003o>@00ob/2003o:003003o8@00oa/00?lI00800?lI00<0
0?lG003o2P00o`X01000o`X00`03o`D01Ol000Go0@0500Go000300ko000?o`005?l000D05?l000<0
5ol001[o000Ro`001@0So`000`0To`00;?l003?o000503?o000303Oo0012o`00@_l00080@_l01?oo
ool00ol0003oooooooooo`06ooooo`008Oooool01_l0003oooooooooooooool00?l:003o4P800?lI
01@00?lN003o:000obT00?lc003o>P00odD00?m?003oG`00nXT04>?4006DnP0TW>001<GR003oOP00
of400?mG003oCP00odL00?m6003o?@H00?lh00`00?lg003o=P00ocH00?lf003o=@00ocH00?ld003o
<P00oc<00?l`003o<`00ocL4003o>00M003o?@00odL00?m7003oE000oeP00?mU003oKP00ogT00?RM
0276a`00mMd03<O[003oc`00on400;oo01VDn000^?l08Eko04Aog00LQo`078[k003hn`00on000?o=
003o``00okT00?nb003o[P00ojD00P00oj@03P00ojP00?n]003o_`00dn`00?o7003o_`00olD00?oE
003hn@0NMOd018ko003coP00onl00?oR0`00on40E@00onL00?oa003eoP00b?l07V;j0195o`08;Ol0
]P2Q0=80OP1T3o@0;B?_01h]o`0h9^`086oY003Vo`00oOl00?og003ol`00ooL00?on003fo`00h_l0
09Wo05HPc`0IKOl009_o03/Yk`0<IOl00=Co003_o`00o_l00?oh003ol@00ooD00?Wm002Po`0<T?l0
4dGo02=6oP0j5_l00X7o006Oo`0G]?d00?o`003oh000om800?o=003ob`00old00?kS01VRlP06j]P0
0?nb003oY`00ojT00?jc003o]000ojH00?nH003oU000oiD00?nF003oX@00ojP00?nc003oa000omP0
0?o_003?o`0j?>`075O_03<gk`0XGN`0;U?R0037o`00Wol00?CI003o[`00oih00?n@003oP`00ogP0
0?md003oKP00of`00P00ofl01P00ofd03nn<003[QP00od400?lg003o:P800?lX00L00?lO003o6P00
oaT00?lI003o6000o`l00?l>00@00?l:00<00?l900;o1`05o`401P05o`000`0Co`005?l001?o0005
01Co00808ol000<08Ol002?o000So`000P0So`000`0Uo`00<_l003?o000203;o00@0<ol000<0=?l0
03oo0012o`000P12o`04ooooo`03o`000?oooooooooo00Kooooo000Qooooo`08o`000?oooooooooo
ooooo`00oa<00?lI003o6P00oah2003o:00C003o:`00ocL00?lk003oAP00odh00?mL003oN000hn80
8HCg00Bbn005an<00>jP003oIP00oeT00?mE003oBP00odL00?m6003o@`02003o?@800?lj00P00?lh
003o>@00ocP00?li003o>P00oc/00?ll003o>PP00?lh04400?ll003o@`00odL00?m9003oD`00oeL0
0?mR003oI`00og<00?mn003oSP00o;400>nn003o[007klT07<3I00gHl@00o^400>GY003ok@00noX0
<7Cj011oo`0?fOT00?oN003od`00olP00?nm003o]P00ok<00?n`003o/@00ok<00?nl00K[i`0@XoH0
0?WY003og000omD00?oO003bn00^KO80DC[f00eno`00lO`00?o`003oi`00onD00?o[003ol000o_X0
0kOo04mMa@0H=ol0;3k^04TIl`3O07X0j`1_04`>i@0;Lol009Go00VQo`00aOl00>Oo003ho`03003o
o`0<003jo`00lOl00>Go0037o`00V_l06C_o02laoP0HIOl00;go003Jo`00kol00?Wo0P00ool0>`00
o_l00>ko00JTo`0HJNl05U3o0:/1W@3?09@0?RG_01Pik`00_Ol00?Kl003ojP00omh00?oG003of000
mNd0=Gk_02>9oP00om`00?nn003o^`00ol801lk[01O<j000okT00?nT003oX000oil00?nR003oY000
ojl00?ng003oa000omD00?7b01N@o`00L?l0ZP710<<0W00O>O800<Co003jn`00on@00?o7003oZ000
oiD00?n8003oO000ogD00?mY003oIP00of@00?mO003oF`00oeL00?mF003oCP00ocd00?ld00800?lX
00<00?lU003o6@00oaT00P00oaT00`00oaP00?l;003o2P04003o2P0300Co0`05o`001Ol100@01Ol0
00@01_l000go000>o`004ol01P0Do`000`0No`008ol002?o000402?o000302Go000bo`00<ol000L0
<ol000@0=Ol003co0011o`00@_l01?ooool00ol0003oooooooooo`06ooooo`008Oooool01?l0003o
ooooooooooooool2003o6@0E003o8`00obP00?lX003o;000ocL00?li003o@P00odL00?mC003oG@00
og400?nO003bg@0K[O@00?nX003oP000ofX00?mQ003oE`00oeD00?m=00H00?m700/00?m9003oAP00
od@00?m5003oBP00odh00?mC003oC@00od000?lj003o>@02003o>00Q003o>@00ocP00?ll003o@P00
odL00?m8003oBP00oe@00?mG003oG@00ofL00?m/003oM@00oh000?n:003oUP00oi`00?nV003o[P00
ok/00?no003ob000om@00?k[01B8oP1<?M/00=So003knP06_?d00?WX003ofP00olX00?nm00800?ne
03000?nl003oaP00kn@048c_02EZlP00hO`00?o[003okP00l?h026_o04Hkh`0JSO`00=ko003onP00
oo400?o`003ol@00ooD00?_o00k0o`0@M^l008_o002Bo`0h??D0>`ok06L7j00G=?L008co002[o`00
a?l00=So003Uo`00l?l00??o003go`00m_l00?3o003[o`00gol00<_o002co`0GJol0<33d002Uo`00
aol00=_o003Wo`00kol2003co`0J003_o`00iol00=?o002io`00O_l0@1Co0:02e00]>O`09EGo03de
lP0@XNl00?[i003oj`00on<00?oW003hnP0IOoh04g[i00cRl`00om400?oC00n]m`0@P_h00?GZ003o
^`00ojd2003oY00T003oY@00ojh00?nf003o``00oll00?oJ003hm@0HMOd0:c3n0844gP3?0:D0=RSj
01=Tn`00l?L00?oF003o_@00ojX00?nH003oQP00ogH00?m]003oI`00of800?mH003oE`00oe@00?m8
003oA`00ocl00?lh003o<000obT00?lX003o9000oa/00?lJ0P00oaT00`00oa@00?l=003o2`04003o
2P0300;o1`05o`001Ol000@01Ol000<03Ol001Co000Do`001@0Do`001@0Go`008_l002;o000Qo`00
8_l000D08ol000<0:_l0037o000ao`001@0co`000`0ho`00@_l004;o000204;o00Cooooo00?o0000
ooooooooool01_ooool0027ooooo02co0000oooooooooooooooo003o8000obL00?lh003o=000ocD0
0?lh003o>P00od800?m:003oDP00oeX00?mU003oMP00ohh02>7O01ZDiP00lKX00?n4003oLP00ofX0
0?mT003oGP00oeT00?mC003oDP00odl00?m>003oD`00ofh00?en003oEP00oe800?mC003oI@0=l:/0
3MNh003oJ`00odX00?m6003o@P800?lm00<00?lo003o@`00odD00`00odL06`00odh00?mG003oE`00
oeX00?mV003oJ000og@00?mg003oPP00ohL00?nC003oV000oj400?nX003o/P00ok`00?o8003of`02
jOT08F?o02Q@n003^_l09gWk00J[o`0CU?l04N?X003obP02003o`P1<003oa000olh00??]006:o`0Y
B?D03JCo00c?o`00mOl00>Oo025cl@0jAN<02L?o003/o`00o?l00?om003on000oo/00?on003go`00
i_l00=7o002oo`00Z_l008Oo00dmo`1T1?801Dgo00eio000Xol00<Go003Do`00h?l00>Ko003Zo`00
jol00>Oo003Po`00gOl00=Ko0037o`01Ool034oo03lUlP0>M?l00;_o003@o`00f_l00=oo003Uo`00
gol00Loo003Ho`00c?l00j;o00MFo`195^L03SGo00:7o`00/_l00;oo003Xo`00o_h00?od003ol000
ooH00mWo04]:g@0JK_L00?Kk003ok003j_D03JCo031FlP0:Zo/00?k=003o]`800?nb01`00?nc003o
^P00ol/04lg/003mj000on/00?3k002go`00Qol0=1;o0<40^02<1ll00XSo01K=m000on@00?kI003a
eP00n[d00?jJ003oN000of/00?mT003oF000oeL00?mB003oB@00odL00?m00P00ocP01@00ob`00?lX
003o:000ob@00?lJ00<00?lI00<00?lB003o2`00o`X00`00o`X01002o`H01Ol000Go0@05o`4400Go
000300So000@o`005?l000D05?l000<05ol002;o000So`001P0So`000`0ao`00<ol003?o000203?o
000503;o000co`00<ol003?o000ko`001012o`04ooooo`03o`000?oooooooooo00Kooooo000Qoooo
o`0Zo`000?ooooooooooooooo`00ob/00?U>003]R`00odX00?m2003o@`00odH00?m>003oK`00ofP0
0?m[003oM000ohL00?nJ003oa@00]oX00?nd003oU000oh<00?ml003oM`00og<00?m[003oI@00oed0
0?mH003oG@00ofL00>nh01KO[000og000?mR003oL000n:P07L3E003oQ000of400?mC2@00odL01@00
odd00?mE003oE`00oeL00?mO00800?mV01h00?mb003oM@00ogX00?n5003oR000oi@00?nH003oXP00
ojX00?nd003oaP00on401^_l002oo`0W:Ol0R`o802EFn`0=X?800=km003oi`00omD00?o>003oc@00
om400?oG003oj@00n?d02HGo04<AiP07U?l2003;o`0G02=GlP0iANl04:K_003Xo`00l_l00?[o003o
o`00o?l00?Ko003`o`00i?l00=Co0036o`00T_l07C_m01Pco`1m0?`0<1go03/SiP00S_l00;So003<
o`00d_l00P00f?l00`00fol00<?o02:6o`020034o`0G002ho`0WHO<0<Q7o08l3``0V=>l00h[o002l
o`00`?l049ch0038o`0VQMT009[o0032o`00_?l01Hko04HKlP3>0:H0=aSi00AYo`00_Ol00=Oo003[
o`00m_l00P00ool03000nOl00=ko00Z0o`0=L_l00>Go003[o`0]L^d0=4O_00KBo`00noD00?oD003o
`@800?nl01h00?nn003oa`00omh07HK_002fo`00mol00MOo002fo`0/;^l0BaW_0:H4e`0/:O/0;C__
01fXlP00foh09GWO01f?lP0@]Nl00=W2003oN@00ofH00?mO003oE`00oeD00?m9003oA`00od@00?li
003o>000ocH3003o:003003o8@00oaT00?lI00800?lI00<00?l>003o2P00o`/00`00o`X00`01o`P0
1Ol100Go000400Go000300co000Do`005?l000804ol0100Do`000`0Ho`007_l0027o000602?o0003
033o000co`00<ol000L0<ol000@0>_l003go000oo`00@_l01?ooool00ol0003oooooooooo`06oooo
o`008Oooool2o`0000;ooooo02X00?ll003oG`0=al`00?mh003oDP00oe000?mE003oI`0>cLl00?nI
003oP000oih00?O?003Qg00P]nD07kCc00Bhl`00n=P02mc8003oU@01jkH04>6`00?N^@00oY@00?m[
003oI`00ofP00?mh01?0h@0HXo400?bK003oN`00o9X05i_S00bFmP00mIl00?mX003oF000oe400?m8
003oA`00odP2003oA`04003oB000odT00?m=003oE@800?mG08400?mH003oI000ofH00?mW003oL@00
ogD00?mf003oQ@00ohH00?nA003oU000oil00?nT003o/`00olP00[Gj03ALlP0KLNl0W`^a08P8fP0D
L_l00=go003mn`00on`00?oO003of000omL00?oI003oh000on/00?kj00RYo`08Ool0=RgP00eCo`01
Uol0?C7`006Bo`00bol00>7o003]o`00l?l00?7o003`o`00k_l00>Go003Lo`00d?l00<Co002Wo`05
Col0J0G]0><0OP1m2<d07ago02Xdj@01W_l00<7o0035o`00/_l00Z3o0030o`00T_l0@2_P00V9o`00
/?l00:[o002;o`0<@_l0H`Of001Yo`00V?l00:_o00B?o`1;<NH009Oo02m9lP03H_l00:Oo002Yo`00
Tol01d_o07d2b`0H=ol054Wo002ho`00dOl00>7o003[o`00l?l00??o003/o`00gOl048O_034ek@00
`?l08H3c044do00dDO`01=Sm003oj@00omD00?o;003oa000olD00?o:003Yi@00fOX00;oo01Q`mP00
dol00Hgo03`^l`0k>^l0093o00YKo`0>Ro/00;Wo0167o`0MO_H04m7[003geP00ojX00?n;003oL`00
ofL00?mL003oE`00oe400P00odL01@00od400?lh003o>000ocD00?l/00800?lX00<00?lS003o6P00
oaT00P00oaT00`00oa400?l<003o2P03003o2P0300Co1004o`<01Ol100@01Ol000<02_l001Co000D
o`001@0Do`000`0Fo`008ol002?o000702?o000302Co000]o`00;ol000L0<ol000@0>?l0043o0012
o`00@_l00oooool2o`0000Sooooo000Qooooo`0bo`000?ooooooooooooooo`00ofP00?mc02Jjb000
oh000?mU003oG`00ofX02=Jj003Lh`00nK/00?nZ00GGf00OR?d06ike003?f`00okh02/?X02Y[n`00
f>d00>_>003od`08^?D04[SZ003oUP00og`00?mc003oM`00ohD00>_301:Fk@00mkT00?nK003]d00R
Pod00=kN00cHc000og000?mM003oE`00oeD00?m?003oC000odX00?m=003oC`00oe@3003oE`1?003o
F000oel00?mV003oIP00ofT00?md003oM@00ogL00?n5003oQP00oi400?nD003oW@00oj@00?na003o
_P00omX00=;m01APo`0@No@09T;i02M?mP03X?l00?Ko003om`00ond00?oV003oi000on800?oV003o
l000ooX00>co003>o`0WO?d0:dge01Pfk`0=Gol00;7o003<o`00f?l00>7o003Vo`00jOl00>Ko003J
o`08^Ol00<_o0037o`00_Ol00:Co015?o000A_l0FPCc02LGm000IOl008Co002Ro`00/ol00;;o0123
o`0m=>X009Oo011ik`0_7>T01G[o002Mo`00VOl0163o00L_o`1W1=h03Boo001fo`00Tol008Ko05@K
j@00Col0=Ako00EIo`02002Bo`0G01aJo@0<<?l0L@gS001Zo`00Tol00;3o0030o`03]?l00=Ko003E
o`00c_l00=_o003Ao`00]Ol0:4Ka00mAo`0`=>`048[n003Jo`00m?`00?oY003of`00om800P00om40
6000omD00?Wa00]eo`0jHM/0>4W/01QQk`0VCoH0FAk[00>;o`00fol02Goo00[Po000oOP00>?n029[
l`00nNT00?ng003oV000oh400?mc003oIP00oe/00?mG003oCP800?m700D00?lo003o>000ocP00?lg
003o:P02003o:003003o9@00oa/00?lI00800?lI00<00?lA003o2P00o`X00`00o`X00`05o`401Ol0
00Go000400Go000300Ko000<o`004Ol000D05?l000<05Ol0027o000So`001P0So`000`0To`00<?l0
03?o000703?o000303Go0012o`00@_l00080@_l01?ooool00ol0003oooooooooo`06ooooo`008Ooo
ool0:ol0003oooooooooooooool01lcR00SUa004e>@00?n@003oN`00oH<00?n;003f]00MVod04KS]
01RDn`0[ROP01ZSb00OYbP00oi@00?n@003i]00F`mX07j?W02b4nP0WJoD058Sm003ob`00oil00?nB
003oSP00ohd00?nC003k]@0HZO@02=SW00?Sf`0cS^/06[[K003oX000ohX00?m`003oI000oeT01`00
oeL01000oeP00?mJ003oG000of@2003oIP05003oI`00ofl00?me003oM@00og/00P00ohD0N000oi<0
0?nE003oW`00oj@00?nb003o^`00om401L3k003Qo`00dOl00fGo06@Cj000Q_l00=[o016Zo`00j?h0
0>Kl00KRnP00oo<00?ob003on000o_l00?3o003Oo`00b_l00;3o011To`0T@Nl00:3o0031o`00col0
0=Go003Fo`00dol00=;o002_o`0DF?d009oo002eo`00/_l00:;o002:o`03G?l0IPSN04H=n`01FOl0
07go002Eo`00Wol009co005`o`184o004U;o00A>o`1T2LX025co0026o`00Pol073gb0504n03C0:h0
;`Wb010mo`00Mol0077o0056o`143Ol0?Aog001Vo`00NOl0073o02/Qi`2K0JT0E@OV01l^o@00POl0
09go00F1o`0j@>@00:[o02EBo`05Sol00<Go002ao`0?L?l0=bSl002Ho`00]ol00=Oo003co`00oo/0
0?o^003oh`00omh00?oK003og`00onH00?oe003[o`00a?l094CY0;D0W`0g8N/00:Oo003>o`00oO/0
0??_003og`00omd00?kY00fdoP0ZINH01MkR003e^`00oh/00?md003oIP00oe/00?mG003oCP800?m7
00D00?lo003o>000ocP00?lg003o;002003o:003003o9P00oad00?lJ00800?lI00<00?lD003o3000
o`X00`00o`X01002o`H01Ol100Go0005o`4300Go000301?o000Do`005?l000H05?l000<06?l001oo
000So`001@0So`000`0Vo`00<ol003?o000703?o000503Go0010o`00@_l004;o0011o`001?ooool0
0ol0003oooooooooo`06ooooo`008Oooool0;?l0003oooooooooooooool00?nE00;OfP00f>@00?jb
003oZ@00bnT00?[C01NZk00JKol082;o00SEl@08j;h00?6a003oQ000ogP00?mg003oP000oi<00?fj
013Wg018<^X0:F?o01Bbm@00n]801M[R00C8i`00okP00?nY003o^`00on<00iko00f[n`00hMh00>o4
003oT@00ogl00?md003oI`00ofH00?mN0P00oeX3003oF@08003oH000of800?mV003oIP00ofL00?mV
003oI`00ofh3003oM@0c003oP000ohD00?n;003oU000oiP00?nR003oYP00ok<00?nm003ob000omh0
0?oa003go`00`ol02Fko040Zk000X_l06EK_00:Fo`0e>?l00=Co003ko`00ool00?go003fo`00k?l0
0=ko003;o`00Xol05dkk05`@k@0_<_l08GS_002mo`00a?l03JSf01Qio@00/ol00XSo060?iP0?K?80
0:3o002Ro`00U_l00F[o01hen@0g3Ol0H@?^01/Mo`0=>Ol01VGo008008_o04H007So00dco`1d2lL0
91K_03lGm`00HOl0073o001/o`00DOl05Q_o0:h0/@1H2NX0047o001Ao`02??l003Oo0682iP0H7_`0
04co009?o`00D?l01Rco07X1k`0/1ol0@AoX001Uo`00QOl04fOj02TKm`05Gol0>QKa002<o`00Yol0
17;o06PBc@1<7nH00:7o003?o`00iol00?Ko003oo`00oo<00?o^003ok000onl00>Oh003io000n?l0
4<C_002[o`0;A?l0^03:07DLf@00[ol00=ko003mm000omT00?o=003ob000olh00MK/013>m`0GHol0
98[b003Vb`00oh800?mY003oG@00oeL00?m>0P00odL01@00od800?lj003o>000ocP00?la00<00?lX
00D00?lQ003o6P00oaT00?lI003o5005003o2PL01Ol000<03_l001Co000Do`001@0Do`000`0Io`00
8ol002?o000702?o000402Oo000[o`00;ol003;o00L0<ol000<0=ol003co0011o`001?ooool00ol0
003oooooooooo`06ooooo`008Oooool0:ol0003oooooooooooooool00?nS0035k`0XIo<00<oj00gL
i`08R?d06W?g01J`m009iMd00<3d013Gh`00oj800?mg003oK000ofL00?mZ003oL000ohD00?c:00[=
m`04Y?`02/ke029[n@0VTO`02HWn003En`00om001_3I003;l`02`O/06h;o003oe`00okP00?nO003o
SP00oh000?me003oK@00ofL00P00ofH01P00of@00?mS003oIP00ofH00?mX003oKP800?m_0P00ofh0
P000og800?me003oM@00ogD00?ml003oQ@00ohH00?nB003oU`00oj400?nU003o/@00okD00?o1003o
b@00omL00?oZ003eo`00dol049cb03PVi@158O`0>b[S02m9k`0@T?X00=Wo003^o`00m?l00?3o003[
o`00fol00=?o0035o`05V?l0@BOV08@5_000B?l048C`002Zo`00[ol03GSb05<Gk`00Pol007So06D=
i005Bol008ko002Bo`00R_l0063o03h;k`2K0MD0j@1i06H0k`1=1Mh0:c_^001fo`00O?l0073o001K
o`0A9_80D`7^000[o`00Col005Oo00<no`00<ol03AGo08/0m00b0OL001_o04T7oP1=0_l01@co0;80
b`0Y2?l0@`S_04D8n`0;6ol03Q7o0:40fP0l2n8004Co001Po`00K_l005go03LBk`0j3o<03TCo0021
o`00Q_l06TS_05h;k006E_l02H_o003=o`00h?l00>oo003io`00ool00?ol00;Yo`00lOl04YSe00F`
o`00gol02hWo04@^k0126nl074oo011Mo`07GOl0<V?_0138l`00om400?o1003o^`00okT00?nl003o
c00;WoL00?[C003Og@00oiX00?m[003oGP00oeL00?mC0P00odL01P00odH00?lk003o>@00ocP00?lf
003o;P<00?lX00H00?lK003o6@00oaT00?lI003o3P00o`/3003o2P04007o2004o`801Ol000Go0@<0
1Ol000@02?l000oo000@o`004?l0100Do`000`0Ho`008ol002?o000702?o000302Co000`o`00<ol0
00P0<ol000<0>ol004;o0012o`001?ooool00ol0003oooooooooo`06ooooo`008Oooool0;Ol0003o
ooooooooooooool00>7U02aom@0o9O808V_g00f4oP0C/>@049o]003o[`00oi/07<CH00KO^`00lJ/0
0?mW003oGP00oe/00?mO003oI000nXl00joT00CMc`01a^L00?Vl003nd`00c?X0OQZd01aWo`00`_/0
0;_m03I]n@0PDO/03mKl003oe@00ok000?nM003oT000ohD00?mk003oM@00og000?m]003oJP02003o
J`06003oK000og400?mn003mV000nJL00?mh0`00ogD0O@00ogH00?mg003oNP00oh@00?n5003oS@00
oiT00?bd003o/P00ok<00?ng003o_`00ol<00?o>003of000oo000j7o03MMkP05Ool0K`o80>X0SP0M
;_l009_o002mo`00e?l00>;o003Uo`00hol00=3o006=o`00^Ol00;Ko002Po`00N?l0C1?`00Hno`00
Nol009Ko002Ko`00Pol0EAK@02T_k`00C_l0H0OY001Ho`00OOl008;o001io`07?Ol08`oo05h1k`31
0;/0@@G/000Yo`00DOl006Go001Zo`00H?l0053o00XUo`2L0=00BPGa000^o`0k6?l0BPcE0286k`0B
1Ol0]P2g09l0g`0L0Ol0D03o08d0fP1=0?l0[03j05h0o`1/0?H0J`3l0102o`1R0O/0S`3]00@?o`00
:ol04S;o00T_o`00?_l0C@cW03TEh`00DOl006Oo00Y=o`1J1>P0LPZo00EZo`00Y?l00;Oo0030o`00
h_l00>_o003bo`00lOl00:Oo01Ull00`JOl0193o00ZVo`0=J?l0FA[_0196o`00_ol00<?o02AOo@00
lO`00?oQ003oa@00okP00?nb003oZ`00ojX00?n_003g]000oiP00?nC003fR@00of/00?mO00800?mG
00T00?m8003oB@00odL00?m3003o>`00ocT00?lh003o=@00ob`00P00obP01P00ob@00?lJ003o6@00
oaT00?lA003o2`<00?l:00<01?l300Go0005o`001005o`000`0Co`005?l001Co000601Co000301Ko
000Mo`008Ol000H08ol000<0:ol003?o000co`00200co`000`0oo`00@_l004;o0004ooooo`03o`00
0?oooooooooo00Kooooo000Qooooo`0;o`000?ooooooooooooooo`0jLOH04<Wa00JBo`1K:?h00<cf
003o/000k[D00P00og`0;@0@_/<00?mf003oHP00oeT00?mD003oE@00oeL00?mH003oI`00ogL00?VF
00ST/000oiD00?Jo01:Yn`08WOd06hgn01YUo`19:ND0WP;N04/Rc`01Tol01Lcf003o_P00oj<00?nG
003oS@00oh@00?mk003oM`00ogD00?mg003oOP00ogl00?mi003oP@00oid00=g^003nZ`00ohT00?n1
003oN000ogL00?mi003oO`02003oQ@1i003oR000oi<00?nT00_9i000omT00?o;003oc000olX00?o=
003od@00omh00?o_003]o`00Vol06bOo04lFd`1^0nl033go0029o`0@ZNl00<Oo003Bo`00c_l00;Wo
002ho`0i<>d028Ko002Qo`00U_l06DWn04HAg00o2_d0C2;_00mJo`00Q_l007_o00M7o`1A1_D0C`cX
03PBk`00Eol006oo001`o`00K?l005Go004ao`0Z0Ol0^@3Z04X1m0008_l004Ko001Bo`00COl05BCo
000^o`067?l0N03I05T1mP0C2?l08`7o09d0f@0c0?l0=03o09P0k`2b0</0I`3o09/0h`3Q0;@0i02f
0?00TP3Z0:80j@2W0:/0o@1g0?h0Y@3P0:l0aP0O0_l02`Go0742iP1[0^d010go06`1j00i1Oh0:QWd
03PFo`039?l0T@3=01DEo`0:C?l008oo02QHn000U?l00<3o012Zo@00gol00>3o0034o`0>L_l0@Rcn
001No`0OA?l0EAK_012>o`00U_l00>Oo003[o`0/MO406Hk_003oeP00okd00?nb003oY@00oj<00?nO
003oV@00oi800?n7003oO@00ogD00?mW003oH@02003oE`07003oE000odP00?m7003oA`00od@00?lm
003o>P02003o>004003o<000obT00?lX003o8@800?lI00<00?lD003o2`00o`X00P00o`X00`02o`L0
1?l200Go0@0400Go000400ko000Co`004_l001?o00D05?l000<07_l002?o000So`001P0So`001@0X
o`00<ol003?o000`o`00<Ol000H0<ol000<0>_l004;o000oo`001?ooool00ol0003oooooooooo`06
ooooo`008Oooool04Ol0003oooooooooooooool00=kC003oZ@00j/l08icj003nb`00oi<00?mf003o
I000oel00?mV003oD`00odd00?m800800?m701L00?m9003oC`00oeP00?mM003oJ000og000?mk003o
TP00n;`00?7=003og@00i_h037;o07l5^@1L5_/00X?o01>NoP00mmT00?nk00C_a`00ojD00?nI003o
R`02003oQ@0:003oS@0BdlH00?6b003oT000oiT00mGI012An`00m<<00?nE003oR@@00?n507`00?n7
003oRP00oi<00?nH003o[`01c>T03ioi00ZNo000gOD00?oM003of000omh00?oS003om007col0773V
002Ko`00QOl03C_o06H:h`177?d05U3h002Yo`00^Ol03i3l01LmlP00ROl0;bWg00ANo`00R_l007oo
01Xco`1h1=H0W02Z00DRo`00Dol006_o001Uo`00DOl03bGo04D0o`079Ol004go001Io`00F?l00D3o
0014o`00;Ol0HP7/0<X0[@1k0?@050Wo000[o`0j5Nl08aGl0684c00]0o8020Oo08/0o`3I0:h0E03o
0640k`2]0=H0Y03a0<d0_P2o0?<0l02d0<T0m@3e09l0o`0i0?l0103o00D0o`020?l0203l04D0dP3X
0>D0/P1b0?/0>`3i03H0o`2B0>H0LP3d03D0o`2P0>00PP3o0680kP2@0=h0E`7n07T0c00<7Ol00d[o
00ERo`11:NL03F?b02lenP0@P?l00<So003:o`00^?l009go01Pgo02j0;<0FPkc00=co`00aol00>[o
003moP00ooH00>oa003WlP00olh00?ne003oZ`00oj<00?nL003oU000oi800?n7003oPP00ogD00?ma
003oIP00of@00?mH0P00oeL00`00oe400?m:003oA`02003oA`08003oA000od000?lm003o?@00ocX0
0?l`003o9`00oah2003o6@06003o3P00o`X00?l:003o2P01o`T01Ol10P05o`001P05o`401Ol000Go
0006o`003ol001?o00H05?l000<08?l002?o000So`000P0So`000`0Ro`008ol002?o000302?o0003
02_o000bo`00<ol000P0<ol000<0>Ol0ooooooooool00_ooool00ol0003oooooooooo`06ooooo`00
8Oooool04ol0003oooooooooooooool00?mf003oP@00ojh05[_`01Jni@00lk/00?Eh003oF000odX0
0?m7003oA@00od400?m2003o@000od<00P00odL0JP00od/00?mE003oF`00ofD00?m`003oO`00oi<0
0?nU003kc@0AU_P0=TWb0:42i00T9?403Xoo007FoP00l>l00?oP00VdoP00m>402[S/003oYP00oi<0
0?nE003oXP0@_n003KkR003o/@00ok`00>C`01MdoP0:dO000?ZZ003oT`00ohd00?n7003oQP00ohP0
0?n=003oT`00oiH00?nQ003o/@00oML00Y[o02INm@00k_h00?kb003ok000onT00?o^003on@00mOl0
0=_o003:o`0>P_l0:BG[0:82_P0[6Nl006go002Ho`00X_l008oo01@bk`0m6ol0AQ?b001Do`00K_l0
06Ko001;o`123OH0/`3=02PCn`00?_l01c[o020To`00=?l08@o_0:/0e`0S1_l0037o020Pm`00:ol0
K`?]00DHo`006ol05P;o09T0a@1[0?l070;o000>o`0D0_l0X@3D09`0e@140?H0<03n05P0o`3S0;L0
Y@3a0=/0d@3]0;L0o`1E0?l0;`3o05h0o`1g0?l0PP3o02h50?l0000c0?l0:03o09@0dP3h0:h0n@34
0>00U@3j0;l0`02m0=L0a`3K0=80i03Z0;H0m`200?T0E@3M0;L0JP3m04H0n`1H0_@00B3o03X=lP0h
7?l06EGo002Ko`00/?l00:Wo01QBo`00KOl07BWo0=`0X`1o2[P02gSo00Yio`00e_l00?oe003oiP00
omL00?o<003o`000ok<00?nV003oX@00oiD00?nD003oR@00ohD00?mj003oM@00og400?mW003oIP00
of000?mH00<00?mG00h00?mC003oD000oe400?mA003oC`00odd00?mC003_Q`00oeP00?lb003o:000
oa/00?lI003o4`@00?l:00<00ol500Go0P05o`000`05o`00100:o`005?l001Co000Do`0201?o00<0
5?l000@05_l001So000No`008_l01P0So`000`0Wo`00<ol003?o000203?o000303;o000co`00<ol0
00@0<ol000<0@Ol0ooooooooool00_ooool00ol0003oooooooooo`06ooooo`008Oooool04Ol0003o
ooooooooooooool00?mQ003oLP03eLd00=c:003hW`0;_O400?^B003oC@00od800?lk003o>@00ocP0
0?li00800?lh01L00?lk003oA000odP00?m<003oE`00of000?m/003oO@00ohl00?nQ003o_@00fO80
7GSo08/;c@1^5Ll08Roo01iRo00QM_l00=Oo01F4k`0BU_T00??W003o/@02003oXP0=003o/000mn@0
<GGl003ofP00n>D096;o00C9m`00olD00?nY003oV@00oiD00?nC003oTP02003oU00n003oU`00oil0
0?n[003o^000ol`00>Sg01ajm`0YGO005ZGg003ln`00ooH00?og003oo`00l_l00>?o003<o`00/?l0
85CO00hdo`1X0]l004[o00eUlP00OOl008?o001To`0?;Ol0A@WU000oo`0:A?l072Ko00@So`0A3?l0
S@3Z01T5o`014ol0M@;[0641o@022ol0A0?]0:P0iP120Oh00Pgo07X0h00/0_l0Y`3I00l3o`031ol0
K03Q0=80`P3O0:`0S@3i0240o`0G0?l0@@3o0;d0cP1b0?l0T`3S0;X0g03L0><0mP2Y0?d0PP3o00P2
0?l000030?l00@3o02<0o`0D00H0o`0000/0o`0D0?l0Y@3i08`0h`3M0?D0Z02b0?l0h03[0?D0W`3k
08T0o`0X0?l08P020?l0000S0?T0RP3V0=H0d@3708h0j01h0>00AQ3/001Go`00N_l008oo002Fo`0B
Mol0?1We04TEi`1C2?H092Wl01e2nP0Y<_l03Xko003Vo`00onh00?oO003od@00ol@00?nk003o/`00
oj@00?nQ003oU@00oi800?n8003oQ@00ogP00?me003oL`00ofL00P00ofH04`00of400?mJ003oF@00
oeP00?mG003oGP00of<00?ad00G_W000ofL00?m[003ca000of`00?m9003o<000ob@00?lI003o5`00
o`/00`00o`X00`03o`D01Ol000Go000400Go000300_o000?o`004_l000H05?l000<07Ol002?o000S
o`001P0So`001@0Uo`00<_l003?o000^o`00<Ol000L0<ol000<0??l0ooooooooool00_ooool00ol0
003oooooooooo`06ooooo`008Oooool03?l0003oooooooooooooool00?m@003iLP09e><00?nC003o
HP00ofl00>2I003o@`800?lh0P00ocH0:000ocL00?lh003o>000ocP00?lj003oA000odL00?mD003o
G`00og400?n4003oY000ok800?o8003?k`0<Jol00:Wo01Ebm@0@end06iS_03U<lP1C:ND0;d;c003Z
o000omh00?o2003o^`00okT00?nn003ofP0[S_P00=kl016Em00YTOl00<We003o_@00ojP00?nQ003o
V@00oi@2003oU@0n003oV`00oj@00?jm003o_000ol@00?oC003ok@0@R?l0:TGl003>o`00l?l00?co
003mo`00mOl00>[o003Eo`00aol00;Co002Co`00F_l0BA7O06`5g`143_h005ko001[o`00DOl00S;o
07h1k@0L4?`0?@K^0702iP0N0_l0BP7a0=L0/01^0?80703o06H0o`1j0>L08`3o0580o`3T09`0H03o
01P0o`0f0?l0[@3^07H0oP0N0?l0603o04l0o`2_0>T0f02n05d0o`0d0?l0E@3_06<0o`2k0>D0e`36
0<80n03h0:40oP1f0?l0?P3o014<0?l000090?l05@3o0200o`2S0?l0W`3n09L0n`2h0?l0Z@3o04`0
o`0O00@0o`0001/0o`0M0?l0;03o02H0n`160</0_01:0oH03b_o00EOo`0SEOl0;D7X01I;o`0n3o40
[`2X000mo`00R?l009go01<jo`0WKNl00>[o003okP00om/00?oA003o``00okd00?nc003oZ000oj40
0P00oi@00`00ohL00?n5003oO002003oM@04003oKP00ofT00?mV003oIP800?mT01400?mS003oI@00
of`01mZg003`/P0?^=T00?n?007Kc`09dMX01]?D003W^@00k6400?lX003o6P00oaP00?lA003o2`02
003o2P03007o2004o`@01Ol100@01Ol000D01ol001?o000Do`005?l001?o000401Co000301oo000S
o`008ol000808_l01P0So`001@0To`00<?l003?o000co`00<_l000H0<ol01?ooool00ol0003ooooo
ooooo`06ooooo`008Oooool04ol0003oooooooooooooool00?m2003oD009j:`00?mX003oA000od40
0?lo003o=@00obl00?l/003o:P00obT00?l[003o;`00ocD00P00ocP08000ocd00?m7003oD@00of80
0?JR003n/@09/nd00/?_01>SnP0GUNh00<kf0139lP0@gNh00?kO003lj@08d_d0Ob3:048boP0IMO80
0LGk00OAl`0C_o@01N_S003oeP00onH02Mom01aYlP0CV_l00?Kc003oeP00ok`00?n^0P00oj<0?P00
oj000?nO003oX@00oj<00?nb01W0j@00lN/00>WZ003oj000ooD00]?o04Lcm`0KJ_l00>7o003_o`00
k_l00>[o003?o`0FL_l00:?o002Wo`00TOl0:3Sc07T2l@3A0:@04aCo0015o`0;=ol0APo^00P;o`2B
0=H0K@3f04/0lP2Q0>D0C`3o05d0o`3M0<D0Q@3k0:/0h`2H0?l0]03<0<80dP2?0>l0h`3:07H0l027
0=<0G03o0=H0^P1Z0?H0?`3o04`0o`1A0?l0]`3/0?80U0250?l0O`3b0;00k02g0>T0_@3^0?`0T@3m
0980o`0M403o00001`3o0140o`0U0?l0@@3o06D0o`1J0?l05`3o00L0203o00007@3o0080o00k09D0
f00j1O/003[o008Xo`1_0^T0L`_N05DBh`08;Ol0ASO?002Ho`00__l00;So02U[jP04]Ol00?oa003o
g@00om400?o8003o`P00okP00?n_003oX`00oiX00?nD003oR`00ohD00?n100<00?me01H00?m/003o
J000ofL00?mV003oI`00ofT00?m_003oO000lZd04L_R0038k@0?Z>h03:G^003nV000og<00?mD003o
>`00obP00?lK003o6@00oa@00?l<0`00o`X00`04o`<01Ol000Go000300Go000500So000Do`004ol0
01;o000Co`000P0Do`001P0Co`005?l001Ko000Ho`006ol002;o00L08ol000@0:?l003?o000co`00
<Ol01`0co`04ooooo`03o`000?oooooooooo00Kooooo000Qooooo`;o00000_ooool01`00oc800?ll
003kM@00ocd00?l`003o;000obX01000obP0=P00obT00?lX003o:000obX00?l^003o=`00ocT00?m6
003oE`00ofl00>o:01NKm`0KZn<01=GM003bfP0JX?L00?_D003o^P00ok400?ng00Kbe@00^_d03i;o
00S3oP0NGOl096Ob03aLj`0;T_l00?Gk007Nn00<Z_h05XWb02J=k`00no/00?oV003oc`00ol000?ne
003o[`00ojT00?nV003oY000ojL00?n_003o^`00nnD08W3h02i`o@06__l00<oo003Ao`0HBOl009Oo
003Ao`800=go02d00<ko002lo`0^?oh0<4?b002:o`00Pol04TOo00`Vo`230M<0U03N00LBo`0N1ol0
QP3O06D0l02/0?<0g02n0>P0Y`3^0;`0f@3H0<L0lP3/0;H0j`3>0?D0T03g07l0nP1G0?H0T`3X0=X0
n`2G0<`0hP3Y0<<0]03m0?80/P2E0?l0^`3L0<T0d@1o0?l0_03Q0?P0Q`3:0=l0V`3o0>P0eP3]0<@0
m`2a0?l0I`3o00P04P3o0000103o0040o`040?l03P3o00490?l0000P0?l00`3o0180o`0T0:`0i@1@
0NH0@`Gi08`0eP2e0:X0G0cg00YPo`00Ool06W7j002ko`00dOl00=co003Yo`00n_l00?ob003oh`00
omT00?oC003oc@00ol/00?g;003o/@00oj800?nE003oT000ohL00?n5003oOP00ogH2003oM@0E003o
LP00og400?m`003oL`00ogP00?mo003oRP00ojD00?CO06<YiP04Z_L00?jb003oKP00odl00?lo003o
=000obP00?lO003o6@00oaP00?l>00<00?l:00<00Ol900?o1005o`001@05o`00100=o`005?l001Co
000Co`0501Co000402;o000So`008_l002;o00808ol000L08_l002?o000So`009?l002co000[o`00
<?l00080<ol000<0<Ol003?o000co`000P0co`03ooooo`;o00002?ooool0027ooooo00Co0000oooo
oooooooooooo0`00obP01@00obL00?lU003o9000ob800?lS00800?lQ00<00?lT003o:000obP00`00
obP08`00obd00?lh003o@000og<00?c000o8c@00im@00?n@003oT@00kkP01hcl003]cP00oj000?nJ
003oX006dMh00>GT00Ffo000omT00?oS003QoP1B=n40>dC[00Mao`00TOl0<2ko03H[j00@Y>l00=3n
003ojP00om@00?o7003o`000okT00?nd00<00?nc01d00?ng003o`P00oM/01Kcn01ZBmP0m9nH0<C[_
05=;iP0U<ol009So002ko`00aol00<Go01YQk`07HOl01eSo04lHk@00Jol006ko001Io`00>Ol040go
09@0jP260>d0>P3o0:P0k`3f09<0oP100?l05P020?l000050?l0;`3o07@0o`2/0?l0>@3o00<00`3o
00004@3o02`0o`0[0?l0;`3o0400o`2W0?`0T@3T0=00i@3]0>00cP2h0>l0d`3o0?l0JP3Z0>P0i@3M
0?T0a@3o05D0o`0b0200o`0001@0o`020?l0>03o09<0h`3K0=@0aP390=00Q03E07@2jP016_l0;aKV
001jo`00WOl00;;o0035o`00eol00>Oo003do`00ool00?o`003oj`800?oT00P00?C_00?6n@0?/?X0
0>gR003oZ`00oih00?nD003oSP800?n501D00?n0003oN000ogD00?mg003oM@00ogH00?ml003oS@00
l=000?nb003id00_MOD04i;j006Nn@03fm000?ma003oC000ocT00?lb003o:000ob<00P00oaT00`00
oaD00?l=003o2`02003o2P0300?o1@04o`<01Ol100@01Ol000<04ol001Co000Bo`001P0Do`000`0L
o`007_l001ko000802?o000502Ko000co`00<ol0033o000bo`00100co`04ooooo`03o`000?oooooo
oooo00Kooooo000Qooooo`04o`000?ooooooooooooooo`800?lK00<00?lI003o6P00oaT01000oaT0
1@00oaX00?lI003o6`00ob000?lU00800?lX03L00?lY003o<P00ocT00?m7003_KP00oG<00?mV003o
K000og/00?jj002jn`00m;/00?n@003oRP00ohd00?nK003oY000l/@00?ne003obP00^OL079Kb00RK
o`0cF?l0<2Oo0;h0]@2/0id0>3ka00F0o`06e_`00?oU003oe`00om@00?o8003oa`00ol<00?nm003o
_P00ol800?o7003oe`00onl02]co01VIk`01W?l018Wo011Yn`0]<Ml0@TcD0068o`00[?l03ggo02hH
k`1?5Nh09ASo008005;o00P0<A_l00TAo`052Ol0Y03H0>80/@2J0>P0k@2S0?l03`D0o`0000<0o`0>
0?l0603o0100203o0000303o00T0o`0f0?l0E@3o06L0o@2o0?d0U@3k0?40o`1P0?l0Z`3o0;80o`1H
0?l07b40o`0001<0o`0D0?l0>03m0:L0b03V07H0k@1?0?l02@Wo004To`00Aol02dco001mo`00W_l0
0:oo0032o`00e_l00>Ko003bo`00o_l00?oj00800?ob00X00?kh00C6o`0e?nh04:Wj003oc000ok40
0?nS003oW@00oi@00?n>0P00ohD05@00oh<00?mo003oO@00ogl00?n2003oR`00ok000<cY003ai`00
aOP03JCb003db000l;l00/OQ003oK`00odX00?lh003o<@00obT00?lX003o7002003o6@03003o4`00
o``00?l:00800?l:00<01?l300Go0@05o`000`05o`000`07o`002_l001Co000801Co0004023o000S
o`008?l002;o00H08ol000<0;Ol002Wo000ao`000P0co`000`0bo`00<ol003;o0004ooooo`03o`00
0?oooooooooo00Kooooo000Qooooo`04o`000?ooooooooooooooo`P00?lI00<00?lJ003o6@00oaT0
0P00oaT04000oal00?lS003o:000obP00?lZ003o=@00ocT00?m2003oB@00oe400?mK003oLP05flX0
7Hgl00;N]@00oh42003oO@0b003oQ000ohd00?nG003oX@00ojl00?o9003jjP00lOd00;?o01E;n@2?
0MH0U`:`021KiP00SOl00=_o003om`00noD06J7`003oj000eo000=S`003oc@00olH00?o9003od000
omP00?oW003onP00l_l00>7o003;o`00ROl0?1[]04HHf`00L_l008Oo0022o`00Gol02BGo0784j004
9_l0?@o^03X5o`1O0?P05@3o04@0o`2T0?l0nP2X0?h0NP3o00HC0?l000080?l03P3o0500o`1S0?l0
W`3o0500o`1Z0?l0C03o010R0?l0000Q0?l0<03o0;00m@340>h0aP1g0?005`3o008;o`009ol0057o
001^o`00QOl009Co002Go`0;Ool00;7o003Qo`00kOl00?Go003no`00ool00?co003>o`06T?l08VK_
0035nP00oll00?nk003o/000ojT00?nR003oUP00oi400?n800@00?n501800?n9003oV@00j=l00;Gl
04QLg@0ZH>l00>SE003oV`00ohH00?n3003mL000odX00?li003o>000ob/00?lX003o9000oaX2003o
6@06003o5000o`/00?l:003o2P01o`T01?l31@05o`000`0=o`005?l001;o000201Co000301?o000D
o`005?l000805?l00P0Ko`001P0Po`008ol002?o000Ro`008ol002;o00<08ol000@09ol003?o000c
o`00<Ol00`0co`04ooooo`03o`000?oooooooooo00Kooooo000Qooooo`0<o`000?oooooooooooooo
o`00o`h00?l=003o3000oa000?lA003o4P00oa<00?lH1000oaT01000oaX00?lI003o7@00ob<2003o
:00S003o:@00oc@00?lh003o?@00odH00?m@003oK@00ilh04=^X003gR@00og800?ma003oM000ogD0
0?n2003oR`00oiL00?nX003o_000oll04=[e03ARh`0Z;?l0g@2F07P3g`04G_l00j3o003Go`00j_l0
0>Ko01ENo`00aol046Cd003Hn000om/00P00om806P00omD00?oQ003ojP00ooT00?Wo003Yo`00dol0
0;3o01ELoP0g7NL0G13g01/_o@00Hol04CWo010MnP2B0=40?`G`02D1o`2d0<P0HP3o04X0o`2]0=<0
V`3o0>40i@3o0;40o`0L5@3o00000`3o01L0o`0K0?l09P020?l042<0o`000280o`0b0?l0R03E0?T0
X`3m06h0o`0_0?l0NP3/04<:nP00B_l006So001ho`00Nol01T;o06dHk`00/?l00=Co003No`00k?l0
0?;o003co`00k?l009[o030Rk`01S_l00?cc003ofP00ol/00?c?003od@0?emD00?Jl003oV000oi<0
0?n=0P00ohT04000ohl00?nE003oW`00okh00>__03m8j`0]G?@00=OY003oT@00ogH00?mW003oF@00
odL00?lm003o>000oc02003o:005003o8P00oa`00?lI003o6@00oa<00`00o`X00`02o`H01?l300Go
000300Go000300Oo0009o`003ol000T05?l000<08_l0023o000Po`001`0So`001P0Zo`009ol003;o
000co`00<_l003?o00Cooooo00?o0000ooooooooool01_ooool0027ooooo00Co0000oooooooooooo
oooo0P00o`X02000o`/00?l:003o2P00o`/00?l:003o3000oa800?lC1@00oaT03000oah00?lQ003o
:000obP00?lZ003o=000ocP00?ll003oA`00kFX00?mm003oM`800?mU03@00?mW003oJ@00og400?mi
003oR000oiT00?n[003o_`00om@00?oa0030o`0PAO`0MPoM09H9]00k:N`0Ab[`02Q6n003Qol02ZGo
03Y<f00:MOl03K[l003jo@00onT00?oS003oi000onL00?o^003om000ood00?Go003So`00b?l00;Go
002Co`0P9Od0R`C803d?l0096ol0MP?b0301o`2S0=D0RP3j0880mP2_0=@0cP2]09H0m@3X0<H0gP3`
0?`0Z@3o05D0o`0V?@3o00008@3o02T0o`2Y0>H0m@360?D0Z03^09X0k`2E0>h0@@Gb05@Bn`04C_l0
063o00Q;o`1M1nL02e_o002Po`00T_l05hGb003Eo`00hol00>Go003Go`0:POl0CcSm0034o`00no/0
0?o_003klP0=R_h03H_b00?GkP00okd00?nS003oU`03003oU00I003oU@00oid00?bj003dg@0VV_X0
8XSX003eiP0<aN000?n6003oK`00of<00?mG003oBP00odH00?lk003o>@00ocH00?l]003o:@00obP0
0?lT003o7`00oaT00?lC003o2`02003o2P0300;o1@05o`401Ol000@01Ol000<04Ol001?o000Ao`00
2@0Do`00100Qo`007ol002?o000Ro`0602?o000402oo000]o`00<_l003?o00Cooooo00?o0000oooo
ooooool01_ooool0027ooooo00Co0000oooooooooooooooo2000o`X01000o`/00?l:003o5000oaD2
003o6@04003o6P00oaT00?lN003o90800?lX02X00?lZ003o=000ocP00?ll003oA`00od`00?mC003o
E`00oeP00?mM003oI@00ofP00?mg003oR`0:kK`00?kA003Al@00i?L00>_n02Aeo`0LHnl02iKo02QD
i`00]Ol028Wo03@Vm`1<8>l0IaOG04/VfP00Y_l00=ko003fo`00oo/00?kh003nn@00e?d00=go003k
o`00n?l00>co003?o`0DBo/20027o`0A001Qo`0H9_l0WP3a0600m`2m0=D0h`310>80h`3]09H0kP2h
0>H0e03f0:/0gP3C0?D0`P3o05h0o`2M0?l0?P3o00<0?@3o0000@P3o02/0o`1J0?l0NP3o07h0g@33
08d0k`1c0>D0I`3o00`=o`00>ol004Co00TUo`1J4O/005Wo00Y7o`1A3o<048;m0036o`00d_l00=Co
0038o`00Rol0<d3_0036o`00h?l03K?o035Wk`0GFNl0:fO_003UgP00okL00?nW003oXP00oil00?nI
003oW@00oj800?nX003de00JQ_X0@UKa003il000okX00?nQ003oP`00og000?mU003oF@00oe@00?m:
003oA`00od@00?m0003o?P00ocP00?le003o=`00od<00?lT003o6P00oa@00?l;003o2P01o`T01?l3
00Go0PH01Ol000<04_l001?o000Bo`00200Do`00100Ho`007_l0027o000Ro`0602?o000302Go000b
o`00:ol000Cooooo00?o0000ooooooooool01_ooool0027ooooo00Oo0000oooooooooooooooo00Co
0P02o`H00Ol900<00?l:0P00o`/01@00o`X00?l<003o2P00oa000?lG00@00?lI00D00?lP003o9`00
obP00?lX003o:`02003o>004003o?@00odL00?m7003oC@800?mG03800?mL003oI`00ogP00?nP0139
h@13NNl0;V[_00fKo@0>S_l049Wd003Mo`0@]o406[K/003_o`00e_l04:Wk005Xo`2X1Z`0J`gO01]/
o`00Xol00<7o003[o`0EV_@00<co00e/o`02X?l00>[o003[o`00g_l00<Go00]Zo`0o8nP006Oo0112
oP0_2ol0D@3o0=@0^P3m03T0o`000?l06@3o00P0o`0?0?l0DP3o06<0o`1Y0?l0T@3o03<0o`0d0?l0
0Ch0o`000280o`0W0?l0M03l0=@0f03e0980oP1@0?l09`3o00h0o`004Ol00Qoo03lAk`0e1o80EP;i
0785f01R2MH0063o002Fo`00^Ol00<?o002jo`00/Ol008_o01/oo`04Pol0853b01e0o`0i;nl03/?o
003Yn`00l]h00?nj003o/@00ojP00?nT0P00oj<06P00ojL00?nc00Wbe`09/_h0:Uo[00REm`00ojl0
0?nA003oO`00og@00?mW003oH`00oeT00?mH003oD`00oeT00?mH003mL000odh00?m7003cK`00hJ<0
0?ld003o9@00oaX00?lC0P00o`X00`01o`P01Ol000Co0P0500Go000400[o0008o`005?l0017o0080
4ol01`0Do`00100Ko`007Ol002;o000Ro`0602?o000302Go0?oooooooooo00;ooooo00?o0000oooo
ooooool01_ooool0027ooooo00So0000oooooooooooooooo00Go0@05o`001?l200Go0@@00?l:00<0
0?l;003o2P00o``00P00o``3003o6@03003o6P00oaT00?lU00800?lX03000?lY003o<000ocP00?lh
003o?P00odH00?m8003oB`00oeH00?mG003oHP00mgl06<_A01KIg009dnT00?S>003nfP00b_`04ZOo
003ok`00on/00?oW003ok`00n_d00=ko006Ho`1K5^80EagN044Aj`0g:>d087c]0036o`00U_l09ESZ
00/go`00^Ol00=Oo003Io`00aol0853o02=8o`194?h01c3o028?o`270?l0Z`3S0>X0``3o02P40?l0
00030?l00@3o00@0o`080080o`0@@03o00004@3o01H0o`1Z0?l0]03I0>/0ZP3h09/0a@0e0?l06@3o
0241o`0_0_h0]P2X07X1k00:8?l0133o001Io`00P_l009ko00800:_o00h06fGh01UJo`167/@07eO_
02iBk`0QC?800:oo0220m@00m?/00?oW003od000ol000?ne003o/`<00?na01/00?ne003o_`00lN40
5hCo012nn@00jMh00?n/003oTP00oh@00?mh003oL`00of`00?mX003oHP00of@00?:S007UY`00hl@0
0?m^003oLP00oI802MZW00KbHP00odd00?lX003o6@00o`h00P00o`X00`01o`P01Ol100Go000600Go
000600co0007o`004ol000ko000Co`005?l00P0Co`0401Co000301Go000Io`008Ol000L08ol01?oo
ool00ol0003oooooooooo`06ooooo`008Oooool01?l0003oooooooooooooool200Go00801Ol100<0
1?l200Co0`00o`X01@00o`X00`00o`d00?lC003o6@02003o6@800?lJ0`00obP01@00ob/00?lh003o
>000ocT00?m200800?m702P00?m@003oE`00oe/00?mX003oO@00ohP00?nF003oXP00olH0883h00B/
o000om`00?o>003od`00on800^;k02Yom@0DFOl06G?g006Mo`0@Iol0CAo`02TZk`0OC_804FGo01`]
o`00ROl00;Co0034o`00bOl00;[o001lo`0E?ol022;o07/1k`1S0>l0dP3:0?X0GP3o0300o`0:B@3o
0000803o00@0o`0e0?l0G@3k0=<0l@3E0=80h@2H0>H0@03o08l0oP2n0<h0O`3`0483j`00>_l005Go
001^o`00Pol008oo002Do`00S_l0547o07P6c@0@B_d00:Co002oo`07`?l00>Go003fo`00o_800?oR
003od@00olD00?o10P00okd07P00ol000?o7003oa@00olX00?CZ01aQk`00bOL00?o4003oZ`00oi/0
0?n?003oQP00oh<00?n;003oT000ohL00?mm003oV@01g^T03N;D013[W@0;bN800>CG0130b`0F`=40
4>FQ003oE@00oa`00?lC003o2`800?l:00<00ol500Co0`05o`002@05o`001P07o`002_l000[o000:
o`003_l000oo00804ol00P0Do`00100Eo`007_l0023o000Ro`0402?o00Cooooo00?o0000oooooooo
ool01_ooool0027ooooo00Co0000oooooooooooooooo1@05o`000`04o`801?l3007o1`03003o2P03
003o2`00o`X00?l<00<00?lI00<00?lJ003o7000obD00P00obP0;000obT00?lb003o>000ocP00?lk
003oAP00odL00?m9003oEP00oeP00?mQ003oJ@00ogH00?n1003oU`0>dN009gOo003bjP00olD00?nn
003o`@00o]/04jke00bdo@0=/O8019ko003So`08]ol009[o001oo`0f;_/0W@Fn08/3b@09B_l008Ko
01QWn00=T?800:;o002Co`00M?l03C7o02L5o`390<P0o`0OCP3o0000?P3o01@0o`180?@0_02^0?l0
Q@3o09d0lP3O0:<0b@2g03T0lP005ol003Ko001>o`00I?l007?o00e/lP06COl08c?l04LFm@157nl0
:2SZ002co`00cOl00>?o003do`00ood00?o_003ohP00omT00?o@003oc@00olh00?OS003Gl000eo<0
0?oP003gk000m?P02XCo003llP00om800?no00;e]`00ok<00?nY003oXP0?eN801]OW00Wb/000mZ`0
1M[>003AkP12HMd03L7[00GCa`00kiD00?mR013[I@00od400?l^003o7P00oaP00?l<0`00o`X01004
o`<00ol300Go0005o`4;00Go000600Go0@05o`001ol000[o000@o`004ol00P0Do`000`0Ho`006_l0
01go000302;o00Cooooo00?o0000ooooooooool01_ooool0027ooooo0_l00002ooooo`L01Ol000<0
0_l6007o2@00o`X00`00o`X00`00o`/00?l=003o6@02003o6@06003o6`00ob@00?lX003o:000obX0
0?lc0P00ocP09`00ocT00?m5003oA`00odL00?mA003oE`00oe`00?mV003oKP00ogX00?V]00G6j`0B
_O800??;003o/@00ojl00?nd003o_`00oll00?oI01>[n`09dod00?gi003ho`00i_l00<3o00Ubo`2J
1J@0X@2_068?c`0i9?l0:AOk001ao`01Lol01d7o001Ko`0_6^h0R03n0>`0PP1@0?l0000m0?l02P3o
07T0hP3d0?40^@3c08l0b`3U05@0o`0g0?`00PSo03H8mP0P6Ol04Cco001Eo`00D?l0;Q7_09T1b017
5>X006Ko002Bo`00^?l00=3o003Uo`00lol00?kn003om@00ond00?oT003oh000oml00?oZ00JTo`11
Lnh00lOo003Vo`0oF?805fkd01R@k`0[Lo400;Cn003Am`00ko005H_m003kg@00kMH00?3`00ZCo@0:
cN`08;7N02iYk@0JN?l0?6Go003o`P00oh800?mM003oB@00ocX00?l^003o9`00oa/00?lI003o3`04
003o2P0500;o1P04o`801?l200Go0005o`400`05o`003@05o`401Ol000Go0@03o`D00Ol8003o3`00
o`h00?l?003o6`02o`X01Ol100_o000Co`00100Do`000`0Fo`006_l001_o0003ooooo`;o00002?oo
ool0027ooooo00Go0000oooooooooooooooo00[o000500Go000300Go0P05o`001?l300@00?l:00<0
0?l<003o4P00oaT00`00oaT01@00oah00?lX003o:000obT00?lb00800?lh02X00?li003o@`00odL0
0?m7003oC@00oeL00?mH003oI@00ofP00?mg003mUP00l;h00?nV003oXP00oj400?nS003oZ000ok<0
0?nl003oa@00omX00?oR003oj000ooP00<co02YNn`0O?o80<3W/02deo`0;@?l0Q0c108`5]@0U7Nl0
81co03T:o`04:Ol02a?o0540l`3R09`0o`1;0?l0:P3o00m>0?l0000m0?l0A03o0980oP200>d0d01m
0?l0CP3o02D0o`0F0?l0Q`3W01d3o`1K0o40037o000_o`0X1_l0]03605X2j`0@E?h009_o002co`00
_ol00=So003]o`00mol00?kn003no000n_T00=cj003inP00oO/00>?o01U[o00mFNl0=S_k021Tk`00
bo/00?ga003Bn`16EnL057go03=?f@0cA]l028go03mUhP0BJ_/0K1oO00nLo`05c?004:Ok003mc`0N
`mh04[oJ003^^`00oeD00?m3003o=@00obP00?lU003o6P00oaT00?lB003o3005003o2P800ol50180
1Ol100Co0P05o`001?l300?o1@02o`L00?l9003o2P00oaH04>ei003o=@00n4L00>6;003o>@02o`H0
1Ol000_o000Ao`0601Co00Cooooo00?o0000ooooooooool01_ooool0027ooooo00Ko0000oooooooo
oooooooo00co0006o`0500Go000300Go0@03o`D00Ol900D00?l:00D00?lF003o6@00oaT00?lM003o
9003003o:005003o<000ocP00?lh003o>000od<00P00odL09`00odd00?mG003oF000of400?mV003o
L000ogX00?n7003oS`00oi<00?nD003oV`00oj<00?nY003o/`00ok`00?o4003odP00oml00?o]0039
oP0:X?l00F?o002>o`00X?l005co044Cg`0B;O80=aKo09@2f@2^0;P0UP3<08/0]`390=80gP3:0=P0
eP3l0;H0o`0e0?l06@1=0?l0000i0?l0803o07P0m03g0;/0o`2H0?l0/P3T0940j@120?l0SP3]09L0
gP0f0_X001Ko0109o`2c0=00J03]00<Xo`0LB_X008co002Ao`0FBOl00;Oo003Do`00iol00>go003S
o`0JT?P0487n0138k`0>cOl01Goo05Hei@1K7Ll00;?o003hn`00mmh00?oD003og`02c>d00?O[002o
o@02VOl00>_d012^nP00d?P04h_o003of@00ojl00?nT003oV000glh02mbl003oJ000od/00?lk003o
<@00obP00?lT00<00?lI0P00o`/6003o2P03007o2@00o`T00Ol900@00?l:00l00?lC003o8000lF/0
1]n_02KIR00@jfh00?lJ003o2P05o`401Ol000So000=o`003ol001;o000Co`000P0?o`04ooooo`03
o`000?oooooooooo00Kooooo000Qooooo`07o`000?ooooooooooooooo`0Ao`005?l000[o000400Go
000300Go0@05o`001Ol000<00?l:00<00?l;003o3`00oaT00P00oaT01P00oa/00?lQ003o:000obP0
0?lY003o=P800?lh00D00?lj003oA`00odL00?m7003oC`02003oE`0U003oH@00ofL00?mZ003oM@00
og/00?n5003oR@00oi<00?nE003oWP00oj<00?na003o]000ol800?o;003oe@00on@00?oe003Zo`0^
DNL00;Wo002mo`0<T?l04f[c001mo`0@A>l0BPKo02P8o`1T0?40DP7o08P0i01^0>l0_P3E0?P0X03o
08D0o`1<0?l00`1<0?l0000j0?l03`3o09D0o`2S0>d0`@380?l0k03O0;/0aP200?l0g03205T0o`0P
0?l0:P3g0800o`2P0<<0;`Ki000oo`00I?l007Go011Lo@0i;?0008Wo02i8nP00_Ol00=So003?o`01
M?l04dkm002Lo`0IJo<0BAGW015So`0/EMl028[o00CCm@00ol/00?o0003o_000okd00?o6003=m@0@
b>D00?o5003o_P00omH06:[d00^ek@00oiH00?mo003oP000o:P00<3L003jL000odH00?lh003o;`00
obP00?lV003o6`800?lI00<00?lE003o3000o`/02P00o`X02`00o`/00?lB003o6P00obH00?m300GT
YP00og`00?lf003o6P00o`d00Ol800L01Ol000<01?l3ooooooooool00_ooool00ol0003ooooooooo
o`06ooooo`008Oooool02?l0003oooooooooooooool05?l001?o000:o`001_l01005o`000`05o`40
0ol4007o2@02003o2P03003o3000o`d00?lG00800?lI00D00?lL003o9P00obP00?lY003o;@03003o
>005003o@000odL00?m7003oB@00oe@00P00oeL04`00of000?mV003oIP00og<00?me003oP000ohD0
0?n:003oU000oi/00?nT003o[`00okH00?o2003ob@00om800?oR003ok@00nO/00P00gOl04000dol0
0<Go002do`00W_l007co024koP00@_l003;o000Eo`0@0Ol0@`3b0;H0nP3C0?D0n`3=0?l0I@3o00m<
0?l0000`0?l0603o04D0o`1;0?l0Y03k0<T0m`2R0=40h@3R0>00i@2Y09@0lP2E0?40IP3i0=L0a02@
0?803@So01`Fo`06;ol02d?o00<jo`0n4?H0?AkO00ieo000]?l00;go00fIm000NOl0S0^n050NeP0Q
Fol00:Ko003Go`0KY>H00k?m003lg@00ok`00?nb003oZ`00ojX00?n[003l_P00ojH00?nM003oWP00
m/405<k;003oT`00og/00?m_0P00ofX02000mW/00?mL003o@000ocP00?l^003o:@00obL00?lK0`00
oaT01000oa400?l?003o2P00o`/7003o2P0D003o3`00oaH00?lM003o;`00ocX00?mI01:eh003lh<0
0?lf003o8@00oa<00?l;007o2003o`@01?l200Go0@04o`<00_l6007o2000oa84ooooo`03o`000?oo
oooooooo00Kooooo000Qooooo`08o`000?ooooooooooooooo`0Co`004_l001Co000?o`0600Go0005
00?o1@00o`X00?l:003o2P00o`/00P00oaT02@00oaX00?lO003o:000obT00?lZ003o=P00ocP00?li
003o@P03003oA`0Y003oC`00oeL00?mG003oF000of<00?mV003oI`00og400?me003oN@00ohD00?n7
003oU000oi`00?nV003o/`00ok`00?o4003ocP00omL00?oR003oj`00ooP00?[o003[o`00gOl00<[o
002ko`00YOl0093o001ko`00H_l00cKo03D6o`0V0?l0=@3o0680o`2M0?l0i`3S0?l0]P3o0240C@3o
0000=P3o00@0o`1A0?l0D`3o06<0o`1e0?l0J03o06<0o02U0?H0/`3G0=T0d@320<l0j`1=0?l08`3o
05X0l01j0?@01`_o04l5j`0^6?P005oo0028o`00Uol007oo038Sl00f9>D0X@NO02HZo`00T_l00>Co
003omP00l_800<gg003oa`00ok400?nU003oXP00oih00?nH003oUP00ohl00?n<003oR`00oi400?:_
003oMP00ofX00?mT003oG@00oeL00?mB003oB000oc`00?lh003o:P800?lX00<00?lP003o6@00oaT0
0P00oaT05`00oaH00?lE003o2P00o``00?l:003o3000o`X00?l<003o2`00oaD00?lI003o6P00ob@0
0?m[00o@/`00ogX01kOW00CUT`03ggX00?lb003o7@00oaD00?l;00@00?l:00<00?lB003o7@00obL0
1?ooool00ol0003oooooooooo`06ooooo`008Oooool01?l0003oooooooooooooool301Co000300_o
0005o`001Ol000801Ol000<01Ol100Co0P01o`P00`00o`X01000oa400?lI003o6@00oa/3003o:004
003o=000ocP00?lk003o@P800?m700<00?m9003oC@00oeD00P00oeL09P00oe/00?mU003oIP00ofP0
0?mc003oM@00ogX00?n5003oR000oi@00?nQ003o/P00ok/00?o:003od`00omL00?oO003oi000onh0
0?og003ko`00k_l00=Wo0030o`00Wol009Wo0029o`00Nol006Wo01<go`1/1L/0TP3a07T0oP2h0>P0
i@3<0?L0^03o06/0o`0bC@3o0000>P3o0040o`0?0?l02@3o0180o`0@0?l0103o00<0o`0?0?l02@3o
04H0n@2Q0;40m@2e0?80V`3a07h0o`290?T0G03f0;@0iP0E3?l04SSo001Qo`0b9o/043co06h9d`0n
:N8027?o02e@k`06O_l00N3l003oiP00omH00?o;003o^P00ojX00?nS003oV000oi@00?nB003oR@00
ohD00?n4003oOP00og`00?mg003oJ@00of<00?mK003oE`00oe000?m7003o@P00ocX00?lh003o:P00
obT00?lX003o9000oa`5003o6@800?lE00@00?l?003o4@00oa<00?lC0`00oaT04`00oal00?l^003o
C000jjl00=WJ02J0oP09cm800>73003oJP00ocP00?lM003o5`00oa400?l>003o4P00oaX00?lm00GU
QP00odX01?ooool00ol0003oooooooooo`06ooooo`008Oooool02Ol0003oooooooooooooool05?l0
01?o000Ao`004?l000co000500Go000B00Go0@00o`X00?l:003o2`00oa@00?lI003o6P00ob@00?lX
003o:P00oc400?lh003o?P00odL00?m8003oB@00od/00?mA0`00oeL01@00oeP00?mS003oIP00ofH0
0?mY00800?me02400?mj003oQ@00ohT00?nD003/`000n=<00?WG003DmP00nO000?oW003oj@00onl0
0?oa003oo@00nOl00>co0035o`0EEO`08b[l00UGo`00LOl006oo001So`04??l0?0Sn0980f`2N0<`0
f@2g0?D0V`3k0:00o`1d0?l0F03o01@0E@3o00006P3o01T0o`2Z0>D0dP3W0<D0e@3H0<D0k@3U0:T0
k`1f0>@0W02V0>`0?0Oi01XQo`2?0/40E0oh00i>o`0<BOl00;Go012To`0dFOL00?Ci003og000ol`0
0?o1003o]000ojD00?nN0P00oi@03P00ohP00?n5003oP@00ogL00?me003oL`00ofP00?mU003oG000
oeL00?mD003oB@00odL00?m00P00ocP01P00obh00?lX003o:000obP00?lN003o7@800?lI00<00?lJ
003o6@00oaT01`00oaT03@00oaX00?lV003o=000nY@00=gM003bc00:W_X05Y;[00;V`@06eJT00?m7
003o9@00oa/00P00oaT01@00oad00?m400O`O002gK`00?fK00Cooooo00?o0000ooooooooool01_oo
ool0027ooooo00Co0000oooooooooooooooo100Do`000`0Bo`001Ol000Go000200Go000300Go0@03
o`H00?l:00800?l:00/00?lH003o6P00ob<00?lZ003o:`00ocD00?li003o?P00odd00?]l003oF`04
003oE`03003oF000oe/00?mU00800?mV02D00?mX003oL000ogD00?mf003oOP00ohD00?n:003oU`00
n[d0:Yc]01j=m00OJ?l00>Wn003bn`00ho/00?kl003ooP00o_l00?Co003Wo`00dol00ICo02Hgn`1H
1_d043Go001Io`00E?l0137o04h4l@0o0?l0>`3o06H0o`2R0?l0i@3S0?l0c@3o03L0o`0605D0o`00
02@0o`040?l0C`3o0<00o`1^0?X0f@3m0:00o`0a0?l01P3o00@0n`110:P0g`1i0>/0?0kl038Jl`00
Rol00:co003@o`00gol00>_o003hm@00om/00?o;003o_P00ok<00?nS003oV@00oi@00?n<003oQP00
oh<00?mf003oM@00og<00?mX003oIP00of02003oE`04003oD000odL00?m7003o?0800?lh00<00?la
003o:000obP00P00obP01@00oah00?lK003o6@00oaT00?lJ00L00?lI01D00?lL003o9000obP00?lf
003oG@00ngT00?n=003Mh00C`M800?me003oE@00ocd00?l]003o9`00ob@00?lU003o:`00od<00>NQ
01k5g@0ARoL01?ooool00ol0003oooooooooo`06ooooo`008Oooool01?l0003oooooooooooooool3
01Co0003013o000:o`001Ol000<01Ol001H01Ol100Co0`00o`X00?l:003o3`00oaT00?lZ003o<@00
ocL00?lj003o?P00od<00?mB003oK@03f]400?mg003oH`00of800?mO003oH`00ofD00?mV0P00ofL0
1@00ofT00?ma003oM@00ogD00?mh00800?n501l00?n>003oU@00o[800?kH00>Wo`0XKOl0:5Cb03QI
h`0=_O`00>oo003eo`00l_l00>co003Po`00bol00;7o002=o`0HA?d0E0KQ000bo`0==O/002Go004=
o`0>0?l0=03o0:/0d@2o0>`0jP3P0?l0LP3o02d0o`0205D0o`0000H0o`010?l05@3o04L0o`0P0?l0
K@3o02D20?l0000F0?l08@3f0:/0L`3o00d<o`00@ol03F?d002Co`00/?l00=Ko003/o`00oOl00?o_
003oh000om<00?o8003o^`00ojX00?nI003oU000ohX00?n5003oO@800?me00@00?m[003oIP00ofD0
0?mI0P00oeL02000od/00?m7003oA`00oc`00?li003o>000oc@00?l[1000obP01P00ob<00?lO003o
6@00oa/00?lJ003o6`800?lI01P00?lJ003o6`00oah00?lT003o:000obX00?lg003oAP00oeT00?mf
00gY`P09]NT00?n5003oH`00odD00?li003o<@00obh00?lc003o?`00oe000?f300K?f@0^DNL4oooo
o`03o`000?oooooooooo00Kooooo0002ooooo`;o00001?ooool00ol0003oooooooooo`02ooooo`;o
00000oooool5o`0000?ooooo0ol00004ooooo`04o`000?ooooooooooooooo`D05?l000<03?l000Go
0005o`000P05o`005`05o`400?l:003o2P00oa400?lL013_>@06kh801_9]003oC@00odh00?mH00[R
XP00ojP04;[J003nVP00og<00?m^003oK000ofh00?ma003oL`00og400?mc00@00?me02400?mo003o
Q@00ohH00?nB003oV000ojL00?nl003gg`00n?X00X?o03llkP0FQOl00<3o003Ro`00i?l00>3o003D
o`00R_l0;S_/02dmk`0O9oP0D0?n0603eP1a0?T05P;o04d1k`0_0?l0BP3o0<D0e@3e0;/0o`2?0?l0
E@3o00@0F@3o00000`3o0080o`080?l000020?l0000K0?l0D03D0>`0LP3o06h0g`0A8_l0067o00AZ
o`0/>?l00<Go003Vo`00nol00?oj003olP00k_800=;d003Yk000okT00?nK003oU000ohH00?n5003o
NP00ogD00?md003oJ@00ofH00?mT00<00?mG00@00?m:003oA`00odL00?m20`00ocP00`00oc000?l/
003o:@04003o:008003o8`00ob800?lP003o7P00oaX00?lO003o8@00ob@3003o:00C003o;`00ocP0
0?m6003oIP00n9800?ng00:en000i^800>nR003mKP00odD00?ln003o?`00od/02N:B003oR`00l;d0
98gl003n[P04ooooo`03o`000?oooooooooo00Kooooo00001Ooooooo0000oooooooooooo000000[o
oooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool00oooool01?l0003oooooooooooooool401Co000301;o0008o`001Ol000801Ol001T01Ol1
00Co0`00o`X00?l:003o4@00oaX00?lg003`U00N^]800?Yi003oKP00ogX00?NV01RYkP05i]400?nF
003oQ@00ogh00?n3003oQ@00mZh00?n<003oNP00ogH00?me00800?mf02400?mo003oQ@00ohD00?n;
003oU000oi/00?nY003o^`00olh00?oW003Vo@00Wol0EQSR01V>n@00c_l00=Oo003Co`00b_l00:go
01M5k`1@9=l0?A_a008Uo`0g1oD0bP2n0:<0f@3>0<l0I@3o06<0o`2<0?l0e@3U0?l0V@3o00P0G`3o
0000703o04<0n@2H0=40_`1V0>l0?@Wo000oo`0P9O/025Ko01MioP09^_l00>go003do`00iOl02J;o
0297n`0L[NH01^g4003oWP00oi@00?n9003oQ@00og`00?mf003oL`00ofT00?mV003oI000oeP2003o
E`05003oC@00odL00?m7003oA000oc/00`00ocP00`00oc000?l/003o:00=003o:00D003o:@00ocH0
0?li003oAP00of805MRk0034l@0OH?T04;kW01CB]@00ofh00?mB003oC@00oe000?mh00KEe000f=d0
5Zob007Ra`00og<4ooooo`03o`000?oooooooooo00Kooooo00001Ooooooo0000oooooooooooo0000
00_ooooo00Go0000ooooooooooooooooo`000003ooooo`Go00001?ooool2o`0000;ooooo0P0Do`00
100Co`004_l000oo000:o`0400Go000G00Go0@01o`P00?l:003o4`00oaT00?lV003o@@00lIL00>cA
00^_h`00fm/01LkQ02edkP00hM`00?Zj003n[@00oi`01]3G003j_`04a>d00?nJ003oQP00oh<00P00
oh408@00oh@00?n5003oQP00ohL00?nB003oUP00oj400?ne003oa000omL00?o[003jo@00dOl08Tki
01mSm@00^Ol00<Co0030o`00^ol00:ko002Do`00NOl005oo001;o`038ol08PGf08l0kP3U0:40k@2L
0;d0lP3=0?80j@3W0?l0C01P0?l0000F0?l0DP3c0=D0Z03k04X0o`0V0_h0H`GB0549k`0m7^h064k_
002mo`00f_l00=co01:@lP0fC^L02lWm003ig000okP00?nQ003oU000oh/00?n5003oO`800?me00@0
0?mZ003oIP00ofH00?mK0P00oeL01P00oe000?m8003oA`00odL00?lo003o>P<00?lh00<00?le003o
<000obX02P00obP2003o:@0D003o=@00ocP00?lk003oA`00oeL00?nC003Md000j]`03JOc003oVP00
og<00?mR003oG@00ofH00?ml003o^P08H_l05lkI003oOP00oeL3ooooo`;o00002?ooool00005oooo
ool0003oooooooooool000002?ooool4o`0000Cooooo00Co0000oooooooooooo00000_ooool00ol0
003oooooooooo`03ooooo`04o`000?ooooooooooooooo`D05?l000<04?l000Go0005o`000P05o`00
5`04o`<00Ol9003o2P00o``00?lI003o8@00oc`05=b`003lT`00i<000>C901V]k`13;?P0893c02Ak
n@00j>`00?S?00W2l@04[_`00??N003oX`00oi800?n900@00?n500T00?n8003oT`00oi@00?nL003o
ZP09hn@03>gZ003=o000iod00P00_ol05000Rol05D?o002Bo`02R_l00Wko002Uo`00X?l009;o0020
o`00J_l004go000`o`004Ol0AP3o06d0o`2l0>@0lP2R0?l0KP3o07l0o`0hH03o0000703o01h0o`1f
0?00_02R0>L0XP3A08X0d`06:?l006So002Do`00/?l00;Wo002mo`0NE?l00<Go003nl@00om@00?nl
003oZ@00oi/00?nB003oQ@00oh000?mf003oM@00og000?mW003oIP00of02003oE`03003oE@00od`0
0?m700800?m700<00?ln003o>P00ocT00`00ocP01`00ocH00?ld003o<000obh00?l]003o;P00ob/0
0P00obX2003o:`0F003o<000ocH00?lh003o>000od000?m7003oE000of/00?mo003o[00@ZoX00<WZ
003eX`00ogD00?mb00SW/@00okX08:o^00NSlP0A_Mh00>>T003oC@Cooooo00?o0000ooooooooool0
1_ooool00005ooooool0003oooooooooool000001oooool01ol0003ooooooooooooooooo0000oooo
ool000000oooool01_l0003oooooooooool0003oooooo`0000Gooooo00Co0000oooooooooooooooo
100Do`000`0?o`001ol000Go000300Go000H00Co0P01o`T00?l:003o2`00oaL00?lM003o?`00l6P0
0?mB003oF`00ohD01=K=006hm@00kmd04iCk01Bck`0PMol0:dkk00[Em`00old00?nb003oXP00oi/0
0?nE0P00oi008@00oi400?nC003oU000oiL00?nS003o]000i>X06hCm03]@m00SEo8094Sh03Hkk`0U
CNH045[b04PXiP126^l05dSh0021o`00M?l006Ko001ao`00H?l0<Acj03`7n0091_l0603o05<0lP1b
0?l0/@3[0>80l03n0;L0o`0m0?l01@1P0?l0000F0?l0203m0600k02o0=<0f`1W0?H0D07o01`mm00@
Aol00Uco044XlP0BEol08eoj0034o`00foh00nWb00SFk@00i=T00?^i003oV@00ohX00?n4003oN@80
0?me00@00?m/003oI`00ofH00?mM0P00oeL02@00oe<00?m9003oA`00odP00?m7003oA@00od000?ll
003o>P02003o>@04003o>000ocT00?lh003o>0<00?li1@00ocP05000ocT00?lj003oAP00odT00?mF
003oG`00ofh02Nf]01[1l@0<W_X00?S0003oT`00n:<03[G[025jl003f]D00_:M00oF^P00kH400?m2
1?ooool00ol0003oooooooooo`06ooooo`0000Goooooo`000?ooooooooooo`000007ooooo`07o`00
0?ooooooooooooooool0003oooooo`000003ooooo`04o`000?ooooooooooooooo`;o00001Oooool0
1?l0003oooooooooooooool501Co000300ko0005o`001Ol000<01Ol001T00_l6003o2P00o`X00?lD
003o6P00ob800?l^003o>000odT01NF]00;P[`00fM/00?nF003oWP00okD00?;^02TemP0OM_808i7S
003of`00k^<00?W8003k/@00oid00?nE00800?nF01l00?nJ003oX`00ojL00?nd003oc00@co@00=So
002`o`02W_l00;7o0030o`00Y_l05co_06X:f`1P2O4012_o03h=o`05=?l005Oo0010o`055_l0UP3P
03`0o`0a0?l0UP3W0</0i`2_0?l0k`340?l0X@3o05X0o`0<0680o`000200o`0]0?d0R03c07l0`P2V
0644lP280LH0Ab?d01`ho`00X_l03HSk01E5k`0o?od0:fCo03I?l00@`>h00=_Q003oXP00oi400?n6
003oQ000ogX00?mf003oM@00ofh00?mV003oI@00oel00?mH003oE`00oeH00?m;003oB0D00?m700X0
0?m6003oA000od800?m2003o@000od<00?m9003oC@00od@00?m00P00ocX00`00ocP00?li003o@002
003oA`0A003oC000oeL00?mO003oJP00ogh00?nO01^hg@0PX_800??A01bDn@0:`N/00/g_003kZ`00
og400?mV003oJ@00ocl01?ooool00ol0003oooooooooo`06ooooo`000_ooool2o`0000Wooooo0ol0
0003ooooo`?o00001Oooool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooooooo`D05?l0
00<03Ol000Go0005o`000P05o`006P04o`800Ol8003o2P00o`X00?l@003o6@00oa/00?lW003o<000
oc/00?m;003oG`00oY/00?mf003oP000el/01k_g00Rnm005`_X08Gkn02JCk00JQOl04JSj003o_`00
ojP00?nS0P00oj807`00oj<00?nV003o/000okH00?o7003ofP00onh00?gl003`o`00iOl00=Ko0031
o`01Ool05Uoc034[kP2Q0=P0I@7k00<Ro`00=_l04b3o0880k02T0<T0Q@3^06X0oP3@0<T0l`2i0>40
n@3o0:`0o`140?l0:@3o00/0H`3o00004P3o00L0o`020>`0W@191Ol04Sgo019do`00Z_l00<ko007?
o`00eol07HSo003Ho@0=a?d00NoA003o]@00oj000?nE003oS@800?n501h00?n3003oP000ogT00?mb
003oI`00ofH00?mQ003oF@00oeL00?mF003oDP00odd00?m<003oBP00odd00?mC003oEP00oe@00?m:
003oB@00odd00?mF003fSP00i[L00?mQ003oB@00odD00?m3003o@P00od@2003oA`0B003oB000oeH0
0?mG003oH@00of/00?mk003oSP00ok002LW^012ol@0?cm/00?bW003i[P00og`00?mP003oD`00odH0
0?lh1?ooool00ol0003oooooooooo`06ooooo`008Oooool01?l0003oooooooooooooool301Co0003
017o000=o`001Ol000@01Ol000D01Ol100;o1`00o`X00?l:003o3002003o6@0c003o8`00obP00?le
003o?000odT00?mG003oH@00ofd00?nC003m]P0Jf;`00?nn003ck00fHNT0>6KY003fkP00olD00?nd
003o[000ojL00?nZ003o[P00ok<00?ne003o_`00olP00?oG003oi000oo800?ko003^o`00gOl00<[o
002bo`00Tol0633h0780k@2A0<00O@3U02@8n`013Ol06@3o0580o`3M0:d0/P3O0;H0o`3f0;d0o`1e
0?l0aP3o06@0o`0=05`0o`0000D0o`030?l08`3o01P0o`0P0?l02@040?l0000B0?l01@3[09X0R`3S
01=5m`00OOl05IW_003Jo`00lOl00?_n003lm`00onT00?oM003o`000ok000?nS003oV@00oi@00?n@
0P00ohh02@00lZL00?B`003oP000og@00?m]003oJ@00of@00?mM003oF004003oE`0=003oFP00mg`0
0=je003lN`00oe/00?mG003oG000ofl07[S9003hV@00of000?mB003oB003003oA`800?m801800?mD
003oE`00oed00?mV003oKP00og`00?nD003o]`0JV^`02mO@003oW000oh@00?mc003oI@00oeL00?m;
003o@`00ocT4ooooo`03o`000?oooooooooo00Kooooo000Qooooo`04o`000?ooooooooooooooo`D0
5?l000<02Ol000Go0005o`000P05o`000`04o`800Ol8003o2P02003o2`0e003o5`00oaT00?lO003o
:000ob`00?lh003o?`00odT00?mF003oH@00ofd00?mm003oS`00ojP00<_Y012Fl00eO]`04jOm003[
j000ol@00?nh003o/`00okD00?ni003o``00olD00?o8003od000omX00?oW003ol@00ool00>ko003B
o`00_Ol00:_o002Ho`0IDoT00S3o04l4l@2R0>40O03K04h0o`0]0?l0TP3l0;80n`3f0900n@2L0?l0
[`3o03X0o`1G0?l05P3o00D0F`3o0000C`3o00P0o`0V0?l0M`3o04H0o`2P0?l0D03o04`0o`1B0?l0
I03o06T0o`080?l07`2Y0M00<aSm02l[k`0;UOl00>7o003ho`00ooL00?oZ003ofP00ol/00?nm003o
/P00ojD00?nQ003oV@00oi@00?nI003oY000nM@01=;D003oT000oh000?mn003oP`00ogL00?mY003o
H`00oe`00?mH003oFP00of000?mW003oR00=d><00?n7003oK000ofX00?mc003SbP01aNX01nnQ003o
JP00oeP00?mE003oC000odT00?m=003oC`00oeD00?mH003oG`00ofH00?m]003oM@00oh@00^k2003/
i`0<S?l00?o;003oT`00ogX00?m[003oHP00oeL00?m8003o@P00ocP01?ooool00ol0003ooooooooo
o`06ooooo`008Oooool01?l0003oooooooooooooool201Co000401?o000@o`003Ol000Ko00<01Ol0
00<01Ol100?o1001o`T00P00o`X01000o``00?lG003o6P00oad2003o:00^003o=P00ocX00?m6003o
D@00oeP00?mU003oL000ogh00?n?003oZ000k<X00>_]03EEl@0=`O400?oK003ob@00olP00?g?003n
f`00b?P00?oO003oe`00om/00?oY003nm@00o_/00?[o003Yo`03Wol0>CW`001_o`00Q?l006ko0014
o`008?l0CP;R0<l0W`2W0>00T`3[0>80e`3[0<@0oP1Y0?l0703o01<0o`0?0?l015`0o`0001/0o`04
0?l0603o04h0o@3=0?D0[`3Z0>`0oP2?0=l0h`3L0<L0d@3e0>D0]P3R0<`0o01;09`0b@0>>_T063[o
03MJeP00dOl00?So003om@00onH00?oH003oc000okl00?ne003o[`00ojP00P00oj<03000ojT00?k6
01JDoP0=/^T00?nU003oV@00nJd00]oD00KM_000ogT00?mY003oI`800?mV00h00?mX003oM000m[<0
4Hgi00?FhP00ohh00?mn003oSP04jm805hgi00g5fP00oh400?mS003oF@<00?mG01@00?mH003oFP00
of@00?il003oP@00og`00?n0003oS`00jm404:_m03Y=j@0H[oP02^bX003oN`00of`00?mQ003oE`00
odX00?m5003o>0Cooooo00?o0000ooooooooool01_ooool0027ooooo00Co0000oooooooooooooooo
100Do`000`09o`001Ol000Go000300Go000800Go0@00o`X00?l:003o2P00o``00?lH003o6@00oa`2
003o:00?003o=P00ocP00?m6003oCP00oeP00?mT003oKP00og/00?n;003oV`00ojd00?o900C9mP0=
I_l00?cc00800?oR01T00LKh00>ko`0XOOD00?Wg003ojP00oo800>Gm00:lo`00k_l00>co003Ko`00
]ol02f[o04hNhP00H_l005Co044<j@0E1_l05`7o05X0o@3H0<T0kP390?h0LP3o00X0o`020600o`00
0500o`080?l0O@3o08h0l`2Y0;40o`2/0?h0kP2:0;H0j`270>l0G`3_0:@0k01W0?P0R03L04/;l00<
Fol009;o002fo`00e?l00>[o003go@00onh00?oP003od`00olL00?o1003o^P00ok@00?nb003o/@00
okL00?o;00jfn`0AZ?@00?o1003oa`04]_H0;YKU003oW`00ogh00?me003oK`00of`00?m^003oM000
ogl01^nY00CMgP07]_400?be003oW@00n<P0;W_g003Uf000oi`00?mm003oJP00ofD00?mN003oF`00
oeh00?mQ003oIP00og<00>bo003U``00oiX00?nC003oW@00ok/01]O_015lo`00o=/00?nX003oPP00
og<00?mV003oF@00oe400?m7003o@`Cooooo00?o0000ooooooooool01_ooool0027ooooo00Wo0000
oooooooooooooooo01Co000Co`004_l001Co000:o`000`05o`000`05o`401Ol200?o1P02003o2P0G
003o2`00o`h00?lI003o6@00ob000?lX003o:`00ocP00?lk003oA`00oeH00?mK003oI`00og400?mo
003oSP00oid00?n`003oa@00o>l06h3o01ZLo`00V_l00P00aOl05P0CFoh00<?o003_o`00mOl01;Ko
00>Jo`0OJod00=Oo003Ko`00_ol0;3Wf040`g`0l3Oh02Rgo02DNo`270]X0C@3i03P0o`2V0>`0[03h
0?X0a@3o02IR0?l0000i0?l02P3o08/0h03`0>/0a03@0<`0J`3o0;`0f`3?0=40>P3o01D0o`250>L0
D0;W00DEo`220MP0?QGo00Iho`0?W?l00<3o00fllP0aNnl00??m003kl000oml00?oJ003lfP00old0
0?o?003oa`00okh00?o3003oe008eOP07hCj003lj@0HZN`04i_m00GVi@05lZH00?n5003oO000ogH0
0?me003oM`00og/00?n5003oV000l]003WKo00?Zh`00ol404=kR02:6kP09e]X00?n=003oO000og80
0?mW00<00?mV01@00?mZ003oL@00ogh00^fm03Umk`00e=L00?nY003o[P00jmX02ikm0321o000i]d0
0?nX003oUP00o:<00?me003oI000oeP00?m<003oA`Cooooo00?o0000ooooooooool01_ooool0027o
oooo00Co0000oooooooooooooooo0P0Do`000`0@o`001Ol000Go000500Go000b00;o1P00o`X00?l;
003o2`00o`l00?lI003o6P00ob@00?lX003o<P00ocT00?m3003oD000oeh00?mU003oK000ogd00?nE
003oVP00ok@00^KE003/i00MSN`05Ioo0036o`0S@ol0<5_g02Pho@202n400Vco015co`00_Ol03J3o
02Hjo`00W?l00;oo0032o`00]ol008So005>o`0;9_l0L07k02@3o`1]0?X0Y@3a09h0n03T0<00f03a
0?l0L03o02YQ0?l0000Z0?l00P3o03X0n03;0;40o`2g0>d0K`3m03L0o`1b0?/0k@2Q06H1l0005_l0
=@c_0011o`00D_l0=17b060:hP0N=?X03c3o011kn`09T?l0;E3o02mLjP0@gNl00?o`003im@0MQoh0
0?[c00ZGo000nn<00?o>003od000omd00?_g01f;lP0:MOl07i;n003RkP00okX00?nN003oSP00ohD0
0?n40P00oh<09@00ohH00?n=003oV@00ok@00>SW02Ynl@00goH07h;b003ei000okH00?n?003oP`00
ogD00?md003oK`00og000?mb003oO@00oiT00?nC003o/P0FWoX04;_b003oaP00ol400>oZ00^Do`0J
D?l02<3k003o`P00mLh00/3W003oSP00ogd00?mW003oF000oe<01?ooool00ol0003oooooooooo`06
ooooo`008Oooool01Ol0003oooooooooooooool04_l000805?l01@05o`000`04o`801?l4007o2002
003o2P0_003o3000oa<00?lI003o7000obP00?lb003o>000od<00?m;00gbLP00oh000?mi003oO`00
oi`06/cG003o]P0@emT04j_b01^Io00mKO<00?g_003ni000j?<00>gl00ZMo`1b6=l05dcm03TTo`0k
?Nl0F2Gk07XCc@0@INl08V__015Uo`00V_l008Co001Wo`0W7O00FP7O0;P0h03A0;d0mP2]0<X0l`3b
0;d0o`2O0?l0RP3o02<0H@3o0000:@3o02D0nP2c0?X0UP3>0=80GP3o02d0o`0C0?l0?P;o07<0g@1e
0OT00RSo001?o`00J_l007Go01iGj`0@G?L0EQC/07P6c`0]?_T0?2Wa011Ao`00]Ol00>?o003bo`00
j_l06VKd00BPo`0KPOl00?_b003oh000onH03n_e003coP0UHOT00>So003mk000olh00?ng003oXP00
oiH00?nB00800?n>02H00?nE003oTP00oiL00?nP003o/000olh00=oj00jOo`00l^T00?_3003oYP00
oi<00?n6003oP000ogT00?mg003oMP00ogl02NnP00CIi@03im<00?o600;<m@0RT_800?oO003ofP00
mo@02:oo019Xo`00m_/00?oR00;ClP08b>/00>3D00Bmh@00oh800?mT003oH@Cooooo00?o0000oooo
ooooool01_ooool0027ooooo0_l00002ooooo`0301Co000;o`001ol000H01Ol003<01?l2003o2P00
o`X00?l:003o3000oaL00?lI003o8`00nd800?m6003oB@00oe000?a/003c/00=hm<00?nC003oWP00
e^P00/?j01c4g`0J[^/0=4_U011lo`00n^D00?o:003ob000om400^7e00^?o`0CPOl00=Ko01Z]n`0@
Wol03e?o0:P1/`0h6?`0N13N03HVo00@?ol032Wo00Hgo`1>0ol0`P370?X0>@3o0200o`0_0?l0I03o
09<0o`0e0?l0903o00<0F`3o00000`3o0040o`060?l060020?l01@0k0?l02P3o07D0c03f09X0nP31
0=80VP3k06P0jP0?1ol001ko024=o`1`0ND091Of00=3o`06K?l0097o002Ro`06Q?l08D?m00=Oo`19
5O80`02Q04@JfP0bB_D03H_l03QllP00^?l016oo00Y]o`00eOl00?Gn003jnP04`oh03gKo002ho`0/
B?h00=?o003nk000om000?o0003o/@00ojL00?nX003i_000okD03m?N003oZ`00ojT00?n^003ma@00
omT00:on02=dl`00o^800?o1003oZP00oi`00?nC003oS@00ohX00P00ohL05@00oh`00?nQ01G>j00S
SoT05ZOh003:o@0AVod00?gh003]m`0BMol06W7m03Y0nP0EMol06YSc02j<k00C[_`01<oZ01;V/P00
oh<00?mc003oL003ooooo`;o00002?ooool0027ooooo00Ko0000oooooooooooooooo01Co000<o`06
00Go000I00?o1@01o`T00?l:003o2P00o`/00?l<003o6@00oaX00?lV003nGP00lKP00?R;003oL@00
ohX00<kW003Si`07i]X03^3Y012Xl`1Q8]h076Sk01:^k@00i_800=3_003oa@02003o]P0B003o_@00
m=h00?_[02VRl`00ooD00?[l00jWo`0^B?L02fko001fo`0e8?L09SKd070?fP2J0</0L07n0:X0f03m
05h0o`080P3o00000`3o00/0o`0=0?l0301L0?l0001H0?l02P3o0140o`150?l0P03o05X0o`1c0?l0
LP3E0>P0dP2k06/0o`0n0?l0Q`3l03P3oP1A2oL0047o0014o`0I7?l0HA3K034Co`1?7?@01gOo002l
o`00`_l00;co002Zo`00L_l06S[o011jk`01HOl0KBKQ04`Jg@0T;_H0ZPJn05@Pg`00W_l02HSo003B
o`00R_l073Oc01U8o`1O8nD0;5S`00j^o`00ond00Mg]003chP00ol<00?o;01FKn`02h?<04j_^003o
``00ok`00?o900G:m@00iO`01Ico03A]oP00l_X00>3X003o`P00oj`00?^d003k/`00oK800?N]003o
V000oiX00?nX003o_@07fNX04[gf02>>h`06K_l00JCo003Do`00T_l0I`gO08X1d@1=5_`0J1oe01QL
o`00k?<00?o5003oZ000oi@00?n;003oR@Cooooo00?o0000ooooooooool01_ooool0027ooooo00Co
0000oooooooooooooooo1P05o`0200Go0@0300Co0P00o`X00?l:00800?l:02T00?lA003o6@00oaT0
0?lU003o>P00ng`08<G5003>f@0NV^/0=83^064[j00ES^l05H7^012XmP0IV_P00>7h003oc@00ol00
0?fh003oZ000oj@00?nV003o[`00okL00?o6003oe000om`00?k]0039o@0IS?800:go006_o`00UOl0
08oo03D]o`099_l06@_o05L0o`3B0=H0o@250?l00`1O0?l0001I0?l0303o04`0o`0/0?l0PP3o0=d0
n`2F0>h0hP3h0:L0W@3j08`0k`0Y0?l05`3o07P0kP0Y4oL004Ko001Ko`00GOl08BKo03@WiP00M_l0
4FOb01a/o000cOl00=So003Ao`00]ol03S_o02iDm@00aOl00<go00]Yo`00T?l0KQCQ0:l4c`0j;N`0
=bS_040_n@0MBol0463o02HGk`2e0=P0g02A04l[k@00Yol04[co01NCo000__h00?oX003lj`00g_d0
@6oP003cn000omd00?oF0138m@00W_l07Xgb001ho`0kA>l06hK_012Bn@07h^/00?o8003^i@03_Nh0
0:ge003cb`00ojT00?nZ003o]000okl00?oF003om@00fOl0@3KR0390o`0:N?l006co02`Co`2/0[40
T0Jh058AiP1T9Nd04<?g01CHjP00mm400>c0003_b`0@h;H01?ooool00ol0003oooooooooo`06oooo
o`008Oooool01?l0003oooooooooooooool400Go00801Ol100<01Ol000;o1P01o`T00`00o`X0:P00
o``00?lF003o6@00oaX00?lW003o=@00lhh00>W2003mX`0<k;L00>3G01Aok@00nM`02m;B003o^@0A
]>H04:k`003h`@00oih00?nK003oV@00oi`00?nO003oX`00ojd00?nh003o``00om000?oL003ok@02
gOl00>;o003Fo`00`?l00:?o0021o`00DOl0A@gQ03d0o`2E0>/0k`330?l06Uh0o`0005X0o`020?l0
4P3o06@0o`280?l0C03b0>l0a03o0:d0o`3W0;00a`3J05h0k`0W0?l00`Ko00XAo`0[7NX005_o001]
o`00L?l004co05d3l000Mol00;Go003?o`00gol00>Oo003Vo`00/?l045Co00fmlP00i?l00?Oo003^
o`00e?l007[o01eIn`00[_l01HCo00f7o@0R@Nl0N`KJ0=h0Q`320;P0BAKe00IMo`16BN`09D?b06h;
kP0dDo@01hGo00JGo`0@N^l0KCC1002oo`06Vo`00?Gj003XoP00Uol0>SWa040Dn`2m0=H0J0oX002Z
o`00joT00?Cb003in00BS_`05[Kg003oe@00ol800?o8003ef@00om400?oR003go000hol00:;o01``
o`1:4_T0GP[[03hLl00<B_l04EGi02mCn`0RRND085Oc02i>m00@a^T00>[b01:8o`00o^04ooooo`03
o`000?oooooooooo00Kooooo000Qooooo`04o`000?ooooooooooooooo`D01Ol000<01?l300Go0P03
o`D01000o`X0:P00o`d00?lG003o6@00oaX00?lU003o<P00nfX00?mO003oHP00ogT00>ON012bk@00
okD00?nC003oUP00k<D00?nR003oU`00ohh00?n@003oTP00oi@00?nF003oW`00oj@00?nb003o_`00
ol/00?oH003oi@00ooL00?Go003Ko`00Y?l008?o001go`00F?l0>`__0:40i@3`08/0n`2=0?l0<5h0
o`0001d0o`040?l0C@3o0:<0o03[0?L0`@3j0:H0e02m07l0o`2>0?L0j@1o0;`0e01m0?L010go000/
o`00C?l006Go001jo`00QOl0087o01=7o`167O@00:oo003Lo`00k_l00?Co003fo`00j?l0<:kU003n
n002003ol00k003nn`07]_l08eSn011[k`00gOl00?;o003So`0=QOl0@BKZ078?mP0a9?P03TWo00jL
o`00hol00<Go015Io`01__l0>67F01E/o`1Z3n00HASA01I>n@1D=_@087KS00^0o`0UCO80GACW0<40
ZP134_<0>R_`02Xio`0IHol0;FWU00R@o`0g?ol01kGo003Jm@0@j^804j?]016kk000on`00?Ch01R1
o`00aol057oo04HBo@3a07X0_03@01h^o`0>Vol018Wo00^Co`00moX00<3n00J?o`0NO^h0:Tkb01lh
o`0FPOl01?ooool00ol0003oooooooooo`06ooooo`008Oooool01?l0003oooooooooooooool300Go
000300Go0@04o`801Ol000D00?l:00<00?l;003o3P00oaT00P00oaT09`00obH00?l/003o>`00od<0
0?m=003kK000lY400>2X003fW`00og/00?mi003oN`00ogh00?n1003oQ000ohD00?n6003oS000oi@0
0?nH003oX`00ok400?o1003oc`00om`00?oX003om`00n?l00>3o01Uhn@0Z=OH0:Roc004ho`0=3Ol0
=`3o0:@0i@3X0<l0o`160?l00@1M0?l0001J0?l0303o04/0o`1X0>L0eP2l0?l0j`3>0:D0j`1Y0?`0
@@3o0:<0k`3;0;T0S03E03/1oP0H6?`004?o01Y;o`00O?l009Co002Oo`00Tol00:Ko006^o`00iol0
0?Go003oo`00ooP00?oe003ok000on<00?oM003oh000ond058Oo003Do@08X_h00lSk003ok`00joL0
0;?o01:2oP0HH?l02WKo00:Yo`00k_L00?oX00g2mP0@`_<00?KO003ki000l_/056So002jo`0:coP0
3[O`00JZo`0a?^H0Y@GD0:P0eP1@8_@05T7o00fdo@02col02ZOn02NAnP0i:?l0ARWW00Eho`0YFOd0
9f_V05Del00=YoP00M;o012Bm@0WAN/0093o00=eo`0l9>P0^@2f07@7f@0X=_T01k3o003So`00k?40
0?oF003YgP00oLh00?oB00nOn`00foP03M7W1?ooool00ol0003oooooooooo`06ooooo`008Oooool0
1?l0003oooooooooooooool200Go000400Co0P05o`000Ol8007o2@@00?l:00<00?l;003o2P00oaH0
0`00oaT02000obH00?lX003o<P00ocP00?m3003oB`00oeD00?mQ0`00ofL06`00of`00?mb003oM@00
ogD00?mi003oQ000ohD00?n?003oU@00ojD00?nh00C[f@00o^L00?o]003om`00o_h00??o003Oo`07
T?l0CSo`03D=l01_0=d0P`3P0600o`3E0<d0o@2=0?l03`1N0?l0001J0?l04P3o09@0o@3N0=D0f02H
0?l0T@3o0980hP0[0?l06@3o04D1n00f0?h0R@3O0><0VP0j0ol021;o03XEj`00K_l009Ko002]o`00
_ol00<ko003Mo`00k_l00?[o003onP00onl00?oT003ogP00omD00?oA003od000omX00=Kg003og000
n=P00?oI003oe000om/00?o]003io00PS^@06g3_003jn`00om/00?o:003oa@00ok/00?ni003ob`08
/OX04Zgm00JWo000omX00?oM003;o00BK_l0<ECk03LblP0=ROl07Fko00B>o`00lNl00?oO003nl@01
X?l00<7o003al`00m_4009Go00Aoo`0`B?T0A4;_00YXo`1O6MD08RKi07P:h01C5>L01TWo005bo`0f
;oL045oj003_o`00onD00?o3003o[@00oj400?n_007Rc@00k/P00?nn1?ooool00ol0003ooooooooo
o`06ooooo`008Oooool02?l0003oooooooooooooool01?l300Co0P02o`L00Ol81P00o`X00`00o`/0
0?lB003o6002003o6@0?003o7000obH00?lX003o;000ocP00?lj003oA000odT00?mC003oE`00oe/0
0?mS003oIP00ofP00?m_00800?me01D00?mk003oQ@00ohP00?nD003m^P00mmL08:Gj003Do`0>Z?l0
0<Oo003Xo`00iOl00=Go00>Qo`02J?l004ko00d>o`2K0=h0h@2g0>T0a`3o03H0GP3o00008P3o0080
o`0K0?l0@@3o09X0j`3S0;D0h@1X0?l0@03o01l0o`060ol001?o004Bo`1G0O`0F03n0;P0c@2X0=`0
:@kd03Y;n@00TOl00:Wo0034o`00e?l00>3o003_o`00o?l00?of003ok@00on400?oE003ocP00olD0
0?o3003oa000olH2003o_`0g003o`000ol@00?o>003og@00o_P00<3o00mmo`00hO/00?oI003o_@00
ojh00?nT003oX`00okP08jSM003oaP01c>`00?nl003o``01f>P01jol003Eo`0FEOl00=So02BOo`00
kNX00?k8003o`000jnX00jci00b/nP00om<00?o=00g@k`0Pa?400>3m00mLo`2;0/@0Z`2k09l0c03>
0:<0?AK_002Lo`00d?l00Z?o01aik`01W?l05Yol003mf`00ojH00?n@003oR@00oh/00?n>003oW`04
ooooo`03o`000?oooooooooo00Kooooo000Qooooo`04o`000?ooooooooooooooo`L00?l:00D00?l<
003o2P00o``00?l:003o5@03003o6@07003o7`00obL00?lX003o:`00ocL00?lh003o?@02003oA`0L
003oD`00oeL00?mG003oHP00ofH00?mW003oK`00ogD00?mf003oP`00ohD00?nB003o[`0?/NT0>W7^
025co`0X?nl07U[f00j<o`00b_l00;[o002Wo`00POl04T;o04l0hP2@0>X0gP3V0?l0?@@0o`0000<0
o`020?l02P3o00/0F03o0000F`3o00P0o`1S0?l0U`3n0:L0o`1R0>T0`@310=@0F03o05`0o`0V0ol0
02Go000go`00;ol00A_o08L0g02U0<P0B`oj00<oo`0@I_L07W;a002ko`00c_l00=ko003Vo`00mOl0
0?ok003ok`00on800?oC003oa`00ol800?nj003o/`00okD00?nc003o]000ok<00?ni003oa@00om/0
0=cj02YCo`00f?h0;V?h003Em000ol400?nS003oU`00oi@00?nO003oX@00oi`00?nQ003oX`00ojX0
0?ni003odP00mO4056Sk00GVm`00om`00^o5003o[P00ojX02>SC003/c006kkP00?n/003oZ@00okX0
0?o=003`j`00W?l0DBCi01L[o`0m8mh0DPca060Ko00<IOl00^;l003ln@0SV?l00=Gk003Kk00HV?/0
0?6m003oO`00ogH00?mg003oO`00oi<01?ooool00ol0003oooooooooo`06ooooo`008Oooool01?l0
003oooooooooooooool7003o2P04003o2`00o`X00?l<003o5`<00?lI00/00?lJ003o6`00obP00?lY
003o;000ocD00?lh003o>@00od@00?m7003oBP02003oE`0I003oF`00ofH00?mV003oJP00ogD00?mf
003oP@00ohH00?n?003oW000okL00MkM003kkP0:a?d01Yoo02e=k`00T_l01dWo005Ko`0K7Ol04b3o
08P0k@3g06T0o`1@0?l03`030?l000060?l01`3o0480o`0g0?l0<`3o02l0o`01EP3o00002`3o01l0
o`1^0?l0^@3L0?H0bP3i0;40o@2h0=P0^P3:08X0e01S0^/01B_o008004go01D042?o04/5kP0::_l0
D@cd08@4iP0j5od072go002Po`00`_l00<go003Fo`00eol00>Go003mn`00ond00?oF003oa@00okX0
0?nc003o[@00ojP00P00ojH0=`00ojT00?nc003o_000j>`01i[o012ek@00omh03=WY02Z6k@00bnL0
0?nL003oSP00ohD00?n6003oQ@00ohT00?n>003oT`00oil00?n/003o`@00on800Zco003`k000olL0
0?n^003oXP00oiT00?nH003oT@00ohh00?nA003oV@00ojT00?o3003oiP00cOl06G3e00eno`0PKoP0
4G?d021]j`0:_Oh00?oU003og@04dOT099?i003o]000oih00?JH003oL@00ofT00?mX003oL`00oi80
1?ooool00ol0003oooooooooo`06ooooo`008Oooool03_l0003oooooooooooooool00?l;003o2P00
o`/00?l:003o2`00o`X00?l>003o2P00oa<00?lE1000oaT00`00oaX00?lV003o:002003o:@0O003o
=`00ocP00?lh003o@P00odL00?m9003oDP00oeL00?mH003oI000ofH00?mX003oM000ogD00?ml003o
Q@00oh`00?nF003oY`00ok`00?oF003nm000g?l066?o00MXo`17;nl09CSo04h>k@1M3?80Y`3[0?h0
@`020?l0000:0?l00@3o00l0o`0Y0?l0DP3o0;L0o`1m0?l0b@3o04X0o`0i0?l01eD0o`0005L0o`08
0?l0;P3o08L0f@3c09/0o01M0?l0@03o08P0l01_0>d0123o001Bo`00HOl006Oo03Dkm00:FoD0073o
00eNo00b6_h0QPS7038/l`0GO_8009oo00Ako`0IG_806eSo02QWnP00a?l01Z;o003ZkP00olH00?nc
003oZ`00oj@00?nR003oX@00oj800?nT003oY@00okL00?OM01n5lP0=`N`00?nk003o]@04fm003];X
003dVP00oh000?mg003oMP00ogP00?mm003oP`00ohX00?nI003o[P00mm408Jof00Rao@0GZO/00?[G
003o[`00oiT00?n9003oP@00og`00?mm003oPP00ohl00?bi017Ci`01Zoh07IWd003PnP00j^l00?;f
002mo`0[D_P00>ki003oc`00okl03NS?00^cn@09g<H00?ml003oJ`00of800P00oe`00`00of<01?:I
ooooo`03ooooo`03o`000?oooooooooo00Kooooo000Qooooo`07o`000?ooooooooooooooo`00oaD0
0?l?003o3002003o3P03003o3@00oa000?lF00@00?lI00<00?lK003o6@00ob@00P00obP00`00obT0
0?l]003o>002003o>00X003o@@00odL00?m9003oC`00oeL00?mI003oHP00ofH00?mX003oM000ogD0
0?mn003oQP00oh/00?nD003oZ000ol400>3[0076oP0bBo`06W;h0038o`00^ol00:;o001ko`0I:ol0
U`3c0?`0I03o0080o`0n0?l0K`3k0;<0l03H0?l0N03T0?80d@3Z0?40g`3o07P0o`2j0?l09UH0o`00
0240o`0P0?l0P`3h0;D0fP3F05/0o`0Q0?l0607o04X2o`155>d005go001_o`00OOl008Oo002Fo`00
VOl00Foo01`eo`0?C_l09Dkb03/_k00W>?00?3g_01e4k`0XAOH0:Eoo01EAo`1<;O<04k?k00CRgP00
ojl00?nT003oX000oiT00P00oiD07@00oiH00?nO003o]000l>`06G_n003@m@00ojh00?n@003oSP00
oZ800?mm003oM000og000?m_003oL@00og@00?mg003oQ000oiX04>K800cMk`0QSo<00?o@01c0l00E
LOl01>?D003oU@00ogl00?me00800?mb01P00?md003oQ@04hM801i7h013Yc@00i>`00mK[003ob000
k^4089Wa04Dem`01VOh00?o3003oZ000oj800nK1003Ub`00og400?mN003oE`00oe<00?m@003oDP00
of84ooooo`03o`000?oooooooooo00Kooooo000Qooooo`;o00000_ooool2003o6@03003o5`00oaP0
0?lG00H00?lI0P00oaX01P00ob400?lW003o:000obP00?lZ003o<`<00?lh02X00?m3003oA`00odP0
0?m>003oE`00oeT00?mT003oIP00of`00?me003oM`00oh400?n5003oS@00oiH00?n/003QkP0ISOT0
>e_h01R>o001eOl00>Ko003Bo`0@To@02EOo00H_o`2F0?40o`0F0?l0>03i09l0cP3X0=P0c02V0?l0
n`2W0</0e@2S0?l0m02`0=`0k03[0;L0o`1i0?l0403o005E0?l0000O0?l0;03c0<`0^03a06H0nP0L
0?l00PSo000So`00@_l0067o001co`00QOl009Ko002So`00[_l01iOo002To`00Z_l00:;o02I;k`08
NOl00;Wo0037o`07`_l00>go002fo`07b_X00=;g003Wg000oj/00?nP003oU`04003oU00;003oU@00
mjd00MCO00fJn`00bNd00?jR003oP000ogP00?md003oK@00ofL00P00ofH03`00ofL00?m/003oM000
ogl00?nG00g@g`0DHol04>GF003oYP00lL004:WU003Ej`0@hk/00?mi003oJP02003oIP0D003oJP00
oh800=GB003jZ000oiH03ZoJ00?GfP00oj`00?nl003^i00gQNL00>7b003o^@00oiX00?n=003oP000
og`00?mS003oE`00odl2003oA`03003oA@00odSooooo00;ooooo0_l00008ooooo`008Oooool01Ol0
003oooooooooooooool00?lJ00/00?lI00<00?lQ003o9`00obP00P00obP02`00obh00?lh003o>000
ocP00?ll003oA@00odL00?m8003oD@00oeL00?mJ00800?mW00<00?mb003oM@00og/00P00ohD07@00
oi000?nG003oZ000n=400>kX003Rm@00o_P00?kk003fo`00g_l08Ggn00a=o`0`5?80L0?o0?P0KP3I
0<T0d03B08D0k@1Y0?00I`3j0>l0_`2D0?l0S@3_0:00n@2Z0?T0^P3_0?/0T03n0:H0o`0U0080o`00
00H0o`020?l09@3o01`0o`0H0?l02@3o00e>0?l0000P0?`0R02i0?40OP3h07h0m@0/1?@001_o0012
o`00F_l006Oo001jo`00U?l00:co002mo`00`ol00<Wo0036o`00]_l02Tgo02E8o`00`Ol00>So003m
o000ond00?gV003odP00olT00?K1003oY000oiH00?nD003oT`00ohX2003oR@0;003oRP00oi400?nN
003`aP0@b=/00?nG003oM@00ofd00?mW003oIP00of@00P00of80:@00ofD00?mV003oKP00oh000?nS
003bf`0@/nd04mjm003oS000oi400=cQ01J2o009g/800?ma003oI000oeh00?mL003oH000ofL00?ma
003oL`00og`00=>b003oW@00oi@00?nT003obP0@Z?T00;Wj022mc`00oiL00?n1003oM000ofH00?mH
003oD@00odL00?m5003o?000ocX00?lh00Cooooo00?o0000ooooooooool01_ooool0027ooooo00Ko
0000oooooooooooooooo003o7@00oaX7003o6@800?lJ00L00?lR003o9`00obP00?lY003o:000ob`0
0?le00800?lh03D00?lj003o@P00odL00?m8003oB@00oeL00?mH003oH000ofT00?mc003oM`00ogd0
0?n3003oQ@00oh`00?nD003oU`00ojD00?ng003oa@00om@00?oQ003ok`00ooh00>ko0035o`0YDN@0
06Oo018Uo`2D0Mh0?P3o06X0oP1I0?805@3o07H0n03V0840M03k02l0o`0g0?l0E`3o0<<0e@3M0<T0
cP3M0?d0XP3o02h0o`0=0?l0?@3o07d0o`2E0?l0<`3o04@0o`0]0?l00P1<0?l0000P0?l0803d0:/0
g@2g0>L0_`3O0:h0R`3M0681o`0=7ol02B[o02@Nk`0Z;ol03DOo002Yo`00b?l00=7o003Eo`00dol0
0<[o002Ho`1C7M809fCo003Uo`00o_P00?oQ003oc`00okl00?nd003oYP00oi/00?nD003oT@00ohL5
003oQ@08003oR`00nK800=k4003oP`00of/00?mV003oHP00oed2003oF00@003oE`00oeP00?mO003o
IP00oH`07[oG01BKjP0@^^`04>ZI003oM@00og400?b9003c_000m[d00?mX003oF@<00?mG01L00?mH
003oGP00ofD00?mY003oL@00ogX00?n3003oWP09f>X057ko02]@o`0A_N800?bS003oOP00ofd00?mR
003oE`00od/00?m7003o@000ocP00?le003o:P04ooooo`03o`000?oooooooooo00Kooooo000Qoooo
o`09o`000?ooooooooooooooo`00obL00?lT003o7000oa/00?lI00800?lK00@00?lI003o7`00ob40
0?lU0`00obP00`00ob/00?lb003o=`02003o>00;003o>P00od800?m8003oA`00odT00?mB003oE`00
oeT00?mV003fP000nIX00P00ohX0:P00oh`00?n@003oU000oiH00?nO003oYP00ok<00?o0003oc000
omT00?o[003lo@00jol00=Oo002eo`00POl06b;c0741j0078_l0=1K^02XIkP007?l0;`7o09l0fP1H
0_<02@?o02<0o`1k0>d0a03806l0o0350=00g03[0=l0e`3o0800m`320?D0_03m0<T0o`0m0?l0XP3o
07d0o`100?l00T/0o`0002/0o`1F0>@0c@2;0?h0B@3o05l1n`1>0O`0N@7I05@2m0123^D0ARKY02/m
o`0g>>H06hC/003Ao`00g_l00>?o003To`00fol02iKo02ILmP0R@_805ggc00S@o@00onD00?o=003o
^`00ojd00?nQ003oU@00oi<00?n7003oQ@00oh@00?n0003oNP00ogL00?mh003oN@00ohX00?mo003o
J`00ofD00?mL00H00?mG02P00?mH003oG000ofX00?VN00g@i`00cmX00?N<003oH@00oeh00?mQ00gX
V000ogH00?mF003oC`00od/00?m:003oB`00oe000?mF003oF000oeh00?mU003oJ`00ogL00?n8003o
YP00j]L05:3m003oa000oiH00?mn003oK`00of800?mG003oB000odD00?lh003o=@00obX00?lX1?oo
ool00ol0003oooooooooo`06ooooo`008Oooool01?l0003oooooooooooooool2003o:006003o9`00
obH00?lR003o9000ob<00?lU1000obP02000obT00?l]003o>000ocP00?lj003o?P00od400?m60`00
odL0<`00odh00?mG003oF000of400?m/003aVP02f>@00?n_003oYP00oi`00?nH003oVP00oj000?nS
003o[@00okL00?o3003oc`00omX03N?c00:bo`00dOl00<Oo00V9o`04Iol0J@Wa04/9g`0:Col006Oo
001Io`03=Ol0PP;h08P0j0045ol00QSo08P0c`1H0?T0U`3@02/0o`130?l0OP3n0;X0l`3l08D0/`3j
0;X0o`3e0;P0n`2M0?T0mP3o07`0o`0Z0?l0601;0?l0000N0?l0J@3O0>80R`3_01D0o`004_l01BOo
000do`0P6_D0B1Oo001Xo`00TOl00:ko0038o`00gol00>So003_o`00l?l00>oo003Vo`00aol02F3o
05dMg@04Yol03lKn003hj000ol000?n[003oW000oi@00?n;0P00ohD02P00og/00?me003oM@00ogD0
0?mc003oKP00of`00?mV003oHP00oeT2003oE`0A003oE000odl00?m<003oBP00od`00?m@003oEP00
oe`00?md00;Ad000lZ000?mR003oDP00od`00?m=003oC`00odd01@00odL05`00odP00?m9003oD`00
oeL00?mI003oIP00og000?mm003oSP00ojh05Z3Y003hc000oid00?n:003oM`00ofP00?mK003oC@00
od<00?lh003o<000obP00?lU00Cooooo00?o0000ooooooooool01_ooool0027ooooo00Go0000oooo
oooooooooooo003o:P0:003o:006003o:@00oc400?lh003o>@00od@00?m;0P00odL03P00odP00?m7
003oB000odl00?mF003oE`00oe/00?mV003oL000o9h05/C@016Kn`0HbN/00?nf0`00oj@09`00ojd0
0?ne003oa000old00?oG003oh`00nOX02GGo00N2o`00Zol02dco05h>i00Y;oX00U[o0023o`00P_l0
06Co00XYo`1J0n/04aCo000mo`07<?l0>@oU01HBk`1n0>d02P;o02D0o`1C0?l0g02H0<@0h@1l0?l0
e@380?40]P3E0?h0f@3^0?T0VP3o0;L0o`0i0?l00`1:0?l0000@0?l0903X08h0P03o06D0m`102_X0
04;o001Bo`05@Ol0C0g_03@Og`00O_l00;?o003Do`00iOl00?3o003co`800?_o00l00?Ko012Mn00:
M?l00:Oo03Q8l@0j@^800<_m003oe000ok800?nL003oT`00ohP00?n5003oO`00ogH00P00ogD01P00
og400?mX003oIP00ofH00?mQ003oF@800?mG00<00?m?003oBP00odP01000odL02`00odT00?mE003o
N`00dkh00>b:003oDP00odH00?m5003o@@00od800?lo00800?ll00<00?lk003o?@00od@00`00odL0
5000oeD00?mI003oH`00ofh00?mm003oT@00okP00=?d00O5m000d>L00>W700__]P00ogT00?m^003o
E`00odH00?lh003o;`00obP00?lN1?ooool00ol0003oooooooooo`06ooooo`008Oooool01ol0003o
ooooooooooooool00?lf003o;000obT01P00obP03@00obT00?l/003o<`00ocP00?lk003oA`00of/0
0?Z>003oEP00oe800?m?003oDP00oe@00P00oeL0=000oeX00?mT003oJ000ogH00?n=003Qf@0ZKn40
0>Cc003oa000okD00?na003o/P00okH00?o401?5l000o^X00?oX003ok`00doh0;Ukg00Hlo`0XBo<0
<Bgm06D<j00PBol009go002Ro`00T?l07cGo06`?iP144^l0;RCa001Go`00GOl005Co008fo`0E7Oh0
01Ko04/1o`2d0>H0h02b0800k`1M0?l0X`3U0<40eP2/0>l0Y03o0=T0l@3o0<P0o`1L0?l05@3o00=9
0?l0000A0?l0>@360>H0U@3`0700l`077Ol005;o001Wo`00Jol01D3o03HWl0103n@05FO_003Ao`00
jol00?Co003no`00ool00P00ooT03@00o?X00?_j003io@02/_l05V_n01>?o`00]Od02^o4003oV`00
oi000?n6003oQ@00og/00P00ogD01@00og<00?mX003oIP00ofH00?mQ00800?mG00<00?mF003oCP00
odP01@00odL02@00odH00?m7003oB@00ofD00?9P003oC000od800?lk003o>@07003o>00H003o>P00
och00?m7003oA`00odd00?mG003oH000og400?n6003oZ@0C[_X02=OO003gb00@^nL0:XCY00:oi`00
nJL00>C<00k_N`00oe<00?ln003o<000obP00?lI1?ooool00ol0003oooooooooo`06ooooo`008Ooo
ool01?l0003oooooooooooooool2003o>00A003o<000obX00?lX003o:@00ob/00?lZ003o;@00oc80
0?lg003o>000oc/00?m7003oJ`00gkD00?VS003oIP00oeX00`00oeL0=P00oeP00?mK003oI000ofH0
0?mc003oP000oi400?nc013Mk@0kDmX00mWZ003o``00okd00?nl003o`P00omD01jWk00:Xo`00o?`0
0?cm003To`00YOl0DB?S0;X0X@1^3n803FWc00:6o`00^_l00;Oo01ign@148NX00FKo00Lho`1;4^@0
06[o001bo`00JOl005So0013o`016Ol0;P7o0:h0dP2g0;l0O03Q02H0o`0c0?l0IP3o06h0o`2^0?H0
l0370?l0K03o05T0o`1U0?l03D40o`0002P0o`030?l03P3o02D0o`0C0?l05P3o03h0o`1:0?l0>`3e
0600`@3L02L0o`1C0N/0:Q3n001Jo`00LOl0087o002:o`00QOl02f?o002@o`02`ol00>oo003io`00
ool00?od003ol000ond00?oY003oiP00on`01KSm003Ul000om`00MW^003fc`00oiX00?n>003oQP00
oh<00?mh0P00ogD01@00of/00?mW003oIP00of<00?mJ00800?mG00<00?mB003oB000odL00P00odL0
2@00od@00?lm003o>`00oc`00?lj003o?@00od400?ln003o>P02003o>0800?lf0P00oc@01`00ocD0
0?lg003o>000ocP00?li003o>000ocl00P00odL04`00oeD00?mO003iR004i</00??<01jXm`00kKX0
0?n=003l[P00gmd01lOZ02JLj@09`o401^G7003oI000odT00?li003o:000oaT01?ooool00ol0003o
ooooooooo`06ooooo`008Oooool01Ol0003oooooooooooooool00?lj00800?lh00<00?lg003o=000
oc@00P00ocH3003o>00G003o?P00odD00?m>003oJ@00k<400=C3003gS`00ofd00?mT003oH000oel0
0?mR003oI@00ofL00?m`003oQ`05kk<00?Zg003o_P00mNP04g?o00?`l000om400P00ol/0:@00om/0
2KSk00Nbo`0WM^d00=go0031o`0;Q_l0=CcR03l/k01D:=T0:c7o002To`00aol00=Go003=o`04P?l0
4WCo002Vo`0QAOd07c;o0026o`00R?l007;o001Co`00?Ol0B0_[09D0g@2=0=T0;07o00/4o`0:0_l0
7P3o03`0o`2:0=L0e03B0?/0R`3Y0>@0n`3P0?l0X03o0400o`030400o`000P3o03d0:@3o09T0o`2E
0?h0UP3/0=H0k@3D0=00i`3D0>00V03Z0341n0006ol003go001No`00Mol008go002Lo`00Z_l00;[o
003:o`00gOl00>oo003io`00ood00?ob003ok000on800?oO003oe`00omD00?_E003oaP00ok/00?ne
00gbX@00oiH00?n:003oQ@00oh<00?mg003oM@00og@00?mX00800?mV00D00?mL003oE`00oeL00?mF
003oB@02003oA`03003oAP00od000?li00H00?lh00@00?lf003o<`00obl00?lZ0P00obT07P00obP0
0?lZ003o:@00ob/00?l/003o<@00ocL00?lh003o>P00od<00?m8003oE@00of800?n200;>h00/OOX0
0<K/003lV@00og400?m^003oN@02k:h07IKb02RHm000gl@00?R8003nN`00n7d00?l/003o6PCooooo
00?o0000ooooooooool01_ooool0027ooooo00Ko0000oooooooooooooooo003oA000ocX5003o>080
0?li02P00?lo003oA@00odP00?m@003oFP00ogL00=gH02][j`05^>h00>:V003oLP00ofT00?mW003o
IP00ofT00?ma003oNP00oi/01LO[01>8n`00cOH03Mcj00Z7o`00n?P00?oT003og`00on800?o]003D
o`05M_l045go00mjo`00M?l0KaBc00i`o`03XOl00X7o029;m00WGOH00=Wo0P00iol06@00fOl00=Co
0035o`0@Jo4008oo002Qo`00Uol006Go02X?o`0I4Ol0?P;b0:/0d`1i0NP04QGj000Oo`052?l0E`3d
0:00i`2d0=P0cP2f09L0n`2X0?l0k03C0?l0H`3o0280@03o0000;03o01l0o`2E0?l0U`3e0<L0iP3a
0?l0P02b0>D0_@3Q07@0m@1H0?l0d02[08/0g`0_1nl03BWo000ko`0T@Nl008Wo002Qo`00/_l00<7o
003Ao`00gol00>go003go`00oo`00?o`003oi000on000?oE003od@00olL00?o0003o]@00ojl00?nT
003oW@00oi@00?n9003oQ@00oh<00?mf003oM@00og<00?mY0P00ofH01@00oe/00?mG003oE`00oe80
0?m800800?m700<00?m1003o>@00ocX00`00ocP01000oc800?l_003o:@00obT4003o:003003o:@00
obP00?lX00800?lX0P00obT06000ob`00?lf003o>000ocl00?m;003oF000ofP00?n2003o^@0TU^H0
3=gO00?bQ000oeh00?mI003oG`00m9D00?2R00W_XP00Z?X03MKJ00_De`0@cJh00?e<003o70Cooooo
00?o0000ooooooooool01_ooool0027ooooo00Oo0000oooooooooooooooo003oA`00od@00?lm0080
0?lh0P00ocT0A@00och00?m4003oB@00oeH00?mJ003oF`00of@00?mo003_c`0VRO<00?O5003oS`00
ogX00?md003oL@00og000?md003oMP00oh400?n>00KW``00iN/0=9C]00FSo`0ON?l00m?o003_n`00
koX00=ck003jo@00fol03g_o08D?c01Z3o<0?BWa00eIo`00/_l00=ko01=hm@00Z_l00:Oo003/o`00
n?l00?Ko003`o`00j?l00=_o0039o`00_ol00;Go002Oo`00QOl06b;o06P1j`3P0980@`;m01DHo`00
>Ol003Oo04D8lP1n0>@0D@3o09`0i01;0?l0L`3k0<40j`3U0?D0o`2]0?l05`0o0?l0000W0?l01P3o
04<0o`1`0>d0n@2j0?D0/`3m0><0`P2h0>h0C@3o02@0o`0V0?l0D07m08L0jP2l0;d07@Ko04H9lP1=
6=L03Eco002Jo`00ZOl00;_o003;o`00e_l00=oo003Uo`00nOl00?ob003oi@00om`00?oA003ob@00
ol800?ni003o/`00ojL00?nS003oV@00oi@00?n900800?n500L00?mf003oM@00ogD00?mY003oI`00
ofH00?mK00800?mG00@00?m=003oA`00odL00?m50P00ocT2003o>003003o=@00ob/00?lY00l00?lX
01L00?l^003o>000oc`00?m>003jMP00oY800?nG003Ji`0FV?<00?nC003oJ000oe800?m8003oAP00
odX00?mC003oJ`00oZ`06fca01VUkP00oXT00?ll003o7@04ooooo`03o`000?oooooooooo00Kooooo
000Qooooo`04o`000?ooooooooooooooo`<00?m704T00?m4003o@`00od<00?m5003oA`00odX00?mJ
003^W`00oh800?m^003oL@00oh<00>Zl01jUmP00lmP00?nE003oQ@00ogX00?mf003oM`00ogT00?n2
003oQP00oi800?nV003o`@00om/00?_h01B6oP0CM?/02hKo01Edo`00Xol00=Go00]Oo`0X?_40LAC^
0807f00/D_H00lGo003`o`00n_`00=Co003Xn`00o_P00?oi003on`00ooh00?_o003`o`00iOl00=So
003<o`00^ol009co0021o`00COl0I0GP07`1j@1K1>/0037o001Ao`00Bol0?1[l00LLo`1O0ND0I03]
02<0o`1X0?T0c03>0>l0a@3o05P0o`0203l0o`000280o`0T0?l0^@3k0:/0mP3:0<H0h01k0?l0SP3O
0<d0c01T0?l08@3o004>o`006?l0F@?b05/0k@2o0;l0_@3;00hIo`00H?l007oo019To`00X_l00;Wo
0039o`00_?l01WCo00G0o`00ooT00?oX003ofP00om400?o9003o`P00okH00?nb0P00oj<00`00oiL0
0?nD003oR`02003oQ@07003oN`00ogH00?me003oKP00ofL00?mV003oGP02003oE`04003oD000odL0
0?m7003o@0<00?lh00<00?ld003o:@00obP01@00obP01@00ob800?lQ003o8@00oaT00?lP00800?lN
01/00?lV003o9`00obP00?lX003o:P00oc@00?li003oC000o9X07KG<003cf00@S?P00>WV003oX@00
nG400?m8003o?000ocP00?li003o?`00ogd03>S=00;Q`00?d</00>>V003o=P00oal01?ooool00ol0
003oooooooooo`06ooooo`008Oooool2o`0000;ooooo00<00?m>003oA`00odL01000odL09@00odT0
0?mE003fL`07i<H08=W;00?9``00ohl00?nE003dbP1;G?403Loa003oZ@00ohh00?n5003oQ000oh<0
0?n7003oS@00oi<00?nN003oZ@00ol400?oG013An@00W_l0:2ck00A:o`0M?^l009So009Zo`1<:^<0
:dki00>Fo`07Lol05Eo_003=o`00ooX00P00on/04P00onP00?oV003oj`00oo000?of003oo`00m?l0
0>Wo003Mo`00col00;So01Q;o`00Eol0CA7K06d9mP0:9?l06aoo01X]o`8006Oo00T005Wo00<io`0g
1nl02@Oo00`1o`0b0?l0Q`3_0;l0l@3o06l0?`3o00008`3o00D0o`1H0?`0P`390?d0j`350:P0kP1X
0?l0?`3o08/0l@1c0?@0SP3J01`Do`00>_l003Oo00@Eo`230>h0L0;d06D4k`0F8Ol004[o03DPg`0T
;_l02Hoo002ao`09Ool0>3[_003Fo`00mOh00?o^003og`00om800?o<003o`P00okH00?nb00800?nS
01800?nI003oU000oi000?n7003oQ@00oh800?mf003oM@00og@00?mY003oIP00of<00?mI003oE`00
oe@00?m8003oA`00od02003o>003003o=P00obX00?lY00<00?lX00H00?lU003o8P00oa`00?lI003o
6`00oaX2003o6@05003o6P00oaT00?lK003o7P00ob@00P00obP05P00ob`00?lh003o@P00oeL00?BP
016fl00hHNh0<GGZ003Mh`00oGX00?m0003o=@00ob`00?lX003o;`00jfd00?QI013VL@00mfP05<fe
01??P000od@3ooooo`;o00002?ooool0027ooooo037o0000oooooooooooooooo003oE`00oe<00?m@
003oB`00odX00?m;003oD000oeD00?mJ003oJP00o9`04I;f00N^l@00iMH00?ni003cf00HJ_l00?WA
003oYP00oiH00?nA003oS`00oi800?nO003db000ojd00?n/003o_P0:hnL00?o^00c3oP0V>?d0aP2a
0;X0aP1X1NP0KA;H030`l@0:XOP00<?o003Uo`0HPoh03Y[o01J3m`00nO<00?oJ00800?oF01h00?oH
003oh@00onH00?o`003ooP00m?l00>So003Io`00bol00;Co01QHo@1_2]T0L0?C00hlo`01J_l00Voo
0024o`00P?l007Oo001Xo`00EOl003co000Oo`0H0ol0K03m0;<0e`3c0;/0m`2K0?l0<`3o004j0?l0
0080o`0C03P0o`1:0?l0G03o09L0h`3f09/0o`2O0>l0RP3V02/0o`0O0?l0M@3]05T1l0008?l00Cco
001Eo`00DOl0@a?V04lDj00D<?`06bOo07<4i`2K0k80D0O`001?o`00O_l00h7o00APo`0UA>h07g3_
00=io`00k_/00?oU003of`00om800?o6003o^`00ok<00?nY003oX`00oih00?nE003oU000ohh00?n7
003oQP00oh800?mj003oMP00og@00?mZ003oIP00of400?mH003oE`00od/00?m7003o@0800?lh00<0
0?la003o:@00obT00P00obP00`00ob<00?lK003o6`07003o6@<00?lJ01000?lK003o8@00obP00?lY
003o=000oc/00?m>00SdSP00oid02Z;b00cJf004k;X02^mk003o>P00obX00?lT0P00oad01`00oah0
0?lO003o8@00obh00?BE003oDP00obL01?ooool00ol0003oooooooooo`06ooooo`008Oooool01_l0
003oooooooooooooool00?mJ003oF0D00?mG01l00?mI003oI000ofh00?n3003b]P0D_^T08Hcd00jV
n000bOX04;ka003obP00ok000?nT003oWP00oj000?jn003oa00<Y?l00?gF003oa000enL049?e003@
o`0RL_l0BBgV04lWm@1d0^l0g@2d09X6`00?C_l06[K/00800?ki02D0>GSN003CnP00o^<00?oF003o
bP00olL00?o<003od@00omX00?oT003ol@00n_l00>co003@o`00a_l00;_o002Wo`08Eol0HQ3d054E
l00W<Nl009Go002Oo`00Uol008ko001oo`00Jol005Go000lo`0^2ol0AP3_0><0/02f0<40PP3o0;l0
o03n09@0o`0503P0o`0002`0o`020?l0803o0380o`1g0?l0K`3j0>/0o@2G0?d0Q02d0=D0HP3o03`0
o`0M0?l01P7o00L6o`1S0_l0:b?i001No`00Jol006co01]6o`00MOl007Oo001ao`04>Ol0Q@;]05@7
o@1W1L0052Sk03`@l@1E4Lh006go002Io`00bol00?Wn003ol@00onX00??[003hgP00ol@00?ng003o
/@00ojD00?nS003oW0800?nD00h00?nB003oS@00ohT00?n6003oP`00og/00?me003oKP00ofL00?mT
003oF`00oe@00?m7003o@`800?lh00L00?l^003o:000obP00?lW003o8`00oaX00?lK00`00?lI01P0
0?lL003o9000obP00?l^003o>000odH00?mK003oU@0C`>D02Mo7003oLP00odh00?la003o9000oaX0
0?lG003o4000o``00?l;003o4000oaH00?eU003n=002o`H4ooooo`03o`000?oooooooooo00Kooooo
000Qooooo`07o`000?ooooooooooooooo`00ofH00?mS003oH003003oG`0U003oHP00of@00?mV003o
L`00ogh00?n@003n/P0@kmH00>Gc012=o`00koL00?oA003o_@00ok@00?n_003o]00?b^H05YWl012I
n`00onl00?;Z003Un`12COT0E3cL02i8h@0:]_l04VGk01AAm@149mH00V7o03A^o`00i_/00?oT003o
gP00k^h04=kM003oa`02003o`00P003o`@00ol800?o:003oeP00on@00?ch006oo`00d_l0;6Ce0027
o`0PD>l006oo03/NlP00K?l06dgn002Co`00[Ol00:oo002Uo`00TOl016go001Do`0@=_`002Ko06P0
gP2a0<h0FP3b04<0lP1Q0?X0f`3E0?@0[`3o02<g0?l0000m0?l00P3o00D0o`1F0?l0VP3o0<L0n02Y
0<T0m03M0>D0l02[0>D0`P2f0>00G@3o05h0kP012Ol0027o000eo`04Aol006Ko001eo`00P_l008go
002Eo`00V?l00G_o03@SlP0P8_l00eCo02<Xl@2C0K`0iP1/0906/P0GH^l00;7o003Do`00k?l00?[n
003ho@09Sol01moe003oeP00ol@00?nf003o/000ojD00?nS003oX000oi/00?nH003oUP00oi/00?jW
003oUP00oiP00?n:003oNP00ogP00?b2003nO@00oe/00?m;003oA@02003o>005003o;@00obP00?lX
003o9P00oaX01`00oaT00`00oaH00?lH003o5005003o6@0A003o7@00obL00?lZ003o>@00odD00?mM
007/X@0CVoP04/CR003oP000oe400?lc003o8@00oaL00?l<003o2P01o`T00P02o`L01002o`P00?lS
00;o2P06o`04ooooo`03o`000?oooooooooo00Kooooo000Qooooo`0:o`000?ooooooooooooooo`00
og@00?m_003oKP00og800?mg003oK`800?mY02<00?m_003oMP00oh400?n?003oX000okT00?oH02VA
o@0fKNh00?__00[Rj000n=d00?OF003ob`00onD00<Oo00Ido`02`Ol087S]01aMm00EK^l0;5Kk003T
oP00mo`04:co02BQn`0RL?002W7o003Xo`00n^h00?oF003oc000olH00?no003o]`02003o/`0P003o
]@00ok`00?o6003of@00on`00>om02EDm`0NL_00ARkL038ak`0^B^X074_o01eEn`00YOl00;;o002n
o`00`ol00;go002Xo`00QOl0=Bod050;l`1W1?l0CP;o05<5l@102O<001Go00D5o`0W0?l0P@3]0>80
c03o01<40?l000050?l0203o02D0o`0K0?l09@3o00d0;@3o0000@@3o00<0o`0i0?l0=`3o00h0o`1Y
0?P0l`3C0>l0Y03o09@0o`2:0?l0h@2a0><0aP3E0=H0NP3o00h6o`009?l0043o001Ho`00JOl007Wo
002<o`00WOl00:Go002Zo`00Tol007[o00I]o`00SOl07U;_0488n`2W0LD0J0cM03/Mm@0]?_L00:go
002Jo`00e_l00=_o01EVmP00h?h07jgk013Rj000ol400?ne003o/@00ojX00?nX003oY`00ojT00?nW
003o/@05]O000?k=002hl000ojH00?n;003oS`0;e=@00?RU003oN000oe/00?m9003o@000ocP00?l/
00800?lX0P00oaX5003o6@08003o4000oa800?l:003o4000o`X00?l?003o4P00oa@3003o6@0?003o
9000ob/00?lk003oDP00ofL00?n900Jci`0@e]400?n@003XY`00mf@00?lN003o3`00o`X00ol50080
1Ol10P05o`000`06o`003?l001;o0004ooooo`03o`000?oooooooooo00Kooooo000Qooooo`0:o`00
0?ooooooooooooooo`04iKL00?n5003oP@00l;X00NZn003oO`800?me03@00?mf003oO`00ohP00?nC
003oX`00ll000?oV003Fo@18@_l00=;o00V1o`0OQoD00>Gi003mk00=d>l03g_o09@;aP1J8md037Oo
00Rco000koT04iol00_El@00omd00?oV003ln`06[_l076o_003fn`00on400?o=003o`000okD00?nb
003o[000ojT00?n/003o/@00ok<00?o4003Wk`00iOd00=?o03M@l00m=]P04YGk002do`00`ol048K_
01Q5m@00]ol00<Wo0P00d?l06@00b?l00:[o04<[k`0g6ol0:3Oo001=o`1@2^d00bOo0010o`00<Ol0
B@?b0880l@2c0>80_P3V0?/0FP3o0000o`0Y0?l0F@3o05h0o`1G0?l0X03o04X0o`210?l0=@3o00P0
;03o00005`3o0080o`0V0?l0S03o0740o`1;0?h0S@3H0?l0^03_07d0o`1K0?l0M03b0;T0f`3R09<0
WP3_03`0o`0i2_8003Wo001>o`00G_l006oo0029o`00W_l00;7o00800;[o01h00;_o002go`00Zol0
09;o00E7o`0l<_/00gCo01Xko`0h<md0AROe028jm@02Y_l00Z;o00iLo`0SINh04ike003oi000olX0
0?no003o^P00okL00?nl003oa@0@g=`00?o4003ob00<hO404Yge003Ik`00ok@2003oY`0;012kd`00
k=/00lGM003eNP00oe000?m3003o>000obh00?lX003o8`00oa/01000oaT01000o`d00?lA003o2P00
o``4003o2P0C003o3000o`X00?lA003o5`00oaT00?lQ003o;P00odP04>NV00g=^@00nKl0;fcf02=4
o`00d^H09/VN003o?@00oa/00?l:00;o1`0200Go000300Oo000=o`003ol000804ol000<05?l0oooo
ooooool00_ooool00ol0003oooooooooo`06ooooo`008Oooool0;Ol0003oooooooooooooool05K;^
003oZ@00oZh06i[g00gRc000oi400?n4003oP@00ohH00?n>007_[@00ojP00?nb003beP0KRnH00:Oo
03D_o@0dF>00:dGl00>Eo`00eol00jSo04Pkm@0WKN@076cb02aBo@00g?h00?kO003obP00mlL00?no
003o`@00om<00?Ob006Qo`0NR?l01iOo00[[j`00olX00?ng003o[@04003oX`0[003oY000ojl00?nn
003/jP0@NOH0@TgP01>Fo`0DW_D00>oo003ao`00gOl00X3o03dYi`00]Ol00=So003Po`00gol00=Co
00BAo`0RF_8017co002Bo`05D_l0H0O_0056o`00Gol00DSo038Nl01A0_00A@3k06D0nP3D0;D0l028
0?H0/@3S0>`0i03S0?l0P`3d0>L0mP2P0?`0i03o06d0o`0l0?l01@0Z0?l0000I0?l00`3o02P0o`18
0?l0^P3o0=h0mP3c0?80`@3d0:D0`P3@0940j00k0?l0>P3o0940fP1I0>`0H`3b0<L0`P250>l01AWo
01hKo`186mX0AQ;^00M1o`0=QOl00;So0037o`02003=o`0Z0038o`00^?l00WSo02<hmP0JCO`00;;o
002no`00X?l0<37V04Lei`0^:OH0KACJ04TVm`03]Ol00?;n003oj@00omL00?o;003ob@00ol/00?oN
00foo@04X_l00?7a00nkmP0=[_00;EKU00JinP04dN/01:Gi003^iP03/_L00[ke003mZ@00og800?mL
003oD@00ocl00?l^003o:000ob000?lJ0P00oaT00`00oa@00?l?003o3006003o2P0C003o2`00o`X0
0?l;003o2P00o``00?lF003o6`00ocP00?n2003HZP04k8d00=_N003W_P0JQ^l02nnh00?VX000ofH0
0?lH007o200200Go000300go000Co`004ol000805?l000<06?l001co0?ooool00oooool00ol0003o
ooooooooo`06ooooo`008Oooool0@?l0003oooooooooooooool02Xkl003od000fN8049oj003je`00
oj@00?nC003oS`00oiH00?nW00g8jP00nMl00?o;003bk@0:WOl0LQ[Y0;d0X@2>0mD0N0cG01XenP0;
B_l07Cko00ZYo`00fOP00?Wj01>@o`01Y_d00>[K003oZ`00ojL00?nX003o/P00n]D00;_l02UkoP00
o?<00:gn01ZBnP00omL00?ng003oX`00oih00?nG003oUP00oiX00?nQ003oYP00okl00?S[02Yhk00;
R?l00]kj003ojP00ond00?kj00Rno`0:NOl086KU003<o`00iol2003^o`0K003Wo`00f_l00<go0035
o`00XOl0>ak/01ldo`00MOl007Wo001Zo`00D?l08agh008;o`110?l0_P3O08D0o0310>X0[03[0;D0
f03j0:40/P3n0;80o`3W0>@0o`1i0?h0_P3o03D0o`060080o`0000<0o`020?l00@3o0000903o0000
A03o0040o`0j0?l0M`3o0:@0o`230>@0mP2o0?l0j@3K0<X0e`1F0?l09`3o01H0o`0>0ol00@_o02T4
o`1L0_T0<PK/06L0l`0n3oL04bCo04<UnP0f7o806Tco002fo`00d_l00=[o003Oo`00eol00<3o01Q@
k`01S_l02hCo002co`00jOl00=Ko00Jeo`00ZOl0BbKS0;46ZP1I6Ld094oo00f[lP00eod00>Ob003o
h@00on<00<_h003Qo002R?l0Hb7701aWo`0SE_@07F3_06@gm006[?h04jOi041[iP0;M_h0N1G?01ad
oP0=]n<02=KA003oR@09iKH00?9i003o<000obP00?lK0P00oaT01000oaD00?lA003o2P00o`/;003o
2P0A003o3000oaD00?lL003o9`00oc400?mD003ZZ`00ofP08L6l00>f`000odP00?lV003o4003o`@0
1Ol000go000Co`000P0Do`00100Go`007?l0027o000So`04ooooo`03o`000?oooooooooo00Kooooo
000Qooooo`0:o`000?ooooooooooooooo`0]M?l00??i01F:o@00^?d00?o1003oZ`800?nO02400?nd
02FlkP0LX?P00=gj003jkP0@coX0:gCl03lhe00g8Ol0J`_O08H1j`2m0;d0W@WN002bo`00no800?oC
003oh00IT_l00?o:003l]000oiT00?nG003oWP00ojP00?[A045hiP00a?800?o6003ig00CS_h03J7l
003o]P00oid01000oi@0<P00oiH00?nR003Gf@0NV_/00>o]00oNhP00om@00?o@003og@00oo802K_o
05dVeP0IAol00=?o003ao`00n?l00?Oo003^o`00kOl00>7o003Fo`05SOl08dW_00Qmo`00Sol008So
001ao`00F?l003go008@o`1V0>h0b`2/04@0o`0l0>l0B03o0:@0kP3?0<T0N@3o0;d0h`3_0;X0g03_
0>P0fP3o0;/0o`130?l0@@3o03l0o`0j0?l0403o01/0o`029@3o0000A@3o01P0o`130?l0Y`3H0?T0
Y@3o08h0o`2;0?H0D@3o0240o`090_l0017o000Ro`00:Ol0033o000Zo`1a0_`01bOo001Uo`00POl0
09Co002Lo`00c?l00=ko003To`00j?l00>Go002no`0a??X00;_o003Xo`00j?h00?kl003loP00kol0
0=3o00=co`0:I_l04:G`01EUo`0QC?l0<T_O003@o`00n_X02m;m02MKo00=Ool09HO_01=lm@00j_80
0>kS003il`07UOl00>[T00?^`@00mlP00?7L00>eoP00n]800>[:00[@eP0Q/]L00?^A003oBP00obl0
0?lT003o6P00oaT00?lH003o4@0@003o2P0>003o4000oaP00?lL003o=@00o4L00?m500c_X`00b^P0
0?5S003o8@00o`/01Ol100So000Co`0201Co000301[o000Po`008Ol000808ol01?ooool00ol0003o
ooooooooo`06ooooo`000_ooool2o`0000Cooooo00?o0000ooooooooool00_ooool2o`0000?ooooo
1Ol00002ooooo`?o00001Oooool0;_l0003oooooooooooooool00:oo01ico`03[?h00?oU003oaP00
okD00?n`003o/P00ol000>__01Z=k`04WOl03I_o038dn@0HI?l02[?o002Xo`0a?>P08Bko05/EfP02
I_l00H7o003Zh`00okd00?nk003]i000oj`00?nA003oS000ohX00?n@003oY@08f>d04XOb003ld000
oj/00?Rh00foj`0C`Nh04>nN003oU000ohl2003oR00?003oS@00oi<00?nG003oZ000o;d00?o0003o
]`00okX00?o4003oe`0@dO400;Ko01i4m@08YOl00??o00800?on02@00?oo003mo`00l_l00>go003P
o`00b_l00;Ko002/o`00X?l008oo00AEo`00@Ol002[o07d0i`2h0<L0CP7h00h4o`0B0?l0B03b0:h0
j`1m0?l0C`3o0;l0h`2a0>T0]03U0:X0o`3/0>00o`1[0?l0cP3o06P0o`270?l0O`3o05d0o`010?l0
5@3o00DR0?l000120?l06@3o07H0o`2[0?l0[`3Q0>d0[03o0880o`1O0?l0@@3o02X0o`0K0?l02`_o
000^o`00@_l004_o0015o`1K2od0H`G^00=;o`00ROl00:oo0039o`00fOl00>Go003_o`00lOl00?Co
003^o`0PWnl00>Gn003omP00onh00?o/003olP00n_d059co019So`0NIol00>Oo003bo`0=Z?808g?k
01QOo`0IT?/04eSo01BHo`00g_H00?k[012cmP00l</00?nf003YhP00f^000>[3003oT`00oiH00>_?
00S=h`05elh00?mf003oM000hkL00>F/003oA`00ob`00?lP0P00oaT00`00oa<00?l;003o2`05003o
2P0900;o1`03o`H00_l600Co0P03o`@01?l300?o1@02o`L00Ol800800?l:00`00?l;003o4000oaL0
0?lP003o;`00n5P00[Vn003oI@00oc800?l?00Go000>o`0201Co000301co000Qo`008_l000<08ol0
1?ooool00ol0003oooooooooo`06ooooo`0000Goooooo`000?ooooooooooo`00000:ooooo`05o`00
0?ooooooooooooooool000000_ooool00ol0003oooooo`000003ooooo`03o`000?oooooooooo00;o
oooo023o0000oooooooooooooooo02E5k`00/Ol00?[j003oh@00olh00?o6003ocP03h>H00?oR00;G
nP0CJ^l0IPcg04I4g@00Uol01nCj003cn`0PM_l0687n002`o`0M??<00<Go0032nP00l/h00?nZ003o
X000oid00?n>003oQ0800?n100d00?n6003oT@00i]<08HkU003j^000oi@00?nC00?b]00=a^X04>nL
003oR@00ohD00?n600800?n503@00?n7003oT000oiH00?nM003oY000ojD00?n`003o^000oll00<cj
02dai00<O?l00>on003on000oo400?ob003om@00ool00?Wo003`o`00i?l00=Oo0036o`00^?l00:Ko
002Co`0<Bol0>`Kn01d;o`2D0><0XP2b024?oP006ol0:0?h0;80a`1a0?d0L03D02D0o`0`0?l0EP3o
06T0o`2f0>L0oP2A0?D0/`3R0?80m0380?h0`03o0:d0o`0j0?l0>@3o05H0o`0B8P3o0000AP3o00X0
o`0R0?l0WP3o0>40k`3[0>l0h`2o0>`0[@3Y06h0n@240>80X03O09H0j@0K7^l0053o001Ko`00G_l0
0TSo02DGo`1R0o801D[o00f:n@00c?l00>7o003^o`00lOl00?ko003oo`00oo`00?ch003ol000onD0
0?oR003oh@00onH00?Kh02EYnP00iOd08YWi003[nP00onT00?Gb003gm`00koh08W[_003XoP00onT0
0?o@003o``00m;l00?nU003oW000oj`00?2_003oQ000ogd00?n101g0`@00n:000?]e003oF`00oeD0
0?ic003V[@00oed00?lY003o7000oaT00?lF003o3P00o`/4003o2P0L007o2002o`L01?l300Go0004
o`<01Ol000Go0@04o`801Ol000Go0@04o`801?l300;o1P01o`T00?l:003o3000oaL00?lP003o>@00
hJH02?:K00WHT`00m4401ol001?o000Do`007?l002;o00D08ol01?ooool00ol0003oooooooooo`06
ooooo`0000Goooooo`000?ooooooooooo`00000;ooooo`05o`000?ooooooooooooooool000000ooo
ool01Ol0003ooooooooooooooooo000000Cooooo023o0000oooooooooooooooo058Yl@09SOl00?Cn
003jm000o^X00?oW003<o006V_l069ob02I>lP0>ROl048Co01V7n000o_000?oC003hfP0CanH00mk_
00O/n00TH?l00kcl003of000okP00?nQ003oT`00ohT00?n1003oM`800?mf01`00?mg003oP`06i<<0
0?K1003oR000ogd00?mn003oT`00oi000?n3003oO@00ogh00?mk003oO`00oh@00?n5003oQP00oh`0
0?nD003oU@00oid00?nS003o/`00m=h04:O_00NPo`0QRO000^[a0P00onH09000on/00?oa003oo000
nol00>oo003So`00e_l00<Oo002bo`00W_l008[o01E=o`0k2Ol0f02H0:P0]00C3ol003So000ko`1S
2?405Q3o0404nP1K0?@02`7o01T0o`0g0?l0K`3b0<h0eP3X0<00bP3Y0:80o`2h0?l0h`3b0?l0OP3o
03X0o`2P0?l0NP80o`0S00<0o`020?l0003o00007`3o0000@03o01T0o`130?l0?`3o06d0o`2:0>L0
^03]0;40/03b0:L0k00/0?l01aOo000no`00Fol006So001_o`00LOl05E7b00e?o`1Q5>405Dc[002e
o`00hol00?3o003ho`00o_h00?oe003ol000onP00?oR003of`00om<00?oA003oeP00onH04;ca003o
g`0=l]`00?kF003ocP00om800?oO00C`m00GL?800kgn003og000ok`00?n^003oX000oi<00?n:003o
QP00ogX00?ma003oJP00ofT01_9o003nK000odl00?m6003o@@00ocl00?m7003o>@00ob<2003o6@03
003o4000o`/00?l:00<00?l:00H00_l700?o1005o`001?l200Go0005o`4400Go000B00Go0@05o`00
1Ol100Go0004o`800ol4007o2000o`/00?lJ003]GP0Y][l00?li007o5004o`L03_l001Co000Ko`00
8Ol0100So`000`0Vo`00;ol0ooooo`03ooooo`03o`000?oooooooooo00Kooooo00001Ooooooo0000
oooooooooooo000000Sooooo1?l00004ooooo`03o`000?oooooooooo00Co00001Oooool2o`0000;o
oooo02H03S?o002So`00aOl048ga01Yjo`00j?l00:Oo04lOlP0^Io/01]gh003mj000hoX06YW_0130
j000okP00?n_003o]P00ol000?oH003>n`03/?d00?oP003o_000oil00?n=003oP`00ogD00?mb003o
JP00ofP00?mZ003oL@00ohD00?mh003oL@00ofh00?m_003oL`D00?me0P00ogH0=P00ogl00?n5003o
Q@00oh/00?nB003oU000oid00?nZ003dd@00aO800?oP003og@00omL00?oE003og000on400?o/003o
nP00m_l00>Oo003Lo`00d?l00<7o012:n`0]@o`006oo00@no`1h1Nh0FPKg04h0o`0[4_l005?o001M
o`00COl004Oo01XJk`065_l001;o0301k`2C0?L0W03`0?H0/02U0?00L@3o08X0o`3:0>X0m@2j0?l0
QP3j0?40o`3V0?l0a@3o08<0o`0h0?l01b40o`0001l0o`090?l0F`3o0;l0l03k0=40jP2<0?l0MP3o
04l0o`2>0=l0W03Z04h6j@07=?l005oo001`o`00O?l008So002?o`00Tol00hKo002ao`00aol00>Ko
003`o`00o_l00?ok003ol000onT00?oQ003of`00om400?o>00800?o800<00?o:003oc000ol400`00
okl07000ol<00?o>003nj`02`_l07f__003Al@00ol000?nY003oV@00ohd00?n1003oM@00ofl00?mV
003oH000oeP00?mC003oBP00od<00?lj003o>000oc400?lZ003o9P00oa/00?lI003o5000o`/4003o
2P0500;o1P05o`001Ol100Go0005o`403005o`002P05o`400_l7003o3P02kcL00?RP003o9P04o`80
3_l001Co000Ho`0502?o000302go000[o`00<ol000?ooooo0_l00008ooooo`0000Goooooo`000?oo
ooooooooo`000007ooooo`07o`000?ooooooooooooooool0003oooooo`000003ooooo`03o`000?oo
oooo000000Sooooo02Go0000oooooooooooooooo03`>o`0QH?X009[o00dno`04K_l02Xgo02I:k`00
[ol009gn00O]fP00ol<00>WU003Pe@00okH00?nO003oWP00ojD00?nd003od`0C]O/05JKm00R<o`0A
b^@04>nZ003oT000ogd00?ma003oI`00ofH00?mU003oH`00of@00?mW00@00?mV0P00ofL00`00of/0
0?m/003oL@03003oM@0e003oM`00ogh00?n5003oQ@00oh/00?nD003oU@00oj400?n]003o^P00ol00
0?o3003oa`00om000?oA003og@00onT00>_l003Co`00Y?l00<Oo0034o`00]_l047Ko02lJo`0:=Ol0
G@WR03@>o`00@Ol08QOo01<ko`00JOl0073o001Zo`00GOl004co000go`007?l05P?o08`0l03k0680
/`3V05l0o`1A0?l0]03S0=D0bP3/0;/0eP3o0=h0o`3o0:<0o`1^0?l0?@3o00<08`3o00008`3o03/0
o`2[0?P0_`2^0?l0R03o05X0o`0^0?l08P3o03D1o`0h2?l04Bg_001No`00L?l0087o002Bo`00W?l0
0:Wo002go`00aol00=Wo003Yo`00l?l00?ko003onP00oo000?oX003oh@00om800?o?003o``00ol80
0?nm003o_000okL00?nd00<00?nc01/00?ni003oaP0@e>X078Cj044jg`00c?T00?o9003o/@00oid0
0?n:003oO000ogD00?mX003oH`00oeP00?mB003oB000odD00?li003o>000ob`00?lX003o9P00oa/0
0?lI003o5`00o`l01000o`X00`04o`@00ol500Go0@0:00Go000300Oo0006o`001ol000@01Ol000P0
0_l7003o6`00jWd00_lK00co000Do`005ol0023o00<08ol000<09_l002Wo000ao`000P0bo`04oooo
o`03o`000?oooooooooo00Kooooo00001Ooooooo0000oooooooooooo000000Oooooo00Oo0000oooo
ooooooooooooo`000?oooooo000000?ooooo00Co0000oooooooooooo00001oooool08ol0003ooooo
ooooooooool0HPGn01`ao`0A:_l0<a;n010/o`1G5?T018[o003im`0@h^D00?nh003oZ@00oj`00?VW
003oT000ohd00?n@003oVP00ojl04<gG021lo`00omD02>CS016=n@00jN<00?;1003oP000of`00?mU
003oF`00oeX00?mH00800?mI00D00?mH003oFP00oe`00?mQ003oI003003oIP0R003oI`00ofd00?md
003oM@00ogH00?mh003oP@00ohD00?n6003oS`00oi@00?nI003oX`00ojX00?nc003o^000ol800?o8
003od@00omT00?oV003en`0<Nol0<3k_01=gk`00Zol00:?o00QYo`0I8_l0a`2_07`6e@04@?l007?o
001Xo`8008Go01H007oo001co`00I_l005Co000ko`0c2ol0;`3o0:@0f02I0>l0^03B03P0o`0b0?l0
J@3o07D0o`3P0<00Z03o0<80mP3_0>H0o`1_0?l0N`3o04<0o`098P3o0000>P3o01L0o`140?l0W@3H
0?h0f`3@06l0oP0V0?l03P3o004>o`00:?l004;o001Ho`00Iol007_o002Bo`00XOl00:ko002mo`00
cOl00=_o003To`00kol00?Oo003no`00oo800?oY003oh@00om800?o;003o`P00ok/00?nd003o/`00
ok000?n/003oZ@00ojP00?n]003o/P00okT00?o:003_kP0?Sol05X_n00WZm@0@iM000?nU003oS@00
ogh00?mc003oI`00oel00?mG003oB`00odL00?ll003o>000oc42003o:005003o8@00oaX00?lI003o
4P00o``01000o`X00`05o`401Ol000Go000700Go000700Oo000@o`002_l001Co000?o`004Ol001;o
000200go000700Oo0005o`400_lA00;o700;o`405?l001So000402?o000402Go000/o`00<ol0037o
0080<ol01?ooool00ol0003oooooooooo`06ooooo`000_ooool2o`0000Wooooo0ol00003ooooo`?o
00001?ooool2o`0000Gooooo017o0000oooooooooooooooo011Ao`194n`0[@2m0<l0R@2E0=80KQ;I
00Yno`03l>H00?no003oZ000oiH00?n=003oQP02003oP@0=003oQP00oi400?G6012ol`07/o@00?n_
003oZ000nlH06GWn007<iP00ohX00?mW003oG009003oE`03003oF000of000?mU00<00?mV00D00?m^
003oM@00ogD00?me003oO@02003oQ@0H003oR`00oi@00?nE003oX@00oj<00?n]003o/`00ok/00?o5
003oc`00omH00?oU003on000hol01YGo02Tek`00R?l056_n001Po`1;3Oh0O`CO040;nP0K@nl008go
0P00Vol05`00UOl008Oo001fo`00HOl004oo000ho`0Z2?l0aP2^09H0j00X0?l0=P3V0140o`0I0?l0
;03o05/0o`2;0?80SP3o0:`0o`3M0>H0o@3E0?l0X`3o02T0o`050280o`000280o`030?l0<@3o07l0
o02=0=`0i@2[0=h0?03o01H0o`022ol002?o000ho`00@_l02SCo00e5o`00QOl009co002Zo`00^_l0
0<So003Eo`00h?l00>Oo003_o`00mol00?kl003olP00onP00?oJ003obP00okl00?nd003o/`00ojT0
0?nT1000oj<05P00ojL00?nb003o`000omL00n7k021DmP1<K]`01l3m00GEe`00oiP00?n6003oM`00
ofP00?mQ003oE`00odL00?m6003o>@00ocP00?l/003o:000obD2003o6P03003o6000o`h00?l:0080
0?l:00<00Ol900Go0@04o`801`05o`001`0:o`004ol000go000Do`004_l001Co000Co`00100Do`00
1`0Co`004Ol000oo000@o`005?l001Wo000Qo`000`0So`00100Vo`00<ol002oo000bo`0303?o00Co
oooo00?o0000ooooooooool01_ooool0027ooooo02;o0000oooooooooooooooo00^Eo`1G6^00S@G@
02h_o00VAOl066_o02J6o000m?@00?7H00Ob]@00ohl00?mo003oMP00og@00?me003oNP00ohL00?Z_
01ZFk00?dmh00?nG003oQ000nYP00>^m00[Hg000mi`00?mR003oEP00oe000?m=0P00odT04000od/0
0?m?003oE@00oeH00?mG003oF000oeL00?mJ003oI@00ofH00?mW003oJ000og400?me003oMP00ogT2
003oQ@0`003oQ`00oi<00?nD003oV`00oj<00?nW003o/`00okX00?o4003od000omP00?oV003mn@0M
To8095?g00hno`0Z:oh0A`Oa04`Ak`1=4nT00U3o02D/o`0BJ_L00:?o002^o`00[?l009oo0029o`01
EOl014?o03<FlP0_4Ol0K@7^05@1n`1^0o/00QCo000Do`021ol03`3o02D0o`0l0?l0I@3o09h0m`3T
0>@0k@3N0?h0^`3o07h0o`0N9@3o00007P3o0140o02:0;T0lP200?l0L`3g0940iP130?<0;0?o0547
nP025_l0<0[o03LAm`0;C_l008Ko00aeo`00WOl00;[o003:o`00d_l00=Ko003Go`0:]?l00;Co003_
o`00c_d00??a003od@00okd00?nc003oZ@800?nS01h00?nO003oW000oi`00?nL003oX@00ojT00?nk
00?Ak004[Oh0:6_Q03MDm@06h?L00?o8003o[@03kl400?jB003oL`00ofD00?mH003oC000odH00?li
003o>000obX00?lX003o8000oaX00?lI003o5000o`/3003o2P04007o2005o`401Ol000Go0@@01Ol0
00D02Ol000ko000=o`005?l001?o000201Co000301?o000Do`005?l000D05?l000@05Ol001So000L
o`008_l00`0So`001@0Yo`00;ol003;o000co`00<_l000<0<ol01?ooool00ol0003oooooooooo`06
ooooo`008Oooool04Ol0003oooooooooooooool01Voo01mNn00`>O800Y7o01:>o`00j_/00Zoo00>b
n`08WoL04:oU003oU@00og@00?m[00800?mW00h00?m`003oOP00ok/05jkd003Xg@00ohd00?m_003o
JP00ofl04]Ve003oK`00oeL00?m9003oB0D00?m700<00?m8003oB`00oe800P00oeL2003oF0800?mV
00D00?mW003oK@00ogD00?me003oN@02003oQ@0G003oR@00oi800?nD003oVP00oj<00?nV003o/`00
okd00?o=003oe`00on800?o_003mo@00h?l00;So002:o`1Q3=h0n01[0;X0[@0S9_l008Wo00J4o`00
/_l00P00__l05`00^Ol009co001fo`124ND0EPKo058>g`0`3o80B@Cf000Wo`01<_l003Ko000Uo`05
2?l0>P3o0580o`1D0?l0_03Q0=h0d03o05`0o`1e0?l0N03o04L0o`0J02H0o`000200o`0k0?d0[P3V
0=00j03F0?`0N02i0=h0_@3:0;<0`P1o0>h0b02d030;o00G>Ol044kc02L/n`0W<ol008;o002ho`00
^_l038Wo011ol`0BE?l07ECl00Yfo`0:G?l00jOo003ni`00ol800?n`003oX`00oj400?nG003oU@<0
0?nD01H00?nF003oW`00okT01nKJ003iiP0=boH06kOe01Iio009X?`00?oM002fn@00ml400>j`003o
K`00oel00?mD003oB@00oc`00?lh003o:P00obP00?lN0P00oaT00`00o`h00?l:003o2P02003o2P03
00Go0005o`401Ol000D01Ol000@03Ol001Co000Do`004ol02@0Do`000`0Ko`007_l001oo000502?o
000302go000^o`00<ol000H0<ol01?ooool00ol0003oooooooooo`06ooooo`008Oooool04Ol0003o
ooooooooooooool00?3`003PoP15Dnh00>Sn003gj`00om/00>7f007@j@00ojd00?fM003oO@00ofT0
0?mT00800?mR00/00?mU003oO00;a<d089[O00;Mg`00oh400?mO003oFP00oeH00^mV003oD@0:003o
A`06003oB`00oe<00?mG003oE`00oeT00?mP0P00ofH01000of/00?me003oM@00ogP2003oQ@0`003o
R@00oi<00?nD003oW000oj<00?nW003o/`00ol004=o/003nk`00o_@00?oh003fo`00hOl00;Wo005S
o`1?4=h0G`Go04/;k`03F?l009ko002go`00b?l00<co003>o`00a?l00h?o048Lh`0R8Ol06Ckm001S
o`0C;?l0F0KX0010o`00Bol004Wo00hUoP1j0>d0_03D0:T0b02k0=@0f02n0<T0j03U0;@0f`3l0?D0
n@3o0:`0o`0C9@3o0000803o00X0oP290;X0n@230?l0N@3b09`0g0140?l0L`3S07D0o@1j0?T0]`2g
0882h@1R0]T0G0Gi09`3^P0N9_T007?o002Go`05LOl0<C3_04dZk01:==T046Gk02Ado@10=M<03h?o
00f_oP00n/`00?nZ003oXP00oiX00?nE0P00oi@06000oi800?nC003oU000oi@00?nJ003oX`00l;L0
0?c6003_i@0MOol09F;o00fGo`00W?l02l;^003][P00og`00?m^003oL@00oeP00?m5003o>000obd0
0?lX003o7@800?lI00H00?l>003o2P00o`X00?l:007o2004o`<500Go000400[o000Bo`003_l001?o
00L05?l000L05Ol001Ko000No`007ol002?o000Qo`008_l000<08ol000D09Ol002[o000_o`00<ol0
03;o000603?o00Cooooo00?o0000ooooooooool01_ooool0027ooooo017o0000oooooooooooooooo
003og000e?d0>4g]006coP00o=H00?no003be`0DYNh00?J/003oN`00ofT00?mQ003oF@02003oE`08
003oF000of800?mg00Vmb@00oJ@00?mT003oD`00odT2003oA`05003oA000od<00?ll003o>`00ocX0
0P00oc`00`00odD00?m7003oA`02003oA`05003oC000oeL00?mG003oF000of000P00ofH01000of`0
0?me003oM@00og`2003oQ@0`003oS000oi@00?nE003oWP00oj<00?nZ003o]000olH01lcg03ETg000
h?l00?;o003Po`0GP_X008[o04`;k`0KBOl04FGo02@go`0B?nl008co0032o`00dol00=_o003Io`00
c?l00H7o05/[n@02Kol009;o001lo`126^L0;QW_001Fo`00H?l005[o01l/m`0]4Ol020So0400k`2a
0=`0H@3n06`0o`260?l0[@3o0?@0aP3o06d0o`0b903o00007`3o00X0o`0l0?T0Y03<0>80R`3j03@0
o`130>l00`_o03L?o@047ol00AOo05d1nP0E:ol02T3o00D/o`1e1n40;Qko04XDo@0H>Od0Cb[^011m
m`07S_l04J;o013?n`00kol05:Gl00kOj`00g>`00?k8003oYP00oih00P00oi@06P00oi000?n:003o
R@00ohP00?n7003oR`00oi800?nD003oV`00ojT00?o0003oj@0MQ?l0U`CF012Qo@00oM<00?nX003o
T@00ohX04;O=003oL@00oe<00?lo003o<@00obP00?lP0P00oaT01@00o`h00?l:003o2P00o`X01Ol1
00H01Ol000<03?l001Co000Do`00200Do`000`0No`008_l0023o000602?o000402Go000Yo`00<ol0
037o00H0<ol000<0=_l003go0?ooool00oooool00ol0003oooooooooo`06ooooo`008Oooool07Ol0
003oooooooooooooool00?;900NOn@0/G_<00<?l003o_`00ojP00?n[00KRgP00i/800?m`003oHP00
oeP00?mG003oD`00oe400?mB003oEP00of800>K200?W[@00oeL00?m7003o@`00oc`00?lj00L00?lh
00<00?li003o@P00odH00P00odL04000odT00?mD003oE`00oeL00?mM003oIP00ofL00?m`003oM@00
ogH00?n0003oQ@00ohT00?nB003oU@00oiT2003oX`0[003o/000okH00?o7003nj`09Vol05GWo003C
o`0@Xo@09SOk05LPi@0WGo`009Wo002Wo`0R>Ol03G7o03/fm@00X_l00>3o003Wo`00i?l00=go00BL
o`00]ol00;Wo002Zo`0>J_l0CAKV02dYnP00K?l0073o001Xo`00FOl0047o01TBn`2A0>D0I03m0340
o`1/0?l0^03L0;d0nP3`0<X0o`1n0?l03P0S0?l0000S0?l00@3o01`0o`2[0?80c@3T0=L0SP3B02@0
o`080_l001[o000ho`00A?l01S;o03LKnP00HOl007ko0156o`0i:oT046go00>1o`0>Aol00gGo002l
o`00fOl00?;o003om`00onX00?gP003obP00okh00?n^003oX@00oiD00?nD003oT000ohL01P00ohD0
4`00ohT00?nA003oW`00okh00=kX02JGmP02/od0=g3[012On@00gn/04=c;003o/00@dN/04>^]013H
]`00oe<00?lh003o:P00obD00P00oaT01P00o``00?l:003o2P01o`T01?l400Go0@@01Ol000<02ol0
00go000Ao`000P0Do`000`0Co`005?l001Co000201Co000501_o000No`007Ol002?o000Ro`001P0S
o`000`0co`00<?l003;o000703?o000303_o0012o`3ooooo00?ooooo00?o0000ooooooooool01_oo
ool0027ooooo017o0000oooooooooooooooo003o[@00omL05GGn003hi@00ok<00?nF003oR@00oh@0
0?B?003oI@00oeP00?mC003oBP02003oA`08003oB000odL00?mA003iO000odh00?m3003o>`00ocT3
003o>003003o=`00ocP00?lh00@00?lh00<00?lj003o@000odH00P00odL0?000oe000?mG003oE`00
oeh00?mV003oJP00ogD00?mf003oP000ohD00?n7003oT@00oi@00?nI003oXP00oj<00?n]003o/`00
okd00?cF01JQn`0[PM/0AdKY00Qeo`0<H_l0@2Ge02@ln`02X?l00=_o00fhlP0S=Ol00<go00NWo`04
]Ol00?7o003co`00lOl00>go003To`00f_l00<go002^o`0:BOl0>bW]001lo`00Q?l0083o001co`00
I?l004ko01DJnP0N2_l020?o01P0o`1@0?l0_@3U0?40a@3o0900o`0h0?l012<0o`000280o`010?l0
:P3o0740g03H09T0o`1[0?l0=P3o05<0iP181o<004;o001No`00Iol006Ko002Bo`00W?l03Gko00fL
lP00/ol00;;o00e_o`179?@04XWo003Fo`00mol00?o]003og000ol`00?nn003o/000oj<00?nI003o
U@00oi000?n60`00ohD06P00oh<00?n0003oOP00oh400?n4003oR000oiT00]SS006Mm00=bN800>WO
003]d00=cnP09F[o00ZXn003_O@02;Cj00gQ^@00oh000?mG003o@`00ocD00?lY003o6`00oaT00?l<
0P00o`X00`02o`L01Ol100Go000400Go000301;o000Do`004ol000L05?l000@07ol002?o000Ro`00
8_l01@0So`000`0Yo`00;?l0037o000703?o000403So000ko`00>_l004;o00Cooooo00?o0000oooo
ooooool01_ooool0027ooooo01Oo0000oooooooooooooooo00;Ya`0FaoP0=5Sb01Fao`00k<P00?n<
003oO000og400?mU003oFP00oeD00?m9003oA`00odH00?m2003o?@00oc`00?lm003o?002003o>00:
003o=`00oc400?l]003o;000ob/00?lY003o:P00oc000?lc003o=P800?lh02L00?li003o>P00odD0
0?m7003oB@00oe000?mG003oF000of400?mX003oM000og`00?n3003oQ@00oh/00?nD003oV`00oj@0
0?nW003oZ@00ok400?nc003o_@00ol<00?oF013]k@00e_l047Co0:03^02D0/<00gOo002Wo`00h?l0
0?Oo003]o`00[Ol00?Sn003ko@00oO`00P00ool05`00oOl00?Ko003_o`00iOl00=co0031o`05T?l0
09_o002Mo`00UOl008So001io`00IOl005;o000no`008ol00P[o0280o`110?l0Q03i0;X0n`3o08/0
o`0502D0o`000200o`0W0?l0Z@3]0>P0g@3N0;L0f02V0=/0R03g00dAo`00B_l006Oo001io`00S?l0
09oo002ao`00_?l00<Oo003<o`00b_l00;Ko00YHo`156>l009Go00g3o`00o?L00?oQ003ob`00ok/0
0?n[003oX@00oiD00?nC003oR0800?n500<00?n2003oNP00ogH00`00ogD05P00ogL00?mo00gbVP00
i]/00?VY00C_]`02i;X00?nM003aa`00l=h02Jch05@Yl@0aH?D04;;U003`[000oH@00?e^003nS`00
odD00?lO003o6@00o`d2003o2P0300Co1005o`801Ol000<01Ol000<01_l000go000Co`001P0Do`00
100Lo`008ol001ko000Ro`0202?o000302;o000So`008ol000808ol000@0;?l003?o000bo`00<_l0
1P0co`00100no`00@_l0047o0011o`04ooooo`03o`000?oooooooooo00Kooooo000Qooooo`0Bo`00
0?ooooooooooooooo`00oiT04L;H00nFn@00j>h00MW=003oQ`00ogD00?mX003oG@00oeL00?m;003o
A`00odH00?ll1000ocP01000ocD00?l`003o;000obX2003o:@800?lX00H00?lY003o:000obP00?lZ
003o;000oc@3003o>00:003o@000odL00?m8003oD@00oeL00?mH003oI@00of/00?n2003_Y0800?n@
01P00?nE003oWP00ok000>;T003o_@00okT00?nk003o_`00ol@00?o<003ogP00o?/00;;o01QLk`1U
5o/0E2;A00JDo`00g_l00?Wo003omP00oo800?kb003ok000ond2003ol00H003omP00ool00?go003c
o`00kOl00>7o003Eo`00b?l00;So002/o`00W_l008co00=Jo`00C?l004Ko00l_o`005ol03`Co08H0
k01m0>l0X`3d0>`0]`3o07P0o`049@3o00009@3o00D0o`170?l0M`3j09H0a@3]07@0o`2U0>H0L@3m
014Xo`00I?l007Wo0028o`00Wol00;Ko0039o`00dol00=Wo003Ko`00aOl06GGk00Eco`0Z;O<0>U7a
0035o`06j_L00>oS003o`000oj/00?nN003oU000oi000?n6003oQ@00oh800?mh003oM@00ogH01@00
ogD00`00og/00?n1003oO@02003oOP0?003oQ000oi000?nV003odP0;Z_T00>gH022gb@0=U?H00=SN
003Xb006khT00?lk003o8@00oaT00?l<00800?l:00<00_l600Go0P05o`000`05o`000`0Co`005?l0
01?o000601Co000501ko000So`008ol002?o000Ro`00100So`00100Xo`00<ol002ko000ao`0603?o
000303Go000go`00>ol00080@_l000<0@Ol0ooooooooool00_ooool00ol0003oooooooooo`06oooo
o`008Oooool2o`0000;ooooo00d00?n=003o[P07Z_L00NWC003oW000oh800?ma003oIP00oeL00?mD
003oB@00odL00?ll00<00?lh00@00?lb003o;P00obP00?lY2P00obP2003o:@0U003o=P00ocP00?lh
003o?000odL00?m8003oE000oeL00?mO003oIP00og<04>nO003=h`00n;X00?nP003oY000n;h00?oH
00RBo`00o]d00?o=003le`00nmd00?oG003ofP00l_800:ko02a?l00i>^T00:Wo00]Wo`01JOl00Y?o
003gn`00onL00?oR003og`02003oh@0K003oi000onh00?oa003on000ool00?Oo003`o`00hol00=_o
003=o`00__l00:ko002No`00R?l0;SSo03<Dk`00:_l07`ko05l0k@160?l0e02l0=h0``3R0:/0g032
0>d0e@3o05P0o`0402D0o`000100o`1<0?X0e@2j0?l0OP3o04<0o`0L0?l03@ko000ko`00Eol0067o
01E=o`0:F?l00ico003<o`00gOl00>?o0P00jOl03000h?l00<Ko01QGo`0_?^D0<eW]00eio`00[_l0
0?oJ003o]`00oih00?nD003oS0800?n500/00?mi003oM@00ogD00?me003oL`00ofl00?m/003oJ000
ofX00?m/003oJ`02003oK00B003oK`00ogD00?n2003oX`0AYO404KGZ003oY@00oh<08=RM003oSP04
e<H00?mK003o=@00ob800?lI003o3000o`X00Ol91P05o`000`0?o`005?l001Co000501Co000301Oo
000Io`008?l000L08ol000@0:_l003?o000co`00<_l01@0co`001@0eo`00@_l004;o000oo`00@?l0
0080@_l00oooool2o`0000Sooooo000Qooooo`0Eo`000?ooooooooooooooo`00oi000?n/00K2k`00
old00?nP003oQ`00ogL00?mX003oF000oe400?m7003oA000ocX00?lh003o=@00obh00?lY00D00?lX
00@00?lV003o9000obL00?lU1@00obP0A000obT00?l]003o>000ocP00?lj003oA`00od`00?mG003o
F@00ofH00?m/003oO000oid08:OE003dh000okP00?ni003nf@07YOl069Wo003im`00l_H09h_[003Y
n`00no000?oc003>oP11;mL0?6OO007>o`00j_l07FKf003Bo`0PV^d01lKi003of`00om@00?oC003o
d@00omX00?oQ003oi000oo000?od003oo`00mol00>oo003Ro`00g?l00=3o002no`00YOl009Ko001n
o`0/:?X0@0;m0347o`1D0?l0e@2M0;40f@2/0</0S@3h06D0o`270?l0a@3o0?h0R`3o04X0o`0=903o
00008@3o03H0o`1_0=H0g03B0<d0M`3/0240o`0A2ol02Qoo000fo`0c7?d0K`[m03HhiP07R?l00=;o
003So`00kol00?;o003eo`00lol00;oo012En@0;_?l04YS_05LZo@0QPOl04;3k003df000oj000?nD
003oQ`00ohD00?n0003oM`02003oM@05003oL`00of/00?mW003oIP00ofL00`00ofH2003oH`0?003o
IP00ofP00?mh003SbP0/Xm400?fL00?LYP00of000?mK003oH001d[X00LO1003o@P00ob400?lH00<0
0?l:00<01?l300Go0@05o`000P05o`001008o`003Ol001;o000Co`0401Co000301Oo000So`008ol0
00808_l01@0So`0202[o000302oo000co`00<ol000D0<ol000D0=?l0047o0012o`00@_l0047o0002
04;o00Cooooo00?o0000ooooooooool01_ooool0027ooooo01?o0000oooooooooooooooo00GU_008
_>L03;o_00nkl`00cmh00?Nj003oS@00ofd00?mM003oE000odT00?m3003o>000ocL00?l/00<00?lX
00D00?lV003o8@00oal00?lN003o6P02003o6`04003o6@00ob400?lP003o90<00?lX04@00?lY003o
=P00ocP00?lm003oB@00oeP00?mO003oI@00ofd00?me003jV@0>aMl06Z;c003VmP00on005;ca0038
m`0JOo`0HRC[00mho@0^M^/09SSh02ImlP0OHo803J_h02]^iP0=/_/068om003nl@00oO001iKn00gS
lP00oml00?_H003obP00olP00?o:003od000om400?oK003ohP00onh00?oe003no`00l_l00>[o003P
o`00dol00<[o002`o`0P@O8007?o001Qo`09<Ol0R`;90=d0U@1k0><0SP3W02h2o`0R1?l0=`3b0300
o`2I0=80iP3O0>X0dP3o0;00o`120?l01B<0o`0001d0o`0B0?l0M03o09L0jP2k0:80l02<0>/0Y`3=
09`0e@1G1ND0BA3^001No`00Uol00<7o003Lo`00j_l00?;o003mo`00oo`00?oh003nmP00oOH00?kf
003FoP05W_d00?;/003diP05d>000?nO003oU002003oQ@06003oN`00ogH00?me003oM000of/00?mW
0P00ofH06@00ofD00?mQ003oG000oeT00?mH003oF@00oeP00?mL003oIP00nJH02^jX003oGP00oe@0
0?m9003o@`00odH00?aS003mP000ogP00?lQ003o5`00o`/00?l:007o2004o`801005o`000`0@o`00
5?l001Co000501Co000301Ko000Qo`008ol000808ol000D08_l002?o000So`008ol002Ko000303?o
000303;o000co`00<ol000<0<ol000@0>?l003co000lo`00@Ol00`12o`000`11o`3oooooooooo`02
ooooo`03o`000?oooooooooo00Kooooo000Qooooo`0Co`000?ooooooooooooooo`07a>`079gc003o
ZP0:f<402L7_02b5o@00j]400?n4003oLP00oeT00?m7003o?P00ocP00?l`003o:P02003o:004003o
9000oaT00?lJ003o6PH00?lI00@00?lK003o6P00ob@00?lW0P00obP08000oc000?lh003o?@00odh0
0?F@003oO`00ogd00?mj003oQ@00oiT00?k<003>nP0;JOl03Hoo02Q9lP08Soh00<Om021co`00f_/0
0?Kc00JHn`00mOD00>3j00Vgo`0=_?800?ke003oi000omD00?oC003bi`0@kl800?o30P00ol008@00
ol400?o2003oa000om000?oG003ohP00oo400?cn003do`00j_l00=So003@o`00b_l00;oo002Bo`0_
8o00:RK_048>i01K1?l0H`WQ06/0k`0<4?l00b?o000[o`007?l01P?o01l0o`1<0?l0VP3_0;P0lP3o
09T0o`1T0?l03@0T0?l0000O0?l04`3o02<0o`1I0?40^`2O0><0C@7g01<Go`00>?l0=aK`054=lP0Q
A^P00:7o003Jo`00k_l00?So003oo@00oo400?o_003oj000on800?oO003diP04kmP00?o6003o^@00
ok400?nK003oT@00ohH00?n5003oN`02003oM@06003oL000ofL00?mV003oIP00of800?mM1000oeL0
2000oeH00?mD003oE000oeP00?m_003oE`00odH00?m00P00ocP01P00ocL00?le003o=@00oc800?lL
003o4`800?l:00<01?l300Go0005o`000`05o`000`06o`004?l001;o000501Co000401So000Lo`00
8?l0027o00H08ol000<0;Ol003?o000co`001P0co`001@11o`00@_l004;o0011o`00@?l000<0@_l0
1?ooool00ol0003oooooooooo`06ooooo`008Oooool04_l0003oooooooooooooool07Ikk003o[@00
ohD00?n?003Vh@0@/_<05<GO003m]`07c</00?mX003oD000od<00?lh003o;0800?lX00<00?lR003o
6P00oa/02@00oaT00`00oaX00?lI003o8`02003o:013003o:P00ocP00?lm003oCP00mjL04Igb003o
X@00ohd00?nI003h`@00enD05Hkl060Nj01=;nl00=Sh003fgP00n>400[?e00k1k@00ol@00?o7003o
c`00on@01<;o02JKj@00onL00?oA003oa@00ol000?nn003o^`00okL00?nc003o]@00ok@00?no003o
`P00old00?oG003oiP00o_L01;7o00K8o`00bOl047Co002bo`00/Ol00:co002;o`0L<?l0a02]05<=
o`0T;Ol03CKo05@EiP0N6Ol004_o0015o`0A6_P0?07o04d0o01F0?l0SP3o0>00i03l0<T0o`1/0?l0
0@0W0?l0000L0?H0S02j0=D07`;o01TXm@00F_l006Ko00]:o`0FA_d07gGf0036o`00k?l00?[o003o
nP00oo000?oV003oh@00omP00?o@003obP00ol000?nf003o[P00oj800?nE003oTP00ohP00?n5003o
NP800?me00D00?m]003oI`00ofH00?mS003oG003003oE`03003oE@00odl00?m800800?m80P00odL0
2`00od<00?lk003o>000oc@00?l]003o:@00obP00?lT003o7000oaP00?l>00800?l:00<00_l700Co
0P05o`000`05o`000`0Ao`005?l001Co000401Co000301Ko000So`008ol000L08ol000<0;Ol002oo
000ao`000P0bo`0503?o000303co0012o`00@_l00080@_l000<0@Ol004;o0012o`001?ooool00ol0
003oooooooooo`06ooooo`008Oooool05Ol0003oooooooooooooool00=kW003gU@00ofd00?m^003o
P`00mZX04;GW022Tk@0@_>L01MFh003oF000od<00?lh003o:P00obP00?lT003o6`0<003o6@17003o
6P00oaT00?lV003o:000obX00?lf003o?@00od/00?m`003Bd@00gN000?n]003hb`00`OT00Xkn00>Y
o000e?T07g[o003lf000ok401Nne003j]`00oj/00?nY003o/P00okh00?_N00VCo`0YH_800?SY003o
bP00okh00?ne003o/`00ok000?n/003o[@00ok400?nc003o]000ol000?o;003oh000oo800>go045T
i@00Sol03Fko06TOeP0gB?H0=47O005ho`0U<?l0BQgl03dOm`0H8ol007?o00e`n`00K_l00e[o001X
o`00E_l0AA?o0602h`2J0>L0`@3;0>@0/@3m06`0o`210?l0AP3o00807`3o00000`3o00H0o`010?l0
00050?l0000O0?l0;@3I0;40S03b02lOm`00I_l0087o002Ao`00Yol00<Ko003Jo`00kOl00?Wo003o
nP00oo000?oR003og@00om800?o=003o`P00okT00?nc003oY@00oj000?nE003oT@00ohH00?n5003o
N`00ogH00?me003oJ@02003oIP06003oH@00oeP00?mG003oE`00oeD00?m:0`00odL01`00odH00?m1
003o?000ocT00?lh003o<000obT00P00obP01@00ob400?lJ003o6@00oaD00?l;00800?l:00<01Ol1
00Go0005o`000`05o`000`0Co`005?l001Co000501Co0003023o000So`008ol000D08ol000<09ol0
03?o000co`001`0co`00100io`00>ol003ko0011o`0504;o00Cooooo00?o0000ooooooooool01_oo
ool0027ooooo017o0000oooooooooooooooo003jS`00ofP00?mJ003oG@00ofh00=Ff00G3l00[L_D0
2>nd003oO@00oe/00?m7003o>@02003o:00;003o7P00oaT00?lI003o6@00oaL00?lH003o4000oa<0
0?lB003o5@00oaH01000oaT08@00oaX00?lM003o:000obT00?le003o?000od/03O2C00W4e`0>a_T0
1N3W00>nmP0]DO000>7_003o_`00j]/00L[]00O<hP00oiP00?n?003oT000oi<00?nK003oYP00okX0
0?oH0033o@09R?l00?GW003oaP00okD00?n_003oY@03003oX`0R003oY@00oj`00?nc003o^P00ol/0
0;?k003Wo`00aol035Wo080Aa`0QC_l0<Roo011`nP0UF?h08Rkl01]4o`0@P>l05dSo00=Zo`00Sol0
09ko002Co`00Qol007So001Wo`00Aol0;@Sa09`0f`1B0?l0M`3o0;<0n@3k0<X0o`2<0?l051d0o`00
02T0o`0;0?l02P3o03l0o`0/0?l07`3o0180o`010?l02`3o03P0o`0n0?l0603_0680?@7o00hVo`00
Gol007oo002Ko`00/ol00<Wo003Fo`00i?l00>oo003moP00oo000?oQ003ofP00om400?o7003o`@00
okH00?n`003oX`00oj000?nE003oT`00ohL00?n6003oO`00ogH00?me003oJP02003oIP06003oF`00
oeP00?mG003oE`00od/00?m80P00odL01P00odD00?lj003o>@00ocP00?lg003o<0<00?lX00D00?lP
003o6`00oaT00?lG003o3`03003o2P0300?o1@05o`801Ol000<01Ol000@02?l000oo000@o`004_l0
100Do`000`0Fo`007_l002;o000602?o000302go000co`00<ol000D0<ol000D0=ol004;o0012o`00
@_l0047o000504;o00Cooooo00?o0000ooooooooool01_ooool0027ooooo01?o0000oooooooooooo
oooo00;`RP00oe@00?m9003oBP00oe`00?F:003P_P02em403KKW007]V`00ofX00?mM003oA000obX0
0?lT00800?lI00/00?lH003o5000o`h00?l=003o2P00o`/00?l<003o2`00o`d00?l>003o5@03003o
6@0A003o7000obL00?lZ003o=P00ocd00?m<003fO007l[804K_/04TLl@0`Go@00>CO003i]000oi80
0?Jh00g`[@00ohd00P00ogh03@00oh400?n7003oT@00oil00?k;01[3h`07WOl0:8Se003Vk000ol<0
0?n`003oY000oj800`00oil08P00oj800?nT003o[000okH00?o:00?9m`0WE_007d?l00J@o`0?K_`0
0<So003Eo`00d?l00;Co02Tdo`09Ool00;Co002bo`00^_l00;Wo002_o`00WOl008co001lo`00J?l0
04ko02PFm`0>0ol0:03o09L0h@360?H0n`2_0?l0G03o00PL0?l0000]0?l0103o02D0o`1m0?l0GP3o
0=80o`1B0?l0[03o06l0m02J0>l0_P380=h0d`3808D0h`290>X0E@_/030Ik@0I;Ol008Ko002No`00
^_l00<_o003@o`05Y?l02;oo003nm`00onT00?oO003od@00olT00?o1003o]@00ok800?nU003oXP00
oiH00?nD003oT000ohL00?n5003oNP00ogD00?m^003oIP00ofD00?mI00800?mG00H00?mB003oB@00
odL00?m7003oA000oc`3003o>006003o;@00obT00?lX003o:000ob800?lK0P00oaT01P00oa800?l<
003o2P00o`X00Ol900Go0@D01Ol000<04ol001Co000Do`00100Do`000`0Fo`008_l002?o000602?o
000402Go000]o`00<Ol003;o00D0<ol000<0=Ol0043o0012o`001`12o`04ooooo`03o`000?oooooo
oooo00Kooooo000Qooooo`06o`000?ooooooooooooooo`00of400?m30P00ocT02`00ocl00?m:003o
HP00nj`04i3i003db`00oJ@01N7B003nG`00ob`00?lP00800?lI00@00?l@003o2P00o`/00?l;1000
o`X01000o`/00?l:003o3@00oa83003o6@0O003o8`00obT00?lh003o@P00oe<00?ml003_``0VV>l0
0<G_01RcmP00ml@00?n:003oM`00og400?m_003oK@00ofh00?md003oMP00ogl00?n<003oW000okX0
0Kgk02a?o`0OG_H04<[U013_`000ojL00?nP003oU@02003oU0800?nF02400?nO003oY@00okL00?oA
00b`n@0ZI_l01WOo003gn`00n?P00?gj003go`00h?l05XS_04LRk`0=S_L00<_o003>o`00d?l00<So
002go`00VOl01Foo001No`00EOl004?o00<Lo`0/1?`0=P3o09P0m03_0;X0o`1e0?l0;@3o00@06`3o
0000;P3o00L0o`0@0?l0M03o0=P0mP2a0=T0k@3i0:00aP3h0<L0g03:0;d0Q@3d04d0mP250?h0A`;a
00TKo`1<1_l0`02l02@Ko`02Col043ko01iAo`00Z_l00;3o04A4j@09]Ol00>co003imP00onD00?oH
003ocP00ol800?nl003o/`00ojd00?nS003oX000oiL00?nD003oTP00oh`00?n6003oN`00og<00?mW
003oIP00oeX2003oE`06003oD000odP00?m7003oA`00od400?li0P00ocP01P00obl00?l[003o:000
obP00?lS003o6P<00?lI00L00?l@003o2`00o`X00?l:007o2@04o`@01Ol100@01Ol000<02_l0013o
000Co`00100Do`001@0Eo`007ol002?o000So`008_l000@08ol000<0:ol003?o000co`001P0co`00
100do`00>Ol003ko0011o`0604;o00Cooooo00?o0000ooooooooool01_ooool0027ooooo01Go0000
oooooooooooooooo003oB000ocH00?l]003o;P00oc@00?m2003oF000oh<00=CU025>oP00f^l00?VQ
003oA`00obP00?lJ003o6@00oa400P00o`/7003o2P800?l;01400?l<003o4P00oaT00?lI003o8`00
obh00?lm003oDP00of400?N]02ZBj@00n;l00?nV00K3j`0?a]D01>nA003oI`02003oG`0?003oH@00
ofD00?mX003oLP00ogX00?n=003oX@00ok/00?kZ00ifo`00h?/00<Wh003o]@00oj000?nF00@00?nD
02400?nE003oUP00oj800?k901:ijP04/?`00>Ga003Gk`00o^000?oN003oj000noX04;oo006;o`0f
?OL04Yoo003Io`00h?l00=ko003Bo`00]Ol054Cm05DIjP1=2^l0E0gW01PGn01h0><0]@3@0;/0l`35
0<80mP2Q0?l09@3o00H0103o00000`3o00<0o`050?l00@0D0?l0000_0?l03`3o02@0o`1o0?l0;P3k
0<40a03o09l0o`3I0?00/03Q06d0o`3G0<h0E@3f00/3o`1Y0O004b_o001Bo`0e7?<0:QOo03THmP1A
1nH0O@WL001Go`00ROl008Go03I0j00[I?l0:5ge003So`00ond00?oQ003of000oll00?o3003o^P00
ok<00?nY003oX`00oj800?nN003oW@00oih00?n^003oS000ogL00?m/003oIP00oe/00P00oeL01000
odh00?m7003oA`00odD3003o>006003o=`00obd00?lY003o:@00obP00?lN0P00oaX00`00oaT00?lD
003o2P03003o2P03007o2005o`401Ol000@01Ol000<02?l001;o000Do`001@0Do`000`0Eo`007Ol0
027o000502?o000402Co000^o`00;ol0033o00D0<ol000<0@?l004;o0012o`001`12o`04ooooo`03
o`000?oooooooooo00Kooooo000Qooooo`06o`000?ooooooooooooooo`00ocH00?lY0P00obD03@00
obP00?lj003gT`0<eLd05;?a016Jj@00oj004>>i003gO`00ob<00?lI003o4P00o`/03000o`X0:`00
o``00?lD003o6@00ob800?lg003oE`00gKX05M2d00_Ee000lkl00?mg003oQ`00i/h00?mf013_N@00
oeP00?mE003oEP00oeL00?mL003oI@00of/00?mi003d[000k]<00?oB012em`0CCoX00?CW003o_`00
ojL00?nG003oT`00oi000?n:003oR000ohX00?n@003oU000oiL00?nY003o^`00l]L00P00ol805`00
olL00?o>003og`00noX068kj05lRi00=KOl00=?o003Xo`00jol00>So003Lo`01R?l0;3S_019Ko`06
E_l03BGo04h8j01Y1OD0F@;b06D0o`350=l0o`0W00D0o`0000D0o`0?0?l0;03o02`0o`0e0?l04@0C
0?l000080?l06P3o07P0o`3F0?/0e@3o06d0h`3C07P0o`290>0203T0o`0U0;l0cP1o0>l00AGo000d
o`00Eol007;o005Po`00M_l006ko01hTo`1X2L/0G@kL02LKo`0X5ol09bco0026o`00aOl00??o003o
nP00onl00?Sd00?IlP00om800?o8003o^`00ok<00?n^003oZ@00ojX00?ng00;]f001`Nh00?_8003o
O`00og400?mW003oGP02003oE`05003oCP00odL00?m7003o@`00oc/00P00ocP00`00ocH00?lZ003o
:002003o:006003o7@00oaX00?lI003o6@00oaH00?l>1000o`X00`03o`D01Ol200Go000300Go0003
00co000Do`005?l000D05?l000<07?l002?o000So`001P0So`000`0Zo`00<_l003?o000503?o0003
03oo0012o`00@_l000L0@_l01?ooool00ol0003oooooooooo`06ooooo`008Oooool2o`0000;ooooo
01000?lZ003o7P00oaT00?lI003o7@00obd00?mU003[Q`00o9H00<OX003gTP00oe000?li003o7@00
oaL00?l<1000o`X01@03o`H00?l:00?o1@00o`X00Ol900@00?l:00l00?l;003o3@00oaT00?lO003h
L@0@kiH03l[0003nS`06f[/00?mT003oD`00oeT00?af003oC@00odX00P00odL04000odT00?mA003o
E`00of000?mV003oMP00oiP01<C]013>mP0:SOl06XKo003bh@00okL00?nO003oU000ohT3003oQ@80
0?n601h00?n;003oTP00oiL00?nN003oZ000oj/00?n`003o]`00olH00?WV0036o`0LPOX0>UKY02YU
o`00gol00?Ko003eo`00lOl00>_o003Do`00`Ol00:Wo001bo`1<4^402c_o000lo`053ol0@`3o0=h0
``3o02h40?l000080?l08`3o04P0o`2T0?l0H03o08P0o`1K0?l04@3o00TA0?l0000_0?l0:`3o04@0
n`2S0<X0o`3V0=H0i@3<09L0m00k0?l05`3o00h3o`0X0_L0V`3O03h>n`00B?l006Ko0026o`00VOl0
09oo00Eeo`0P@_d064go01Xem`3;0:@0iP1V04/>g`0=S_`00<[o003Uo`00m?l00?So01JSo`00a?h0
0?o^00oSjP00l=X00?nm003o]@00okH00?nm003Zi@0_L]T01<kP003oW`00oh400?md003oJ000of80
0P00oeL01@00odh00?m8003oA`00odD00?lj00800?lh00D00?l_003o:000obP00?lX003o8`04003o
6@03003o4@00o`X00?l:00<00?l:0P05o`000`05o`401Ol000Go000200Go000300Wo000@o`005?l0
00@05?l000D05ol001oo000Oo`008Ol002;o000402?o00P0<ol000<0=?l003_o000no`000P12o`00
1@11o`00@_l004;o0012o`00AOl000?ooooo0_l00008ooooo`008Oooool04ol0003ooooooooooooo
ool00?lM003o5P00oa000?lA003o4P00oaP00?lQ003o=@00odX03NBd01;E/`00od@00?lV003o6000
o`h00P00o`X02P02o`L01?l300?o1005o`001?l200Go0003o`@01Ol000;o1`03o`D4003o2P0N003o
3P00oaX00?lT003o>@00ocL00?m600?[YP00od`00?ln003o?@00oc/00?lm003o>`00oc`00?m0003o
AP00odP00?mE003oG000ofP00?mf003oV@00f>H00Z7m078Hi@0DMO@02;Gh00?Ih@00oid00?n;0P00
ohD0<000oh@00?n3003oQ@00ohD00?n6003oQ`00ohl00?nC003oU`00oil00?nU003o/@00ol400?[T
02M]f`0k=_D02;go003XoP00oO/00?oj003ooP00o_l00?Co003Yo`00eOl009So04dVi`0DAo8006oo
00IBo`103oD0P03b0>80^`3o00P0o`1:0?l0J03o05`0o`0l0?/0/P3n07h0l03b0?00_P3i0<@0o`2;
0?l0C`3o05<0o`0f0?l01`l0o`0002@0o`0[0?l0_@3_0=X0Z03o07h0o`2>0?T0/03P08<0o@1[0=@0
21Wo00PTo`0`4O/0FPCg040BhP0T9oD01F;o002Zo`00^_l00;So002do`00Y_l007So03hLi`127_l0
<C?V040Ml@0BMO`05f_o00NKo`00eol07hWi00V>o`0QPOD0;X?j003niP00ol/2003oa00@003od@02
d_L0:X[_00?Uf000oid00?n:003oO@00og400?mV003oG@00oeL00?mC003oB000odL00?m6003o>P80
0?lh00L00?lc003o:@00obP00?lX003o9P00oa`00?lK00800?lI00<00?lE003o3000o`/00`00o`X0
0`01o`P01?l200Go0@0400Go000400[o000Do`005?l001?o00@05?l000<05ol002;o000So`001@0S
o`00100Zo`00;ol003;o000bo`0403?o000303_o0012o`00@_l000H0@_l000<0D?l0ooooooooool0
0_ooool00ol0003oooooooooo`06ooooo`008Oooool01Ol0003oooooooooooooool00?lA00@00?l:
00T00?l;003o4`00oal00?le003oK@08d[d00?mL003o9000oa<00P00o`X01004o`@01Ol100Go0@05
o`4400Go000500Go0@05o`001Ol100Co1001o`T00`00o`X02000oa000?lG003o6`00ob400?l/003o
@000oc000?l[0P00obd05@00obh00?ld003o>000ocT00?lk003oAP00odl00?mO003oL000oh400?nF
003o`P0BZ?`04ikm01;@n00?c^<00?2g003oT000ohD00?mm003oN@02003oM@03003oM`00ogl00?n5
00800?n502X00?n;003oT`00oiH00?nO003oZ`04j=000;[j01R<n@04VOl00=?m003ok`00on`00?o`
003ol@00ood00?Wo003^o`00g?l00;oo002Xo`00Vol008Go001Vo`0C<o@07PGo0;L0b`3X0:T0d03Y
0>H0dP2k0?P0nP2_0;<0o`3/0=@0bP3T0:D0o`3J0?l0o`1V0?d0f@3o0;l0o`0m0?l0603o004>0?l0
000c0?l03`3o05P0n`2^0=d0e@240>l0=P3o09`0k`180?00613o00T^o`00C_l0047o0487k`08@?l0
2Dko02``o`0@W?T00<go003Bo`00col00;[o015Xo`0`:N/007oo002Ro`02Q?l0=B_g050Ck00<M_l0
5fgk01APo`0KGOl00:go003co`00on/00?oJ003od`00omH00?oW002Po`0E[?800?o4003o[000oj40
0?nM003nT000ofh00?mT003oF000oeL00?m:00800?m700D00?ln003o>000ocP00?lf003o:`02003o
:003003o9@00oa`00?lJ00800?lI00@00?lE003o3P00o`X00?l;0P00o`X01002o`H01Ol000Go0@05
o`4300Go000300Ko000;o`004?l000D05?l000<06?l002;o000Oo`001@0So`000`0Uo`00<ol003?o
000503?o000303co0012o`00@_l000H0@_l000<0C?l0ooooooooool00_ooool00ol0003ooooooooo
o`06ooooo`008Oooool01ol0003oooooooooooooool00?l:00;o1`04o`<00P03o`D03P01o`P00?l:
003o5`00odP00?6i003RLP03dk@00?lo003o3@02o`P01?l300Go0@05o`001Ol12@05o`0200?o1@<0
0?l:00D00?l<003o5P00oaT00?lJ003o7`02003o900E003o9`00obP00?lX003o:P00obl00?lg003o
>000od<00?m>003bP000nK400?nO003oZP02/?L029Co013Md`00olX04kcY003oU000oh@00?mh00D0
0?me00<00?mg003oNP00oh<00P00ohD0:@00oh`00?nD003oV000ojD00?nl00CNiP00on<00>kU003o
h000omh00?oQ003oi@00oo000?oh003lo`00k_l00>7o003>o`00_Ol00:Oo005lo`0/<^l06aol08<1
k@1<0Nl0GP3_07H0n`1M0?l0K@3a0>00^01c0?l0X03W0;<0j@220?l0j`2h0?L0XP3H0?/0n@2_0?l0
S@3o0580o`0600h0o`0002@0o`020?l0M`330?l0_`3O05h0h@0I0?l0<03o08/0^`0>9ol005Oo001S
o`00E_l0H1GV02hfo000UOl00;3o0030o`00g_l00>7o003Oo`00_?l0=Cgo002To`0YDo800=?o0031
o`0[C?L006ko03PVm0282/@0Ea?a00>1o`00e?l00?Ko003om`00on`2003oj`0D003omP0dPNl00=Oi
003ogP00hMl00>?^00J/kP09g>000?nC003oJ@00oe/00?mG003oD@00odP00?m7003oA000ocX00?lh
003o=P00ob/2003o:003003o9`00oaT00?lI00<00?lI00<00?l=003o2P00o`X00`00o`X00`01o`P0
1?l300Go000400Go000400Oo000Do`005?l001?o00D05?l000<08?l002?o000So`000`0So`00100U
o`00<_l0033o000bo`0503?o000303Wo0010o`00@?l000D0@_l000<0A?l0ooooooooool00_ooool0
0ol0003oooooooooo`06ooooo`008Oooool01Ol0003oooooooooooooool01Ol100D01Ol000X00ol6
003o3`00odT00>:K003o9P00ob<00?lF00;o1`05o`001Ol13@05o`000`04o`801?l4003o2P02003o
2P03003o3000o`l00?lG00<00?lI01D00?lJ003o7`00obH00?lX003o:P00ob`00?lh003o?`00od/0
0?m]00WUa006`nT00?[E02bFk@0dPOl02Nk6003oX00=lZ@00?n3003oMP00ogD00P00og<0<@00og@0
0?me003oM@00ogD00?mf003oN@00oh@00?n5003oQ`00oi800?nD003oWP00ojH00?nf003o`000olH0
0?o<003od@00omP00?oQ003oj`00ooT00?Oo003Wo`00g?l00<go002fo`00W_l00WCo040;o`2B0Kl0
D`KQ000Vo`151?00NP7N00l3o`2;0>H0f@2X04<0o`0V0?l0?03o0880j03]0;T0/@3d09l0o`3=0>L0
o@3C0?l0G03o00802`3o00003@3o0040o`050?l0303o02@0o`220=80cP1^0?l0>P3o00d2o`004_l0
2A_o00Dgo`00I?l00P00M_l0:00W=_00B1cL00UVo`00aol00>3o003/o`00kol00>ko00foo`0ZLo`0
0>Ko0038o`00mOl00?7o003Go`00`?l07e7_07T8hP2T1:X06cKo002=o`06]?l00>go00_4o`0BXOl0
0>ko003Ko`0ASod087kd02Q_g`0EJOH08iCl01J_m000oj400?n1003oJ`00of800?mG003oEP00odd2
003oA`05003o?`00ocP00?lh003o;`00obX00P00obP00`00ob800?lJ003o6@02003o6@03003o3`00
o`d00?l:00<00?l:00@00Ol800Go0005o`401Ol11005o`000`0<o`003Ol001Co000501Co000301oo
000Po`008_l000D08ol000<0<?l003?o000co`00100co`0704;o000304Oo001Ao`3ooooo00?ooooo
00?o0000ooooooooool01_ooool0027ooooo00Ko0000oooooooooooooooo00Go0008o`0200_o000:
00Wo0006o`001Ol000;o1`0@kcl00?lV003o3002o`L01?l400Go0@<01Ol000<01_l000Go0006o`00
2@05o`0200Go0@0300?o1@01o`T00?l:00800?l:00<00?l;003o4@00oaT00P00oaT05@00oaX00?lL
003o9@00obP00?lY003o=@00och00?m9003oHP00jk/07:OX01Y[lP0]FNl00?oM003`[000ohl00?mn
003oM@00og000?m^003oI`02003oJ003003oK@00og400?me00800?me01400?mm003oQ@00ohD00?n>
003oU000oiP00?nS003oZ`00ok@00?nm003o`P00ol/00?oA003og`00on/04=Oj003Mo`02003<o`0G
0031o`08R?l0=dS`00Q>o`1T2]L0JP?X02TNnP00FOl02DWo010/o`017?l0G@3X08@0k@0F0ol03@7o
03`0o`2M0?<0/`3V06<0o`2n0<l0k0330?`0R`3o05D0303o00006P3o02T0o`1B0?l0D@3i0<H0bP3i
0=/0a03R0<@0U@3f05D2l@006ol003Wo001Bo`00K?l0087o002?o`00S_l02U7o031Am@00`?l00>So
003bo`00nol00?co003ao`02d?d00?og0P00oo@06@00o_X00?;o003Ao`00U_l0B3O_01]Ln`0^EMl0
K0gH00eko`0@[_<04g3o00iQo`00_ol07ESo03]Vk`00jod04]OZ003GlP00oll02Nk5003oS@00ogX0
0?m]003oIP00oel00P00oeL01`00oe400?m:003oA`00oc/00?lh003o=P00ob/00P00obP00`00ob<0
0?lL003o6@03003o6@03003o2`00o`X00?l:00<00?l:00<00Ol900Co0`05o`001@05o`000`0=o`00
4?l001?o000501Co000301co000So`008ol000@08ol000<0<_l0037o000bo`00100co`00100lo`00
?ol0047o0011o`0304;o000304Wo001Ao`3ooooo00?ooooo00?o0000ooooooooool01_ooool0027o
oooo00Ko0000oooooooooooooooo017o000Co`0301Co0003017o000=o`002Ol000801?l200d01Ol0
00Ko0007o`002Ol000[o000;o`004Ol0013o000>o`004ol0013o000=o`003_l000L01Ol000@01Ol1
00Go0003o`@00_l70`00o`X2003o2`0D003o4P00oaT00?lI003o6@00oa`00?lW003o:000oc400?lm
003oB`00oel00?n:003ed`0bE?40697m00[:i`00o[`00?n7003oLP00ofP6003oIP08003oJ@00og00
0?me003oMP00ogP00?n4003oQ@00ohX2003oU00Y003oW`00oj@00?nb003o]@00ol400?o4003od@00
oml00?oY00kHo00_I_P036_o002bo`00Z_l08F;l034Co`1b2m`08c7g011:o007I_l0083o001`o`00
EOl02BWo0:40]00o1ol002?o0206o`2=0>80KP3j06H0m00e0?l0J`3/0<D0a`2o0?H0o@200?l0703o
01L0o`0N0?l08P3o00401P3o0000?`3o01d0o`170?l0T`3_0>80j`2n0:d0eP1U0?l0W@3^0=T0]P1]
0>`0D0;b01lNn000?_l07cWb0027o`00W?l00:[o002go`00`_l02]?h003ao`00oOl00?ol003om000
onl00?oW003oh`00on000?oR003ok007g_l01Vko01EfoP0SH_P00=;o00F/o`0>R_80:D3o04Hbf@1L
7O<06C[o01]8o`0n<o800<Oo003kl@00omD00?o1003o[P00oi`00?n:003oNP00og@00?mY003oIP00
of@00?mO003oG@00of000?mA003oAP00ocX00?lh003o<P03003o:003003o7P00oa/00?lI00800?lI
00<00?lD003o3`00o`X01000o`X01002o`H00ol400Go0005o`4500Go0003017o000@o`004ol000<0
5?l000@05ol001co000So`008_l0100So`000`0]o`00<ol003;o000303?o000303Go0010o`00@_l0
00D0@_l000<0BOl0ooooooooool00_ooool00ol0003oooooooooo`06ooooo`008Oooool01?l0003o
ooooooooooooool701Co000401?o000Bo`004_l001;o00<04ol000<04_l001?o000Do`000`0Do`00
1P0Bo`005?l0017o000?o`005?l000Oo00L01Ol000<01?l400?o1000o`X00P00o`X01000o`/00?l:
003o3`00oaL2003o6@0C003o8000obP00?l`003o@000oeH00?mX00KK^P0@`Ml00>K;003;iP00nm40
3K?O003oT000ofP00?mS003oHP00oeh00?mQ003oH`03003oIP07003oJ000ogD00?me003oM`00oh80
0?n5003oR002003oU00Z003oW@00oj<00?n]003o/`00ol000?o6003odP00oml00?o/003io@00col0
4doo0021o`02K?l00dko05P:k`1@3?@08U3d002Go`00WOl009Ko001ao`0J<?L0C0[_03@7oP00=?l0
04Ko02`Hl@0D7_l0C0Gn03@1o`0=0Ol0;@3o0600o`3>0>P0l0330?40f@3o06h0o`300?l0G`3o0340
o`0:1@3o0000@03o0280o`2`0?L0a02c0?l0`P3[06h0o@0V0?l0F@3g03@0o`1h0?H0cP2A03<3o`15
1_<0CAGS00EXo`00W_l00;Oo0036o`00e?l00>Ko003bo`00ool00?od003okP00on800?oL003oe000
om400?oC003oh004__`04IWm003ao00LLNl00?7m003jo@00h_l00:Wo050Pm03J0900``2j0;00cP1=
6_`09eKd00CIm`00om800?nm003oZP00oiX00?n=003oP`00ogH00?me003oK`00of`00?m`003oN`02
f<800?ZF003oC`00od@00?li003o>000obh2003o:004003o9`00oaT00?lJ003o6P800?lI00<00?l?
003o3P00o`X01000o`X01001o`P01?l400Co0`05o`4500Go000300_o000Ao`004ol000<05?l000<0
5_l001_o000Ro`00100So`000`0Uo`00:?l003?o000403?o000303_o000oo`00@Ol000<0@_l000<0
Aol0057o0?ooool00oooool00ol0003oooooooooo`06ooooo`008Oooool01ol0003ooooooooooooo
ool06?l001_o000Jo`000P0Go`000`0Fo`005?l001Co000901Co000601?o000Do`005?l001;o000D
o`004ol00P0Do`000`0;o`004?l000Oo000400Go000500Go0@05o`001?l200?o1@01o`T00P00o`X2
003o2`0A003o3`00oaP00?lI003o6`00obL00?lb003oDP00k:000?>[02K8a003f=800?n6003=cP00
mJ000?md003oJ000oed01000oeL0=`00oe/00?mP003oIP00ofH00?mX003oL@00ogD00?mg003oP`00
ohD00?n<003oU000oiD00?nP003oY000ojl00?nd003o`P00old00?oF003oh@00oo400=Ko00=/o`0>
@Ol0GB3;0409k`1h1mT03S[o02`nl@00SOl00;;o002co`00W_l07TOd05@Ej000@_l0H0Km0018o`00
HOl005go001=o`0G9?l001co00L:o`200>D0X`3=0>T0/02B0?l0a@3]0?<0cP3^0=X0oP1k0?l0U`3o
01L0103o0000@P3o0080o`0d0?l0G@3b0<l0`@3c06/0o`100?l04P3o004;o`005_l0>0Gj03d2k`31
0;H0_P2Y00TLo`00J_l008Ko012Pn`00a_l00=Go003Uo`00lOl00?oo003om@00onT00?oO003od@00
oll00?o9003oa`00om400=?`003mi@00oml00=;e003oj000on`00<Kn00mmo`0GC?l0@1gk0744fP29
0mT0X0;000UTo`00iOh00>c^003mdP00ok@00?nQ003oUP00ohP00?n3003oN`00ogH00?mh003oS@00
h]H05L_G003oN`00oeP00?m8003o@P00ocT00?lg003o:P800?lX00<00?lT003o6@00oaT00`00oaT0
0`00oa000?l<003o2P05003o2P800_l600<01Ol100Go0005o`000`05o`000`07o`003Ol001;o0004
01Co000801co000Po`008ol002?o000Ro`008ol002Go000/o`0403?o000303So0012o`00@_l000<0
@_l000<0AOl0053o0?ooool00oooool00ol0003oooooooooo`06ooooo`008Oooool01?l0003ooooo
ooooooooool202?o000802;o000Qo`007ol002?o000Lo`006_l001So000Go`0>01Co00804ol000<0
5?l000[o0005o`001@05o`000`05o`801Ol0007o2004003o2P0A003o3000oa<00?lI003o6P00ob80
0?l`003iS`0@dk<00?RQ003Ua`00og@00?mT003nP000oW800?mI003oE`00oeH01@00oeL0=`00oeT0
0?mO003oIP00ofL00?ma003oM@00ogL00?n4003oQ`00oi400?nD003oU`00oj<00?nU003o/`00ok/0
0?oA003ogP00onD00?o/003on@00l?l00<co002Do`1:3nl0kP1S06l7jP07Eol00YSo002ko`00b?l0
0<Oo002No`0]6^H007Oo00I]o`182_L06Dgb001fo`00LOl0063o001>o`00<?l01@[o07h0o`3h07h0
P03o0540o`2O0>l0bP3P0:L0o`3R0?X0o`2V0?l0;03o00<00`3o0000AP3o01T0o`2E0?/0e03k08D0
l@2f0:D0jP1C0?d0@03o00X@o`00<ol003[o000Ro`1J0?@0A@KY06h6kP0S9o@09bWo00aPo`00]_l0
0<ko003Ko`00j?l00?Go003nn`00on/00?oK003oc`00ol@00?o2003o_P00okd00?o0003o`P00ol@0
0?o8003oc`00omP00?o/003Fo@00`Ol09cgb00I/o`0QBOl00g;o015Bo`0EL?l07Hcb00JRn`00mM<0
0?ng003k^@00oid00?nB003oR@00ohH00?n9003oY009ZO403Jof003oP000of400?mD003oC000od@0
0?lj003o<`00obX00?lX003o9`00ob05003o6@03003o5@00o`/00?l<00H00?l:00@00Ol800;o1`03
o`@01?l20P05o`4200Go000300So000?o`004_l000<05?l000<06ol0023o000Ro`000`0So`000`0U
o`00;?l003?o000203?o000303Co000jo`00@Ol000@0@_l000<0A_l0ooooooooool00_ooool00ol0
003oooooooooo`06ooooo`008Oooool01?l0003oooooooooooooool702?o00808Ol000<08ol001go
000Po`000P0Ho`0:01Co000601?o000Do`004ol0013o000Do`002?l01@05o`0200Go0@0300?o1@00
o`X00?l:00800?l:01<00?l=003o5P00oaT00?lK003o9`00ocH00?m6003oG@05_L@00?mL003oC`00
odh00?m=003oBP00odT00?m8003oB@00od/00?m@00<00?mG01d00?mJ003oI000ofH00?m`003oM@00
ogl00?n5003oS@00oi@00?nG003oW`00oj@00?nZ003o/`00ol400>WZ00Zio00?fNh00?kl003jo`00
f_l00<So01IEo`0a6Ol0<ACj03XKo`00P_l00;Co003>o`02003Go`0G006Zo`0=Po800;;o0020o`0i
5>0007_o002<o`00OOl006?o0019o`088ol0EP3k0:`0c01g0?l0D@3d01h0o`0j0?l0J03o0:/0k`3h
0:/0oP2>0?l0^`3o04<00`3o00007@3o01/0o`1_0=d0hP2i0?l0VP3_0;d0c02V0=l0J`7B03d<lP00
BOl005?o01TZo`0d7?L043[o018ho`1W2_40M`S?001Io`00Y?l00;Wo00:_o`00aol00jKo013Bo000
no/00?kR003oc000ol800?nh00@00?nc02800?ne003o^`00ol800?o>003of`00oo@00=So02i6lP00
aol009Oo0035o`03e_l0<5gk05@Nm@00c?l00?gX003of`0:_OD00>_F003ae@00oi`00?nD003oV@00
kl<0;H[U003ia`00ohH00?m_003oK000ofP00?me003oA`00ocP00?l_0P00obP00`00obD00?lO003o
6P05003o6@05003o3`00oa000?l<003o2P00o`/01P00o`X01001o`T00_l600Co0`05o`4200Go0003
00Oo000Bo`004ol000805?l000<05_l001go000Qo`000P0Ro`00100So`009?l002[o000bo`0203?o
000303Wo000oo`00@Ol000<0@_l000<0DOl0ooooooooool00_ooool00ol0003oooooooooo`06oooo
o`008Oooool01?l0003oooooooooooooool802?o000302;o000So`008ol000808_l000D07ol0027o
000Po`005_l001Wo000801Co000501?o000Do`005?l000Wo0007o`000`05o`001@05o`401Ol000Go
0003o`<00_l600800?l:0P00o`/02@00oa000?lH003o6@00oad00?lX003o;P00od000?iK003o@`02
003o?`03003o@000od@00?m600800?m70P00odP08000odd00?mG003oE`00oeL00?mR003oIP00og@0
0?mm003oQP00ohh00?nI003oW`00oj800?nU003oZ000ok400?ni003oa`00on@07X[n01BDn000i_l0
0=oo00iUo`01LOl0>S?P00MYo`00VOl05TKh01]Do`0=Lol00=go0P00j_l06000hol00=[o003Bo`00
V_l03H7e002Uo`00W?l0083o02dZlP0_5^d06`_o0:P0c@1o0>`020[o004@o`080_l0;P3o06T0o`3M
0<P0fP2k0<L0o03a0;/0o`1b0?l06080o`0004@0o`0i0?l0a`3I0><0^03[0740nP0m0?l0U03U05H3
mP00<ol005_o001]o`01H_l007Oo0029o`00M_l0<23c01`do`1<7Ml02UWo01aAo`0_=?D085Ge038Z
k00DM_l02Hko00S6n000olh00?nl003o/P00ojX00?nV003oY@00ojL00?n/003o/`00okX00?o:003o
g@00nOL00LSo00Moo`00mo/00?_/003oh000nn`01Xko002loP0GJ_@096O_0039oP0CUO`04/3f00O`
dP00ojh00?nW003o[000ol/02ioo007[c000oj000?bX02;6g000e/h00nFn003lM000och00?lg003o
;@800?lX00<00?lV003o8@00oaX01@00oaT05000oaP00?lG003o4`00oa000?l=003o3000o`d00?l?
003o4000oa800?lH003o4P00o`/00Ol9007o2003o`D00ol300Go0@0:o`004ol00`0Do`00100Fo`00
6_l001co000Oo`0202?o000702So000bo`00<ol003;o000lo`00@?l0047o000204;o000304Ko0?oo
oooooooo00;ooooo00?o0000ooooooooool01_ooool0027ooooo0_l00002ooooo`0302?o000Vo`00
8ol000X08ol000L08_l002?o000Qo`008Ol002?o000Eo`005ol000805?l000<04ol001Co000Do`00
0`0Do`00100Ao`004ol001Co0009o`0600Go000400Co0`00o`X00?l:003o2P800?l;00P00?lB003o
6@00oaT00?lM003o:000obT00?l`003o<`<00?lh00@00?li003o>P00od000?m50P00odL08000odT0
0?m=003oE`00oeP00?mM003oJ000ohT00?nP003oW@00ojh03NS3003o]000ojl00?nb003o/`00okH0
0?o1003_f@00l?D00=ko01UYnP00`Ol00:go00ITo`240]000W;o003=o`00`_l08TK_003>o`08W_l0
0>oo0P00n_l06000lol00>ko003So`00eOl00<Oo002ko`00ZOl008go00U5o`1?1NT0dP2M06D2l`0G
4_l003;o000Vo`150Ol0WP3D0;L0]0290>l0K03o09L0o`3D0?/0o`2c0?l09P80o`0001d0o`0M0?l0
H`3g0<40f@3605d0k`0J0?l03@Co01h=o`0V;o@006Go001ko`00SOl009go002Wo`00U_l02H?o002K
o`00TOl0>3K_00j0o`03Wol00k7o01Qno`09/_l0BCg`01>CoP0:g^@00?ng003oY`02003oX`0V003o
X000oj800?nS003oY`00okH00?_A013PkP0QQNh03XWo00f6mP00ioL00?oD003o``00l/P00?3@003o
f@01e_403X[o07@FkP18B^L00??i003ofP00ol/00?k=003lc`00omX04jO_003GkP0:Xo405Xgi01>_
l@04h<X00?m^003oE000od@00?lh003o=000ob/3003o:004003o9`00ob800?lK003o6PX00?lI00h0
0?lM003oA000oHX00?lm003o6@00oaH00?lD003o:P00ob<00Ol@00Co0P07o`003Ol001?o00@05?l0
0P0Ao`001`0Jo`008_l002Oo000ao`00<_l003?o0010o`000`12o`001019o`3oooooooooooooool2
o`0000Sooooo000Qooooo`09o`000?ooooooooooooooo`0[o`00<ol002So000]o`009?l000X08ol0
00H08Ol002?o000Ro`007_l002?o000No`0901Co000301?o0007o`001Ol000@01Ol000<01Ol100Co
0`04o`<01000o`X02`00o``00?lF003o6@00oaT00?lM003o9P00obP00?lY003o;@00oc800?lg0080
0?lh00<00?lj003o?@00odH00P00odL06@00odX00?mD003oE`00oeX00?mW003oPP00bmX01lWM01;4
k00?bnT00?o:003o_`00ok/00?nn003o`@00ol/00?WV00^Ho`03I_l0:T?_00EFo`0V;_l0@bKi011c
m@0<ROl00P00jol00`0JSOl00??n003lnP02003on@0I003oo@00ool00?Co003/o`00h?l00=;o0030
o`00W?l008?o001Fo`133O40P0;=04d4k000>ol004oo00<io`1E2ND040Oo0:@0fP0d0?l0HP3c0<@0
j`3d0;h0oP2K0?l0B0020?l0000O0?l04P3o0:X0b`3m09X0o`1T0?P07@3o004?o`00;_l004Wo001Q
o`00Mol008oo002Uo`00]_l00;ko0034o`00`Ol00:[o03L]n`0FP^l00=So003`o`00n_X00?Gj01Fo
k@00jNl02nCS003o[P00oj<00?nM003oV002003oUP0U003oW`00oj<00?na003od`0JQ_<07VSo003c
jP00f_@07Wko003od000ok400?nX003o[000okd00?cU00Blo`0FInl05E_f021FoP00hO/01/;k01>P
o000j?P01k;k012IkP00j?000=_S00GDe@00oj000?6O003oHP00oe400?m4003o>@00ocP00?le003o
:P05003o:003003o9P00obD00?lS00800?lS01400?lQ003o7P00oa`00?lI003o6`00ob400?lZ003o
B@00mj/00?I>003o:000obD00?i1003`L000jY800?l`00;o200200Go000;00Oo000:o`002ol000_o
0006o`000_lU007i;P02oR`05_l002;o000Yo`000P0co`001@0fo`00@Ol004;o0012o`00@ol000Co
oooo00?o0000ooooooooool01_ooool0027ooooo00_o0000oooooooooooooooo037o000co`00<?l0
03?o000[o`00;_l002_o000802?o000302;o000So`008Ol000808ol000<07_l001Go000Fo`001`0D
o`000`0?o`004_l000ko000600Go000300Co0P00o`X00?l:00<00?l:00D00?l?003o6@00oaT00?lI
003o7@03003o:003003o:@00obh00?le00<00?lh03`00?m1003oA`00odL00?m7003oDP00oeL00?mI
003oIP00ogL00?:h00;Tc`0`L?800hKo003In@00fNd00?o@003obP00ol/00?oD003oi`00nO`00=Wo
00V1o`1Z1Nl0d02E030Qo`00^Ol00>;o003noP00ooP00?ce003okP00onT00?o[003ok`00oo000?om
003jo`00k_l00>7o003Eo`00`?l016co01PlnP105Od0C0c/004ao`0m7o`0:3cm001Xo`00H?l004co
03@HkP110_l03P7o02H0o`1i0?H0/@3b0?@0^03o04`20?l0000M0?l00P3o05X0j03R0;X0nP2D0?D0
R03f02D3o`0T5?@01SOo00Q6o`0V>o800UOo00BAo`00`?l00=3o003Do`00d_l00<7o01A_o`0[=oP0
0<co003ln`00onT00?oI003oc000ol@00?nl003oX`00oiT01@00oi@08@00oil00?nd003og@0FS?l0
1MKa003o`P00ol`02Gko00S?i@00oj@00?nI003oW000okH04;Gd00C<m@0L]Nh01m;h00f7o`0mCo00
09Co01aNnP00/_l0<EON003VmP00olL00?n[003oT`00ogl00?m`003oG@00oe000?m7003o?002003o
>003003o=000ob`00?lZ00800?lX01T00?lY003o:000obX00?l[003o;000obl00?le003o;000obP0
0?lW003o:000obX00?lf00[_P@0G`md00>RJ003o@P00od<00?jB02boa@00oeP00?lM003o2`03o`H0
1Ol200801Ol000X01Ol100Co0P01o`/00?l`00S7U@01obH03ol001ko000So`00:ol00P0co`00100l
o`00@Ol004;o0012o`04ooooo`03o`000?oooooooooo00Kooooo000Qooooo`04o`000?oooooooooo
ooooo`80<ol000P0<_l003?o000ao`00<ol002oo000[o`00;ol002Co00L08ol000H08_l002?o000R
o`007ol002?o000Qo`0501Co00804ol00P0Do`000`0?o`001Ol000Go000400Go000300Co0P04o`<0
0Ol900800?l:00<00?l<003o2`00oa000P00oaT2003o6`0:003o9P00obT00?lX003o:@00obd00?lg
003o>000ocT00?lj003oA@800?m703P00?m>003oE`00oeP00?mT003oKP00oh000?nK00?Fc`00gNd0
?d_O00S5oP00o^T00?oL003of`00o^P00?ke003foP0J[>T056?n07HBh00e9o807dWo00:[o`03g_l0
0?oe003oi@00omd00?oK003og000on400?oS003ok`00ooP00?Wo003[o`00g?l00<go002ko`0@MoD0
APk/0884bP0=Bo8007go00Yio@00Qol007oo001`o`00H?l0047o000So`091ol0E@3h06H0o`2d0>/0
mP2X0?l0<@80o`0004@0o`010?l0@P3]0;X0c`2e0<L0d0380;@0SP3Y09l0i@0k2?80HP[?03dQn00i
;O8046?o0037o`00g?l00>?o003Uo`00eOl05HCo02=BnP0GMoD00mCm003oiP00ol/00?nm003o[P00
oj800?nH003oU000oi000?n;003oR000ohT00?n=003oU000nkT04[Of02i]n00=imT00?nQ003nX`0;
dML00?G@003oT`00ohT00?n;003lX000oZd00?K401[De000ol`00>;g00afo`292^T0NA3?06`Hf`0U
Do800K3n003hd000oj@00?n:003oN@00of/00?mN003oD`00odP00?m6003o?@<00?lh00`00?lg003o
=@00oc@00?lf003o>P00od@00?m7003o@000oeP00?RO003oC000ocH2003o<00<003o=P00od000?mO
00[_]`0B`[P00?mT003gR`08bm<00>Nf00CeF@00oah00?lB0P00o`X04002o`H00_l7007o2000o``0
0?ld00;D[P00mY400?lF00So0@0Co`006ol002;o000Wo`00<Ol003Co0010o`0204;o00Cooooo00?o
0000ooooooooool01_ooool0027ooooo00Co0000oooooooooooooooo0`0co`00100bo`00<ol003?o
000`o`0203?o000302Oo000Zo`009ol000X08ol000<08?l001Co000Do`001P0Do`000`0Bo`003?l0
00Wo000600Go000300Co0P00o`X00?l:00800?l:00<00?l;003o3P00oaD00`00oaT01P00oad00?lX
003o:000obP00?lZ003o<P800?lh01h00?li003o@000odL00?m7003oC@00oeL00?mJ003oI@00of`0
0?mi003oRP00oj000?o5003_l`0`H^T00>Wm003olP00o?H00<Cn01R[l@00eol0167o054QjP06TOl0
0;Go02=Ql`0dMOd05f[k003al@00omD3003od@0k003oeP00on400?o[003nnP00kol00=Wo00^Zo`0@
ZO/00:?o025Il@119NP0;R_o01ICo`00WOl00:Co002Ho`00Rol007?o001Po`00A_l05QG_02@2o`2n
0</0g@390=/0]@3P0?@0o`1l0?l05P3o0000o`0:0?l0VP3>0?40V`3O03l0o`1=0Md05@Wo038Do`0J
5oh0=aCl005Zo`00Wol00<7o003Io`00j?l00?3o003bo`00lOl00>7o002Ao`149nX00:Ko003OnP00
o]L00?ng003oY@00oiT00?nD003oSP00ohH01000ohD08000ohL00?nD003o^`0Z]>D00^f_003oR@00
oh<00^nL003oR`00og`00?mi003oO000oh400?n9003oUP00oil00?nd013?e`0PSo@03V[o04LJn01=
6Nd0R0WK012<n`00mnD00?Rn003oU@00ogl00?ma003oI@00oeT00?mA0P00odL0<@00od@00?lm003o
>P00ocP00?lj003o>@00och00?m:01S;TP00ohX00?mQ003ZYP03b=000?mH003o@`00ocl00?ln003o
@`00odd00?mL003nRP0Ma^000?nZ01:ohP0J`M<00?mO003o>@00obH00?lI003o5P00oa000?l<003o
2`00oa800?lI003o>P03ejd00>VP003mA@02o`P01Ol200[o0P0;o`804_l802Go000bo`00>_l0047o
0012o`001?ooool00ol0003oooooooooo`06ooooo`008Oooool01?l0003oooooooooooooool603?o
000603;o000co`00<_l0033o000co`00<_l02@0So`00100Ro`007Ol001oo000Lo`0501Co000501?o
000Do`005?l001Co0006o`000P05o`001@05o`401Ol000Go0@04o`<00ol500@00?l:00<00?l;003o
5@00oaT00`00oaT01@00ob000?lX003o:000obP00?l/00800?lh05X00?li003o@P00odL00?m7003o
C`00oeL00?mH003oI000of`00?mj003oS`00o[000?k>003jm001Rol00;oo003Qo`0=_O8055oo01Ii
o`0@O>l0<SCo00=/o`00col00=oo00A^o`00f_l00?Sb003kg@00olX00?o3003oa000olX00?oA003o
g@00on`03/ko01ZdjP02U_l0<ck_03X^j@0g@Nl0;ccQ01Ain`04POl00:go002ko`00]?l009oo001n
o`0@CoD02S7o00@Wo`1Z0^40Z@3Q09l0fP2=0?80IP3o0;<0o`3f0;h0o`180?l0003o00P0o`1X0?T0
`0360><0=@3o00L6o`00:ol004Oo0019o`0Z6nl0E1_X00M]o`00`_l00>3o003`o`00nOl00?oo003n
o`00m?l03[go00JVo`0ZB_l0>eWS00gCm000okh00?nU003oU@00oi43003oQ@0U003oOP00og/00?mk
003oP@00ohP00?Vg003Mg000oi400?mf003oL`00og000?m_003oKP00ofl00?md003oM@00oh400?n8
003oU000ojL00?o3003mk`0AO^l04HSo01:0o`00Y?l07VGk01:Yo006aO/00=OH003oU@00oh000?me
003oI000oeP00?m@003oB@02003oA`0L003oAP00odD00?m5003oA`00odT00?mF003fUP09/nd00?bL
007BeP08kZ@00?mS003oD`00od`00?m@003oF`00oe`00?mU003oO000nk<01L3^003o/`00og@00?mC
003o?@00ob/00?lT003o7P800?lJ01400?lI003o6`00obD00?lj00SI_@00iY/00?l^003o6`00oaT0
0?aV003hCP05fGL04M`e02_o000eo`00@Ol004;o0004ooooo`03o`000?oooooooooo00Kooooo000Q
ooooo`04o`000?ooooooooooooooo`P0<ol000H0<Ol003?o000co`00;_l002So000Yo`0702?o0004
02;o000So`008ol002?o00P05?l000<04?l000Go0005o`001@05o`000`05o`400?l:003o2P02003o
2P800?l;1000oaT01P00ob000?lW003o:000obT00?lX003o=P800?lh04l00?m2003oA`00odP00?mA
003oE`00oeT00?mU003oKP00ohX00>?800G1l@0SQo/05G_k00NQo`0KI_l03e_o002Ho`07D?l0>BS_
050GoP0?G?l00=Ko003ho@00o?/00[7o01:>j`00om@00?o4003o_`00okd00?nn003o`P00old00?oN
003olP00b?l0<UG^01/go`0U@_l00i3o002Lo`0R@>d00:co0031o`00c?l00<[o0030o`0BO_l043oo
04T7i@114?P0C`Ck04T5nP1H1O<05`So0201o`1C0?/0fP3?0?80[P3o07@0o`050?l0203o0980e03h
09@0n@1;0?l0G03g01/Mo`00FOl006[o001Wo`0FD_80=CGh01b3k`00hol00?;o003ooP00ooL00?ob
00800?o`00`00?gi002`o`0JPO/04:W^003Qi000oj800?nC003oR000ohD00?n3003oN@00ogH3003o
M@05003oN@00mI`00?n5003oLP00ofT01@00ofH0<`00ofP00?mb003oMP00oh@00?nA003oZ000ol<0
0?CZ04=FnP00m_H04<K]003Yi000hO006WKg029TmP00mml00?n[003oZ@00k<l00?n3003oK@00oeX0
0?mE003oD000od/00?m<003oD@00oeH00?mM003oF`00of800?mj003V_P00f^d03=CR003oSP00og40
0?mV003oL@00ohT00=2c003oL`00og/00?nS003acP0_ZN400?nA003oL000oeP00?m5003o>@02003o
=00C003o<P00oc`00?lZ003o:000obl00?m0003dW`03gjL00?m5003oBP00ofl05jk?003aN@01oaT0
4?l502Ko000co`00?ol004;o0004ooooo`03o`000?oooooooooo00Kooooo000Qooooo`04o`000?oo
ooooooooooooo`L0<ol000D0<_l003?o000co`00<ol002oo000203?o000302Oo000So`008ol000L0
8ol000<07Ol001Co000Do`00100Do`00100Co`004Ol000go0008o`0300Go000400Go0@05o`001?l3
00;o1`D00?l:00<00?lA003o6@00oaT00P00oaT07`00oa`00?lW003o:000obT00?lZ003o=P00ocP0
0?lj003oA000odL00?m9003oE@00oeL00?mL003oIP00og000?n4013S]@02[_402]7b00CZk@00o_D0
0=co02ATj`0Q9_l0A0Wh0<h0_02F0/805E_m00NZo`00oo800P00onD00`0Aamd00?o2003o]`03003o
/`0l003o^`00ol/00Mka003]oP0<[ol0<S7Z006>o`00e_l00=ko002`o`0f?NH02jCo003Ao`00fol0
0=[o0038o`0WD^l0;2[_00AYo`00IOl0>a?j000eo`00>_l0027o00h3o`0g0?l0S03o0=80l03o07L0
o`090?l0003o0580m@360>L0[@2l0=l0N03a02HNo`00G?l007_o002<o`00W?l00:co003=o`00j?l0
0?Oo003on`00oo000?oW003oh`00omh00?oR00S:lP0<k]d00noO00k0h@00oih00?n?003oQP00oh@0
0?mi0`00ogD0E000og000?m/003oK@00of`00?m[003oIP00of800?mM003oF`00oel00?mN003oH@00
ofH00?mZ003oM@00oh<00?nK003db000eo400KCm01^bk`00om800?nj003o/P00m]L04J?n00jbnP0K
VOd04<W`003of`00cnd03LoP003gU000ofH00?mM003oE`00oeT00?mN003oJP00mY@00n^O003oK`00
ogH00?n7003oYP00gnD00>?P003oY`00ojD00?ZK003kW`07bnT00?Rl003oT`00mkd04=3]003Pk007
YoH00=CK003`V`00ogd00?me003oDP00oe000>JJ003oHP00h9l00?ln003o>000och00?m:003dO@0@
gm400>jG00W=aP00/mX00?R7003hEP0:o`406ol002Go000bo`00>_l004;o00Cooooo00?o0000oooo
ooooool01_ooool0027ooooo00Go0000oooooooooooooooo03[o000<03?o000303;o000Uo`008ol0
00H08ol000D08_l001oo000Oo`007_l001Ko000701Co000301?o0005o`001Ol000D01Ol000<00_l6
003o2P00o`X00`00o`X00`00oa800?lI003o6@02003o6@0c003o8`00obP00?lX003o:P00ocL00?li
003o?@00odL00?m8003oD@00oeL00?mH003oG`00ofL00?ma003oOP00oi000?nT003o^000olX00?oS
016Xn`0GHOL0[PFg0;X0cP2/0[<09S_b00eko`00_Od00?oT003od`00olT00?o1003o]000ojh00?nY
003oY`00oj`00?nc003oa000iNh096Go04Q:j000a_h00>gj003mnP00l_h00;go03]2hP0=[OX00>3o
00800>Wo03H01=Go002_o`00^ol00:Oo01a6o`0g7?D0067o001Ko`0`7?T0I@?S09T0k03J0;D0mP2h
0?l0F`3o00<0o`000?l0303o0640e@3B0780n00O0_l0327o001Eo`00K?l008go002Xo`00__l00=?o
003Ro`00l_l00?kl003okP00on400?oH003od@00olT00?o3003o^@00ok@00?n^003oUP00ohT00?n5
003oP@00ogH00?me003oL`00ofX00?mW003oIP00ofD00?mR003oGP00oeT6003oE`18003oG@00ofH0
0?md003oR`00nk008hKe00Vmk`00o]H03j_k003de`00oj000?nF003aZP0=lZH00?jk00?0jP0CNOl0
CTka00bdmP00o[P00?n6003oL@00ofX00?mX003oJP00ogd00=[B00?<gP00mkd00?nG0032f000ol/0
0=_U00BHoP0gA?`02[Ce00VOn001^Nd08J;R02YLo005/?@01:KY01Jok005Ool0<77[038ZnP0GO?h0
1=7G00_]eP01e]X00?mo003oO@00iL800mc@00cYTP00oeH00?m@003^KP00ofX02>ZH00_Ke000jYh0
0?ei003cH@00ob000_l@00oo000Mo`009Ol003;o000eo`00@?l01?ooool00ol0003oooooooooo`06
ooooo`008Oooool02?l0003oooooooooooooool0?_l003Co000go`00=?l0200co`001@0bo`00;?l0
037o000bo`00:?l000T08ol000<06ol001Co000Do`00100Do`000`0Ao`002_l000Go000500Go0003
00?o1P00o`X00?l:00800?l:00<00?l;003o3`00oaP00`00oaT01`00oa/00?lU003o:000obP00?l[
003o>000ocX00P00odL06P00oe400?mG003oF000of400?mV003oJ000ogD00?mn003oRP00oiT00?n[
003ob@00on<00=?m00QSo`231m/08BOo01m?nP13:Od00<co003hnP00omX00?o;003o_P00ok<00?nY
1000oj<07@00ojX00?nl003ni00DQoH02XSn00K[k000omd00?oV003jnP0DM>l0=c7T002ho`00lOl0
0?Wo003go`00lOl00>?o003Eo`00V?l0;CGO009eo`00POl006oo001@o`1D2M`0CP3b09<0nP3^0;/0
o`0W00<0o`0001h0o`060?l0B`2j0=X0IP7S02P?o`0>9?l0?1Wh01aImP04Sol00:Wo0037o`00d?l0
0;oo00?Ao`00on`00?oO003od`00olX00?o0003o]000ojh00?nU003oV`00oi<00?n6003oQ@00ogT0
0?me003oM000of/2003oIP03003oI000oeh00?mG00<00?mG01d00?mA003oC`00odl00?mA003oE@00
oeL00?mO003oMP00d]802]GU012`j`00n[400?nL00?Gh@0G]>/00?nC003oO@00og/00?mo003oU@03
klX03Ioj00FKo@0TNOh00>CN013SYP00oh`00?mk003oO@02003oU`0^003oa@0DYOh01KK^01Zli@0O
S?h038go01J2oP0e<nh04I;o003dfP01a^/00?C200[Zb000_OL00?;D003_e@0<R_/0<D?o01AooP0?
Xol00>cV003Ag`0NROH03Jce00nYl@05cN800<C`01bLj@00oi/00?f0013NXP0E`lP00?Rh003Jd@05
hlH00?mU003o@000obL00?lB00Co0`0?o`006Ol002?o000/o`00<ol003Co00Cooooo00?o0000oooo
ooooool01_ooool000;ooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo0_l00003ooooo`Go
00000_ooool3o`0000Gooooo00So0000oooooooooooooooo03go0011o`00@_l003co00L0<ol00P0b
o`0303?o000302_o000So`008ol000H08ol000<07_l001Go000Do`000`0Do`0201?o0003017o000=
o`001Ol000H01Ol000<00Ol8003o2P00o`X00`00o`X01P00oa000?lI003o6@00oaT00?lK003o9080
0?lX00P00?l]003o>000odD00?m?003oEP00oeT00?mN003oI0800?mV01H00?mb003oMP00oh<00?n@
003oW@00ojh04=gB003Ho002/Ol0:dOo00^7o`0LHol00;oo035?k@0<QOl00?[i003oh@00ol`00?nk
003o[`00oj<00?nO0P00oiP07@00oi`00?nU003ga00?_?T00Kg`003je000olL00?o:003of`00go`0
49;o019no`00fOl00?km003on`00ooh00?_o003^o`00hOl00<_o002co`00Xol008co001]o`00E?l0
02Wo02H2o02U0=P0o`1000@0o`000280o`0T0?`0R@2H0?l0P`3M09T0g02D0<P0Q`?L010hk`0FAOl0
34[o002Io`00/Ol07TCo003Io`00o_H00?oR003odP00olP00?nk003o/`00ojD00?nR003oU@00oi40
0?n6003oQ@00ogT00?me003oL`00ofL00?mV003oI@00oe/00?mH0P00oeL01@00oe000?m9003oB000
odP00?m700800?m800H00?mC003oF@00of/01nZa01>?n`08c<`2003oOP10013PaP0CU_P00?ZL003o
K`00ofX00?m`003oW005]>d00KcZ003ocP00l]X09I7S01NXlP00ojd00?nD003oY`07a^l04<kM02R3
m00_>ol06Z7V007;e`02fN800>k?003`cP0<cnh01]WS003oV`00l8d00?mg003^ZP01d=@00?nK003o
W000e^<03n?W00feh006gm`00?nH003oS@0=b]T00nR[003]_000dN0027Co03ail@08VOP00=oC003k
b`0RW?l00?oO0032m`00jmT00>B[003oC`00obh00?lD00;o1P09o`005?l001oo000Uo`00;ol003?o
00Cooooo00?o0000ooooooooool01_ooool00005ooooool0003oooooooooool000002_ooool01Ol0
003ooooooooooooooooo000000;ooooo00?o0000ooooool000000oooool00ol0003oooooooooo`02
ooooo`05o`000?ooooooooooooooo`10o`000P12o`000`0lo`00<ol003?o000903?o0003037o000T
o`008ol000D08ol00P0Qo`000`0No`006Ol001Co000701Co00L01Ol000L00Ol8003o2P00o`X00?l:
003o2`00oa000?lF00@00?lI02800?lT003o:000obT00?la003o>`00oeH00?6M003oK000of/00?ma
003oKP00og400?mc003oM@00ogh00?n<003oX@00ojX00?nk00;El@08K_l0>D7e00^;o`0<d?d00>Cj
003jn`00e?l0183o01jGo000g_/00?GR003o_P00oj/00?nM1000oi@0>000oiP00?nZ003o]000l[d0
0?n`003o/P00ok/00?o@002knP1:;^T00;So003nm`00onh00?o`003ol`00ooh00?;o003Uo`00eOl0
0<Go002Yo`00ROl0@2G_000[o`0n1ol0S`3R0:P0i`3Y0;X0o01U0?l05@3o0000o`0=0?l0NP2o0>D0
E@3h00@@o`0B9ol0?0gg03@Co`143nl0R`KJ01/Zo`00L?l006_o01Pio`0EI_800<Cn003oj000omL0
0?o;003o^`00ok800?nT003oX@00oiD00?n@0P00ohD2003oMP04003oL@00ofL00?mV003oH@<00?mG
00<00?m;003oA`00odP01@00odL04@00odT00?mE003oJ000oiP04=35003nRP00of<00?mV003oO`00
h=D00?me003oH@00oeh00?mS003fQ@00ohH04>BR00800?nN03D01l;W00R^m00P`lT00>gE01^Pm`0B
TOh00>SR003cdP04a>X00=O[003oU@00oHX00?n2003oU000iMX01lOX003oX`00ofP00?mI003bKP00
of@00?mQ003oJP00oh<00?jh00S7h000ohX00?m/003oHP00ng000?mI003oK@00jkd03mGS003gX`00
i/L00<kV02=do`0@JOl06gKi039No@0MG_<00>c8003oJ`01kgh00?8l003o4P02o`X02Ol1017o000P
o`009?l002Wo0004ooooo`03o`000?oooooooooo00Kooooo00001Ooooooo0000oooooooooooo0000
00_ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000001?oo
ool2o`0000;ooooo0`12o`00100ho`00?Ol003ko000fo`0703?o0004037o000^o`00;ol002[o00P0
8ol000<08_l001Co000Do`000P0Do`0201?o0003013o000:o`001Ol000@01Ol000<01?l300;o1`00
o`X01@00o`X0:@00oaD00?lI003o6@00oaT00?lM003o9`00obP00?lY003o<`00oc`00?mE00?Q`000
o:P00?Fa00[Jb000oh<00?mj003oN`00oh400?n8003oU`05a=h00>kM003od@00m?T0;5Oo02i5lP04
Zol00?oS003of@00on@04=Kj01RDo`00d_d0=eK/01Boj`00i^P00?n]003oV000oi400?n<00800?n9
03d00?n?003oU000oiL00?nM003oW`00ojD00?n`003ndP0:`oT09io^003Kn000on@00?oQ003oi@00
onl00?ok003`o`00h?l00=;o002mo`00T?l007_o04<Kg`1h0Mh0X02/03P5o`0[0Ol0LP3o0>T0X`3m
0840o`0>0?l0@P3S0=L0^03@08X0l`0X7?/005[o01i1o`00LOl006go03TGo`0k8Ol0O0[Y0787f@0:
E_l00;Go003_o`00oo<00?oW003og000ol400?nc003oYP00oj400?nF003oT`00ohH00?n5003oNP00
ogD00?ma00800?mV00@00?mO003oE`00oeL00?m<1000odL0=000od400?ln003o@000od<00?m7003o
B`00og803/K?003jW@00oeX00?mA003oD`00ofL00>f:003oH000oe<00?mD003oEP00oe`00?mR003o
J`00og800?ml003oT000ok000Lo^003QiP00l/l00_7>013_S@00ohd00=OP003dX@00ogl00?mQ003o
IP00ohL00<[/003dV@0a/M400?mO003oA@00od400?m3003oC000oe`00?mh013Tc000b>@00?6P003o
H000odL2003o?`0F003mN`00g[h02nfh003oM@00ofd00nOA002kn00:H_d00]Oa00[=m@00fmh02JgT
01jbf@01i=P00?i_003o=`00k8H00?lm00Co3`0Co`006?l001co00?ooooo0_l00008ooooo`0000Go
ooooo`000?ooooooooooo`000008ooooo`Co00001?ooool01?l0003oooooooooooooool3o`0000Go
oooo00Co0000oooooooooooooooo0P12o`001@10o`00@_l004;o0012o`00>ol000H0<ol000D0<_l0
03?o000co`00<ol0037o000602?o000302;o000Oo`006_l000H05?l000<04ol000Wo0005o`001@05
o`000`05o`400?l:003o2P02003o2P03003o3000o`l00?lH00<00?lI00d00?lM003o9`00obT00?lX
003o=000oc`00?mB00g_T`04jLd068kc003ecP00oil00?n=00800?n:01D00?nF003j]P00lnH049On
003/n@0ZFNX04YWn00cBn000hNX00?o3003o_`00mmL02jGm01fZm`00o]@00?gM02IjlP00[oP00?bc
003oT000ohH01000ohD0@P00ohL00?n=003oT`00oi@00?nJ003oY@00mlL01=[T003oe000old00?o@
003od`00omd00?oY003No@00/?l00<Go0031o`00WOl0:boe020`o`1:4>d0G`[^024MoP04>_l0?PCb
08L0jP2>0?X0h@3Q0?l0;P3o03X0h@3Q06<0m@0a0oD072kc001co`00S_l00:?o00:Go`0:S?d02H_o
03l[mP1b3l<0:bgo00mno`00/Ol00>So00^jo`00boX00?oB003o^P00ojh00?nS003oV`00oi@00?n=
003oQP00oh<00?mg003oM000ofP00?mV003oG000oeL00?mD003oB@800?m700D00?m3003o>`00ocP0
0?li003o>002003o>@0:003o@000od`00?mB003oC`00od@00?m1003o@`00odH00?m9003oB0800?m7
03/00?m8003oCP00oeH00?mJ003oH`00of/00?mm003nZ@0AX^`01?;8003oS@00og`00?m]003oJ@00
lH`00?mQ003oC`00odd00?mB003kRP03am<00?mH003oG000od000?ld003o<000ocH00?m0003oE`0K
dK800<[G003kQP0BaM<00nJ@003o>`00obX00?lW003kB000ocd00?m;003o@000nE000o9g00_VX000
d>`00?C0003__001lXD00?Qh01Nga@0M_L@06MC9003Q[P00m[d02^29003o6@03o`@01_l500;o6@04
ooooo`03o`000?oooooooooo00Kooooo00001Ooooooo0000oooooooooooo000000Oooooo00Oo0000
ooooooooooooooooo`000?oooooo000000?ooooo00?o0000ooooool000000oooool00ol0003ooooo
ooooo`02ooooo`04o`000?ooooooooooooooo`D0@_l000<0@Ol003Go000co`00200co`000`0bo`00
:?l002?o000602?o0003023o000Go`005?l000<05?l000@04ol001Co000Do`003?l01005o`000`05
o`400ol4007o2@05003o2P06003o3P00oaT00?lI003o6@00oaX00?lL0P00obP08P00ob/00?lf003o
?@00odX00?mM003aV`05j=/05Ykb003ClP00n[D00?nK003oVP00ojD00>SB01:cj`0:N_l0=d3k01Z9
n`0@iN000?o;003o]P00ojX00?n_003o`P08]OT03[Wd003o]000ojL00?ne0036i`00nKT00?n8003o
P000og/2003oO00W003oP000ohD00?n5003oQP00oi000?nE003oW000oj@00?n^003o]@00okh00?o2
003oc@00om<00?oT00SVn`0CJol06UGo002Oo`00P?l0F1[Y074;f00@FOP03Eoo001/o`00Jol033Wo
02H9o@0_0?l0[P3K0?h0H@3o01<0h02e09H0^@1:1?X09C3`01A5k`04G_l00;Co00800<_o01d00:7o
02e8h@0:Lol009[o02m@n@0f>?4009Go00Iao`0GQ?T04J7k003oc000ok@00?nZ003oY000oiX00?nD
003oT000ohL00?n3003oM`00ofh00?mV003oH`00oeL00?mC003oB000odL00?m3003o>`07003o>003
003o>@00ocP00?lh00@00?lh02P00?li003o>000ocd00?lo003oA@00odL00?m9003oE@00oeP00?mV
003oO`00ojX0<iCf003d`000oh800?mZ003oF`00oeD00?m=003oAP00ocl00?lm003o?`00odh07]nI
003o>@00ob/00?lW003o9P00obD00?lX003o>P00of<00>6n003gW000odT00?>000cF[@00oc800?lK
0P00oaL05@00oaX00?lQ003o:000ocH00?m<003oJP0@`]T00?RM003oF@00od400?m5003dM@02ke@0
0?i[002ah006^Mh01MJl003lMP00obH00NAH00c6XP04ooooo`03o`000?oooooooooo00Kooooo0000
1Ooooooo0000oooooooooooo000000Oooooo00Oo0000ooooooooooooooooo`000?oooooo000000?o
oooo00?o0000ooooool000000oooool00ol0003oooooooooo`02ooooo`04o`000?oooooooooooooo
o`@0@_l000D0@Ol003co000oo`00@?l003Ko000503?o000503;o000ao`00<?l002go000To`001`0S
o`000`0Oo`005?l001Co000301Co0003017o0006o`001Ol000H01Ol01000o`X00`00o`/00?l?003o
5@03003o6@0T003o6P00ob@00?lX003o:000ob/00?lh003o?000odT00?mI003oKP00oiL04<[V012]
n@00olH00?n]003oZ@00okD00?o<003jlP0PO^l0H27U01B0o`00cOH00?o3003oX`00oiX00?nN00?V
a000`oT05I_d003oY`00ohh00?n=003dY`00ohP00?mj1000ogD0A@00ogH00?ml003oQ@00ohD00?n6
003oS`00oi@00?nL003oX`00ojX00?nc003o`000olH00?oB003oh@05k_T0297o020do`0X>Nl0=1?a
03@Uo`0J:ol057Go002So`00U_l007So001@o`085ol0T`3/0<P0dP3c06h0o`0Y0=<0k`1e0?l0N`;=
04h7kP19<>/04V?o002]o`00h?l00>;o01Z1k`03Uol04:3_003Yo`02Y?l027;o06h9g`0a:nl00<ko
003klP00ol`00?nn003o]P00ojh00?nY003oX`00oih00?nO003oU`00oh<00?mg003oJ`00ofD00?mI
003oD`00odL00?m6003o?@03003o>006003o=@00obh00?l]003o;P00obl00?l`0P00obh01@00obl0
0?la003o<P00oc<00?lf00<00?lh02@00?li003o@`00odL00?m:003oEP00of800?fG00WLi@0QQOX0
0>CV003oT@00of@00?mE003oB000od<00?li003o>000oc<00?l`003o<P00oc<00?lW003o7P00oa/0
0?lJ003o6@00oah00?l^00?XRP0Fa>800>Z@003o;000obH00?mN003h9P00o`d2003o2P0E003o3P00
oaD00?lL003o;P00odh00>^L003Re`00hk400?mA003o;000oah00?lH003o7000oeh00>6c003oI`00
ogP00Ko2003BX@09hjH00^mQ00Cooooo00?o0000ooooooooool01_ooool000;ooooo0_l00009oooo
o`?o00000oooool3o`0000?ooooo0ol00005ooooo`04o`000?ooooooooooooooo`@0@_l000D0@Ol0
04;o0012o`00@_l003_o000903?o000902_o000So`008ol002?o000Ro`008ol001oo000Lo`005ol0
00H05?l000<03ol000Go0005o`000`05o`000`03o`D00Ol8003o2P03003o2P03003o2`00o`X00?lI
00800?lI00<00?lJ003o7@00obD00P00obP05@00obh00?lh003o?P00odh00?mM003oL@00oh`00?ni
01NJo002g^H00?o4003ob00@g>800?k/00JZoP0WENl00=Co002Qo`00i>T00>K0003oU@02003oSP0<
003oVP00mm002<_W003oU000og/00?mh003oN@00ogD00?mc003oL@00og800?mc0P00ogD05@00ogH0
0?mj003oQ@00ohD00?n8003oU000oiD00?nO003oX`00ok000?nl003ob000omH00?oW003en`00/_l0
183o08d7e@2T0lD03V;o00n>o`02002lo`0c002Go`0C>?X0<aC_06@3iP1;1^P0A@3e0=l0/P3o01d0
b@3e0480o`0L9Nl06TGn034Qo`09R_l00=co003_o`00mol01]Co003_nP00oo@00?of003coP00Z_l0
9TCo0299n00RM^l00>Wi003og@00ol`00?o8003ob`00lM`00>_A003o]00?i=T01nc?003[_P00ohP0
0?me003oK@00of400?mE003oA`00odD00?lj003o>000ocL00?la003o:000obX00?lY00800?lX00<0
0?lY003o:000obP00P00obP2003o:@03003o:P00obd00?le00800?lh01000?li003oA000odP00?mD
003oG`00ogd01=KJ01>Hm000gnX00?>/003oHP00odl00?m6003o>P00ocL00?l]0P00obP01P00ob@0
0?lO003o6P00oaT00?lE003o50800?lE02000?lM003o=@00liP00?m1003o5`00o`h00?l=00;o1`03
o`D01?l300?o1@01o`T00?l;003o5`00ocD00?:<00G4h000ofT03/f_00kNU000obT00?l>00?o1@03
o`H00>i:003o8P00ob/00?lE003o:001hhX00?l^00Co1`Cooooo00?o0000ooooooooool01_ooool0
027ooooo00Co0000oooooooooooooooo1`12o`000`11o`00=_l003?o000703?o0003037o000Vo`00
8ol000D08ol000<08?l001Co000Do`000`0Do`000`0Bo`003Ol000So000300Go00<01Ol10`00o`X0
1000o`/00?l:003o4000oaL4003o6@0X003o6`00obP00?lX003o:@00oc<00?lh003o@P00oel00?mc
003k[P0=i[400?3K01^PjP02cOX00?3Z003?m`0EO?l00=3o00aEo`00^Oh00??U003@m`0EdM/00?nI
003oR000oh<00?mo003oQ000oj@05/o>003oO`00og000?m[003oI`00ofH00?mX003oIP00ofL00?mY
003oL0800?me04800?mf003oOP00ohD00?n7003oT000oi@00?nJ003oX`00ojh00?nl003og000onX0
0?oe003coP00a_l05Tgo02P`o`0R<?l03G3o0032o`00eol00=7o01aYnP05F_l0837o000no`0F9ol0
E@3m0<l0_@3o02H0f02M0700o`0D:_@007So0021o`0DL_000>3o003jo`00ooH00?o/003oh@00om`0
0?oQ00CHnP0EO_<01hgo00?Eo`0HNOh0:U?o003bmP00o^`01[Kf003amP0=VO`00?Oc003Zi@0;j_<0
0j_l003GfP00oiP00?n8003gT`05ii800?mL003oB000od<2003o>003003o<000obX00?lX00d00?lX
01D00?lY003o;`00ocL00?lh003o?P00odP00?mA003oH000ogD00?^V002gm@00mLX00?n4003oI000
odh00?m1003o>000oc000?lY003o9@00oal00P00oaT01000oaD00?l>003o2`00o`X2003o2`06003o
4P00obD01>An003e<P01o`P01?l31P05o`005001o`P00?lD003o=P00fLP00?V_003o=P00oTT00Mjd
003mGP03o`D02ol000oo000>o`003Ol000[o0005o`800Ol>00KXQ@00lfL01_l41?ooool00ol0003o
ooooooooo`06ooooo`008Oooool01?l0003oooooooooooooool604;o0004043o000mo`00??l003Oo
00D0<ol00P0bo`000`0/o`009Ol002?o000302?o000302;o000Po`007_l000@05?l000<04ol001Co
000=o`001@05o`000`03o`@00?l:003o2P03003o2P03003o3`00oa@00?lI00800?lI0P00oa/3003o
:00M003o:P00ocL00?li003oA000of`00=[300Ngl@0<_?405JgP007Ui`0?W?P04g?o00BWo`0GBOl0
KB3V01QNo`00eOP00?o5003o/`00o[000?n;003oOP00ogH00?mb003oL@00ngd00?mf003oJP00ofD0
0P00of<00`00of@00?mU003oIP02003oIP18003oI`00ofd00?me003oM@00ogH00?n4003oQ@00oi00
0?nD003oV@00oj<00?n]003o^`00iNP07HWg003?o`02aOl0@43M01=Ao`0=/?L00W?o00J;o`03[ol0
0>ko003/o`00e_l00;So01a5o`00O?l005ko024Ao`2:0>40o`0V0>40bP1R0NL09bCh01IGo`00Z?l0
0<_o003Xo`00n_l00?o_003oh000om400?o:003oc000hNL00?CS003Rk000on<02mgb01N[l`0BV?D0
49?o01mfn`0FV?h0<5Si01JNo@08L_l0:Do]02m[k@01gN@00mc=003o[@0IcM`00?jW003oLP00odh0
0?m2003o>000ocH00?lZ0`00obP01P00obD00?lR003o8P00oal00?lN003o8@800?lP00<00?lT003o
9`00obP00P00obP05P00obT00?l]003o>000ocX00?m6003oE`00of`00?n9003oZP0SRnd00=cU003o
WP04jJ800?mE003o@000ocL00?lX003o9`00oa/00?lI003o6000oa83003o2P0S007o2@02o`L00_l6
00;o1`02o`T00_l<00?o1006o`002_l000ko000Bo`004Ol001;o000=o`002?l000Co0P00ob<00o1c
003?bP00odl00?lE007o4000od000?IQ00[o0P0Jo`007Ol001oo000Mo`006ol001;o0006o`D00^i`
003N[P02oaT01?ooool00ol0003oooooooooo`06ooooo`008Oooool01?l0003oooooooooooooool:
04;o00P0<ol000<0:ol002?o000So`000`0So`002@0Po`005?l001Co000Do`004ol001Co000Co`00
2_l000Ko000200Go000400Go0@05o`000ol4007o2@<00?l:00<00?l<003o4P00oaH00`00oaT00`00
oa/00?lJ003o:002003o:00T003o:@00oc400?lh003o>@00odH00?mF003oKP00oYT00?nK003oY`00
okh00?Gb00BMo`1L6NP0V0;R07D=g003M_l00;Cj003o^P00oih00?n?003oP@00ogH00?m/003oI`00
ofH00?mR003oH@00oe/00?mH003oE`00oeT00?mG003oF000oe`00?mU0P00ofH0AP00ofP00?mc003o
M@00ogD00?n3003oQ@00oi000?nD003oV`00oj<00?n^003o_@00oN804;ck00mRo`0;D_l08Toj01j<
lP00kol00<Wo003`n`00oOP00?oi003no`00lol00=_o002ko`00V?l09BWl04l8oP200>@0mP1l0<T0
a@0`2Nl0FQ;O04dIm`0N@?X00;Co003?o`00fOl00?Sh003og000olT00?nn003o^000okX00?nk003o
_P00olD00?o?007[l@0XNo000?k^003kgP00omL01Lk^003oc000nml049[o003Sm@0GY^d05WSo01g3
j`05_?X01l_U003ZZP00oe400?m3003o>@00obd2003o:004003o9P00ob@00?lI003o6`<00?lI00L0
0?lL003o6P00oaX00?lJ003o7@00oah00?lW00<00?lX01000?la003o>000od800?mf01fic@0=d^<0
0?KH035Jk`0?Rod02L[]00WY/000oe/00?m2003o=000obP00?lQ0P00oaT01P00oa000?l:003o2P01
o`T00ol500Go0@@01Ol000<01ol000go000Co`001P0Do`005@0Co`002_l000?o2003iV800?C4003l
JP05o`D03ol000_o0P0=ma/07ol002?o000Xo`00:Ol002Ko000So`008?l000oo0001oaH00>Nc003f
V@04ooooo`03o`000?oooooooooo00Kooooo000Qooooo`04o`000?ooooooooooooooo`T0@_l000<0
?Ol003?o000co`00100co`000`0bo`00;Ol002Co000302?o0003027o000Oo`007_l000@05?l000<0
4_l0013o0009o`001005o`000`04o`<00_l6003o2P02003o2P03003o2`00oa800?lH00<00?lI00<0
0?lJ003o7@00obD00`00obP06P00ob/00?lh003o>000ocd00?m8003oD`00of000?m`003oPP00oiT0
0?nd00VSm@0KDo/0Q0OW03PaoP0b@O`00<3o003lj@00okL00?nM003oSP00ogd00?mb003oI`00of80
0?mJ2000oeL2003oF@0_003oH`00ofH00?mW003oL@00ogD00?mf003oQ000ohH00?nC003oU@00oj00
0?nT003o/P00ol004>gM002hoP01Mol0ZP:o00F0o`00i_l00?of003oj000on@00?oU003oj`00ooP0
0?Oo003Po`00__l045c_05XFm00a6o00;1So0<T0]P390<<0=aoo009Yo`00LOl0;dO_015DoP0KD_@0
65?m02Mmn`00g_400?o3003o/P00oj`00P00ojX06P00ok800?ng003oa`00i_D04HKh013]f`00okh0
0?na003oYP00oj800>;A00WCf@03j//00?>n003Yi`0lE_d095[n003Wb000og/00?mI003o@P00ocP0
0?lY003o:000ob@00?lN0P00oaT00`00oaX00?lI003o6@03003o6@03003o6P00oaT00?lI00800?lK
02000?lV003o:000obP00?lZ003o=`00ocd00?m>003oL@00oZX05[[g022<kP15=o802=ST003KiP0>
h:L00?m6003o=@00obP00?lQ003o6@00oaH00?l;003o2P01o`T01?l400Go0@05o`001Ol100Go000:
o`004?l001?o00<05?l001406Ol001[o000Lo`007Ol001[o000Eo`005?l000_o0001oa@00?Ym00?o
400Co`007_l002?o000Wo`00:ol003;o000203?o000703;o000ao`009_l001Go0@0>dW801nRD003W
^P04ooooo`03o`000?oooooooooo00Kooooo000Qooooo`04o`000?ooooooooooooooo`L0@_l000<0
@?l003go000eo`001`0co`000`0ao`009?l002?o000302?o000302;o000Do`005?l000805?l000<0
4_l001?o0005o`001005o`001`04o`<00ol5003o2P00o`X00?l;003o3`00oaH00P00oaT01@00oaX0
0?lI003o7000ob000?lW00<00?lX01`00?l[003o=`00ocP00?lh003o@P00odL00?mD003oG`00of`0
0?mo003oYP00ol000?[]01mVlP0KG?l01:[o00Bmo`0YJ?P00?;]003oaP00ojh00?nG003oP`00og00
0?mT003oF000oeL00?mE0P00oe400`00odh00?m=003oD004003oE`1:003oF`00ofD00?mV003oK`00
ogD00?mi003oQ@00ohX00?nE003oW`00oj@00?n`003o^000olP00?oN003^o@0bCnh00H3o01EQoP0=
R?l01>o/003oe000om400?oG003oh`00o_H00?3o0035o`00Xol0CRO^00UPo`00SOl03T?o08d2l@2W
0<T0=Qkn01QDl`00b?l00<3o01UNm@00eOl00=Cn01^[nP0@Zo<00?c5003oY`00oj<00?nQ003oXP00
oj@00?n^003o_P06c?<08ekO013Pf`00ok<00?nO003oT000ohh00?nK003oRP00ohH00?n@00k[b000
dOX00?3F02fRh002hkl04>1m003oEP00ocL00?lX003o9P00oa`>003o6@0E003o6P00obD00?lX003o
:@00oc400?li003oA000oeX00=c;003b^000o<h04:k_003`^@00ohL00?mU003oA@00ocL00?lX003o
8@00oaX00?lC00800?l:00H00ol600Go0@05o`001Ol000So000@o`0401Co000401Wo000Oo`008Ol0
02;o00808ol00P0Ro`002`0Mo`005?l000;l8P01mfd02o4U023o000Xo`00<?l003;o000co`00=?l0
00<0=Ol00P0co`00100Uo`004O`@00?o;P00m5L4ooooo`03o`000?oooooooooo00Kooooo000Qoooo
o`05o`000?ooooooooooooooo`14o`001@12o`001@11o`00@_l004;o0012o`00>Ol000H0<ol000<0
<_l002Go000So`000P0So`000`0Qo`005ol001Co000201Co000301;o000?o`001Ol000@01Ol000<0
1?l200?o1@00o`X00P00o`X00`00oa000?lI003o6`02003o7P03003o8000ob800?lU00<00?lX00<0
0?lY003o;@00ocD00P00ocP06P00och00?m6003oBP00oeL00?mU003oLP00oh<00>W=003In00GUO`0
5Y[j00_?n@0;f^h00?gN01ZjmP0DXNl03Z[_00^Rn`00lL/00>:f003oL`00oel00?mG003oD@00odX0
0?m70P00odP2003oA`03003oB@00oe400?mG00800?mG01@00?mR003oIP00og400?me003oO`00ohH0
0?n@003oY000okH00?nh003o_@00olP00?oE003fl00`KNl06XCo003Uo`0:Nol00?_/003ndP800?o4
03800?o=003oh00@h?T00IGo02U4n`0SC_`008co002io`00X?l06Coo021@k`0Y7nl03fGo012Xk`00
j?l00=ko02eRk000b_l00?oW003ocP00k=000?n/003oW@00oiD00?nD003oUP00oih00?nU003o^`00
o>401h?o003hkP0Egl400?nH003oQ`00og`00?mg003oL000ofl00?mk003Ch000jZh00?VB003eV@00
k<P04=nl003gMP00oc@00?lX003o7`H00?lI00@00?lH003o5P00oaP00?lG1@00oaT05@00oaX00?lL
003o9`00obP00?l[003o>000od000?m=003oK@00oh000N^f00jAnP00o<000?mi003oG@00odP00?lk
003o;`00ob800?lI003o4@02003o2P0600Co0`05o`001Ol000Oo000@o`004_l00`0Do`000`0Lo`00
8Ol002?o000702?o0005023o000;oaD04_l802?o000/o`000P0co`00300go`00>ol003oo0010o`00
@_l0047o000oo`00>_l003Go000]o`008_l0013o0PCooooo00?o0000ooooooooool01_ooool0027o
oooo00Go0000oooooooooooooooo04Co000904;o000303Wo000co`00<ol00080<ol00P0bo`000`0X
o`008ol002?o000202?o000601ko000Eo`005?l001Co000?o`002Ol01@05o`002`03o`@00_l7003o
2P00o`X00?l;003o5000oaT00?lP003o@000oc800?lZ00@00?lX00<00?lZ003o;`00oc@00P00ocP0
6P00ocX00?ln003oAP00odP00?mA003oH@00n8X00?n;003oUP00lMH058_o031<l`00hO400?no003o
/000okX03MWO01^]i@00nld00=gG01bDl@0=b=d00?^9003oGP00odl00?m91`00odL0C000odP00?mA
003oE`00oeP00?mP003oIP00og@00?mo003oR000oi000?nN003lb006/o800?oE00[WiP01b_L00>Gf
003BoP0PQol03LKi003oh002iNH00?o6003o^000okD00?nh003oa`03enl00jgn03=_i`00eod00;;o
01Mno`00jol00>co003Bo`00WOl0=R[a00:Xo`00iOl00?kj003mn007Y?h0A5oO003Tl000okP00?nU
003oVP00oi<00?n@003oSP00oi000?nD003oW@00m<`03KKj02aBo004Sol00m;Q003oUP00ogl00?mb
003oJ000of800?mM003oH@00nGH00?mK003oE@00oeT02]J`003gP@00ocd00?l[003o9000oa/3003o
6@800?lB00P00?l;003o3`00o`/00?l?003o3P00o`l00?lC003o5`<00?lI01H00?lK003o7`00obL0
0?lX003o=@00oc/00?m8003oF000o7T00>_301bDm@0@Zo003]b`003oI@00oeH00?m?003gC@00ob/0
0?lJ003o3`00o`X00Ol90P05o`000`06o`003_l001Co000201Co000301Ko000Oo`008_l000@08ol0
00<09_l002[o000^o`000P0^o`001`0Zo`00:ol002oo000bo`00=?l003Wo000no`002012o`001011
o`00?Ol003Oo000To`04ooooo`03o`000?oooooooooo00Kooooo000Qooooo`;o00000_ooool704;o
0003043o000no`00>?l000L0<ol000T0;ol002?o000So`008ol002;o000Io`005?l001;o0009o`00
0`05o`0200Go0@0300?o1002o`H00?l:00800?l:02T00?l;003o4P00oaT00?lQ003o?P02fZ000?m:
003o=`00oc@00?l`003o<@00oc<00?lg003o>000ocT00?ll003o?`00odD00?m7003oB000odd00?mH
003oJ`00l;P00l3T003n_@00a?@019_k00G:mP00h]l00?nP003oU`00ojL00>gY00Fel@00oi/00?n9
003oV@00njH00?ZQ003oD`02003oA`05003o@`00od000?ln003o?@00od@00P00odL0<@00odP00?m:
003oE@00oeL00?mQ003oJ000oh800?6d003oX000oj400?nd0034n@0XS?h04JGj01>>oP0ZH_T01Y;o
0121m@00io`00?oQ003oa`00okT00?n`003oZ@00ojD00?nZ003o^@00i^H0;E?l003]k`00onD03k?o
0168o000oOL00?oe003UoP00YOl0C2WO00=/o`00`ol00?oZ003og@00onP05:Ko002[n`0=l[H00?nG
003oT000ohL00`00ohD05`00ohX00?nB003oX`02hmP00>3i00NYo000olX00?nO003oP`00of`00?mR
003oE`00oe<00?m9003oB000od@00?m1003o@P00oeX02<V<003o;`00ob<00?lK00800?lI00h00?lD
003o3`00o`/00?l<003o2P00o``00?l:003o3P00o`/00?l:003o3P00o`X00?lD003o5`800?lI01T0
0?lJ003o9P00obP00?ld003o>P00odL00?mG003oK`00m;d00<gb012Zj@00m;<00?mj003oLP0@k:P0
2N6Z003o?P00oa`00?lC003o2P02o`L01Ol100Go0007o`004ol000<05?l000<08?l0027o000So`00
0P0So`001@0Vo`00;ol0037o000co`00<_l000@0<ol000@0=Ol003So0011o`00@Ol01012o`002@15
o`00B?l004Wo001:o`00BOl004Oo0014o`00@Ol003co0003ooooo`;o00002?ooool0027ooooo00Ko
0000oooooooooooooooo057o001:o`0804;o000303So000co`00<ol00080<ol000<0<_l002oo000T
o`000`0So`006@0Po`005_l001?o0007o`000_l800?o1P02o`H00ol600;o1`01o`T00?l:003o2`00
o`X00?l;003o3000oaH00?lJ003o8000ob/00?m@013M/000ofl00?m5003o?000ocX00P00ocT01@00
ocd00?m3003oB@00od`00?m900800?m:00/00?mA003oE`00oel00?mn003_`@0@/>P05Lo`03N;m`00
e>D00?^e003_Y@02003oQ@0=003oU00<eM/04j_S003oT@00ofh00?mQ003oI000o6D00?m8003o@`00
oc`00?lh003o>P03003o>00J003o?@00odD00?m7003oB000oe800?mG003oGP00ofX00?n5002ih`00
h^P00?nm00caeP04c?T0=SSU02Enk`00i_<00=c[003oh001d_X04h3n003gh@00okh00?n_003oX`00
oj82003oW`0d003o[P00h^/00>_R003o_`00olP04:[Z006in`00oml00?oQ00gPm@0NMoP0?cKn02QS
m002`ol00?oN003oc`00olL00?o5003]g000oj`00?n@003oQP00ohD00?n2003oO`00oh800?n4003o
Q`00oi@00?n[003hi00BJ^l04>OK00gTe`00oJ800?m]003oG000oeD00?m8003o@`00ocT00?lh003o
=P00oc@00?lf003o<@00obD00?lK003o6@00oaP00?l?003o30T00?l:0P00o`/06@00o``00?l@003o
6@00oaT00?lJ003o8P00obT00?lf003o?`00odX00?mK003oK`00ohh00?g:022Xi000mLd00?FN003o
[`02b>001]mn003o=`00ob000?lE003o2P01o`P00P05o`001P0?o`005?l001Co000Do`007_l002;o
00<08ol000D09?l003?o000ao`00<ol003;o000303?o000403Oo000lo`00@?l0043o00<0@_l000P0
A?l004Oo001@o`00COl0053o001Ao`00D?l0057o0080D?l000<0COl004Wo0?ooool00oooool00ol0
003oooooooooo`06ooooo`008Oooool01_l0003oooooooooooooool0DOl0053o00P0@_l000<0>_l0
03?o000co`00100co`002`0Vo`008ol002?o000Ro`006ol001Co000<o`000ol7003mEP00oaT00?l>
00D00?l:01D00?l;003o4000oaL00?lI003o8@00ob/00?lh003oG007/NL00?;?003oJ@00odP00?m6
003oA@00odH00?m;003oE000oY<00?ig003oF@00oeH00P00oeL05@00oeh00?mX003oPP00kL400=gb
03/Yn`0<Z_X00?o0003oT`00ogh00?mc003oM000oh@00?[101jDm`00kKH00?mP003oE000odX00?m5
003o?P06003o>0800?li01P00?ll003oA`00odL00?mB003oE`00of800?m^003oQ`00okh08ZCa013]
jP0OU_@01Xon003Pn@0E]?D00?o;003o]`00ol<00=S_02=`k@00j^/00?nk003oY@00oih2003oU00H
003oU@00oi`00?nT003oY@00ojH00?nc003Nj`00om000?o:003ocP00onD00>Sn03aWmP04W?l00?[j
003oe`00ol400?nd003oZP00oj@00?nE003oQP00oh<00?mi0`00ogD04000ogP00?n3003oS@00oj@0
0?o>01Z@n`0/J_l04:Kh00K@c@00og<00?mL003oD@00odH00?lk003o=`00oc02003o:007003o9P00
ob<00?lJ003o6@00oaL00?l?003o300=003o2P0K003o3000oa800?lI003o6@00ob800?lZ003o>000
odT00?mV003oK000og/00?nD00K>jP0]C^l04iCo003if@0I^>/00?Zc003oL`00oeD00?l`003o6@00
o`d00Ol900Go0@05o`003Ol000805?l000<05_l001oo000So`000P0So`000`0Vo`00<_l003;o0004
03?o000403Ko000no`00?_l0047o00@0@_l000<0BOl004go001Ao`000P1@o`08057o00Cooooo00?o
0000ooooooooool01_ooool0027ooooo00Ko0000oooooooooooooooo057o0018o`0504;o0003047o
000no`00>?l000D0<ol001<0<?l002So000So`008ol002;o000Qo`005_l001?o0007o`000Ol?003_
V000odX00?lO003o5`00oaD00?lD003o4P00oaD00?lF00800?lI01800?lP003o=@00odD00?m:003o
GP00nKh00=jm003oJ000oeH00?m@003oC`00oeP00?b0003oM`06dMd00?JM003oJ000of<2003oI@0:
003oJ@00og800?n;003o/P0GY>/049;j002ko@05a>`04>BJ003oL0800?mW00P00?ma007^[000`^80
0?bI003oE`00odP00?m2003o>@800?lh0P00ocL2003o=P<00?lh03400?lj003o@`00odL00?mA003o
F000ofD00?mb003iW`04_nD01k?k04M:k`0[S_000>?Q003i`P00m;X00?nR003oX@00okD00>SY03Ib
l000[_d00o3=003oX@00oiD00?nB003oR`00ohT00?n;003oSP00oi000?nE003oW000ojP00?n]003o
]P00ol@00?oR003eo@0WLn/05W7o003Uo`09hnP00?nl003o[@00oj400?nE003oR`00oh<00?mg0080
0?me0P00og@03`00ogD00?mi003oR@08i/L03jkg00RIo`0n=?X00?7]00?b/@00ogH00?mP003oC`00
od@00?lh003o<002003o:007003o8`00oa/00?lI003o6@00oaD00?l?003o2`0?003o2P0J003o3000
oa@00?lI003o8000oc000?m400;_L@0Bg<D03NRg003T_000ok<00>?[03A=k`0WA_806I?h003]e`06
a^400>7W003WcP00mHX00?lR003o3@00o`X01Ol100Go000<o`0201Co000301Ko000Qo`008ol00080
8ol000<0:ol003;o000co`000P0co`00100do`00>?l004;o0010o`0504;o0004053o001>o`00D?l0
053o00H0DOl000@0E?l005Ko001Io`00Fol01?ooool00ol0003oooooooooo`06ooooo`008Oooool0
1ol0003oooooooooooooool0COl004_o0014o`001P12o`000`11o`00<ol003?o000203?o0080<_l0
0140:_l002?o000So`008_l001co000Do`004Ol000Co0P00nc<01Nf800gGW000mUL00?ln003o<000
oah00?lI003o6P02003o6`0]003o8`00obX00?QL00;V^P0;iYd00?mn00CDcP0DgK`00?md003oI@00
of400?mR003oKP03i/@03NW;016_j`00oi`00?mn00?bQ`03i9d00?n=003oO`00ohD00?C000j/m@0B
^O400?g00178j000o:P00?me003oHP00oe/00?mG003oFP00of400?j>00[QU@00odX00?lm003o>@00
ocL00?lb003o;@00ob/00?lY00800?lZ01/00?l/003o=P00ocP00?lh003o?@00odP00?mF003oH`00
ofd00?mk003oU000ol005jGi04Mbf00@[oX01NG=003oV000oh`00?n;003oT@00oj@00=oO01enl@06
/o`00nKB003oW000oi400P00ohD0:@00oh<00?n2003oQ000ohD00?n8003oT000oiH00?nP003oZP00
ok/00=?b01>>o`0kB?00DRCU00i/o`0FaND00?no003oZP00oid00?nC003oQP00og`00?me003oLP00
of`00?mV003oJ000of/00?m`00SbQ006g;@00?nm01[6f@00gN<099[X00KV``00ohX00?^D003oH`00
od<00?lg00800?lX00H00?lP003o6P00oaT00?lG003o4@00o``7003o2P0400?o1@01o`T00_l600;o
1P800Ol81@00o`X07000o`/00?lH003o7@00oTP03NB6003[[00F[]H06<Jm00?;b000bo804<KT003H
m@0eD^d00YWi003nY@00oh000?mc003nJ`00ocT00?lQ003o4@00o`X00ol300Go0@09o`004ol001Co
000Ho`0302?o000302Co000ao`00<ol000<0<ol000<0>_l0047o0010o`001012o`000`18o`00D?l0
053o0005057o0080D_l000@0GOl005[o001Qo`00H?l00P1Qo`04ooooo`03o`000?oooooooooo00Ko
oooo000Qooooo`04o`000?ooooooooooooooo`80DOl000<0Bol004;o0012o`000P12o`000`10o`00
?Ol003Wo000203?o000403;o000co`00<ol002co00<08ol002X08Ol001So000Do`003Ol000Co0`00
oa800?lf013QX@0C`]@00>c5003oA`00ob`00?lV003o8`00obH00?lX003o:@00ocD00?m600O/Y@0R
`L`00<oV00O<k`00mZd00?n5003oO@00ohX04>RQ003oR`00ojd00[ca003Pj@00oL000>Nn003]dP00
dOD00?nf013_YP00oj@03]oO01BQn@00hM/2003oS`0>003mT`00of400?mG003oC`00odP00?m9003o
C000of800?]F003o>`00ocP00?lb003o:P00obT4003o:00f003o:@00obP00?lY003o<000ocP00?lj
003oB@00lgd00?:C00c[Y@00oi<02Mk400Z]n`0EW_T00?k=003Mi00=ikD00?n0003oM`00og/00?n4
003oW@00okh09:SH006[nP00okh00?nL003oR@00oh<00?mi003oMP00ogD00?mf003oO000oh<00?n7
003oT000oiP00?nU003o]000o]L04:;_002Ro`0gA_l00=;o003Km@00oLT00?n^003oW`00oi<00?n5
003oM@00og<00?mY1@00ofH04P00ofT00?mb003oQ000oYL00?^g00f/n`0@[N`00?k400k?g`00ofl0
0?m7003o<`00obP00?lS003o6P00oaT00?lE003o3P800?l:00l00?l;003o2P00o`X00Ol9007o2005
o`000ol500Go0004o`<01Ol000Go0@04o`801Ol100;o1`03o`D00`00o`X05`00o`/00?l>003o6@00
obD00?m2003oBP00oeP00?mL003hV@07`N`00?nM003n/@00gn@04;kZ003[Z`00ofh00?mF003o@000
ob`00?lO003o5`00o`/00Ol800801Ol000<04Ol001?o000Ho`000`0So`000`0[o`00<ol003?o0002
03?o000303[o0010o`00@_l000@0@_l000<0D?l004ko001Ao`001P1Ao`001P1Ko`00G_l0063o001P
o`00HOl0063o0080HOl01?ooool00ol0003oooooooooo`06ooooo`008Oooool01ol0003ooooooooo
ooooool0DOl004oo0014o`001@12o`000`11o`00=Ol003?o000303?o000602oo000[o`008ol002;o
000Qo`008?l00P0Do`00=00:o`001?l3003o3P00ocd00>W000VgiP00ogT00?m:003o=@00obh00?l[
003o:@00obl00?le003o?@00odd00?mT003oQ`00okD02kCi003ib@00ok800?nS00GKi@00i^P00>WH
012`i@1AC>h0>ck_022Jh00TU^`068Sj041Bk@0</_`03h?m003=k@0?__<00?Bk003mX000og/00?m/
003oHP00oeH00?m>003oA`00odH00?m2003o@000ocd00?lj003o=@00ob`:003o:00J003o:`00oc40
0?lh003o@`00of/04<Jb00OEk000nL<03>_S0221n@0@b=800?nI003kYP00ogD00?m]003oJ`00ofl0
0?mk003m_P06dNd04j_l0229lP0<dNh00?j_003oQ@00ogH5003oM@0C003oN000oh@00?n=003oU`00
oj@00?nb003obP00onl00<co02I7o@05d_l00?oU003ob000ok/00?nb003oX@00oh`00?me003oK@02
003oIP0B003oG`00oeT00?mI003oG000oeh00?mT003oJ`00ogX00?nA003o_`0iGo405HK_00CGh@0H
aKd00?mI003o<`00obP00?lL0P00oaT00`00o`d00?l:003o2`03003o2P05007o2005o`001?l300Go
0004o`801@05o`001@05o`401Ol000Co0P03o`D00Ol800<00?l:01X00?l@003o6P00ob000?l[003o
=P00odh01];=00k/_P00ogT00?n1007Ld`0nHOh00;gY003eP000oeD00?m0003o<000ob@00?lI003o
5@00o``00_l700Go000>o`005?l001Wo00<08ol000<0:_l003;o000co`000P0co`000`0jo`00@?l0
04;o000304;o000304Wo001=o`00DOl000D0DOl000D0F?l0067o001No`00HOl0063o0005067o00Co
oooo00?o0000ooooooooool01_ooool0027ooooo00Oo0000oooooooooooooooo053o001=o`00A_l0
00@0@_l000<0@?l003go000do`00100co`000`0^o`008ol002?o000202?o000a01Oo000Do`004_l0
00Ko0003o`D00?l@003o9`00nF803Lg0003U_@00of<00?m3003o>000ocT00?lh003o?@00odH00?m<
003oE`00ofh00?n6003_b@0=ZoT00/Ol01:SmP00f^T07G[h025Il`09bO800/C[003?k@00Vod00>GJ
003Ja`00hLl00Lkc003o]@00jLP00?k=0038j`00oj000?n0003oKP00of800?mG003oCP00odL00?m3
003o>@02003o>003003o=`00obl00?lY00<00?lX00@00?lW003o9@00obD00?lQ0P00obH3003o:00d
003o:@00ocH00?lm003oC`00og000>G;00BZn`0cC^/01l;]003oZ@00oh000?m]003oHP00oel00?mP
003oI@00og400?nB02Nak00KQO`097gn00Zek`00oiX00?ml003oM000ofh00?mW003oJ@00of`00?mc
003oM@00ogl00?n=003oW000ojX00?ni003ob`00mnd00jSo02/nm`0COoD03Mcf003og000oMP00=W[
00bbk000m;T00?mi003oI`00ofD00?mL003oF0@00?mG00`00?mH003oI000og800?nC003hcP05WOT0
983l01GH_P00og400?m;003o<`00obH2003o6@03003o4P00o``00?l:00<00?l:00<01?l200Co0`05
o`000`05o`4300Go000800Go0@05o`001Ol100Go0005o`401Ol000?o1003o`D2003o2P0K003o2`00
oa800?lI003o7P00obX00?=M003Z[000mgh00?mM003oJP00l;@02LSV003Be@00ohD00?]i003oB`00
ocD00?lY003o8P00oah00?lM003o6@02o`P01_l101?o000Fo`008_l000808ol000D0:ol003?o000c
o`00<ol003Oo000604;o0003053o001Ao`00DOl000<0DOl000D0D_l005Wo001Io`00HOl0063o0006
067o000306Go0?oooooooooo00;ooooo00?o0000ooooooooool01_ooool0027ooooo00Co0000oooo
oooooooooooo0P1Ao`000`1<o`00@_l004;o000304;o000703Ko000co`00<ol003;o000co`00;Ol0
02Ko000202?o000f02;o000No`005?l001Co000<o`001?l3003o3@00oaT00?lX003o@P0=gKP06jWN
003lVP00oe000?m6003o@P00odD00?m@003N[P00og<00?m/00GY_000ok402<[^05@/mP0F<o80KaWN
00Fin@0@i<`00<W_00;bZP00oi@00?37022Ym000j<<00?n200?]V@00oh/00?mn003oQP00oZd048kk
003o^@00oh@00?mZ003oF`00oe<00?m7003oA@00oc/00?lh003o=`00oc400?lZ0`00obP02P00obL0
0?lQ003o7000oa`00?lJ003o6@00oaX00?lL003o7P00obH2003o:00;003o;`00ocP00?m7003eO@0I
e[/01/_M035DlP0Q^?D06<KD003oP`00oed00P00oeD02`00oeL00?mM003oJ`00oh800?n/007;k@0>
b^X01^g7003kW000ogD00?mZ00@00?mV01D00?mX003oL`00ogl00?nC00OY``00ol<00?SH003og@00
loP02F;o09d:d00Z<?T00<7o003hnP0LX?@04ISj003Ji000nZX00?mb003oI`00of000P00oeL00`00
oeD00?mB003oC`02003oD`0>003oF000of`05L7B00KJf000j=@00?2h026]h@06ejL00?mJ003o?@00
ob@00?lI003o5`00o`d3003o2P0500;o1P05o`401?l200Go0005o`400`05o`000`05o`401Ol000Go
000600Go000300Go0@04o`800ol500800?l:01X00?l<003o4P00oaT00?lN003o<000odh00?m4003o
A`00oeL00?md007M`00;Y_/00?_1003Ee000ogL00?m9003o=P00obl00?l`003fCP0Agh400?ln00Co
0`0=o`005?l001oo00808ol000H0;ol003?o000co`00<ol003Go000oo`0304;o000304?o001=o`00
Col000D0DOl000<0EOl0067o001Qo`001`1Qo`000`1Xo`00L?l0ooooo`03ooooo`03o`000?oooooo
oooo00Kooooo000Qooooo`07o`000?ooooooooooooooo`1@o`00COl004Co000404;o000303_o000d
o`00<ol00080<ol000<0;_l002Wo000So`000P0So`00=00Qo`005?l001Co000Ao`001_l1003m;000
obL00?lo003o@@00odd00?n9012jjP00oh800?mO003oD`00oeD00?mY003M[`00g]/00?nT003kXP03
/_D06Y[i0030l00=X?H03;3k00NMnP00dll00?nC00[VVP00ofd00?mb00g8e@00oI@01n:`003oI000
oeh00?mO003oI@00og800?^_01NLl@07^?P00?:W003oK@00oeT00?m=003oB000ocl00?lh003o=`00
obh3003o:004003o9@00ob400?lK003o6@800?lJ1000oaT2003o6P0f003o9000obP00?lZ003o=`00
od400?mE003fQ@0@`^800?^i00OSf`00oIL02NMm003oC000odP00?m7003oBP00oeH00?mZ003oS000
ojl09XO`01;0j@00oiT00?mm003oJ`00ofH00?mP003oGP00oed00?mR003oIP00ofd00?n5003g/`05
[_/02;Ok03akg@0=[o803;7o01ASo`1b3]P0CaSb019@o`0JRNH00;gm003od@00ojH00?n3003oKP00
ofD00?mH003oE`00oe400?m:0`00odL03P00odP00?m?003oIP00niT00?mZ00[cPP00ofX00>2Q017G
bP0=g:l02n]b003o9000oaT00?l?0`00o`X00`03o`D01?l300Go000A00Go000M00Go0@03o`@00?l:
003o2P00o`/00?lB003o6@00oal00?lZ003o<P00oc`00o9I003eWP00gL/08G[m03=kn@0>emd00>Nb
003oF000odH00?m3003oE00@d<P00>jB003o8002o`L01ol001?o000Lo`000P0So`001P0[o`00<?l0
03;o000co`00>ol0047o00<0@_l000<0@ol004ko001Ao`00101Ao`000`1Io`00G?l0063o0006067o
000406?o001Zo`00J?l006oo00Cooooo00?o0000ooooooooool01_ooool0027ooooo00Co0000oooo
oooooooooooo0P1Ao`001P1:o`00@_l004;o0012o`00?_l003Ko0080<ol000<0<_l002oo000Xo`00
0`0So`00=00Qo`006?l001Co000Co`002Ol000?o1000lED00?:Q00;EdP04k9`00?jL003oX`00gN40
0?n8003oL@00ofX00?m]003oN`00nkH01Zgh00SDj008V_/00]?R0032k`00mK800?nR003na005`_00
0?nT003oN000of<00?mB003oD`0>kWX00?mD003oC@00od/00?m:003oD@00oeP00?mW003oS000kML0
4<7[003oX000ogT00?mN003oCP00odH00?lj003o>000obl3003o:003003o8P00oa`00?lI00X00?lI
01/00?lK003o8`00obT00?lc003o@@00oeL04>n;00ffi@00ogH00?R<003oJP00odL00?lm003o>@00
ocl00?m5003oB`00nH/03MWP003/iP0aLo800>?S003oZP00ogP00?mU003oFP00oeP00`00oeL05`00
oed00?mV00KTU@0Ad=D00>SA013/_000oMX04;;l002co`01[?l0@bW^060R_@01__h00?[e00nFo@0T
RoD00>7A003oRP00of`00?mO003oE`00oe<00?m800<00?m700<00?m3003o@@00od800P00od@02@00
od<00?m4003oB000oeP00nVe003nN`00oc800?lL003o5@03003o2P0600Co1004o`801Ol000Go0@05
o`001Ol14005o`008005o`800ol4003o2P00o`X00?l;003o4`00oaT00?lP003o:000oc@00?m6003n
PP06dM`00?GK01F:nP00g=@00?n2003oIP00oe/00?mN003WZP07dL800?eQ003o7`00o``01?l200ko
000Eo`008?l002?o000Wo`00<Ol00P0co`000`0ko`00@_l004;o000204;o000304ko001Ao`00D?l0
00@0DOl000@0Fol0067o001Qo`00H?l01@1Qo`00101Uo`00L?l0073o001`o`04ooooo`03o`000?oo
oooooooo00Kooooo000Qooooo`07o`000?ooooooooooooooo`1Ao`00C_l004Co000304;o000603Wo
000co`00<ol0037o000]o`009_l00P0So`000`0Ro`008?l001co000201Co000N017o0005o`000ol5
003o7000oe/02>Zl01Jj``00a^003NGF00O>i`00m;T00?nB013_Y`00lK/00?VQ003Ng00CIOl0;e7_
00CZe@00ohd00?j<003oLP00og/00?31003Uf@0@`NP00?NN003oF000odD00?lo0P00oc`05@00och0
0?lm003o@P00odP00?mA003oHP00oh@04>Zm01fAoP00o/d03mK8003kKP00odl00?m5003o>@00ocH0
0?lZ003o:@00obP00?lS003o7006003o6@800?lH1@00oaT02`00oaX00?lV003o<P00odX00?R400SD
b`0DfID00?mE003oA@00och00?lg00800?lf00l00?lh003o>@00od@00?mH003hZ@05fNP0@5gZ00^i
o000ilh00?n6003oFP00oeH00?mC003oDP00oe@00P00oeL06@00oel00?mY003oN`00ohD00?nG003n
c`0BXoh00?oY00?DmP06T?l03Vco00gKiP00om400?[G013Nj00>XOL00>[2003oKP00oe`00?mG003o
C000odP00?m7003o@`00ocX01`00ocP01`00ocT00?m500_GT@00m:D00?lY003o6@00o`h00P00o`X0
0`02o`L01Ol200Go000800Go000500oo000;o`002Ol001?o0009o`000P0:o`0600Go000O00Go0@03
o`D00?l:003o2P00o``00?lH003o6`00obL00?l]003o>P00oeT00?BT003oU`05`>L02;7d003`]`00
oi@00?mn003oM`03g/400?2Q003oA@00obl00?lT003o4`05o`D04ol001ko000So`009?l0037o0002
03?o000303So0010o`00@_l00080@_l000<0B?l004oo001Ao`000`1Ao`000`1Jo`00G?l005oo0005
067o000406?o001[o`00J?l006ko0080L?l01?ooool00ol0003oooooooooo`06ooooo`008Oooool2
o`0000;ooooo0P1Ao`002019o`00@_l004;o000no`00=?l0037o000_o`009_l00`0So`000`0Qo`00
7_l001So000201Co000f01?o0008o`001Ol0007o2000oa800?lW003o@`00oeL00?m[003oQ`0C`N40
3M;]003mb@03a_H02lo]00KLi00RK_l00>gR002oi000c]h00?mf003oF@00oe/00?mZ00g2e@00oh`0
0?RD003NeP00oeD00?li003o<000obh00?l`003o<P00ocH00?li003o@000od/00>mk01GBb@00kN80
>3gY002go@0Kb]`04>j7003oE@00od<00?lh003o<P00obX00?lX003o9@00oad00?lJ1000oaT01@00
oaD00?lA003o3`00o`l00?l=00800?lB0`00oaT06@00ob400?la003oH`00cmh00nn100gQ]@00odP0
0?le003o;@00obT00?lZ003o:000obd00?lf003o?000od`00?m^003i^006]>404>jk00;ZY`00oed0
0?mC003oB@00odL00P00odP06P00odh00?mF003oE`00of400?mX003oM000oi403[_Y00;?i000ol<0
0?oI00?Jo00mD^l03N3^003o_`00oj`00?n^003oWP00oiX00?mY003oF@00oeD00?m8003oA`00od<0
0?ll0`00ocP00`00ocD00?lb003o;@03003o:P05003o;`00och00?Qe003o7`00oa<00P00o`X00`01
o`T01?l200Go000600Go000300[o000Co`002ol000805?l000<03_l001Co000@o`000P0Do`000`0;
o`004?l000Ko000400Go000K00Co0P02o`L00?l:003o2`00oa@00?lJ003o9000obT00?lh003oBP00
of800?n0003o^@0IQ_d02;?h016ml000ok000?Za00;Vh`06lJX02NF;00;ZP000mk400>An007gC@0=
o`405ol000808ol000T0;ol003?o000co`00>_l004;o0011o`00@_l004Co001@o`001@1Ao`000`1P
o`00HOl0067o0005067o000406So001`o`00L?l006ko0080L?l00oooool2o`0000Sooooo000Qoooo
o`0=o`000?ooooooooooooooo`1@o`00COl004Co0012o`00@?l003Oo000`o`009ol002?o000202;o
000301ko000Ko`005_l000@05?l001h02_l000Go0005o`800?l:003o4P00ob400?la003o@`00oe`0
1^N=003nb@0FOOl01]Oj002goP06F_l01hcl00;_a000oi800n35003iU@00oUd00?m4003oA`00o6`0
2lGN003oJP00odL00?Yd003oBP00obX3003o:00@003o:@00obX00?lf003o>@00odD00?mI003gT`00
_nl09hKk00[Ci000n[d03>fO003oEP00odD00?lh003o<@800?lX00<00?lN003o6@00oaT00`00oaT0
1000o`/00?l=003o2P00o`/2003o2P0@003o2`00o``00?l;003o5@00oaT00?lK003j?@0BeHX00?m@
003o>@00mV800?lf003o:000obH00?lU003o9P800?lX00T00?l[003o=`00odL00?mU00^cc`08b[X0
0?ma003gL@00od/01P00odL06000od`00?mE003oF000of<00?m/003mRP00l;@00?jV003oZP00nm40
0:Cl03Y0oP01`_T00?ne003oW@00oi000?n0003oLP00of@00?mG003oD000odL00?m6003o?@800?lh
00D00?lg003o;P00obT00?lX003o:@02003o:006003o9P00ob@00?lU003o8P00oaH00?l<0P00o`X0
0`04o`<01Ol000Go000400Go000500ko000=o`003ol001Co000Co`000P0Do`00100@o`005?l001?o
000Do`0201?o000301Co000=o`003Ol000@01Ol001h01?l4003o2P00o`X00?lB003o6@00ob@00?l[
003o>000odP00?mK003oQP00c>/05GCk0490k000j?H00>SV022On001f/D02Lg?01O0f`0Ad;X06<K=
003hF@00obl02Ol101Go000Ro`008ol002_o000ao`0203?o0006043o0012o`00@_l004;o001;o`00
D?l00`1Ao`000`1Co`00F?l0063o0006067o000606;o001_o`00L?l0073o001_o`00L?l01?ooool0
0ol0003oooooooooo`06ooooo`008Oooool04Ol0003oooooooooooooool0DOl0053o0016o`00@_l0
047o000co`006?l900cl5P0Co`005?l001;o000@o`003_l000<04?l001L03Ol000Oo0005o`001Ol1
007o2000o``00?lG003o9000oc800?m8003oG`00oIh02:Kk04lVk00XC?l09UKi04e7k00D[oT00>be
003oK@00ofL00?mM003o>`02003o<`07003o?`04iYX00?lo003o;000obL00?lQ003o7@02003o6`0D
003o7`00ob@00?lX003o:P00ocL00?m0003oCP00og/00?jI003NgP0@/ml00?n?003oJ`00oeD00?m6
003o>P00oc400?lX003o9@00oa`2003o6@05003o6000oa800?l;003o3000o`/01P00o`X2003o2`05
003o3`00oa@00?lK003o8000ob400P00ob004@00oal00?lK003o6P00oaT00?lJ003o6`00ob400?lX
003o<000odd00>No003Z`000mIL00?mB003oAP00od000?lm00800?lj01h00?ln003oA@00odL00?m7
003oBP00oeH00?mI003oIP00ofh00?mk003oS000oid00?nf003ei@0SIo`02=gZ003o^000oid00?n9
003oN@00ofd00?mR003oE`00oe000?m7003oA000ocT00?lh003o=`00obl3003o:003003o9`00ob40
0?lK00800?lJ00<00?lI003o5@00o`d00P00o`X00`03o`@01Ol100Go000300Go000700So0007o`00
4ol001Co000Bo`005?l001?o000801Co00804ol000<04?l000go0008o`000P05o`007P05o`400Ol8
003o2P00oa800?lK003o:000oc<00?lo003oC`00of000?mg003`a00B^?H0?Ec[01eCo@0RNo800>kN
003oT000ofT03O9J003oB000ne000?lK00;o1`0:o`005?l001co000So`009Ol002oo0080<ol000D0
>ol0047o0012o`00@_l0053o0004057o000405co001Qo`00HOl0063o00<0HOl000D0Hol006oo001`
o`00KOl006oo0003073o00Cooooo00?o0000ooooooooool01_ooool0027ooooo01;o0000oooooooo
oooooooo053o001Ao`00B?l004;o000no`00<ol001?o3P05lX400OlH00?o1@03o`l00Ol>007m;004
o`<400Go000P00Co1001o`T00?l=003o6P00ob800?l^003o?P0:kh`00?jI003j[@0RS_000<Ok02FR
kP00n^l02i?m003o]`00o9000?mN003oB000ocL00?lZ003o9P00ob800?lT003n=`00oal00?lI003o
6000oaH00?lG003o6000oaT2003o6P0A003o9000obP00?lb003o?000od/00?mR003oS@0Oa]/087Wm
003QbP00og400?mO003oD@00od800?lc003o:@00ob800`00oaT00`00o`h00?l<003o2P02003o2P03
003o2`00o`X00?l:00H00?l:00<00?l;003o3@00oa800P00oa@01000oaL00?lF003o5P00oaL4003o
6@08003o7@00obT00?]I003jI`00oe@00?Yl003o?`00ocT5003o>00L003o>P00od800?m7003oA`00
oe800?mG003oH@00ofL00?me003oP@00nZT00?GG003lkP0JO_l02/gk003?m`00oj`00?n:003oNP00
of`00?mU003oF000oe<00?m7003o@`00ocT00?lh003o<@<00?lX00<00?lU003o7@00oaT00`00oaT0
1P00o`h00?l:003o2`00o`X00_l600Go0@D01Ol000<04_l001?o000@o`00400Do`008P0=o`002?l0
00Go0005o`000ol5003o2P00oa@00?lV003o>@00od800?mM00[VQ`00o8800?n:003Td`00[?X03NSU
012QoP0a<?h00LCk003mX000oeL00?m1003o;P00ob400?l@00?o1008o`004ol001Go000Po`008ol0
02Go000_o`0203?o0005043o0012o`00@_l004[o001@o`000`1Ao`000`1Eo`00GOl0063o0004067o
000306;o001_o`00L?l000D0L?l01?ooool00ol0003oooooooooo`06ooooo`008Oooool0<?l0003o
ooooooooooooool0DOl0053o0017o`00@_l0043o000co`008Ol000;e<000f8L00?iJ00C_I004hH/0
3O9N003o3`01o`P00ol500?o1002o`H00?l:003o3@00oaX01Mm/003o@000och00?mA003f]P0;cNH0
5i?b00;<e`03f=400=gJ003o/004[n/00?fm003oM`00oe`00?m4003o<000ob@00?lJ003o6@00oaH0
0?lD003o3`800?l<01L00?l:003o3000o`d00?lA003o5`00oaT00?lK003o:000oc800?m1003oD`00
ofL00?n2003Vf@0CW_L00?fj003oP`00ohL00?n?003iL`00oc@00?lX003o8@02003o6@03003o4P00
o`h00?l;00P00?l:00<00Ol9003o2P00o`X01`00o`X3003o3003003o4000oa800?lF00800?lI00/0
0?lL003o9`00obl00?l_003o<P00obl00?l]003o;000obd00?lb003o=P02003o>00H003o>`00od@0
0?m7003oC`00oeL00?mR003oIP00og800?n0007_XP0<bn8049_f04dji00?H_l01;7k003Wg@00oiL0
0?mn003oL`00ofL00?mO003oEP00odT00?m20P00ocP02@00obd00?lX003o:000obD00?lM003o6@00
oaX00?lI003o5P02003o2`800?l:00<00_l600Go0@05o`400`05o`000`0:o`003_l000oo000A01Co
000301?o000Do`003Ol000801Ol002401?l3003o2P00oaD00?lk003cW000ofH00?FZ00?1f`0H_Nd0
4=WL00[Gj@00iLT00?370134l@02aO804<SL003oS`00of800?ln003o;@00oa`00?l?00;o1P05o`00
4Ol001Co000Eo`007_l002;o000So`00;Ol003?o000jo`000P12o`001@18o`00D?l0057o001Ao`00
Dol000L0HOl000<0J?l006_o001]o`001@1`o`04ooooo`03o`000?oooooooooo00Kooooo000Qoooo
o`04o`000?ooooooooooooooo`80DOl000d0BOl004;o0012o`00=?l0027o0001oU400?i1003O/`03
aMH00?>X003o?@00oa`00?lA00800?l:01P00?l;003o3`00oaT00?lX003jP00=iHl00?mH003oJ000
o:D049Kj01Rck@00oi<00?mg003oL`00ogX00?jb00Fji@01f/<00?>N003oDP00oc800?lL003o5P00
o`d9003o2P0G003o3@00oaT00?lJ003o9@00oc/00?mL003]X@00oH`00?nC003dcP0AROh00=OT003o
[005`n400]?@00W_J`00ocD00?lX003o6P00oaT00?lH003o3P00o`/01000o`X01P01o`T00ol600;o
1`05o`400ol500Go0@800ol500<00ol6007o2@01o`T02000o`X02@00o`/00?l>003o4P00oaL00?lI
003o6`00ob000?lS003o9P04003o:003003o:@00ob`00?ld00800?lh01X00?m3003oA`00oe000?mH
003oH`00ofX00?me003oP@00oiP00>CK00G7nP0FXOl04i?e003nj@00nl/00?nM003oR000ogd00?mh
003oKP00of<00?mB003o@`00ocX00?lf003o:P800?lX00<00?lP003o6P00oaT00P00oaT01`00o``0
0?l;003o2P00o`X00Ol800Co0`05o`401005o`000`0?o`005?l001Co000401Co000301?o000Do`00
5?l000`05?l001d04ol000[o0005o`001?l2003o2P00oaX00?mC003d``03cMH05jkH00cWa`00mID0
2Nnd0138b@00oh<00?j?003bWP0=kj`08:Cl003ec`06hK`00?mB003o;`00ob400?lD007o2@04o`<0
1Ol000ko000301Co000801?o0@0Mo`40;Ol003Ko0011o`00@_l004So001>o`03057o000305Wo001Q
o`00H?l000<0HOl000<0IOl0073o001`o`001P1`o`04ooooo`03o`000?oooooooooo00Kooooo000Q
ooooo`07o`000?ooooooooooooooo`1Ao`00D?l004co000204;o000;03Go000/o`005ol000Go1`00
n6h00]?=01R`eP00ngH00>9L003o:@00oaT00P00oaH06P00oa/00?lZ003nH`00og800=g4003oOP01
gLL01LSV00GSa00<bLd00?j@003oD`00oeH00?mW00o5c@00nZ<03>>a01RedP00jKd00?m:003o5`00
o`/00?l:00;o1`02o`H01Ol20P04o`<00`03o`D00Ol8003o2P02003o2P0E003o3P00oaP00?lR003o
>P00mYX00<GQ003Bi@00lLX00]7`03Dal@0eOo401koe00K]a`00ogD00?m?003o=000obP00?lJ003o
6@00oaD00?l;00@00?l:00@00ol600?o1@05o`001?l20`05o`002@04o`<01?l200Go0005o`401?l3
00Go0P02o`H00_l7007o2006003o2P04003o2`00o`h00?lC003o60800?lI00@00?lL003o7P00ob80
0?lW0`00obP08000ob/00?lh003o>000ocd00?m8003oD000oe`00?mW003oL@00ogP00?n7003oV000
ok000?oB00>ho@0TJ_@00?oI003o]P00oj000?nE003oT000n[T00>^o003[b@00ofP00?m4003o>000
ocD00?lZ003o:000obL00?lM0`00oaT00`00oa000?l:003o2P02003o2P0300?o1@05o`401Ol00080
1Ol000H01_l000oo000?o`004ol001Co000Co`0901Co000401Oo000Eo`005?l001Go00D05?l001`0
4ol0013o0006o`001?l3003o3@00obD00?iT00?Jc009dMH00?mZ003oE000oeT01>n[01[5b000of`0
0?mL003oH`00ohX02mgH021>k`00f=400?m/003o?`00ocD00?lP003o3`01o`P01?l20P05o`002@05
o`800ol;007o?@03oc005olC033o000no`00@_l004Go0003057o000305Co001Qo`00HOl000@0HOl0
00<0H_l006ko001`o`001P1`o`04ooooo`03o`000?oooooooooo00Kooooo000Qooooo`04o`000?oo
ooooooooooooo`80DOl002P0COl004;o0012o`00>ol003;o000To`004Ol100;o5@06jE`00?mU00;D
d@0<hk/00?QZ003o:@00ob800?lQ003o9`00ocX01NR?00gN_00=a^400=WL00fjk`00i=400?m`00[]
K000od800?lm003o@P00oF/00<[F003^OP00odX00?Y]003Z[`00ng000?lB007o2004o`801Ol11P05
o`006004o`<00Ol8003o2P00o`/00?lE003o6P00obT00?lk003oF`0:jYl02M?Y01:Jm@0l<_X02]CY
003j``09_^X02lo600?bO@00ocl00?lV003o6`00oaP00?l>003o2`800?l:0P01o`P01005o`001?l2
00Go0005o`4700Go000600Go0@05o`001Ol100Co0P05o`401?l20P03o`D6003o2P03003o3`00oaH0
0?lH00<00?lI02000?lM003o8`00obL00?lX003o:@00oc400?lh003o?@00odT00?mH003oJ000oh/0
0?n5003oRP00oi<00?nO003o/@00gNH00=7n01n0l@00bO/00>CJ003o]@00ojh00>cA00Bbl@0I]>L0
0nnC003mK000odL00?lj003o=0800?lX00L00?lT003o6P00oaT00?lI003o5`00o`h00?l;00<00?l:
00<01?l100Go0@05o`000P05o`000`06o`004ol001Co000801Co000;01Ko000Oo`007?l001So000S
o`007_l001co000So`006Ol001_o000Fo`000`0Do`006`0Co`003Ol000Co0`00oC@03]f200kFW000
oeT00?1W003o=@00obd00?m600;bYP0FbL@00?mG003oA@00od`00?6F00k:c00Dfk@00LoJ003aUP00
of<00>jd00;bCP00ocH00?lE003o2`02007o2@07003o<000mhh00>:>007o9`0Eo`80;Ol003So0002
04;o000504go001@o`00DOl0057o001Lo`001@1Qo`00101Yo`00Jol006oo001_o`05073o00Cooooo
00?o0000ooooooooool01_ooool0027ooooo00Co0000oooooooooooooooo0P1Ao`009@1;o`00@_l0
04;o000ko`00<ol002[o000Mo`002ol0007o2`00mS`00?:/00_@c000of@00?lj003o;`00oc400?li
003oA@00oed00?n601>=i00]Jod00;_]003oPP00oeD00?li003o;000obT00?la003oC@07il<00?mP
003o:@00ob400?lW003jC`02o`P00P05o`001006o`002?l000So0007o`0200Go000300Go0@05o`00
1?l200800?l:01<00?l>003o6@00ob800?l`003nK`00eLd00?nD003l^P00/oT00?_7003oR`00ohH0
0=bg003]Y00;kV400?lT003o6@00oaH00?l<00<00?l:00<00ol400Go0005o`401P05o`000`05o`40
1Ol000Go000200Go000300Go0@05o`001Ol000801Ol000@01Ol100Go0004o`<00ol51000o`X01000
o`/00?l:003o4P00oaH4003o6@0N003o8P00obP00?lX003o:`00ocL00?m1003kI000og@00?2J003P
j@00ok802M_9003o]000ojl00?o10030n@0TG_l0LA7[0123lP0:`o/00?oE003od`0PY?P00=cJ003_
XP00ofh00?mH003oAP00ocP00?le0P00obP01P00ob800?lI003o6@00oaT00?lG003o3@<00?l:00<0
1?l300Go0005o`000P05o`001007o`004ol001;o000Co`0601Co000301co000Mo`006Ol000808ol0
00X07ol002?o000So`008Ol002?o000Po`008ol001go000No`005ol00`0Do`00:00:o`000ol5003o
5@00n4L00?lE003o4P00oa000?lH003oAP0<`]<00>ne003o@@00oc400?lb003o?P00oeL00?md01f]
i@0Bc]400?jZ00KFe`00g;/01mJM003o:@00oaP00?lF003o6P00ocT00=fn00GHZ003o`h06Ol002Wo
000co`00?Ol004;o0018o`00D?l0057o001Bo`05067o000306?o001`o`00L?l000L0L?l01?ooool0
0ol0003oooooooooo`06ooooo`008Oooool01?l0003oooooooooooooool2057o000Y04oo0014o`00
@_l0043o000co`00:Ol001ko000?o`000ol5003o6P00od/04[SK003jW@00od`00?m1003o@`00og80
0?mX003oM`07a]l00<c/00GJcP0@dm404<o300gHVP00obX00?lL003o6P00obD00?aU01Fbf000lhP0
0?lG007o2P02o`L00ol600Ko000:o`004?l001;o000Co`000P0Bo`000`0@o`001ol000Go000200Go
000E00?o1@00o`X00?l<003o6000oal00?l/003oAP00oeX00?m_003l^`0GM?D00m7M003oMP00of<0
0?mF003oA`00ocH00?lQ003o6@00oa<00?l;00800?l:00D01?l200Go0P05o`401Ol000Go0@0?00Go
000600Go0@05o`001Ol000Co0P05o`000Ol91000o`X00`00o`/00?lA003o5@03003o6@0Q003o6P00
ob@00?lX003o:@00oc<00?ll00G_I@09g<@00>_V0165o000aO`0:g?`00gAiP00om000?oI003]o004
S?l0H`[S029]m@06[_l02:;l002io00=e^T00?n[003oR000og000?mM003oBP00oc`00?lf003o:P00
obP00?lR00<00?lI00<00?lA003o2P00o`X00P00o`X00`02o`H01Ol100Go000200Go000300Ko000B
o`005?l000L05?l00P0So`00100No`008ol002?o000Qo`0602?o0004027o000So`007_l001_o00<0
5?l002D03ol000Oo0004o`<01?l300Co1003o`H00?l=003o:P00kid00^mI003o9P00ob000?lT003o
<000od000?mM00ObX@02P?l08Igk003_eP00oY800?mA003o<000obD00?lT003o:`00k9H02Knl003o
<@02o`X04ol002;o000_o`00=_l0047o0014o`00Col00080DOl000<0F_l0067o001Qo`000`1Qo`00
0`1Vo`00K?l0073o0006073o00Cooooo00?o0000ooooooooool01_ooool0027ooooo02_o0000oooo
oooooooooooo057o001@o`00DOl004Go0012o`00@?l003?o000Xo`006Ol000Oo0`00oa800?lX003o
A`00nYd00?fW003oI000oe/00?2;00_I^007gjl00?VX01VigP0LbLX00?mh003Z`P00oWh00?lj003o
6`00oa000?l=003o4P00ob800^eh003o@001o`X01Ol100Oo000<o`004Ol000D05?l00P0Co`00600D
o`002Ol000Go0005o`401?l2003o2P00o``00?lG003o6`00obP00?ld003oB@00ofL00?fE003>k000
nl400?mb003oE`00odL00?li003o:`00oad00?lI003o3P800?l:00<00ol600Co0P05o`001`05o`00
1@06o`002Ol000Go0008o`001ol000T01Ol00P05o`400`04o`<00ol5003o2P03003o2P03003o2`00
oa000?lG00800?lI02400?lJ003o6`00obT00?lX003o<000ocP00?m7003aPP00kY@00>S0013_[P0L
emT02L7h01>knP0CUo`07f3d03Hok`221=T082o_02MEo00LQOh00>;i01>UkP00mML00?>c003dVP00
mgd00?mH003o@P00ocP00?lZ003o:000ob@00`00oaT01@00oa@00?l=003o2P00o`X00Ol800D01Ol0
0P0Bo`0501Co000401Ko000Oo`007Ol001ko00@08ol000<08_l002?o000So`000P0So`000`0Ro`00
8ol002?o000202?o0003023o000Qo`006_l000<05?l002<03ol000co000:o`001Ol000?o1000obl0
0?EE003o7P00oaD00?lD003o6@00obH00?m6003lV`03flP00[Gc02ego`00g]d00?n8003oEP00od<0
0?lh003o=P00ocl00>jD003TU@00obX00Ol=00Go100<o`<06ol002Ko000ko`00@_l004go0002057o
000305co001No`00HOl00080HOl000<0I_l0073o001`o`000P1_o`05073o00Cooooo00?o0000oooo
ooooool01_ooool0027ooooo00Co0000oooooooooooooooo0P1Ao`006`1>o`00AOl004;o000mo`00
<_l001ko0`08o`@00OY500[[K@03gY/01]ff003Vc004fM401=oB003oQ`00n;H01Zkd003XgP01`_40
8<c>003nO000oeH00?ma013QT`00ob800?l=003o2P0200;o1`06007o2`00nf000?dg00Go0P0<o`00
4ol02@0Do`00600Bo`004ol000Oo0005o`001Ol2007o2@00o`X00?lH003o7P00obT00?lf003oBP00
hi/00?Fd00bgk`0=gld01]^U003oEP00od800?ld003o:000oa/00?lI003o3@800?l:00<00ol500Go
0005o`401@05o`002`0>o`003ol000oo000Do`003?l001Co000=o`003ol0017o0005o`002Ol000H0
1Ol000@01Ol100Go0004o`<00ol51@00o`X09@00oa000?lI003o6@00oaX00?lK003o9000obP00?lY
003o=P00oc`00?m<003oG000ofh00?n0003oW@00n]@03[7n022]iP06b_d00:Ko07PEm`0T@_l00=Wo
003oi000old01]oS00f>o007/?P07J;W01^ee`04j:400?m=003o>@00obh00?lX003o9P00oaX00P00
oaT00`00oaH00?l<003o2P02003o2P0300Co0`05o`001Ol100801Ol000<04?l001Co000Do`00100D
o`00100Jo`008ol002?o000Po`0502?o000302;o000So`008ol000P08ol000<08_l001oo000Io`00
100Do`00800Ao`002?l000Co0P03o`H00ol5007o2@00o`/00?l?003o7P00mfl01NNL0076/P00oj@0
0?n]00RJn`08f=L00?mf00OTQ000lX000?mE003oE000i:`00>mg003o?`00k5@00?lg003VQP01n4D0
2OTc02oo0011o`00C?l00P1Ao`000`1Ko`00HOl0067o0002067o000306Ko001`o`00L?l000D0L?l0
00<0LOl007co0?ooool00oooool00ol0003oooooooooo`06ooooo`008Oooool2o`0000;ooooo0P1A
o`00:`1@o`00Aol004;o0011o`00<ol001Wo1P00jGD00?R5007B_`00iiX00?]m003oGP00ni001lkN
00bkjP00k/`01Mce01]^o`0ZK>002mOQ00[_L@00ocl00?l`00gb;`00oa400_l600Go0@06o`001ol0
00[o0007o`X03?l101;o000Fo`006?l001co000No`008Ol001oo000Ro`007_l001So000Fo`000`0D
o`00600?o`001Ol000Go0@01o`P00?lA003o6P00ob@00?l^003o>P00od/00?n@0074kP0THoh01Joe
00gK/P00oFl00?m2003o=P00obT00?lM003o6@00o``00?l:007o1`H01Ol000T04ol0013o000Bo`00
5?l001;o000Do`004Ol001Co000Co`000P0Do`001@0=o`005?l000[o000:o`001_l000@01Ol00`05
o`401`01o`P00?l:003o2P00o`X00?l;003o3@00oaD00P00oaT08@00oaX00?lP003o:000obT00?la
003o>@00od<00?mB003oHP01lXD00?N`01ZSmP00k]l00?o:00?Xj`0VV_<0>3o]019Po`0VRnD00?[=
003o/000ojX00?74003o^003g^L00?b^00CaV@00ofP00?lk003o<000obT00?lW003o7002003o6@06
003o5`00o``00?l:003o2P01o`T01?l30`05o`00100:o`004Ol001?o000Co`0301Co000301ko000M
o`008Ol001D08ol000<08Ol001go000Io`000`0Do`007P0?o`002_l000Oo0005o`401?l2007o2000
o`l00?lN003o;P07h9400?mU003dM000mj/00ZGc003hb`03eND02=K>003oO`00hj`03MK4003b/`04
`[l05;7A003lV`06cK@00_lf00Sa<`0Oo`d0?_l004Wo0080DOl000<0Eol0067o001Po`000P1Qo`00
101To`00K?l006oo001_o`04073o000307Co0020o`3ooooo00;ooooo0_l00008ooooo`008Oooool0
1?l0003oooooooooooooool2057o000L053o0016o`00@_l0047o000do`009ol000ck5003ob400?``
003o7`00obL00?lm003^S00@kj`086om01Z1nP0`QMT05g?o003Ki`0@g/400>mo003o<P00ob400?lE
007o2@05o`402_l001;o00805?l000@05_l001_o000Oo`008_l01`0So`000`0Ro`007ol001[o0002
01Co000J01?o0007o`001Ol0003o2`00oaP00?lX003o@`00och00?m8003oE@00ogH00?nS01BDm`0:
ilT00?n;003oI000odP00?lk003o;P00ob@00?lI003o3@00o`X00ol500Go0005o`4200Go0005013o
000?o`004ol001Co000Co`001@0Do`000`0Co`005?l001?o000201Co0003017o000Do`003Ol000D0
1Ol00P05o`400`05o`000Ol9003o2P02003o2P03003o3000oaD00?lI00800?lI02400?lN003o:000
obP00?l]003o>000ocd00?m=003oJ000njX05I;]00GBh000ok<00?nY003o^`04f^D03Kch01ZRl@00
o>X00?nl003oW`00oi000?n7003oP`00oi000?mY003oF@00odL00?li003o=000obX00?lX003o8000
oaX00P00oaT01@00o`l00?l<003o2P00o`X01?l300<01Ol000<01_l0017o000Do`00100Do`000`0R
o`008ol002?o000H02?o0003027o000Io`005Ol000805?l002004_l000_o0005o`001Ol1007o2@00
o`h00?lK003o;@00oc`00?mD003mUP00m=P0?Tgc002[nP00olP01^g@00>Ql@0=jI400?mD003oA@00
odh00?lX007o=00Ao`409?l0037o0010o`00Aol0053o001Ao`00EOl005go00<0HOl000<0Jol0073o
001`o`001P1`o`000`1mo`3oooooooooo`02ooooo`03o`000?oooooooooo00Kooooo000Qooooo`04
o`000?ooooooooooooooo`<0DOl001l0BOl004;o0011o`00=_l002go000Po`004ol000Ko0P01o`P0
0?lI003o<P00nH<04<kR01ARo`0@]>h00?o>003ThP0PYMh00?n3003oC`00oc000?lN003o3`02o`H0
1_l001;o000Do`005ol001ko000Qo`008_l000X08ol000/08_l0027o000Jo`005?l001?o000:o`00
1?l2003o9@00odd00?a/003fX002003oH00?003oHP00ogd04>N[003@m000lll00?n1003oH`00oe<0
0?m:003o@`00oc000?lP003o4@00o`X01?l300801Ol000<01_l000go000@o`003@0Do`0201?o0004
01Co000>o`005?l000co00D01Ol000<01?l200;o1`00o`X00`00o`X01@00o`/00?lI003o6@00oaT0
0?lM00800?lX01h00?lY003o=`00oc/00?m<003cT@00dM800>GC003eXP00oi400?nH003oZ@00olD0
0<gf019Zo`00oN@00?o0003oW@00ohH00?mh003oLP00ofH00?mJ003oC@00od@00?lh003o=P00obX0
0?lX003o9@00oad2003o6@06003o5`00o`/00?l:003o2P01o`P01Ol10P05o`000`0=o`005?l001Co
000201Co000301Go000Lo`007Ol000`08ol000L09_l002oo000Uo`00:Ol002ko000So`00:Ol000T0
8ol002808?l001Oo000Do`005?l001?o000:o`001Ol000Co0`00o`/00?lA003o7P00obl00?m?00;T
X008aNX06YO/011/o`0PM_801kok003Ci`00oX`00?m0003o9`00oaH00_l700_o0@0Oo`00:_l003?o
0012o`00A?l0053o001Ao`00Dol0101Qo`000`1Ro`00K?l0073o0005073o000307Go001fo`3ooooo
00?ooooo00?o0000ooooooooool01_ooool0027ooooo00Co0000oooooooooooooooo0P1Ao`007@1>
o`00Aol004;o0012o`00=ol003;o000Ro`006Ol000ko0003o`D00?lN003o?P0<kfX00mW901k=eP0=
f]X00>75003oS`00^>X04=V/003oF@00ocl00?lX003o5P02o`H02_l001Co000Jo`008_l000<08ol0
00L09_l002So000Yo`00:ol002go000Uo`009ol000D08ol001X07_l001Ko000Do`004?l000Go0000
oa400?R300G3b`00jM/03JWL003nY000og/00?bU01RSj00iMmh04:3n003d/`00og@00?m^003oM003
gkL00?m`00C_B`00oa@00?l:00Go0@801Ol000<02_l001?o000Do`001@0Do`000`0Co`005?l001Co
000701Co000501?o000Do`005?l000co0008o`000`05o`001005o`401Ol000Go0001o`T2003o2P03
003o3000oa000?lH00<00?lI01X00?lV003o:000obT00?ld003o>000odH00?mI003lN000og<00?mh
003oP000oh/00?Vc003Lj@00eo/0<Dgi01>eo@00d^d00?nP003oP`00ogD00?mW003oH000oeL00?m9
003oA0800?lh00D00?l]003o:000obP00?lT003o6P02003o6@05003o5000o`d00?l:003o2P04o`80
0P05o`000`08o`004?l001?o000201Co000301So000So`008ol000T08ol000H0:_l003?o000Yo`00
;_l003?o000]o`0203?o000702_o000co`00:ol002oo000Xo`009Ol002Co000502?o000O023o000J
o`005?l001Co000Ao`001_l000Go0001o`P00?l;003o6P00obP00?lk003oJ000miD01;_T003Ul@07
cn`09V?o01ado@00jl/00?m<003o8P00o`h01?l201;o000Ro`00;Ol003?o0010o`00@ol004oo0002
057o000505[o001Qo`00HOl0067o001Yo`001P1`o`000`1go`00P?l0083o0004ooooo`03o`000?oo
oooooooo00Kooooo000Qooooo`04o`000?ooooooooooooooo`80DOl00200D?l004Go0012o`00@Ol0
03Go000bo`008ol001[o000=o`000ol4003o<P0LbJh00?FF016ZmP00mXP00>RD003oI`00oe/00?n1
013Md@0;d/@00=jX003oK`00ocD00OlC00[o0@0Fo`008Ol002;o000Uo`00:ol002oo0080<Ol000L0
<_l003?o000co`00<_l0033o000^o`009Ol000@08ol001P06_l001Co000Do`001ol000;o1P00oad0
0?m<003oJP00mZT04:[/003n]@00n/P00>[i048jo`0ET?X00?no003oU@02f/X06kCV01bgd@00mH`0
0?Ag003o5001o`P200Go000300So000Do`005?l001805?l00P0Co`000`0Do`001Ol000Go000200Go
000300Go0@04o`<00Ol800800?l:00<00?l;003o3P00oaL00P00oaT07`00oa`00?lX003o:000ob/0
0?ld003o>@00od<00?m;003oF000of800?mZ003oM@00oh@00?nW003`h`0BMol0EQgk01:To`08Z?T0
0?^g003oP@00og<00?mV003oGP00oeL00?m8003oA`00ocX00?lh003o=000obX00P00obP03000obH0
0?lM003o6P00oaT00?lD003o3000o`X00_l700Go0@05o`002?l001?o00<05?l000<05ol001oo000S
o`001P0So`002@0Vo`00;_l002So000]o`00<ol003;o000`o`00<ol0033o000203?o0009037o000c
o`00<Ol003?o000`o`00<_l002co000[o`009?l000@08ol001h08_l001co000Do`005?l000[o0005
o`400_l6003o2P00oaX00?lY003o>`00odl00?ZA022ggP00l<400?ng026dm00:Z^`03NB_003oFP00
odL00?lF00Co0`0Ao`008Ol002[o000co`00?Ol004;o0017o`02057o000805Co001Oo`00H?l0067o
001Ro`00KOl0073o001_o`03073o000307So0020o`00P?l000Cooooo00?o0000ooooooooool01_oo
ool0027ooooo00Co0000oooooooooooooooo0P1Ao`007`1?o`00A?l004;o0011o`00=Ol0033o000S
o`004ol000Ko0`01o`/00?/m013PY`0XR^P03MG9003oG@00ocT00?ld003o@000oh800=70003oK000
hk400>NY00gE_`00o5802_l201[o000So`00:Ol002oo000bo`002@0co`000`0_o`00:Ol002?o0002
02?o000K027o000Eo`004ol000go0005o`400Ol:003o7`00oc/00o9_003[a00@bMl00<3c02I[lP0X
F?802;od00RelP0@eNT00nbm003eQ`00mVD00?la003o7`00o`d00ol400Go0006o`004ol000P05?l0
0P0Fo`000`0Do`005Ol001Go000901Co0003013o000;o`001_l000<01Ol000<01Ol100;o1P00o`X0
0P00o`X01@00o``00?lI003o6@00oaX00?lM00800?lX01T00?lZ003o=@00ocP00?m0003oB000oe00
0?mG003oI@00og400?mm003oS`00i<<00NoX02e`i@0:h^l00o;7003oXP00ohP00?me003oJ@00oel0
0?mG003oB`00odL00?m000800?lh00<00?ld003o;@00obX00P00obP02P00obD00?lP003o7000oaP0
0?l=003o2P03o`D01Ol000Oo000Co`0201Co000401Ko000So`008ol002;o00H08ol000@0;?l003?o
000co`00<?l00P0co`000`0bo`00<ol003;o000603?o000703;o000co`00<_l003?o000^o`00;ol0
02Go000302?o000T02;o000Ho`005?l000go0005o`000_l7003o4@00obH00?li003oE@00ofP00>nQ
00Nme`00og@00>nY00;WX@00ogl00mOH00[Ia000l[X00?]A007o3P07o`806Ol002Co000bo`00=Ol0
03oo0012o`00B_l0053o001Ao`00Fol0063o001Qo`00I_l01P1`o`000`1ao`00NOl007oo0004oooo
o`03o`000?oooooooooo00Kooooo000Qooooo`04o`000?ooooooooooooooo`80DOl001`0COl004;o
0012o`00?_l003?o000]o`008?l000Oo8P00o6H00?lZ003ZF00:fL000?JJ01OLX000oe800?lQ003o
7P00oc<00?j8003SW`00ob`00?lQ003oHP00ij005Mmm00ob;00Oo`009ol02P0co`001@0bo`00<ol0
03?o000_o`00:ol000<08ol001H06_l001Co000Bo`001_l000;o1`00ob@00?Ac01;2_000lkH00?n6
003If@0VEOl048Oo003UeP00oi<00>G:00oSb@00ofl00?lk003o8P00oa<00Ol90P05o`000`0@o`00
4_l001Co000401Co000301Oo000No`005ol000808_l000H05ol002;o000Oo`005?l001So000Eo`05
01Co000401?o000Do`005?l000So00801Ol000<01Ol100Go0003o`D00P00o`X01P00o`/00?lE003o
6@00oaT00?lJ003o8P800?lX01`00?lZ003o>000ocP00?m0003oA`00od`00?mG003oH`00og400?n0
003oT000oj@03N;F00jFo`0O/O`00?o;003oY@00oiH00?n>003oM@00of@00?mI003oDP00odP00?m7
003o@@00oc/00?lj0P00ocP2003o=`0:003o?`00ocT00?m6003o9P00oa/00?lE003o2`04o`<01Ol0
01;o00805?l000<06Ol001oo000So`001@0So`000`0]o`00;_l002co000203?o000303;o000co`00
<ol000T0<ol000<0<_l003?o000co`000P0co`000`0`o`00<_l002Wo000302?o000P01oo000Do`00
3ol000Co0P00o`/00?lI00OXK@00ogP04LK90038d`01dLd00?f6003oC000odD00?li003oA`00kY`0
2ZCX003Sa@00oe<00?la003aH@06o`L06?l102Go000bo`00=Ol003ko0012o`00BOl004oo001Do`02
067o000306?o001/o`00K_l000<0L?l000@0Lol007oo0020o`00O_l01?ooool00ol0003ooooooooo
o`06ooooo`008Oooool08_l0003oooooooooooooool0DOl0053o0018o`00@_l0047o000go`00<ol0
02Wo000Ko`001ol5003oJ000n8X03NFH007Kf`00odT00?Q<003o5000o`/00?l>003o;P00m/H01<;<
003o7`02o`H01_l800Co2@00oeP03?l:02Oo000bo`0203?o000503Go000ho`00??l003Ko000lo`00
0P0do`0403?o000303;o000^o`009_l000808ol001T07_l001Co000Do`001ol000?o1@00oCD04>mh
003dS000oeH00?mU003eW005`n/03]kK00?/X000og000?n1016ei`00e<D01?9U003o8P00o`l00_l6
00Go000:o`004ol000@05?l000D06_l001co000Lo`008ol001oo000202?o000601ko000So`008?l0
01go000So`007?l01`0Do`000`0@o`003?l000Go000200Go000600Go0@01o`P00?l:003o2P00o``0
0?lF0P00oaT01@00oa`00?lT003o:000obP00?l`00800?lh01D00?m2003oA`00odd00?mG003oJ000
oh800?n?003oW000ojX00>cN04EMkP0GOo`03nCY003o^P00mlH02;_V003oS`00ofd00?mR003oF@00
odh00P00odL04000odH00?m2003o@000od400?m3003oCP00k:800?mc00?FY`00ocX00?l]003o>`00
nE800Ol900Go000>o`0201Co000401go000So`008ol002;o00@08ol000@0<_l003?o000bo`00<Ol0
1@0co`000`0bo`00<ol003?o000;03?o0080<_l002L0:ol002?o000So`008Ol001Oo000<o`000Ol@
003o6`00obT00>^B00>hi`02iJ<00?]X003oP`04g[800?m3003o:000ob400?la00O`P000lXT01=Fc
00C1f000lgh02NfP003hP`07o`d06ol002Co000/o`00;ol003Go000mo`00AOl0057o001Mo`00HOl0
06;o001]o`00101`o`00101fo`00P?l0083o0020o`04ooooo`03o`000?oooooooooo00Kooooo000Q
ooooo`0To`000?ooooooooooooooo`1Ao`00C_l004Co0012o`00>ol003?o000`o`009?l001Go0001
ob805]R?003Y``0=^_L01n]o003o;@00o`d01?l300Go0004o`<00?lG003oFP0AgIH00OlM00oo000H
o`007?l0017o2@0Qo`80<_l003?o000go`00?Ol00P10o`001`12o`00@Ol004;o000no`00?Ol003So
000do`00100co`00100Xo`008ol002;o000Po`0201Co000E00_o0004o`<00?l?003o8000obl00?lo
003lI@05kk008Y?H00KU``00ogD00?mK003oGP00nWl00N?501[4`@00oc@00?l@00?o1@05o`003ol0
00<05?l000D05Ol001So000Oo`008ol0023o000402?o0003023o000So`008_l000808ol000<07Ol0
01oo000Mo`001P0Do`001P0Co`001ol000Go0005o`001?l300;o1`800?l:00D00?l?003o6@00oaT0
0?lK003o8`02003o:00N003o:`00ocH00?lh003o>P00odD00?m7003oD000oeP00?m`00k[eP0U]mD0
0?o2003o`@00o]/00;co01N:nP00k_800?oF00R^m000lMX00?nF003oQ000ogH00?mO003oE`00oe40
0?m<003oB000odT00?m=0P00oeH02`00of@00?Fg00[4f@00oX`00?mU003oG`0;l9l00?la007o2`05
o`403ol000805?l000<07_l0027o000Ro`000`0So`000`0Wo`00:Ol002go000203?o000303;o000c
o`00<ol001<0<ol002H0<Ol002_o000So`008ol001Wo000<o`000?m0003SUP00oeL01Mo700SZ/`00
oe<00?l/013_E@04bll01>mT003o7@00oa400?l@003o5@00ob@00?m700CXW@03XoT02=:[003o<P02
o`L03ol001Oo000Ho`403_lJ00og:@0Oo`006OHP04[o001Io`00HOl006Co00H0L?l000<0N_l0083o
0020o`001?ooool00ol0003oooooooooo`06ooooo`002?ooool2o`0000Cooooo00?o0000oooooooo
ool00_ooool2o`0000Cooooo0ol00005ooooo`0Ro`000?ooooooooooooooo`1Ao`00BOl004;o000j
o`00<ol002oo000Uo`007?l000oo0002o`X00?lj003Ma000j[401<fg00[OQP03o`H03ol001?o000?
o`001^lc003eT@0O`;h04?8c01go000Uo`00:_l002ko000ao`00=ol003ko00<0@Ol00P12o`001`11
o`00@_l004;o0010o`00@_l003So000eo`000`0co`006`0bo`008ol002?o000Qo`005?l001;o000;
o`001?l2003o2P00oaH00?lT003o=@00oeL01kgO02J4i000e^`00?b0003oA`00od000?m7003lSP04
lY@00?NA003o5005o`402Ol001?o000301Co000301_o000So`008?l000<08ol000<08_l002?o000S
o`000P0So`001P0Ro`008ol002?o000Qo`008ol0023o00H05?l000<03ol000So0005o`000P05o`00
1`01o`P00?l:003o2`00oaL00?lI003o6P00ob800P00obP06P00ob`00?lf003o>000ocP00?m1003o
A`00odP00?mE003oFP00ofd02NnR00ZokP0>Vol00?GZ00;Vl@07H?l0BBWm00J=o`00lO`03KCo003l
h000kMX00L[T003^^`00of/00?mL0P00oeL04000oeP00?mL003oK@00lkT00?mg013_P004hkL08Yg]
01fYf`00d]l00=GA013OY@00oTP00?lA00Go0@0?o`0201Co000301oo000So`008ol000<08ol000@0
<_l003?o000ao`00<Ol0600co`009P0bo`009ol002?o000Lo`003ol0007o6@00lIX03lOA00KUZP00
ocD00?lF003o4`00obT01MjV003oDP00oa@00ol400Go0@04o`<00?l?003o@P0?h:800?2c003LcP0@
hWL00?m300;o2002o`/00OdY013QUP03fh000?UP00Wk=P0mo`00E_l0063o001So`00KOl00`1`o`00
1@1ao`00Nol007co001no`00Ool000Cooooo00?o0000ooooooooool01_ooool000Oooooo00Co0000
oooooooooooo00002_ooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo00;ooooo
00So0000oooooooooooooooo04oo0013o`00>?l002Co0@808_l001H06_l0013o0006o`800?lX00WW
W00?e:T00?m0003VS`05o``04ol001go000Po`007ol001Co0@05oaX00?Ul00_o2`0Xo`00<_l003Go
000io`00?ol02`12o`02047o000O03ko000co`00<ol003?o000ao`009_l002?o000Po`005?l001?o
0007o`001Ol1003o2P00oaD00?lT003o?@00oeP00?^M00W0k`00kYh00?mP003o>P00obh00?lY003o
9@00obL00?Y?007o2@05o`404?l001?o000201Co00808Ol000<08_l002?o000So`00300So`000`0P
o`008_l001oo000301Co00804ol001402Ol000Go0005o`000ol4003o2P00o`/00?lE003o7@00ob80
0?lW003o:000obT00?l`003o=`00ocT00?ll003o@`02003oA`0Y003oC`00oeL00?mO003oK`00oi00
0?nj003WmP0ES?l049[l019;n02>0mH084Ob021Mo`03[ol09Ic_01R/lP09fMH00?n=003oL`00ofL0
0?mS003oHP00ofD00?mc00_NbP09aN/00=k:003<k`0K[>d048ob003Za000ofh00?m=003mG@03kHl0
0?Q700Co0`0>o`005?l001Wo000Ro`00100So`001@0Uo`00:ol003?o000co`00<_l000T0<ol000D0
=ol003_o000eo`00>?l0047o000203Wo000403oo000fo`00>?l003Oo00D0<ol002@0<?l002Co000O
o`004_l000;o3@00odT04]Bm00?RU`01oa`01Ol300Ko0`01nb<00N:S003fW@03oa@03ol001?o000@
o`000ol9017NL000ocX00?M^003o>@0Je:X00=bO003oB@05iHL01=VX00;WT`0;iV804ol901Cm8@0Z
o`h0Eol0067o001Vo`0206oo0080L?l000<0Lol0083o0020o`000P20o`04ooooo`03o`000?oooooo
oooo00Kooooo0007ooooo`04o`000?ooooooooooo`0000_ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`02ooooo`0No`000?ooooooooooooooo`16o`00?Ol002Ko0@02jU802_l500co
0@03oaP00?l^003o600@kcX00?6[00?NN001o``01OlC01Go0@0Ro`00:_l002co000Zo`009_l001?o
0@02odd07_4R03Co000mo`00@Ol03`12o`007@11o`00??l003?o000co`00<Ol002Ko000So`007?l0
01Co000?o`001Ol000?o1000o`X00?lF003o;P00nZ400?NA00S[_@0BZ^P00?n5003oCP00oc400?lU
003o6@00oa@00?l=00;o1`05o`403Ol000805?l000<05Ol002?o000Po`004P0So`000`0Ko`005ol0
01Co000301Co000?00go0005o`001Ol000;o1P00o`X00?lB003o8000mDL00?l`003o;`00oc<00?lf
003o>@00od<00?m:00800?m702X00?m;003oD@00oeL00?mH003oI@00ogd00>;K01>Ok009NOh00>3m
00R;o`0D?ol0S0;D01A<n`01]Ol00?[d003oe@00okh00?nQ003oS@00ogh00?md003oKP00og400?mj
003gV@02k<h0=Ugf022TkP0=kk400?n@0075`000mid00?mC003o9P00oad00?lH007o6@05o`404_l0
01Co000No`0402?o000402Wo000co`00<_l0037o00P0<ol000D0=Ol003Oo000co`00@Ol004;o0002
03ko000704;o000oo`00?ol004;o000no`00@_l003ko000203_o00<0<ol002D0<_l002_o000Ro`00
4?l0007o3000j8H00?YM00;o9@0?o`405ol001Ko000?o`000Ol]003XL00=o`407?l0027o000Po`00
6?l001?o000=o`402?l500Co1P00oaH00?m100__UP00oc<01?dS00Oo5@0Loa40=_l0043o001<o`00
F_l0067o001Wo`00Kol000<0L?l000<0LOl007So001no`000P20o`04ooooo`03o`000?oooooooooo
00Kooooo0007ooooo`04o`000?ooooooooooo`0000Sooooo1?l00003ooooo`;o00001Oooool2o`00
00;ooooo0140@Ol003Ko000Ao`P01>Qm003o9@00ob<01MRF00S`U@0@fZD00>:U003lFP01oa<02_l1
01[o000So`00;_l003;o000303?o000402[o000TnQ<0=Ol003oo0080@_l000/0@ol004Go0017o`00
COl004_o001=o`00C_l004Wo001<o`00A_l004?o000504;o000P03ko000eo`00<ol0037o000Uo`00
8?l001?o000Bo`001_l000Go0P01o`T00?l?003o6`00obl00?9`01nmdP03YO80:WWX003d^@00hZ00
0?l_003o6`00oa<00?l;00;o1P05o`002Ol001?o000Do`005_l001oo000Po`0B02?o000301oo000S
o`008ol000<05?l001804ol000[o0005o`001Ol1007o2000o`X00?lH003o>@00jIh00?m:003o?`00
ocd00?m2003oB`00nGH00>em003oE`00oeH2003oE`0X003oF`00of<00?mY003oN`00mjL00?_=003o
e@00onL05:7o00EHo`2d0Kd0?acY00IIo`00i_D00?oA003o_000ojH00?nF003oR`00oh800?mn003o
PP00n:l03jg]00Z[n`0@iL`05<?V003eS`00oeT00?B7003mN@00obT00?lI003o3P01o`P01?l300co
000Co`005Ol001ko00@08ol000<09Ol003;o000co`002@0co`001011o`00@_l003_o0011o`0204;o
000303oo0012o`00@_l000@0@_l000D0@?l004;o000no`00?_l003Ko000203?o0008033o000Qo`00
2_l3003eP000oW`00^Xh01Co000Po`0202?o000501oo0007m3003?l;01go000Vo`000P0Zo`004P0W
o`009?l0023o000Jo`004Ol000?o1@00o4l00?Jd007o4P0Eo`00:?l003Ko0012o`00C_l005?o001P
o`00HOl006_o00<0L?l000<0L_l007oo0020o`000P1oo`001020o`3oooooooooooooool2o`0000So
oooo0007ooooo`04o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`000005oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0loooool00ol0003oooooooooo`06oooo
o`001oooool01?l0003oooooooooool00007ooooo`07o`000?ooooooooooooooool0003oooooo`00
0003ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0loooool00ol0003ooooooooo
o`06ooooo`002?ooool2o`0000Wooooo0ol00003ooooo`?o00001Oooool01Ol0003ooooooooooooo
oooo000000_ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool02Oooool01Ol0003ooooooooooooooooo000000Sooooo
000QooooooOo00002?ooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo
8Oooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo
8Oooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo
8Oooool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-0.111595, 0.918695, \
4.21637*^-5, 4.21637*^-5}}]
}, Open  ]],

Cell["\<\
Ovviamente alla fine dell'esercitazione \[EGrave] opportuno \
disinstallare la funzione:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Uninstall[link]\)], "Input"],

Cell[BoxData[
    \("./mandelbrot"\)], "Output"]
}, Open  ]],

Cell["\<\
I pi\[UGrave] temerari possono modificare il codice mostrato in \
modo che i grafici risultino colorati utilizzando sfumature di un'unica \
tonalit\[AGrave].\
\>", "Text"]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"5.1 for Macintosh",
ScreenRectangle->{{0, 1440}, {0, 874}},
WindowToolbars->"EditBar",
WindowSize->{722, 763},
WindowMargins->{{42, Automatic}, {Automatic, 0}},
PrintingCopies->1,
PrintingPageRange->{1, Automatic}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 59, 0, 136, "Title"],

Cell[CellGroupData[{
Cell[1860, 57, 133, 5, 91, "Section"],
Cell[1996, 64, 235, 5, 50, "Text"],
Cell[2234, 71, 215, 4, 75, "Input"],
Cell[2452, 77, 509, 10, 104, "Text"],

Cell[CellGroupData[{
Cell[2986, 91, 65, 1, 27, "Input"],
Cell[3054, 94, 70, 1, 27, "Output"]
}, Open  ]],
Cell[3139, 98, 459, 8, 104, "Text"],
Cell[3601, 108, 663, 11, 140, "Text"],
Cell[4267, 121, 634, 11, 122, "Text"],
Cell[4904, 134, 607, 9, 140, "Text"],

Cell[CellGroupData[{
Cell[5536, 147, 71, 1, 27, "Input"],
Cell[5610, 150, 67, 1, 27, "Output"]
}, Open  ]],
Cell[5692, 154, 201, 4, 50, "Text"],
Cell[5896, 160, 478, 8, 104, "Text"],
Cell[6377, 170, 234, 4, 68, "Text"],
Cell[6614, 176, 37, 0, 40, "Program"],
Cell[6654, 178, 33, 0, 32, "Text"],
Cell[6690, 180, 24, 0, 40, "Program"],
Cell[6717, 182, 163, 4, 50, "Text"],
Cell[6883, 188, 38, 0, 40, "Program"],
Cell[6924, 190, 190, 4, 50, "Text"],
Cell[7117, 196, 21, 0, 40, "Program"],
Cell[7141, 198, 90, 3, 32, "Text"],
Cell[7234, 203, 517, 9, 104, "Text"],
Cell[7754, 214, 195, 12, 190, "Program"],
Cell[7952, 228, 415, 7, 86, "Text"],
Cell[8370, 237, 415, 9, 86, "Text"],
Cell[8788, 248, 303, 7, 68, "Text"],
Cell[9094, 257, 177, 8, 130, "Program"],
Cell[9274, 267, 135, 3, 50, "Text"],
Cell[9412, 272, 1016, 16, 212, "Text"],
Cell[10431, 290, 127, 4, 70, "Program"],
Cell[10561, 296, 665, 10, 140, "Text"],
Cell[11229, 308, 92, 3, 55, "Program"],
Cell[11324, 313, 588, 9, 122, "Text"],
Cell[11915, 324, 205, 4, 50, "Text"],
Cell[12123, 330, 35, 0, 40, "Program"],
Cell[12161, 332, 375, 8, 86, "Text"],
Cell[12539, 342, 813, 18, 140, "Text"],

Cell[CellGroupData[{
Cell[13377, 364, 69, 1, 27, "Input"],
Cell[13449, 367, 70, 1, 27, "Output"]
}, Open  ]],
Cell[13534, 371, 256, 7, 68, "Text"],

Cell[CellGroupData[{
Cell[13815, 382, 66, 1, 27, "Input"],
Cell[13884, 385, 74, 1, 27, "Output"]
}, Open  ]],
Cell[13973, 389, 535, 10, 104, "Text"],

Cell[CellGroupData[{
Cell[14533, 403, 107, 2, 59, "Input"],
Cell[14643, 407, 69, 1, 27, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[14749, 413, 118, 3, 59, "Input"],
Cell[14870, 418, 70, 1, 27, "Output"]
}, Open  ]],
Cell[14955, 422, 356, 6, 86, "Text"],

Cell[CellGroupData[{
Cell[15336, 432, 107, 2, 59, "Input"],
Cell[15446, 436, 69, 1, 27, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[15552, 442, 118, 3, 59, "Input"],
Cell[15673, 447, 69, 1, 27, "Output"]
}, Open  ]],
Cell[15757, 451, 620, 14, 122, "Text"],
Cell[16380, 467, 50, 1, 27, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[16467, 473, 52, 0, 69, "Section"],
Cell[16522, 475, 472, 12, 86, "Text"],
Cell[16997, 489, 6218594, 86069, 242, 6089642, 84473, "GraphicsData", \
"PostScript", "Graphics"],
Cell[6235594, 86560, 277, 5, 68, "Text"],
Cell[6235874, 86567, 547, 10, 122, "Text"],
Cell[6236424, 86579, 607, 9, 140, "Text"],

Cell[CellGroupData[{
Cell[6237056, 86592, 71, 1, 27, "Input"],
Cell[6237130, 86595, 67, 1, 27, "Output"]
}, Open  ]],
Cell[6237212, 86599, 504, 12, 104, "Text"],

Cell[CellGroupData[{
Cell[6237741, 86615, 34, 1, 27, "Input"],
Cell[6237778, 86618, 47, 1, 27, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[6237862, 86624, 36, 1, 27, "Input"],
Cell[6237901, 86627, 40, 1, 27, "Output"]
}, Open  ]],
Cell[6237956, 86631, 347, 8, 68, "Text"],

Cell[CellGroupData[{
Cell[6238328, 86643, 64, 1, 27, "Input"],
Cell[6238395, 86646, 51, 1, 27, "Output"]
}, Open  ]],
Cell[6238461, 86650, 551, 19, 68, "Text"],
Cell[6239015, 86671, 204, 4, 50, "Text"],
Cell[6239222, 86677, 60, 1, 27, "Input"],
Cell[6239285, 86680, 144, 3, 50, "Text"],

Cell[CellGroupData[{
Cell[6239454, 86687, 40, 1, 27, "Input"],
Cell[6239497, 86690, 36, 1, 27, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[6239570, 86696, 44, 1, 27, "Input"],
Cell[6239617, 86699, 51, 1, 27, "Output"]
}, Open  ]],
Cell[6239683, 86703, 590, 17, 86, "Text"],

Cell[CellGroupData[{
Cell[6240298, 86724, 100, 2, 43, "Input"],
Cell[6240401, 86728, 54, 1, 27, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[6240492, 86734, 47, 1, 27, "Input"],
Cell[6240542, 86737, 61, 1, 27, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[6240640, 86743, 47, 1, 27, "Input"],
Cell[6240690, 86746, 60, 1, 27, "Output"]
}, Open  ]],
Cell[6240765, 86750, 412, 11, 86, "Text"],

Cell[CellGroupData[{
Cell[6241202, 86765, 56, 1, 27, "Input"],
Cell[6241261, 86768, 1072, 14, 331, "Output"]
}, Open  ]],
Cell[6242348, 86785, 959, 14, 212, "Text"],
Cell[6243310, 86801, 342, 6, 139, "Input"],
Cell[6243655, 86809, 246, 6, 50, "Text"],

Cell[CellGroupData[{
Cell[6243926, 86819, 51, 1, 27, "Input"],
Cell[6243980, 86822, 35, 1, 27, "Output"]
}, Open  ]],
Cell[6244030, 86826, 320, 6, 86, "Text"],
Cell[6244353, 86834, 72, 1, 27, "Input"],

Cell[CellGroupData[{
Cell[6244450, 86839, 38, 1, 27, "Input"],
Cell[6244491, 86842, 65, 1, 27, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[6244593, 86848, 42, 1, 27, "Input"],
Cell[6244638, 86851, 35, 1, 27, "Output"]
}, Open  ]],
Cell[6244688, 86855, 269, 5, 50, "Text"],

Cell[CellGroupData[{
Cell[6244982, 86864, 165, 4, 59, "Input"],
Cell[6245150, 86870, 2593, 34, 443, "Output"]
}, Open  ]],
Cell[6247758, 86907, 286, 5, 50, "Text"],

Cell[CellGroupData[{
Cell[6248069, 86916, 117, 2, 27, "Input"],
Cell[6248189, 86920, 40290, 870, 296, 8717, 476, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[6288494, 87793, 200, 4, 50, "Text"],
Cell[6288697, 87799, 178, 4, 43, "Input"],

Cell[CellGroupData[{
Cell[6288900, 87807, 38, 1, 27, "Input"],
Cell[6288941, 87810, 61, 1, 27, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[6289039, 87816, 117, 2, 27, "Input"],
Cell[6289159, 87820, 52528, 1042, 296, 19387, 628, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[6341702, 88865, 178, 4, 43, "Input"],

Cell[CellGroupData[{
Cell[6341905, 88873, 38, 1, 27, "Input"],
Cell[6341946, 88876, 60, 1, 27, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[6342043, 88882, 117, 2, 27, "Input"],
Cell[6342163, 88886, 392629, 5827, 296, 355861, 5369, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[6734807, 94716, 241, 5, 50, "Text"],
Cell[6735051, 94723, 450, 9, 68, "Text"],
Cell[6735504, 94734, 1138, 49, 730, "Program"],
Cell[6736645, 94785, 533, 8, 86, "Text"],
Cell[6737181, 94795, 246, 9, 145, "Program"],
Cell[6737430, 94806, 460, 8, 86, "Text"],
Cell[6737893, 94816, 648, 10, 104, "Text"],
Cell[6738544, 94828, 1227, 18, 176, "Text"],
Cell[6739774, 94848, 67, 0, 40, "Program"],
Cell[6739844, 94850, 588, 9, 86, "Text"],
Cell[6740435, 94861, 567, 10, 86, "Text"],

Cell[CellGroupData[{
Cell[6741027, 94875, 184, 3, 27, "Input"],
Cell[6741214, 94880, 66, 1, 27, "Output"]
}, Open  ]],
Cell[6741295, 94884, 558, 9, 86, "Text"],
Cell[6741856, 94895, 209, 4, 50, "Text"],

Cell[CellGroupData[{
Cell[6742090, 94903, 261, 5, 27, "Input"],
Cell[6742354, 94910, 256, 4, 59, "Output"]
}, Open  ]],
Cell[6742625, 94917, 609, 11, 86, "Text"],

Cell[CellGroupData[{
Cell[6743259, 94932, 117, 2, 27, "Input"],
Cell[6743379, 94936, 37010, 942, 296, 6756, 564, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[6780404, 95881, 138, 3, 27, "Input"],

Cell[CellGroupData[{
Cell[6780567, 95888, 38, 1, 27, "Input"],
Cell[6780608, 95891, 62, 1, 27, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[6780707, 95897, 117, 2, 27, "Input"],
Cell[6780827, 95901, 129478, 2062, 296, 65325, 1265, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[6910320, 97966, 380, 6, 68, "Text"],
Cell[6910703, 97974, 479, 8, 123, "Input"],
Cell[6911185, 97984, 88, 1, 32, "Text"],

Cell[CellGroupData[{
Cell[6911298, 97989, 138, 2, 27, "Input"],
Cell[6911439, 97993, 114863, 1974, 242, 66537, 1373, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[7026317, 99970, 187, 4, 50, "Text"],

Cell[CellGroupData[{
Cell[7026529, 99978, 138, 2, 27, "Input"],
Cell[7026670, 99982, 1638603, 22860, 242, 1526638, 21473, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[8665288, 122845, 524, 8, 86, "Text"],

Cell[CellGroupData[{
Cell[8665837, 122857, 133, 2, 27, "Input"],
Cell[8665973, 122861, 1604605, 22456, 152, 1526776, 21491, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[10270615, 145322, 141, 2, 43, "Input"],
Cell[10270759, 145326, 1780851, 24522, 296, 1525467, 21365, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[12051647, 169853, 142, 2, 43, "Input"],
Cell[12051792, 169857, 6359100, 87711, 296, 6088471, 84365, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[18410907, 257571, 112, 3, 32, "Text"],

Cell[CellGroupData[{
Cell[18411044, 257578, 48, 1, 27, "Input"],
Cell[18411095, 257581, 48, 1, 27, "Output"]
}, Open  ]],
Cell[18411158, 257585, 181, 4, 50, "Text"]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

